/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 193 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderPropertyReaderInterface.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 197 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderPropertyReaderInterface.cpp"


PyDoc_STRVAR(doc_Qt3DRender_PropertyReaderInterface_readProperty, "readProperty(self, v: Any) -> Any");

extern "C" {static PyObject *meth_Qt3DRender_PropertyReaderInterface_readProperty(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_PropertyReaderInterface_readProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::Qt3DRender::PropertyReaderInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DRender_PropertyReaderInterface, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            ::QVariant*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_PropertyReaderInterface, sipName_readProperty);
                return SIP_NULLPTR;
            }

            sipRes = new ::QVariant(sipCpp->readProperty(*a0));
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_PropertyReaderInterface, sipName_readProperty, doc_Qt3DRender_PropertyReaderInterface_readProperty);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_PropertyReaderInterface(void *, int);}
static void release_Qt3DRender_PropertyReaderInterface(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DRender::PropertyReaderInterface *>(sipCppV);
}


extern "C" {static void dealloc_Qt3DRender_PropertyReaderInterface(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_PropertyReaderInterface(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_PropertyReaderInterface(sipGetAddress(sipSelf), 0);
    }
}


static PyMethodDef methods_Qt3DRender_PropertyReaderInterface[] = {
    {sipName_readProperty, meth_Qt3DRender_PropertyReaderInterface_readProperty, METH_VARARGS, doc_Qt3DRender_PropertyReaderInterface_readProperty}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_PropertyReaderInterface = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_PropertyReaderInterface = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__PropertyReaderInterface,
        SIP_NULLPTR,
        &plugin_Qt3DRender_PropertyReaderInterface,
    },
    {
        sipNameNr_PropertyReaderInterface,
        {0, 0, 1},
        1, methods_Qt3DRender_PropertyReaderInterface,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_PropertyReaderInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_Qt3DRender_PropertyReaderInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
