/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DExtras.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 97 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qscreen.sip"
#include <qscreen.h>
#line 101 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 104 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 425 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 107 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 460 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 110 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 253 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 284 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 317 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 380 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 403 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 408 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 411 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 414 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 417 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 420 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qwindow.sip"
#include <qwindow.h>
#line 423 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 195 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
#include <QtGlobal>
#line 426 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qregion.sip"
#include <qregion.h>
#line 429 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 302 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 432 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 726 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 435 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 253 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 438 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 205 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 441 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 363 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 444 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 471 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 447 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 384 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 450 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 412 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 453 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 795 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 456 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 459 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcursor.sip"
#include <qcursor.h>
#line 462 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 465 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qicon.sip"
#include <qicon.h>
#line 468 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 471 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 474 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmargins.sip"
#include <qmargins.h>
#line 477 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 480 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 483 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qsurface.sip"
#include <qsurface.h>
#line 486 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 491 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 494 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 497 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 500 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 503 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 506 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 509 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 512 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 515 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 518 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 521 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 524 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 527 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQt3DWindow.cpp"


class sipQt3DExtras_Qt3DWindow : public ::Qt3DExtras::Qt3DWindow
{
public:
    sipQt3DExtras_Qt3DWindow(::QScreen*);
    virtual ~sipQt3DExtras_Qt3DWindow();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QSize size() const SIP_OVERRIDE;
    ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
    ::QSurfaceFormat format() const SIP_OVERRIDE;
    ::QObject* focusObject() const SIP_OVERRIDE;
    void exposeEvent(::QExposeEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DExtras_Qt3DWindow(const sipQt3DExtras_Qt3DWindow &);
    sipQt3DExtras_Qt3DWindow &operator = (const sipQt3DExtras_Qt3DWindow &);

    char sipPyMethods[27];
};

sipQt3DExtras_Qt3DWindow::sipQt3DExtras_Qt3DWindow(::QScreen*a0): ::Qt3DExtras::Qt3DWindow(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DExtras_Qt3DWindow::~sipQt3DExtras_Qt3DWindow()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DExtras_Qt3DWindow::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DExtras_qt_metaobject(sipPySelf, sipType_Qt3DExtras_Qt3DWindow);

    return ::Qt3DExtras::Qt3DWindow::metaObject();
}

int sipQt3DExtras_Qt3DWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DExtras::Qt3DWindow::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DExtras_qt_metacall(sipPySelf, sipType_Qt3DExtras_Qt3DWindow, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DExtras_Qt3DWindow::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DExtras_qt_metacast(sipPySelf, sipType_Qt3DExtras_Qt3DWindow, _clname, &sipCpp) ? sipCpp : ::Qt3DExtras::Qt3DWindow::qt_metacast(_clname));
}

void sipQt3DExtras_Qt3DWindow::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DExtras_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DExtras_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DExtras_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DExtras_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DExtras_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DExtras_Qt3DWindow::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DExtras::Qt3DWindow::eventFilter(a0, a1);

    extern bool sipVH_Qt3DExtras_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DExtras_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQt3DExtras_Qt3DWindow::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DExtras::Qt3DWindow::event(a0);

    extern bool sipVH_Qt3DExtras_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DExtras_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQt3DExtras_Qt3DWindow::size() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_size);

    if (!sipMeth)
        return ::Qt3DExtras::Qt3DWindow::size();

    extern ::QSize sipVH_Qt3DExtras_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_Qt3DExtras_21(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSurface::SurfaceType sipQt3DExtras_Qt3DWindow::surfaceType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_surfaceType);

    if (!sipMeth)
        return ::Qt3DExtras::Qt3DWindow::surfaceType();

    extern ::QSurface::SurfaceType sipVH_Qt3DExtras_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_Qt3DExtras_20(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSurfaceFormat sipQt3DExtras_Qt3DWindow::format() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_format);

    if (!sipMeth)
        return ::Qt3DExtras::Qt3DWindow::format();

    extern ::QSurfaceFormat sipVH_Qt3DExtras_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_Qt3DExtras_19(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QObject* sipQt3DExtras_Qt3DWindow::focusObject() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_focusObject);

    if (!sipMeth)
        return ::Qt3DExtras::Qt3DWindow::focusObject();

    extern ::QObject* sipVH_Qt3DExtras_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_Qt3DExtras_18(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQt3DExtras_Qt3DWindow::exposeEvent(::QExposeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_exposeEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::exposeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QExposeEvent*);

    sipVH_Qt3DExtras_17(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::resizeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_Qt3DExtras_16(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::moveEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_Qt3DExtras_15(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::focusInEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_Qt3DExtras_14(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::focusOutEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_Qt3DExtras_14(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::showEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_Qt3DExtras_13(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::hideEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_Qt3DExtras_12(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::keyPressEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_Qt3DExtras_11(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_Qt3DExtras_11(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::mousePressEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_Qt3DExtras_10(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_Qt3DExtras_10(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_Qt3DExtras_10(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_Qt3DExtras_10(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::wheelEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_Qt3DExtras_9(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::touchEvent(::QTouchEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_touchEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::touchEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTouchEvent*);

    sipVH_Qt3DExtras_8(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_Qt3DWindow::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::Qt3DWindow::tabletEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_Qt3DExtras_7(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_registerAspect, "registerAspect(self, aspect: QAbstractAspect|None)\n"
"registerAspect(self, name: str|None)");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_registerAspect(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_registerAspect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QAbstractAspect* a0;
        ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp, sipType_Qt3DCore_QAbstractAspect, &a0))
        {
            sipCpp->registerAspect(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->registerAspect(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_registerAspect, doc_Qt3DExtras_Qt3DWindow_registerAspect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_setRootEntity, "setRootEntity(self, root: QEntity|None)");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_setRootEntity(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_setRootEntity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QEntity* a0;
        ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp, sipType_Qt3DCore_QEntity, &a0))
        {
            sipCpp->setRootEntity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_setRootEntity, doc_Qt3DExtras_Qt3DWindow_setRootEntity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_setActiveFrameGraph, "setActiveFrameGraph(self, activeFrameGraph: QFrameGraphNode|None)");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_setActiveFrameGraph(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_setActiveFrameGraph(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QFrameGraphNode* a0;
        ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp, sipType_Qt3DRender_QFrameGraphNode, &a0))
        {
            sipCpp->setActiveFrameGraph(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_setActiveFrameGraph, doc_Qt3DExtras_Qt3DWindow_setActiveFrameGraph);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_activeFrameGraph, "activeFrameGraph(self) -> QFrameGraphNode|None");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_activeFrameGraph(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_activeFrameGraph(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp))
        {
            ::Qt3DRender::QFrameGraphNode*sipRes;

            sipRes = sipCpp->activeFrameGraph();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QFrameGraphNode, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_activeFrameGraph, doc_Qt3DExtras_Qt3DWindow_activeFrameGraph);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_defaultFrameGraph, "defaultFrameGraph(self) -> QForwardRenderer|None");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_defaultFrameGraph(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_defaultFrameGraph(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp))
        {
            ::Qt3DExtras::QForwardRenderer*sipRes;

            sipRes = sipCpp->defaultFrameGraph();

            return sipConvertFromType(sipRes, sipType_Qt3DExtras_QForwardRenderer, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_defaultFrameGraph, doc_Qt3DExtras_Qt3DWindow_defaultFrameGraph);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_camera, "camera(self) -> QCamera|None");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_camera(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_camera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp))
        {
            ::Qt3DRender::QCamera*sipRes;

            sipRes = sipCpp->camera();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QCamera, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_camera, doc_Qt3DExtras_Qt3DWindow_camera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_renderSettings, "renderSettings(self) -> QRenderSettings|None");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_renderSettings(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_renderSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp))
        {
            ::Qt3DRender::QRenderSettings*sipRes;

            sipRes = sipCpp->renderSettings();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QRenderSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_renderSettings, doc_Qt3DExtras_Qt3DWindow_renderSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_showEvent, "showEvent(self, e: QShowEvent|None)");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_showEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_showEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QShowEvent* a0;
        ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp, sipType_QShowEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::Qt3DExtras::Qt3DWindow::showEvent(a0) : sipCpp->showEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_showEvent, doc_Qt3DExtras_Qt3DWindow_showEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_resizeEvent, "resizeEvent(self, a0: QResizeEvent|None)");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::Qt3DExtras::Qt3DWindow::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_resizeEvent, doc_Qt3DExtras_Qt3DWindow_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow_event, "event(self, e: QEvent|None) -> bool");

extern "C" {static PyObject *meth_Qt3DExtras_Qt3DWindow_event(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_Qt3DWindow_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::Qt3DExtras::Qt3DWindow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_Qt3DExtras_Qt3DWindow, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::Qt3DExtras::Qt3DWindow::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Qt3DWindow, sipName_event, doc_Qt3DExtras_Qt3DWindow_event);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DExtras_Qt3DWindow(void *, const sipTypeDef *);}
static void *cast_Qt3DExtras_Qt3DWindow(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DExtras::Qt3DWindow *sipCpp = reinterpret_cast< ::Qt3DExtras::Qt3DWindow *>(sipCppV);

    if (targetType == sipType_Qt3DExtras_Qt3DWindow)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWindow)->ctd_cast(static_cast< ::QWindow *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DExtras_Qt3DWindow(void *, int);}
static void release_Qt3DExtras_Qt3DWindow(void *sipCppV, int)
{
    ::Qt3DExtras::Qt3DWindow *sipCpp = reinterpret_cast< ::Qt3DExtras::Qt3DWindow *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DExtras_Qt3DWindow(Py_ssize_t);}
static void *array_Qt3DExtras_Qt3DWindow(Py_ssize_t sipNrElem)
{
    return new ::Qt3DExtras::Qt3DWindow[sipNrElem];
}


extern "C" {static void array_delete_Qt3DExtras_Qt3DWindow(void *);}
static void array_delete_Qt3DExtras_Qt3DWindow(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DExtras::Qt3DWindow *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DExtras_Qt3DWindow(sipSimpleWrapper *);}
static void dealloc_Qt3DExtras_Qt3DWindow(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DExtras_Qt3DWindow *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DExtras_Qt3DWindow(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DExtras_Qt3DWindow(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DExtras_Qt3DWindow(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQt3DExtras_Qt3DWindow *sipCpp = SIP_NULLPTR;

    {
        ::QScreen* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_screen,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J8", sipType_QScreen, &a0))
        {
            sipCpp = new sipQt3DExtras_Qt3DWindow(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DExtras_Qt3DWindow[] = {{19, 1, 1}};


static PyMethodDef methods_Qt3DExtras_Qt3DWindow[] = {
    {sipName_activeFrameGraph, meth_Qt3DExtras_Qt3DWindow_activeFrameGraph, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_activeFrameGraph},
    {sipName_camera, meth_Qt3DExtras_Qt3DWindow_camera, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_camera},
    {sipName_defaultFrameGraph, meth_Qt3DExtras_Qt3DWindow_defaultFrameGraph, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_defaultFrameGraph},
    {sipName_event, meth_Qt3DExtras_Qt3DWindow_event, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_event},
    {sipName_registerAspect, meth_Qt3DExtras_Qt3DWindow_registerAspect, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_registerAspect},
    {sipName_renderSettings, meth_Qt3DExtras_Qt3DWindow_renderSettings, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_renderSettings},
    {sipName_resizeEvent, meth_Qt3DExtras_Qt3DWindow_resizeEvent, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_resizeEvent},
    {sipName_setActiveFrameGraph, meth_Qt3DExtras_Qt3DWindow_setActiveFrameGraph, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_setActiveFrameGraph},
    {sipName_setRootEntity, meth_Qt3DExtras_Qt3DWindow_setRootEntity, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_setRootEntity},
    {sipName_showEvent, meth_Qt3DExtras_Qt3DWindow_showEvent, METH_VARARGS, doc_Qt3DExtras_Qt3DWindow_showEvent}
};

PyDoc_STRVAR(doc_Qt3DExtras_Qt3DWindow, "\1Qt3DWindow(screen: QScreen|None = None)");


static pyqt5ClassPluginDef plugin_Qt3DExtras_Qt3DWindow = {
    &::Qt3DExtras::Qt3DWindow::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_Qt3DWindow = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DExtras__Qt3DWindow,
        SIP_NULLPTR,
        &plugin_Qt3DExtras_Qt3DWindow,
    },
    {
        sipNameNr_Qt3DWindow,
        {0, 0, 1},
        10, methods_Qt3DExtras_Qt3DWindow,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DExtras_Qt3DWindow,
    -1,
    -1,
    supers_Qt3DExtras_Qt3DWindow,
    SIP_NULLPTR,
    init_type_Qt3DExtras_Qt3DWindow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DExtras_Qt3DWindow,
    SIP_NULLPTR,
    array_Qt3DExtras_Qt3DWindow,
    SIP_NULLPTR,
    release_Qt3DExtras_Qt3DWindow,
    cast_Qt3DExtras_Qt3DWindow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DExtras_Qt3DWindow,
    sizeof (::Qt3DExtras::Qt3DWindow),
};
