/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DInput.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 33 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 43 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 46 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 75 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 78 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 81 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 108 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 111 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 164 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 167 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 170 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 205 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 210 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 213 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 216 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 219 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 222 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 225 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 228 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 231 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 234 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 237 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 240 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 243 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 246 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 249 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQAbstractAxisInput.cpp"


PyDoc_STRVAR(doc_Qt3DInput_QAbstractAxisInput_sourceDevice, "sourceDevice(self) -> QAbstractPhysicalDevice|None");

extern "C" {static PyObject *meth_Qt3DInput_QAbstractAxisInput_sourceDevice(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QAbstractAxisInput_sourceDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QAbstractAxisInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QAbstractAxisInput, &sipCpp))
        {
            ::Qt3DInput::QAbstractPhysicalDevice*sipRes;

            sipRes = sipCpp->sourceDevice();

            return sipConvertFromType(sipRes, sipType_Qt3DInput_QAbstractPhysicalDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxisInput, sipName_sourceDevice, doc_Qt3DInput_QAbstractAxisInput_sourceDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QAbstractAxisInput_setSourceDevice, "setSourceDevice(self, sourceDevice: QAbstractPhysicalDevice|None)");

extern "C" {static PyObject *meth_Qt3DInput_QAbstractAxisInput_setSourceDevice(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QAbstractAxisInput_setSourceDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DInput::QAbstractPhysicalDevice* a0;
        ::Qt3DInput::QAbstractAxisInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DInput_QAbstractAxisInput, &sipCpp, sipType_Qt3DInput_QAbstractPhysicalDevice, &a0))
        {
            sipCpp->setSourceDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAxisInput, sipName_setSourceDevice, doc_Qt3DInput_QAbstractAxisInput_setSourceDevice);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DInput_QAbstractAxisInput(void *, const sipTypeDef *);}
static void *cast_Qt3DInput_QAbstractAxisInput(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DInput::QAbstractAxisInput *sipCpp = reinterpret_cast< ::Qt3DInput::QAbstractAxisInput *>(sipCppV);

    if (targetType == sipType_Qt3DInput_QAbstractAxisInput)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QNode)->ctd_cast(static_cast< ::Qt3DCore::QNode *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DInput_QAbstractAxisInput(void *, int);}
static void release_Qt3DInput_QAbstractAxisInput(void *sipCppV, int)
{
    ::Qt3DInput::QAbstractAxisInput *sipCpp = reinterpret_cast< ::Qt3DInput::QAbstractAxisInput *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_Qt3DInput_QAbstractAxisInput(sipSimpleWrapper *);}
static void dealloc_Qt3DInput_QAbstractAxisInput(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DInput_QAbstractAxisInput(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DInput_QAbstractAxisInput[] = {{4, 2, 1}};


static PyMethodDef methods_Qt3DInput_QAbstractAxisInput[] = {
    {sipName_setSourceDevice, meth_Qt3DInput_QAbstractAxisInput_setSourceDevice, METH_VARARGS, doc_Qt3DInput_QAbstractAxisInput_setSourceDevice},
    {sipName_sourceDevice, meth_Qt3DInput_QAbstractAxisInput_sourceDevice, METH_VARARGS, doc_Qt3DInput_QAbstractAxisInput_sourceDevice}
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DInput_QAbstractAxisInput[] = {
    {"sourceDeviceChanged(QAbstractPhysicalDevice*)|(Qt3DInput::QAbstractPhysicalDevice*)", "\1sourceDeviceChanged(self, sourceDevice: QAbstractPhysicalDevice|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DInput_QAbstractAxisInput = {
    &::Qt3DInput::QAbstractAxisInput::staticMetaObject,
    0,
    signals_Qt3DInput_QAbstractAxisInput,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAbstractAxisInput = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DInput__QAbstractAxisInput,
        SIP_NULLPTR,
        &plugin_Qt3DInput_QAbstractAxisInput,
    },
    {
        sipNameNr_QAbstractAxisInput,
        {0, 0, 1},
        2, methods_Qt3DInput_QAbstractAxisInput,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_Qt3DInput_QAbstractAxisInput,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DInput_QAbstractAxisInput,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_Qt3DInput_QAbstractAxisInput,
    cast_Qt3DInput_QAbstractAxisInput,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
