/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 231 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureImageData.cpp"

#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 235 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureImageData.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 238 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureImageData.cpp"
#line 29 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qopengltexture.sip"
#include <qopengltexture.h>
#line 241 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureImageData.cpp"


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_cleanup, "cleanup(self)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_cleanup(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_cleanup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            sipCpp->cleanup();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_cleanup, doc_Qt3DRender_QTextureImageData_cleanup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_isCompressed, "isCompressed(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_isCompressed(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_isCompressed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCompressed();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_isCompressed, doc_Qt3DRender_QTextureImageData_isCompressed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_width, "width(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_width(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_width(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->width();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_width, doc_Qt3DRender_QTextureImageData_width);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_height, "height(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_height(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_height(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->height();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_height, doc_Qt3DRender_QTextureImageData_height);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_depth, "depth(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_depth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_depth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->depth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_depth, doc_Qt3DRender_QTextureImageData_depth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_layers, "layers(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_layers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_layers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->layers();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_layers, doc_Qt3DRender_QTextureImageData_layers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_mipLevels, "mipLevels(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_mipLevels(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_mipLevels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mipLevels();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_mipLevels, doc_Qt3DRender_QTextureImageData_mipLevels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_faces, "faces(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_faces(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_faces(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->faces();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_faces, doc_Qt3DRender_QTextureImageData_faces);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setWidth, "setWidth(self, width: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setWidth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, &a0))
        {
            sipCpp->setWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setWidth, doc_Qt3DRender_QTextureImageData_setWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setHeight, "setHeight(self, height: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setHeight(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, &a0))
        {
            sipCpp->setHeight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setHeight, doc_Qt3DRender_QTextureImageData_setHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setDepth, "setDepth(self, depth: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setDepth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, &a0))
        {
            sipCpp->setDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setDepth, doc_Qt3DRender_QTextureImageData_setDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setLayers, "setLayers(self, layers: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setLayers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setLayers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, &a0))
        {
            sipCpp->setLayers(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setLayers, doc_Qt3DRender_QTextureImageData_setLayers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setMipLevels, "setMipLevels(self, mipLevels: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setMipLevels(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setMipLevels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, &a0))
        {
            sipCpp->setMipLevels(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setMipLevels, doc_Qt3DRender_QTextureImageData_setMipLevels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setFaces, "setFaces(self, faces: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setFaces(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setFaces(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, &a0))
        {
            sipCpp->setFaces(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setFaces, doc_Qt3DRender_QTextureImageData_setFaces);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_target, "target(self) -> QOpenGLTexture.Target");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_target(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_target(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            ::QOpenGLTexture::Target sipRes;

            sipRes = sipCpp->target();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOpenGLTexture_Target);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_target, doc_Qt3DRender_QTextureImageData_target);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_format, "format(self) -> QOpenGLTexture.TextureFormat");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_format(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            ::QOpenGLTexture::TextureFormat sipRes;

            sipRes = sipCpp->format();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOpenGLTexture_TextureFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_format, doc_Qt3DRender_QTextureImageData_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_pixelFormat, "pixelFormat(self) -> QOpenGLTexture.PixelFormat");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_pixelFormat(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_pixelFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            ::QOpenGLTexture::PixelFormat sipRes;

            sipRes = sipCpp->pixelFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOpenGLTexture_PixelFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_pixelFormat, doc_Qt3DRender_QTextureImageData_pixelFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_pixelType, "pixelType(self) -> QOpenGLTexture.PixelType");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_pixelType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_pixelType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp))
        {
            ::QOpenGLTexture::PixelType sipRes;

            sipRes = sipCpp->pixelType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOpenGLTexture_PixelType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_pixelType, doc_Qt3DRender_QTextureImageData_pixelType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setTarget, "setTarget(self, target: QOpenGLTexture.Target)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setTarget(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTexture::Target a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, sipType_QOpenGLTexture_Target, &a0))
        {
            sipCpp->setTarget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setTarget, doc_Qt3DRender_QTextureImageData_setTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setFormat, "setFormat(self, format: QOpenGLTexture.TextureFormat)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setFormat(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTexture::TextureFormat a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, sipType_QOpenGLTexture_TextureFormat, &a0))
        {
            sipCpp->setFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setFormat, doc_Qt3DRender_QTextureImageData_setFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setPixelFormat, "setPixelFormat(self, pixelFormat: QOpenGLTexture.PixelFormat)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setPixelFormat(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setPixelFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTexture::PixelFormat a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, sipType_QOpenGLTexture_PixelFormat, &a0))
        {
            sipCpp->setPixelFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setPixelFormat, doc_Qt3DRender_QTextureImageData_setPixelFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setPixelType, "setPixelType(self, pixelType: QOpenGLTexture.PixelType)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setPixelType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setPixelType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTexture::PixelType a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, sipType_QOpenGLTexture_PixelType, &a0))
        {
            sipCpp->setPixelType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setPixelType, doc_Qt3DRender_QTextureImageData_setPixelType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setImage, "setImage(self, a0: QImage)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setImage(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setImage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImage* a0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, sipType_QImage, &a0))
        {
            sipCpp->setImage(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setImage, doc_Qt3DRender_QTextureImageData_setImage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_setData, "setData(self, data: QByteArray|bytes|bytearray, blockSize: int, isCompressed: bool = False)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_setData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_setData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        int a1;
        bool a2 = 0;
        ::Qt3DRender::QTextureImageData *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_isCompressed,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1i|b", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, sipType_QByteArray, &a0, &a0State, &a1, &a2))
        {
            sipCpp->setData(*a0, a1, a2);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_setData, doc_Qt3DRender_QTextureImageData_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData_data, "data(self, layer: int = 0, face: int = 0, mipmapLevel: int = 0) -> QByteArray");

extern "C" {static PyObject *meth_Qt3DRender_QTextureImageData_data(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureImageData_data(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 0;
        int a1 = 0;
        int a2 = 0;
        const ::Qt3DRender::QTextureImageData *sipCpp;

        static const char *sipKwdList[] = {
            sipName_layer,
            sipName_face,
            sipName_mipmapLevel,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|iii", &sipSelf, sipType_Qt3DRender_QTextureImageData, &sipCpp, &a0, &a1, &a2))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->data(a0, a1, a2));

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureImageData, sipName_data, doc_Qt3DRender_QTextureImageData_data);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QTextureImageData(void *, int);}
static void release_Qt3DRender_QTextureImageData(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DRender::QTextureImageData *>(sipCppV);
}


extern "C" {static void *array_Qt3DRender_QTextureImageData(Py_ssize_t);}
static void *array_Qt3DRender_QTextureImageData(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QTextureImageData[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QTextureImageData(void *);}
static void array_delete_Qt3DRender_QTextureImageData(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QTextureImageData *>(sipCpp);
}


extern "C" {static void assign_Qt3DRender_QTextureImageData(void *, Py_ssize_t, void *);}
static void assign_Qt3DRender_QTextureImageData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::Qt3DRender::QTextureImageData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::Qt3DRender::QTextureImageData *>(sipSrc);
}


extern "C" {static void *copy_Qt3DRender_QTextureImageData(const void *, Py_ssize_t);}
static void *copy_Qt3DRender_QTextureImageData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::Qt3DRender::QTextureImageData(reinterpret_cast<const ::Qt3DRender::QTextureImageData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_Qt3DRender_QTextureImageData(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QTextureImageData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QTextureImageData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_Qt3DRender_QTextureImageData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QTextureImageData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::Qt3DRender::QTextureImageData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::Qt3DRender::QTextureImageData();

            return sipCpp;
        }
    }

    {
        const ::Qt3DRender::QTextureImageData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_Qt3DRender_QTextureImageData, &a0))
        {
            sipCpp = new ::Qt3DRender::QTextureImageData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_Qt3DRender_QTextureImageData[] = {
    {sipName_cleanup, meth_Qt3DRender_QTextureImageData_cleanup, METH_VARARGS, doc_Qt3DRender_QTextureImageData_cleanup},
    {sipName_data, SIP_MLMETH_CAST(meth_Qt3DRender_QTextureImageData_data), METH_VARARGS|METH_KEYWORDS, doc_Qt3DRender_QTextureImageData_data},
    {sipName_depth, meth_Qt3DRender_QTextureImageData_depth, METH_VARARGS, doc_Qt3DRender_QTextureImageData_depth},
    {sipName_faces, meth_Qt3DRender_QTextureImageData_faces, METH_VARARGS, doc_Qt3DRender_QTextureImageData_faces},
    {sipName_format, meth_Qt3DRender_QTextureImageData_format, METH_VARARGS, doc_Qt3DRender_QTextureImageData_format},
    {sipName_height, meth_Qt3DRender_QTextureImageData_height, METH_VARARGS, doc_Qt3DRender_QTextureImageData_height},
    {sipName_isCompressed, meth_Qt3DRender_QTextureImageData_isCompressed, METH_VARARGS, doc_Qt3DRender_QTextureImageData_isCompressed},
    {sipName_layers, meth_Qt3DRender_QTextureImageData_layers, METH_VARARGS, doc_Qt3DRender_QTextureImageData_layers},
    {sipName_mipLevels, meth_Qt3DRender_QTextureImageData_mipLevels, METH_VARARGS, doc_Qt3DRender_QTextureImageData_mipLevels},
    {sipName_pixelFormat, meth_Qt3DRender_QTextureImageData_pixelFormat, METH_VARARGS, doc_Qt3DRender_QTextureImageData_pixelFormat},
    {sipName_pixelType, meth_Qt3DRender_QTextureImageData_pixelType, METH_VARARGS, doc_Qt3DRender_QTextureImageData_pixelType},
    {sipName_setData, SIP_MLMETH_CAST(meth_Qt3DRender_QTextureImageData_setData), METH_VARARGS|METH_KEYWORDS, doc_Qt3DRender_QTextureImageData_setData},
    {sipName_setDepth, meth_Qt3DRender_QTextureImageData_setDepth, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setDepth},
    {sipName_setFaces, meth_Qt3DRender_QTextureImageData_setFaces, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setFaces},
    {sipName_setFormat, meth_Qt3DRender_QTextureImageData_setFormat, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setFormat},
    {sipName_setHeight, meth_Qt3DRender_QTextureImageData_setHeight, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setHeight},
    {sipName_setImage, meth_Qt3DRender_QTextureImageData_setImage, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setImage},
    {sipName_setLayers, meth_Qt3DRender_QTextureImageData_setLayers, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setLayers},
    {sipName_setMipLevels, meth_Qt3DRender_QTextureImageData_setMipLevels, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setMipLevels},
    {sipName_setPixelFormat, meth_Qt3DRender_QTextureImageData_setPixelFormat, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setPixelFormat},
    {sipName_setPixelType, meth_Qt3DRender_QTextureImageData_setPixelType, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setPixelType},
    {sipName_setTarget, meth_Qt3DRender_QTextureImageData_setTarget, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setTarget},
    {sipName_setWidth, meth_Qt3DRender_QTextureImageData_setWidth, METH_VARARGS, doc_Qt3DRender_QTextureImageData_setWidth},
    {sipName_target, meth_Qt3DRender_QTextureImageData_target, METH_VARARGS, doc_Qt3DRender_QTextureImageData_target},
    {sipName_width, meth_Qt3DRender_QTextureImageData_width, METH_VARARGS, doc_Qt3DRender_QTextureImageData_width}
};

PyDoc_STRVAR(doc_Qt3DRender_QTextureImageData, "\1QTextureImageData()\n"
"QTextureImageData(a0: QTextureImageData)");


static pyqt5ClassPluginDef plugin_Qt3DRender_QTextureImageData = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureImageData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QTextureImageData,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QTextureImageData,
    },
    {
        sipNameNr_QTextureImageData,
        {0, 0, 1},
        25, methods_Qt3DRender_QTextureImageData,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QTextureImageData,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_Qt3DRender_QTextureImageData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QTextureImageData,
    assign_Qt3DRender_QTextureImageData,
    array_Qt3DRender_QTextureImageData,
    copy_Qt3DRender_QTextureImageData,
    release_Qt3DRender_QTextureImageData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QTextureImageData,
    sizeof (::Qt3DRender::QTextureImageData),
};
