/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DAnimation.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 47 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationClipData.cpp"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 79 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationClipData.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 82 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationClipData.cpp"


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationClipData_setName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationClipData_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DAnimation::QAnimationClipData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QAnimationClipData, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationClipData, sipName_setName, doc_Qt3DAnimation_QAnimationClipData_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData_name, "name(self) -> str");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationClipData_name(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationClipData_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationClipData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationClipData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationClipData, sipName_name, doc_Qt3DAnimation_QAnimationClipData_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData_channelCount, "channelCount(self) -> int");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationClipData_channelCount(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationClipData_channelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationClipData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationClipData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->channelCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationClipData, sipName_channelCount, doc_Qt3DAnimation_QAnimationClipData_channelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData_appendChannel, "appendChannel(self, c: QChannel)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationClipData_appendChannel(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationClipData_appendChannel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QChannel* a0;
        ::Qt3DAnimation::QAnimationClipData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DAnimation_QAnimationClipData, &sipCpp, sipType_Qt3DAnimation_QChannel, &a0))
        {
            sipCpp->appendChannel(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationClipData, sipName_appendChannel, doc_Qt3DAnimation_QAnimationClipData_appendChannel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData_insertChannel, "insertChannel(self, index: int, c: QChannel)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationClipData_insertChannel(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationClipData_insertChannel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::Qt3DAnimation::QChannel* a1;
        ::Qt3DAnimation::QAnimationClipData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ9", &sipSelf, sipType_Qt3DAnimation_QAnimationClipData, &sipCpp, &a0, sipType_Qt3DAnimation_QChannel, &a1))
        {
            sipCpp->insertChannel(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationClipData, sipName_insertChannel, doc_Qt3DAnimation_QAnimationClipData_insertChannel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData_removeChannel, "removeChannel(self, index: int)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationClipData_removeChannel(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationClipData_removeChannel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DAnimation::QAnimationClipData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DAnimation_QAnimationClipData, &sipCpp, &a0))
        {
            sipCpp->removeChannel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationClipData, sipName_removeChannel, doc_Qt3DAnimation_QAnimationClipData_removeChannel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData_clearChannels, "clearChannels(self)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationClipData_clearChannels(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationClipData_clearChannels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QAnimationClipData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationClipData, &sipCpp))
        {
            sipCpp->clearChannels();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationClipData, sipName_clearChannels, doc_Qt3DAnimation_QAnimationClipData_clearChannels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationClipData_isValid(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationClipData_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationClipData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationClipData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationClipData, sipName_isValid, doc_Qt3DAnimation_QAnimationClipData_isValid);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DAnimation_QAnimationClipData(void *, int);}
static void release_Qt3DAnimation_QAnimationClipData(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DAnimation::QAnimationClipData *>(sipCppV);
}


extern "C" {static void *array_Qt3DAnimation_QAnimationClipData(Py_ssize_t);}
static void *array_Qt3DAnimation_QAnimationClipData(Py_ssize_t sipNrElem)
{
    return new ::Qt3DAnimation::QAnimationClipData[sipNrElem];
}


extern "C" {static void array_delete_Qt3DAnimation_QAnimationClipData(void *);}
static void array_delete_Qt3DAnimation_QAnimationClipData(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DAnimation::QAnimationClipData *>(sipCpp);
}


extern "C" {static void assign_Qt3DAnimation_QAnimationClipData(void *, Py_ssize_t, void *);}
static void assign_Qt3DAnimation_QAnimationClipData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::Qt3DAnimation::QAnimationClipData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::Qt3DAnimation::QAnimationClipData *>(sipSrc);
}


extern "C" {static void *copy_Qt3DAnimation_QAnimationClipData(const void *, Py_ssize_t);}
static void *copy_Qt3DAnimation_QAnimationClipData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::Qt3DAnimation::QAnimationClipData(reinterpret_cast<const ::Qt3DAnimation::QAnimationClipData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_Qt3DAnimation_QAnimationClipData(sipSimpleWrapper *);}
static void dealloc_Qt3DAnimation_QAnimationClipData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DAnimation_QAnimationClipData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_Qt3DAnimation_QAnimationClipData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DAnimation_QAnimationClipData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::Qt3DAnimation::QAnimationClipData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::Qt3DAnimation::QAnimationClipData();

            return sipCpp;
        }
    }

    {
        const ::Qt3DAnimation::QAnimationClipData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_Qt3DAnimation_QAnimationClipData, &a0))
        {
            sipCpp = new ::Qt3DAnimation::QAnimationClipData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_Qt3DAnimation_QAnimationClipData[] = {
    {sipName_appendChannel, meth_Qt3DAnimation_QAnimationClipData_appendChannel, METH_VARARGS, doc_Qt3DAnimation_QAnimationClipData_appendChannel},
    {sipName_channelCount, meth_Qt3DAnimation_QAnimationClipData_channelCount, METH_VARARGS, doc_Qt3DAnimation_QAnimationClipData_channelCount},
    {sipName_clearChannels, meth_Qt3DAnimation_QAnimationClipData_clearChannels, METH_VARARGS, doc_Qt3DAnimation_QAnimationClipData_clearChannels},
    {sipName_insertChannel, meth_Qt3DAnimation_QAnimationClipData_insertChannel, METH_VARARGS, doc_Qt3DAnimation_QAnimationClipData_insertChannel},
    {sipName_isValid, meth_Qt3DAnimation_QAnimationClipData_isValid, METH_VARARGS, doc_Qt3DAnimation_QAnimationClipData_isValid},
    {sipName_name, meth_Qt3DAnimation_QAnimationClipData_name, METH_VARARGS, doc_Qt3DAnimation_QAnimationClipData_name},
    {sipName_removeChannel, meth_Qt3DAnimation_QAnimationClipData_removeChannel, METH_VARARGS, doc_Qt3DAnimation_QAnimationClipData_removeChannel},
    {sipName_setName, meth_Qt3DAnimation_QAnimationClipData_setName, METH_VARARGS, doc_Qt3DAnimation_QAnimationClipData_setName}
};

PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationClipData, "\1QAnimationClipData()\n"
"QAnimationClipData(a0: QAnimationClipData)");


static pyqt5ClassPluginDef plugin_Qt3DAnimation_QAnimationClipData = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationClipData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DAnimation__QAnimationClipData,
        SIP_NULLPTR,
        &plugin_Qt3DAnimation_QAnimationClipData,
    },
    {
        sipNameNr_QAnimationClipData,
        {0, 0, 1},
        8, methods_Qt3DAnimation_QAnimationClipData,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DAnimation_QAnimationClipData,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_Qt3DAnimation_QAnimationClipData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DAnimation_QAnimationClipData,
    assign_Qt3DAnimation_QAnimationClipData,
    array_Qt3DAnimation_QAnimationClipData,
    copy_Qt3DAnimation_QAnimationClipData,
    release_Qt3DAnimation_QAnimationClipData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DAnimation_QAnimationClipData,
    sizeof (::Qt3DAnimation::QAnimationClipData),
};
