/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 45 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 73 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 103 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 106 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 135 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 138 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 141 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 194 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 197 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 200 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 235 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 240 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 243 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 246 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 249 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 252 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 255 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 258 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 261 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 264 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 267 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 270 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 273 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 276 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 279 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAttribute.cpp"


class sipQt3DRender_QAttribute : public ::Qt3DRender::QAttribute
{
public:
    sipQt3DRender_QAttribute(::Qt3DCore::QNode*);
    sipQt3DRender_QAttribute(::Qt3DRender::QBuffer*, ::Qt3DRender::QAttribute::VertexBaseType, ::uint, ::uint, ::uint, ::uint, ::Qt3DCore::QNode*);
    sipQt3DRender_QAttribute(::Qt3DRender::QBuffer*, const ::QString&, ::Qt3DRender::QAttribute::VertexBaseType, ::uint, ::uint, ::uint, ::uint, ::Qt3DCore::QNode*);
    virtual ~sipQt3DRender_QAttribute();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QAttribute(const sipQt3DRender_QAttribute &);
    sipQt3DRender_QAttribute &operator = (const sipQt3DRender_QAttribute &);

    char sipPyMethods[8];
};

sipQt3DRender_QAttribute::sipQt3DRender_QAttribute(::Qt3DCore::QNode*a0): ::Qt3DRender::QAttribute(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QAttribute::sipQt3DRender_QAttribute(::Qt3DRender::QBuffer*a0, ::Qt3DRender::QAttribute::VertexBaseType a1, ::uint a2, ::uint a3, ::uint a4, ::uint a5, ::Qt3DCore::QNode*a6): ::Qt3DRender::QAttribute(a0, a1, a2, a3, a4, a5, a6), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QAttribute::sipQt3DRender_QAttribute(::Qt3DRender::QBuffer*a0, const ::QString& a1, ::Qt3DRender::QAttribute::VertexBaseType a2, ::uint a3, ::uint a4, ::uint a5, ::uint a6, ::Qt3DCore::QNode*a7): ::Qt3DRender::QAttribute(a0, a1, a2, a3, a4, a5, a6, a7), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QAttribute::~sipQt3DRender_QAttribute()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QAttribute::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QAttribute);

    return ::Qt3DRender::QAttribute::metaObject();
}

int sipQt3DRender_QAttribute::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QAttribute::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QAttribute, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QAttribute::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QAttribute, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QAttribute::qt_metacast(_clname));
}

void sipQt3DRender_QAttribute::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QAttribute::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAttribute::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QAttribute::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAttribute::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QAttribute::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAttribute::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QAttribute::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAttribute::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QAttribute::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QAttribute::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QAttribute::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQt3DRender_QAttribute::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QAttribute::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QAttribute::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QAttribute::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DRender_7(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_buffer, "buffer(self) -> QBuffer|None");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_buffer(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_buffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::Qt3DRender::QBuffer*sipRes;

            sipRes = sipCpp->buffer();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QBuffer, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_buffer, doc_Qt3DRender_QAttribute_buffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_name, "name(self) -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_name(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_name, doc_Qt3DRender_QAttribute_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_vertexBaseType, "vertexBaseType(self) -> QAttribute.VertexBaseType");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_vertexBaseType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_vertexBaseType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::Qt3DRender::QAttribute::VertexBaseType sipRes;

            sipRes = sipCpp->vertexBaseType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAttribute_VertexBaseType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_vertexBaseType, doc_Qt3DRender_QAttribute_vertexBaseType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_vertexSize, "vertexSize(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_vertexSize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_vertexSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::uint sipRes;

            sipRes = sipCpp->vertexSize();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_vertexSize, doc_Qt3DRender_QAttribute_vertexSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_count, "count(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_count(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::uint sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_count, doc_Qt3DRender_QAttribute_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_byteStride, "byteStride(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_byteStride(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_byteStride(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::uint sipRes;

            sipRes = sipCpp->byteStride();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_byteStride, doc_Qt3DRender_QAttribute_byteStride);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_byteOffset, "byteOffset(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_byteOffset(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_byteOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::uint sipRes;

            sipRes = sipCpp->byteOffset();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_byteOffset, doc_Qt3DRender_QAttribute_byteOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_divisor, "divisor(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_divisor(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_divisor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::uint sipRes;

            sipRes = sipCpp->divisor();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_divisor, doc_Qt3DRender_QAttribute_divisor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_attributeType, "attributeType(self) -> QAttribute.AttributeType");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_attributeType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_attributeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp))
        {
            ::Qt3DRender::QAttribute::AttributeType sipRes;

            sipRes = sipCpp->attributeType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAttribute_AttributeType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_attributeType, doc_Qt3DRender_QAttribute_attributeType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultPositionAttributeName, "defaultPositionAttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultPositionAttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultPositionAttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultPositionAttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultPositionAttributeName, doc_Qt3DRender_QAttribute_defaultPositionAttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultNormalAttributeName, "defaultNormalAttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultNormalAttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultNormalAttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultNormalAttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultNormalAttributeName, doc_Qt3DRender_QAttribute_defaultNormalAttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultColorAttributeName, "defaultColorAttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultColorAttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultColorAttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultColorAttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultColorAttributeName, doc_Qt3DRender_QAttribute_defaultColorAttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultTextureCoordinateAttributeName, "defaultTextureCoordinateAttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultTextureCoordinateAttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultTextureCoordinateAttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultTextureCoordinateAttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultTextureCoordinateAttributeName, doc_Qt3DRender_QAttribute_defaultTextureCoordinateAttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultTextureCoordinate1AttributeName, "defaultTextureCoordinate1AttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultTextureCoordinate1AttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultTextureCoordinate1AttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultTextureCoordinate1AttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultTextureCoordinate1AttributeName, doc_Qt3DRender_QAttribute_defaultTextureCoordinate1AttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultTextureCoordinate2AttributeName, "defaultTextureCoordinate2AttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultTextureCoordinate2AttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultTextureCoordinate2AttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultTextureCoordinate2AttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultTextureCoordinate2AttributeName, doc_Qt3DRender_QAttribute_defaultTextureCoordinate2AttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultTangentAttributeName, "defaultTangentAttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultTangentAttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultTangentAttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultTangentAttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultTangentAttributeName, doc_Qt3DRender_QAttribute_defaultTangentAttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultJointIndicesAttributeName, "defaultJointIndicesAttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultJointIndicesAttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultJointIndicesAttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultJointIndicesAttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultJointIndicesAttributeName, doc_Qt3DRender_QAttribute_defaultJointIndicesAttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_defaultJointWeightsAttributeName, "defaultJointWeightsAttributeName() -> str");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_defaultJointWeightsAttributeName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_defaultJointWeightsAttributeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::Qt3DRender::QAttribute::defaultJointWeightsAttributeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_defaultJointWeightsAttributeName, doc_Qt3DRender_QAttribute_defaultJointWeightsAttributeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setBuffer, "setBuffer(self, buffer: QBuffer|None)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setBuffer(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBuffer* a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, sipType_Qt3DRender_QBuffer, &a0))
        {
            sipCpp->setBuffer(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setBuffer, doc_Qt3DRender_QAttribute_setBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setName, doc_Qt3DRender_QAttribute_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setDataType, "setDataType(self, type: QAttribute.VertexBaseType)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setDataType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setDataType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAttribute::VertexBaseType a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, sipType_Qt3DRender_QAttribute_VertexBaseType, &a0))
        {
            sipCpp->setDataType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setDataType, doc_Qt3DRender_QAttribute_setDataType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setDataSize, "setDataSize(self, size: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setDataSize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setDataSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uint a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, &a0))
        {
            sipCpp->setDataSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setDataSize, doc_Qt3DRender_QAttribute_setDataSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setCount, "setCount(self, count: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setCount(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uint a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, &a0))
        {
            sipCpp->setCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setCount, doc_Qt3DRender_QAttribute_setCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setByteStride, "setByteStride(self, byteStride: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setByteStride(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setByteStride(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uint a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, &a0))
        {
            sipCpp->setByteStride(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setByteStride, doc_Qt3DRender_QAttribute_setByteStride);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setByteOffset, "setByteOffset(self, byteOffset: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setByteOffset(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setByteOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uint a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, &a0))
        {
            sipCpp->setByteOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setByteOffset, doc_Qt3DRender_QAttribute_setByteOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setDivisor, "setDivisor(self, divisor: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setDivisor(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setDivisor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uint a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, &a0))
        {
            sipCpp->setDivisor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setDivisor, doc_Qt3DRender_QAttribute_setDivisor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setAttributeType, "setAttributeType(self, attributeType: QAttribute.AttributeType)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setAttributeType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setAttributeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAttribute::AttributeType a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, sipType_Qt3DRender_QAttribute_AttributeType, &a0))
        {
            sipCpp->setAttributeType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setAttributeType, doc_Qt3DRender_QAttribute_setAttributeType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setVertexBaseType, "setVertexBaseType(self, type: QAttribute.VertexBaseType)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setVertexBaseType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setVertexBaseType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAttribute::VertexBaseType a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, sipType_Qt3DRender_QAttribute_VertexBaseType, &a0))
        {
            sipCpp->setVertexBaseType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setVertexBaseType, doc_Qt3DRender_QAttribute_setVertexBaseType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QAttribute_setVertexSize, "setVertexSize(self, size: int)");

extern "C" {static PyObject *meth_Qt3DRender_QAttribute_setVertexSize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAttribute_setVertexSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uint a0;
        ::Qt3DRender::QAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_Qt3DRender_QAttribute, &sipCpp, &a0))
        {
            sipCpp->setVertexSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAttribute, sipName_setVertexSize, doc_Qt3DRender_QAttribute_setVertexSize);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QAttribute(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QAttribute(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QAttribute *sipCpp = reinterpret_cast< ::Qt3DRender::QAttribute *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QAttribute)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QNode)->ctd_cast(static_cast< ::Qt3DCore::QNode *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QAttribute(void *, int);}
static void release_Qt3DRender_QAttribute(void *sipCppV, int)
{
    ::Qt3DRender::QAttribute *sipCpp = reinterpret_cast< ::Qt3DRender::QAttribute *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QAttribute(Py_ssize_t);}
static void *array_Qt3DRender_QAttribute(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QAttribute[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QAttribute(void *);}
static void array_delete_Qt3DRender_QAttribute(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QAttribute *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QAttribute(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QAttribute(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QAttribute *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QAttribute(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QAttribute(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QAttribute(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QAttribute *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QAttribute(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::Qt3DRender::QBuffer* a0;
        ::Qt3DRender::QAttribute::VertexBaseType a1;
        ::uint a2;
        ::uint a3;
        ::uint a4 = 0;
        ::uint a5 = 0;
        ::Qt3DCore::QNode* a6 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_offset,
            sipName_stride,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "#J:Euu|uuJH", sipSelf, sipType_Qt3DRender_QBuffer, &a0, sipType_Qt3DRender_QAttribute_VertexBaseType, &a1, &a2, &a3, &a4, &a5, sipType_Qt3DCore_QNode, &a6, sipOwner))
        {
            sipCpp = new sipQt3DRender_QAttribute(a0, a1, a2, a3, a4, a5, a6);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::Qt3DRender::QBuffer* a0;
        const ::QString* a1;
        int a1State = 0;
        ::Qt3DRender::QAttribute::VertexBaseType a2;
        ::uint a3;
        ::uint a4;
        ::uint a5 = 0;
        ::uint a6 = 0;
        ::Qt3DCore::QNode* a7 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_offset,
            sipName_stride,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "#J:J1Euu|uuJH", sipSelf, sipType_Qt3DRender_QBuffer, &a0, sipType_QString, &a1, &a1State, sipType_Qt3DRender_QAttribute_VertexBaseType, &a2, &a3, &a4, &a5, &a6, sipType_Qt3DCore_QNode, &a7, sipOwner))
        {
            sipCpp = new sipQt3DRender_QAttribute(a0, *a1, a2, a3, a4, a5, a6, a7);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QAttribute[] = {{4, 2, 1}};


static PyMethodDef methods_Qt3DRender_QAttribute[] = {
    {sipName_attributeType, meth_Qt3DRender_QAttribute_attributeType, METH_VARARGS, doc_Qt3DRender_QAttribute_attributeType},
    {sipName_buffer, meth_Qt3DRender_QAttribute_buffer, METH_VARARGS, doc_Qt3DRender_QAttribute_buffer},
    {sipName_byteOffset, meth_Qt3DRender_QAttribute_byteOffset, METH_VARARGS, doc_Qt3DRender_QAttribute_byteOffset},
    {sipName_byteStride, meth_Qt3DRender_QAttribute_byteStride, METH_VARARGS, doc_Qt3DRender_QAttribute_byteStride},
    {sipName_count, meth_Qt3DRender_QAttribute_count, METH_VARARGS, doc_Qt3DRender_QAttribute_count},
    {sipName_defaultColorAttributeName, meth_Qt3DRender_QAttribute_defaultColorAttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultColorAttributeName},
    {sipName_defaultJointIndicesAttributeName, meth_Qt3DRender_QAttribute_defaultJointIndicesAttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultJointIndicesAttributeName},
    {sipName_defaultJointWeightsAttributeName, meth_Qt3DRender_QAttribute_defaultJointWeightsAttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultJointWeightsAttributeName},
    {sipName_defaultNormalAttributeName, meth_Qt3DRender_QAttribute_defaultNormalAttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultNormalAttributeName},
    {sipName_defaultPositionAttributeName, meth_Qt3DRender_QAttribute_defaultPositionAttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultPositionAttributeName},
    {sipName_defaultTangentAttributeName, meth_Qt3DRender_QAttribute_defaultTangentAttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultTangentAttributeName},
    {sipName_defaultTextureCoordinate1AttributeName, meth_Qt3DRender_QAttribute_defaultTextureCoordinate1AttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultTextureCoordinate1AttributeName},
    {sipName_defaultTextureCoordinate2AttributeName, meth_Qt3DRender_QAttribute_defaultTextureCoordinate2AttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultTextureCoordinate2AttributeName},
    {sipName_defaultTextureCoordinateAttributeName, meth_Qt3DRender_QAttribute_defaultTextureCoordinateAttributeName, METH_VARARGS, doc_Qt3DRender_QAttribute_defaultTextureCoordinateAttributeName},
    {sipName_divisor, meth_Qt3DRender_QAttribute_divisor, METH_VARARGS, doc_Qt3DRender_QAttribute_divisor},
    {sipName_name, meth_Qt3DRender_QAttribute_name, METH_VARARGS, doc_Qt3DRender_QAttribute_name},
    {sipName_setAttributeType, meth_Qt3DRender_QAttribute_setAttributeType, METH_VARARGS, doc_Qt3DRender_QAttribute_setAttributeType},
    {sipName_setBuffer, meth_Qt3DRender_QAttribute_setBuffer, METH_VARARGS, doc_Qt3DRender_QAttribute_setBuffer},
    {sipName_setByteOffset, meth_Qt3DRender_QAttribute_setByteOffset, METH_VARARGS, doc_Qt3DRender_QAttribute_setByteOffset},
    {sipName_setByteStride, meth_Qt3DRender_QAttribute_setByteStride, METH_VARARGS, doc_Qt3DRender_QAttribute_setByteStride},
    {sipName_setCount, meth_Qt3DRender_QAttribute_setCount, METH_VARARGS, doc_Qt3DRender_QAttribute_setCount},
    {sipName_setDataSize, meth_Qt3DRender_QAttribute_setDataSize, METH_VARARGS, doc_Qt3DRender_QAttribute_setDataSize},
    {sipName_setDataType, meth_Qt3DRender_QAttribute_setDataType, METH_VARARGS, doc_Qt3DRender_QAttribute_setDataType},
    {sipName_setDivisor, meth_Qt3DRender_QAttribute_setDivisor, METH_VARARGS, doc_Qt3DRender_QAttribute_setDivisor},
    {sipName_setName, meth_Qt3DRender_QAttribute_setName, METH_VARARGS, doc_Qt3DRender_QAttribute_setName},
    {sipName_setVertexBaseType, meth_Qt3DRender_QAttribute_setVertexBaseType, METH_VARARGS, doc_Qt3DRender_QAttribute_setVertexBaseType},
    {sipName_setVertexSize, meth_Qt3DRender_QAttribute_setVertexSize, METH_VARARGS, doc_Qt3DRender_QAttribute_setVertexSize},
    {sipName_vertexBaseType, meth_Qt3DRender_QAttribute_vertexBaseType, METH_VARARGS, doc_Qt3DRender_QAttribute_vertexBaseType},
    {sipName_vertexSize, meth_Qt3DRender_QAttribute_vertexSize, METH_VARARGS, doc_Qt3DRender_QAttribute_vertexSize}
};

static sipEnumMemberDef enummembers_Qt3DRender_QAttribute[] = {
    {sipName_Byte, static_cast<int>(::Qt3DRender::QAttribute::Byte), 42},
    {sipName_Double, static_cast<int>(::Qt3DRender::QAttribute::Double), 42},
    {sipName_DrawIndirectAttribute, static_cast<int>(::Qt3DRender::QAttribute::DrawIndirectAttribute), 41},
    {sipName_Float, static_cast<int>(::Qt3DRender::QAttribute::Float), 42},
    {sipName_HalfFloat, static_cast<int>(::Qt3DRender::QAttribute::HalfFloat), 42},
    {sipName_IndexAttribute, static_cast<int>(::Qt3DRender::QAttribute::IndexAttribute), 41},
    {sipName_Int, static_cast<int>(::Qt3DRender::QAttribute::Int), 42},
    {sipName_Short, static_cast<int>(::Qt3DRender::QAttribute::Short), 42},
    {sipName_UnsignedByte, static_cast<int>(::Qt3DRender::QAttribute::UnsignedByte), 42},
    {sipName_UnsignedInt, static_cast<int>(::Qt3DRender::QAttribute::UnsignedInt), 42},
    {sipName_UnsignedShort, static_cast<int>(::Qt3DRender::QAttribute::UnsignedShort), 42},
    {sipName_VertexAttribute, static_cast<int>(::Qt3DRender::QAttribute::VertexAttribute), 41},
};

PyDoc_STRVAR(doc_Qt3DRender_QAttribute, "\1QAttribute(parent: QNode|None = None)\n"
"QAttribute(buf: QBuffer|None, vertexBaseType: QAttribute.VertexBaseType, vertexSize: int, count: int, offset: int = 0, stride: int = 0, parent: QNode|None = None)\n"
"QAttribute(buf: QBuffer|None, name: str|None, vertexBaseType: QAttribute.VertexBaseType, vertexSize: int, count: int, offset: int = 0, stride: int = 0, parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QAttribute[] = {
    {"vertexSizeChanged(uint)", "\1vertexSizeChanged(self, vertexSize: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"vertexBaseTypeChanged(VertexBaseType)|(Qt3DRender::QAttribute::VertexBaseType)", "\1vertexBaseTypeChanged(self, vertexBaseType: QAttribute.VertexBaseType)", SIP_NULLPTR, SIP_NULLPTR},
    {"attributeTypeChanged(AttributeType)|(Qt3DRender::QAttribute::AttributeType)", "\1attributeTypeChanged(self, attributeType: QAttribute.AttributeType)", SIP_NULLPTR, SIP_NULLPTR},
    {"divisorChanged(uint)", "\1divisorChanged(self, divisor: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"byteOffsetChanged(uint)", "\1byteOffsetChanged(self, byteOffset: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"byteStrideChanged(uint)", "\1byteStrideChanged(self, byteStride: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"countChanged(uint)", "\1countChanged(self, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"dataSizeChanged(uint)", "\1dataSizeChanged(self, vertexSize: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"dataTypeChanged(VertexBaseType)|(Qt3DRender::QAttribute::VertexBaseType)", "\1dataTypeChanged(self, vertexBaseType: QAttribute.VertexBaseType)", SIP_NULLPTR, SIP_NULLPTR},
    {"nameChanged(QString)", "\1nameChanged(self, name: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferChanged(QBuffer*)|(Qt3DRender::QBuffer*)", "\1bufferChanged(self, buffer: QBuffer|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QAttribute = {
    &::Qt3DRender::QAttribute::staticMetaObject,
    0,
    signals_Qt3DRender_QAttribute,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAttribute = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QAttribute,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QAttribute,
    },
    {
        sipNameNr_QAttribute,
        {0, 0, 1},
        29, methods_Qt3DRender_QAttribute,
        12, enummembers_Qt3DRender_QAttribute,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QAttribute,
    -1,
    -1,
    supers_Qt3DRender_QAttribute,
    SIP_NULLPTR,
    init_type_Qt3DRender_QAttribute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QAttribute,
    SIP_NULLPTR,
    array_Qt3DRender_QAttribute,
    SIP_NULLPTR,
    release_Qt3DRender_QAttribute,
    cast_Qt3DRender_QAttribute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QAttribute,
    sizeof (::Qt3DRender::QAttribute),
};
