/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DAnimation.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 51 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 55 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 78 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 105 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 108 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 111 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 116 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 119 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 122 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 125 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 128 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 131 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 134 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 137 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 140 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 143 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 146 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 149 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 152 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 155 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 158 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAnimationController.cpp"


class sipQt3DAnimation_QAnimationController : public ::Qt3DAnimation::QAnimationController
{
public:
    sipQt3DAnimation_QAnimationController(::QObject*);
    virtual ~sipQt3DAnimation_QAnimationController();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DAnimation_QAnimationController(const sipQt3DAnimation_QAnimationController &);
    sipQt3DAnimation_QAnimationController &operator = (const sipQt3DAnimation_QAnimationController &);

    char sipPyMethods[7];
};

sipQt3DAnimation_QAnimationController::sipQt3DAnimation_QAnimationController(::QObject*a0): ::Qt3DAnimation::QAnimationController(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DAnimation_QAnimationController::~sipQt3DAnimation_QAnimationController()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DAnimation_QAnimationController::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DAnimation_qt_metaobject(sipPySelf, sipType_Qt3DAnimation_QAnimationController);

    return ::Qt3DAnimation::QAnimationController::metaObject();
}

int sipQt3DAnimation_QAnimationController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DAnimation::QAnimationController::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DAnimation_qt_metacall(sipPySelf, sipType_Qt3DAnimation_QAnimationController, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DAnimation_QAnimationController::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DAnimation_qt_metacast(sipPySelf, sipType_Qt3DAnimation_QAnimationController, _clname, &sipCpp) ? sipCpp : ::Qt3DAnimation::QAnimationController::qt_metacast(_clname));
}

bool sipQt3DAnimation_QAnimationController::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DAnimation::QAnimationController::event(a0);

    extern bool sipVH_Qt3DAnimation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DAnimation_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DAnimation_QAnimationController::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DAnimation::QAnimationController::eventFilter(a0, a1);

    extern bool sipVH_Qt3DAnimation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DAnimation_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DAnimation_QAnimationController::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAnimationController::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DAnimation_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QAnimationController::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAnimationController::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DAnimation_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QAnimationController::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAnimationController::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DAnimation_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QAnimationController::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAnimationController::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DAnimation_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QAnimationController::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAnimationController::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DAnimation_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_animationGroupList, "animationGroupList(self) -> list[QAnimationGroup]");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_animationGroupList(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_animationGroupList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp))
        {
            QVector< ::Qt3DAnimation::QAnimationGroup*>*sipRes;

            sipRes = new QVector< ::Qt3DAnimation::QAnimationGroup*>(sipCpp->animationGroupList());

            return sipConvertFromNewType(sipRes, sipType_QVector_0101Qt3DAnimation_QAnimationGroup, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_animationGroupList, doc_Qt3DAnimation_QAnimationController_animationGroupList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_activeAnimationGroup, "activeAnimationGroup(self) -> int");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_activeAnimationGroup(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_activeAnimationGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->activeAnimationGroup();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_activeAnimationGroup, doc_Qt3DAnimation_QAnimationController_activeAnimationGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_position, "position(self) -> float");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_position(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->position();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_position, doc_Qt3DAnimation_QAnimationController_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_positionScale, "positionScale(self) -> float");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_positionScale(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_positionScale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->positionScale();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_positionScale, doc_Qt3DAnimation_QAnimationController_positionScale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_positionOffset, "positionOffset(self) -> float");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_positionOffset(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_positionOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->positionOffset();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_positionOffset, doc_Qt3DAnimation_QAnimationController_positionOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_entity, "entity(self) -> QEntity|None");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_entity(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_entity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp))
        {
            ::Qt3DCore::QEntity*sipRes;

            sipRes = sipCpp->entity();

            return sipConvertFromType(sipRes, sipType_Qt3DCore_QEntity, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_entity, doc_Qt3DAnimation_QAnimationController_entity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_recursive, "recursive(self) -> bool");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_recursive(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_recursive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->recursive();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_recursive, doc_Qt3DAnimation_QAnimationController_recursive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_setAnimationGroups, "setAnimationGroups(self, animationGroups: Iterable[QAnimationGroup])");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_setAnimationGroups(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_setAnimationGroups(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QVector< ::Qt3DAnimation::QAnimationGroup*>* a0;
        int a0State = 0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, sipType_QVector_0101Qt3DAnimation_QAnimationGroup, &a0, &a0State))
        {
            sipCpp->setAnimationGroups(*a0);
            sipReleaseType(const_cast<QVector< ::Qt3DAnimation::QAnimationGroup*> *>(a0), sipType_QVector_0101Qt3DAnimation_QAnimationGroup, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_setAnimationGroups, doc_Qt3DAnimation_QAnimationController_setAnimationGroups);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_addAnimationGroup, "addAnimationGroup(self, animationGroups: QAnimationGroup|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_addAnimationGroup(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_addAnimationGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QAnimationGroup* a0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, sipType_Qt3DAnimation_QAnimationGroup, &a0))
        {
            sipCpp->addAnimationGroup(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_addAnimationGroup, doc_Qt3DAnimation_QAnimationController_addAnimationGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_removeAnimationGroup, "removeAnimationGroup(self, animationGroups: QAnimationGroup|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_removeAnimationGroup(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_removeAnimationGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QAnimationGroup* a0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, sipType_Qt3DAnimation_QAnimationGroup, &a0))
        {
            sipCpp->removeAnimationGroup(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_removeAnimationGroup, doc_Qt3DAnimation_QAnimationController_removeAnimationGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_getAnimationIndex, "getAnimationIndex(self, name: str|None) -> int");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_getAnimationIndex(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_getAnimationIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->getAnimationIndex(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_getAnimationIndex, doc_Qt3DAnimation_QAnimationController_getAnimationIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_getGroup, "getGroup(self, index: int) -> QAnimationGroup|None");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_getGroup(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_getGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, &a0))
        {
            ::Qt3DAnimation::QAnimationGroup*sipRes;

            sipRes = sipCpp->getGroup(a0);

            return sipConvertFromType(sipRes, sipType_Qt3DAnimation_QAnimationGroup, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_getGroup, doc_Qt3DAnimation_QAnimationController_getGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_setActiveAnimationGroup, "setActiveAnimationGroup(self, index: int)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_setActiveAnimationGroup(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_setActiveAnimationGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, &a0))
        {
            sipCpp->setActiveAnimationGroup(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_setActiveAnimationGroup, doc_Qt3DAnimation_QAnimationController_setActiveAnimationGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_setPosition, "setPosition(self, position: float)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_setPosition(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, &a0))
        {
            sipCpp->setPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_setPosition, doc_Qt3DAnimation_QAnimationController_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_setPositionScale, "setPositionScale(self, scale: float)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_setPositionScale(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_setPositionScale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, &a0))
        {
            sipCpp->setPositionScale(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_setPositionScale, doc_Qt3DAnimation_QAnimationController_setPositionScale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_setPositionOffset, "setPositionOffset(self, offset: float)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_setPositionOffset(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_setPositionOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, &a0))
        {
            sipCpp->setPositionOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_setPositionOffset, doc_Qt3DAnimation_QAnimationController_setPositionOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_setEntity, "setEntity(self, entity: QEntity|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_setEntity(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_setEntity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QEntity* a0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, sipType_Qt3DCore_QEntity, &a0))
        {
            sipCpp->setEntity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_setEntity, doc_Qt3DAnimation_QAnimationController_setEntity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController_setRecursive, "setRecursive(self, recursive: bool)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAnimationController_setRecursive(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAnimationController_setRecursive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DAnimation::QAnimationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DAnimation_QAnimationController, &sipCpp, &a0))
        {
            sipCpp->setRecursive(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAnimationController, sipName_setRecursive, doc_Qt3DAnimation_QAnimationController_setRecursive);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DAnimation_QAnimationController(void *, const sipTypeDef *);}
static void *cast_Qt3DAnimation_QAnimationController(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DAnimation::QAnimationController *sipCpp = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(sipCppV);

    if (targetType == sipType_Qt3DAnimation_QAnimationController)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DAnimation_QAnimationController(void *, int);}
static void release_Qt3DAnimation_QAnimationController(void *sipCppV, int)
{
    ::Qt3DAnimation::QAnimationController *sipCpp = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DAnimation_QAnimationController(Py_ssize_t);}
static void *array_Qt3DAnimation_QAnimationController(Py_ssize_t sipNrElem)
{
    return new ::Qt3DAnimation::QAnimationController[sipNrElem];
}


extern "C" {static void array_delete_Qt3DAnimation_QAnimationController(void *);}
static void array_delete_Qt3DAnimation_QAnimationController(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DAnimation_QAnimationController(sipSimpleWrapper *);}
static void dealloc_Qt3DAnimation_QAnimationController(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DAnimation_QAnimationController *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DAnimation_QAnimationController(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DAnimation_QAnimationController(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DAnimation_QAnimationController(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DAnimation_QAnimationController *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQt3DAnimation_QAnimationController(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DAnimation_QAnimationController[] = {{4, 0, 1}};


static PyMethodDef methods_Qt3DAnimation_QAnimationController[] = {
    {sipName_activeAnimationGroup, meth_Qt3DAnimation_QAnimationController_activeAnimationGroup, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_activeAnimationGroup},
    {sipName_addAnimationGroup, meth_Qt3DAnimation_QAnimationController_addAnimationGroup, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_addAnimationGroup},
    {sipName_animationGroupList, meth_Qt3DAnimation_QAnimationController_animationGroupList, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_animationGroupList},
    {sipName_entity, meth_Qt3DAnimation_QAnimationController_entity, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_entity},
    {sipName_getAnimationIndex, meth_Qt3DAnimation_QAnimationController_getAnimationIndex, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_getAnimationIndex},
    {sipName_getGroup, meth_Qt3DAnimation_QAnimationController_getGroup, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_getGroup},
    {sipName_position, meth_Qt3DAnimation_QAnimationController_position, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_position},
    {sipName_positionOffset, meth_Qt3DAnimation_QAnimationController_positionOffset, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_positionOffset},
    {sipName_positionScale, meth_Qt3DAnimation_QAnimationController_positionScale, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_positionScale},
    {sipName_recursive, meth_Qt3DAnimation_QAnimationController_recursive, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_recursive},
    {sipName_removeAnimationGroup, meth_Qt3DAnimation_QAnimationController_removeAnimationGroup, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_removeAnimationGroup},
    {sipName_setActiveAnimationGroup, meth_Qt3DAnimation_QAnimationController_setActiveAnimationGroup, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_setActiveAnimationGroup},
    {sipName_setAnimationGroups, meth_Qt3DAnimation_QAnimationController_setAnimationGroups, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_setAnimationGroups},
    {sipName_setEntity, meth_Qt3DAnimation_QAnimationController_setEntity, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_setEntity},
    {sipName_setPosition, meth_Qt3DAnimation_QAnimationController_setPosition, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_setPosition},
    {sipName_setPositionOffset, meth_Qt3DAnimation_QAnimationController_setPositionOffset, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_setPositionOffset},
    {sipName_setPositionScale, meth_Qt3DAnimation_QAnimationController_setPositionScale, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_setPositionScale},
    {sipName_setRecursive, meth_Qt3DAnimation_QAnimationController_setRecursive, METH_VARARGS, doc_Qt3DAnimation_QAnimationController_setRecursive}
};

PyDoc_STRVAR(doc_Qt3DAnimation_QAnimationController, "\1QAnimationController(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DAnimation_QAnimationController[] = {
    {"recursiveChanged(bool)", "\1recursiveChanged(self, recursive: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"entityChanged(Qt3DCore::QEntity*)", "\1entityChanged(self, entity: QEntity|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionOffsetChanged(float)", "\1positionOffsetChanged(self, offset: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionScaleChanged(float)", "\1positionScaleChanged(self, scale: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(float)", "\1positionChanged(self, position: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeAnimationGroupChanged(int)", "\1activeAnimationGroupChanged(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DAnimation_QAnimationController = {
    &::Qt3DAnimation::QAnimationController::staticMetaObject,
    0,
    signals_Qt3DAnimation_QAnimationController,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationController = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DAnimation__QAnimationController,
        SIP_NULLPTR,
        &plugin_Qt3DAnimation_QAnimationController,
    },
    {
        sipNameNr_QAnimationController,
        {0, 0, 1},
        18, methods_Qt3DAnimation_QAnimationController,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DAnimation_QAnimationController,
    -1,
    -1,
    supers_Qt3DAnimation_QAnimationController,
    SIP_NULLPTR,
    init_type_Qt3DAnimation_QAnimationController,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DAnimation_QAnimationController,
    SIP_NULLPTR,
    array_Qt3DAnimation_QAnimationController,
    SIP_NULLPTR,
    release_Qt3DAnimation_QAnimationController,
    cast_Qt3DAnimation_QAnimationController,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DAnimation_QAnimationController,
    sizeof (::Qt3DAnimation::QAnimationController),
};
