/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 109 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQLevelOfDetailBoundingSphere.cpp"

#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 113 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQLevelOfDetailBoundingSphere.cpp"


PyDoc_STRVAR(doc_Qt3DRender_QLevelOfDetailBoundingSphere_center, "center(self) -> QVector3D");

extern "C" {static PyObject *meth_Qt3DRender_QLevelOfDetailBoundingSphere_center(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QLevelOfDetailBoundingSphere_center(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QLevelOfDetailBoundingSphere *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QLevelOfDetailBoundingSphere, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->center());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLevelOfDetailBoundingSphere, sipName_center, doc_Qt3DRender_QLevelOfDetailBoundingSphere_center);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QLevelOfDetailBoundingSphere_radius, "radius(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QLevelOfDetailBoundingSphere_radius(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QLevelOfDetailBoundingSphere_radius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QLevelOfDetailBoundingSphere *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QLevelOfDetailBoundingSphere, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->radius();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLevelOfDetailBoundingSphere, sipName_radius, doc_Qt3DRender_QLevelOfDetailBoundingSphere_radius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QLevelOfDetailBoundingSphere_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QLevelOfDetailBoundingSphere_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QLevelOfDetailBoundingSphere_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QLevelOfDetailBoundingSphere *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QLevelOfDetailBoundingSphere, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLevelOfDetailBoundingSphere, sipName_isEmpty, doc_Qt3DRender_QLevelOfDetailBoundingSphere_isEmpty);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_Qt3DRender_QLevelOfDetailBoundingSphere___ne__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DRender_QLevelOfDetailBoundingSphere___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DRender::QLevelOfDetailBoundingSphere *sipCpp = reinterpret_cast< ::Qt3DRender::QLevelOfDetailBoundingSphere *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DRender_QLevelOfDetailBoundingSphere));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QLevelOfDetailBoundingSphere* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DRender_QLevelOfDetailBoundingSphere, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::Qt3DRender::QLevelOfDetailBoundingSphere::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DRender, ne_slot, sipType_Qt3DRender_QLevelOfDetailBoundingSphere, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_Qt3DRender_QLevelOfDetailBoundingSphere___eq__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DRender_QLevelOfDetailBoundingSphere___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DRender::QLevelOfDetailBoundingSphere *sipCpp = reinterpret_cast< ::Qt3DRender::QLevelOfDetailBoundingSphere *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DRender_QLevelOfDetailBoundingSphere));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QLevelOfDetailBoundingSphere* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DRender_QLevelOfDetailBoundingSphere, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::Qt3DRender::QLevelOfDetailBoundingSphere::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DRender, eq_slot, sipType_Qt3DRender_QLevelOfDetailBoundingSphere, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QLevelOfDetailBoundingSphere(void *, int);}
static void release_Qt3DRender_QLevelOfDetailBoundingSphere(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DRender::QLevelOfDetailBoundingSphere *>(sipCppV);
}


extern "C" {static void *array_Qt3DRender_QLevelOfDetailBoundingSphere(Py_ssize_t);}
static void *array_Qt3DRender_QLevelOfDetailBoundingSphere(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QLevelOfDetailBoundingSphere[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QLevelOfDetailBoundingSphere(void *);}
static void array_delete_Qt3DRender_QLevelOfDetailBoundingSphere(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QLevelOfDetailBoundingSphere *>(sipCpp);
}


extern "C" {static void assign_Qt3DRender_QLevelOfDetailBoundingSphere(void *, Py_ssize_t, void *);}
static void assign_Qt3DRender_QLevelOfDetailBoundingSphere(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::Qt3DRender::QLevelOfDetailBoundingSphere *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::Qt3DRender::QLevelOfDetailBoundingSphere *>(sipSrc);
}


extern "C" {static void *copy_Qt3DRender_QLevelOfDetailBoundingSphere(const void *, Py_ssize_t);}
static void *copy_Qt3DRender_QLevelOfDetailBoundingSphere(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::Qt3DRender::QLevelOfDetailBoundingSphere(reinterpret_cast<const ::Qt3DRender::QLevelOfDetailBoundingSphere *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_Qt3DRender_QLevelOfDetailBoundingSphere(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QLevelOfDetailBoundingSphere(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QLevelOfDetailBoundingSphere(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_Qt3DRender_QLevelOfDetailBoundingSphere(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QLevelOfDetailBoundingSphere(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::Qt3DRender::QLevelOfDetailBoundingSphere *sipCpp = SIP_NULLPTR;

    {
        ::QVector3D a0def = QVector3D();
        ::QVector3D* a0 = &a0def;
        float a1 = 1;

        static const char *sipKwdList[] = {
            sipName_center,
            sipName_radius,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J9f", sipType_QVector3D, &a0, &a1))
        {
            sipCpp = new ::Qt3DRender::QLevelOfDetailBoundingSphere(*a0, a1);

            return sipCpp;
        }
    }

    {
        const ::Qt3DRender::QLevelOfDetailBoundingSphere* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_Qt3DRender_QLevelOfDetailBoundingSphere, &a0))
        {
            sipCpp = new ::Qt3DRender::QLevelOfDetailBoundingSphere(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_Qt3DRender_QLevelOfDetailBoundingSphere[] = {
    {(void *)slot_Qt3DRender_QLevelOfDetailBoundingSphere___ne__, ne_slot},
    {(void *)slot_Qt3DRender_QLevelOfDetailBoundingSphere___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_Qt3DRender_QLevelOfDetailBoundingSphere[] = {
    {sipName_center, meth_Qt3DRender_QLevelOfDetailBoundingSphere_center, METH_VARARGS, doc_Qt3DRender_QLevelOfDetailBoundingSphere_center},
    {sipName_isEmpty, meth_Qt3DRender_QLevelOfDetailBoundingSphere_isEmpty, METH_VARARGS, doc_Qt3DRender_QLevelOfDetailBoundingSphere_isEmpty},
    {sipName_radius, meth_Qt3DRender_QLevelOfDetailBoundingSphere_radius, METH_VARARGS, doc_Qt3DRender_QLevelOfDetailBoundingSphere_radius}
};

PyDoc_STRVAR(doc_Qt3DRender_QLevelOfDetailBoundingSphere, "\1QLevelOfDetailBoundingSphere(center: QVector3D = QVector3D(), radius: float = 1)\n"
"QLevelOfDetailBoundingSphere(other: QLevelOfDetailBoundingSphere)");


static pyqt5ClassPluginDef plugin_Qt3DRender_QLevelOfDetailBoundingSphere = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QLevelOfDetailBoundingSphere = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QLevelOfDetailBoundingSphere,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QLevelOfDetailBoundingSphere,
    },
    {
        sipNameNr_QLevelOfDetailBoundingSphere,
        {0, 0, 1},
        3, methods_Qt3DRender_QLevelOfDetailBoundingSphere,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QLevelOfDetailBoundingSphere,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_Qt3DRender_QLevelOfDetailBoundingSphere,
    init_type_Qt3DRender_QLevelOfDetailBoundingSphere,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QLevelOfDetailBoundingSphere,
    assign_Qt3DRender_QLevelOfDetailBoundingSphere,
    array_Qt3DRender_QLevelOfDetailBoundingSphere,
    copy_Qt3DRender_QLevelOfDetailBoundingSphere,
    release_Qt3DRender_QLevelOfDetailBoundingSphere,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QLevelOfDetailBoundingSphere,
    sizeof (::Qt3DRender::QLevelOfDetailBoundingSphere),
};
