/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DAnimation.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 31 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"

#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 35 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 40 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 43 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 46 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 49 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 52 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 55 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 58 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 61 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 64 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 67 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 70 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 73 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 76 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 79 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 82 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 85 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractAnimation.cpp"


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractAnimation_animationName, "animationName(self) -> str");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractAnimation_animationName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractAnimation_animationName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractAnimation, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->animationName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAnimation, sipName_animationName, doc_Qt3DAnimation_QAbstractAnimation_animationName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractAnimation_animationType, "animationType(self) -> QAbstractAnimation.AnimationType");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractAnimation_animationType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractAnimation_animationType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractAnimation, &sipCpp))
        {
            ::Qt3DAnimation::QAbstractAnimation::AnimationType sipRes;

            sipRes = sipCpp->animationType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DAnimation_QAbstractAnimation_AnimationType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAnimation, sipName_animationType, doc_Qt3DAnimation_QAbstractAnimation_animationType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractAnimation_position, "position(self) -> float");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractAnimation_position(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractAnimation_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractAnimation, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->position();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAnimation, sipName_position, doc_Qt3DAnimation_QAbstractAnimation_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractAnimation_duration, "duration(self) -> float");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractAnimation_duration(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractAnimation_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractAnimation, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->duration();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAnimation, sipName_duration, doc_Qt3DAnimation_QAbstractAnimation_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractAnimation_setAnimationName, "setAnimationName(self, name: str|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractAnimation_setAnimationName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractAnimation_setAnimationName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DAnimation::QAbstractAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QAbstractAnimation, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setAnimationName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAnimation, sipName_setAnimationName, doc_Qt3DAnimation_QAbstractAnimation_setAnimationName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractAnimation_setPosition, "setPosition(self, position: float)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractAnimation_setPosition(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractAnimation_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DAnimation::QAbstractAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DAnimation_QAbstractAnimation, &sipCpp, &a0))
        {
            sipCpp->setPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAnimation, sipName_setPosition, doc_Qt3DAnimation_QAbstractAnimation_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractAnimation_setDuration, "setDuration(self, duration: float)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractAnimation_setDuration(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractAnimation_setDuration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DAnimation::QAbstractAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pf", &sipSelf, sipType_Qt3DAnimation_QAbstractAnimation, &sipCpp, &a0))
        {
            sipCpp->setDuration(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractAnimation, sipName_setDuration, doc_Qt3DAnimation_QAbstractAnimation_setDuration);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DAnimation_QAbstractAnimation(void *, const sipTypeDef *);}
static void *cast_Qt3DAnimation_QAbstractAnimation(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DAnimation::QAbstractAnimation *sipCpp = reinterpret_cast< ::Qt3DAnimation::QAbstractAnimation *>(sipCppV);

    if (targetType == sipType_Qt3DAnimation_QAbstractAnimation)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DAnimation_QAbstractAnimation(void *, int);}
static void release_Qt3DAnimation_QAbstractAnimation(void *sipCppV, int)
{
    ::Qt3DAnimation::QAbstractAnimation *sipCpp = reinterpret_cast< ::Qt3DAnimation::QAbstractAnimation *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_Qt3DAnimation_QAbstractAnimation(sipSimpleWrapper *);}
static void dealloc_Qt3DAnimation_QAbstractAnimation(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DAnimation_QAbstractAnimation(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DAnimation_QAbstractAnimation[] = {{4, 0, 1}};


static PyMethodDef methods_Qt3DAnimation_QAbstractAnimation[] = {
    {sipName_animationName, meth_Qt3DAnimation_QAbstractAnimation_animationName, METH_VARARGS, doc_Qt3DAnimation_QAbstractAnimation_animationName},
    {sipName_animationType, meth_Qt3DAnimation_QAbstractAnimation_animationType, METH_VARARGS, doc_Qt3DAnimation_QAbstractAnimation_animationType},
    {sipName_duration, meth_Qt3DAnimation_QAbstractAnimation_duration, METH_VARARGS, doc_Qt3DAnimation_QAbstractAnimation_duration},
    {sipName_position, meth_Qt3DAnimation_QAbstractAnimation_position, METH_VARARGS, doc_Qt3DAnimation_QAbstractAnimation_position},
    {sipName_setAnimationName, meth_Qt3DAnimation_QAbstractAnimation_setAnimationName, METH_VARARGS, doc_Qt3DAnimation_QAbstractAnimation_setAnimationName},
    {sipName_setDuration, meth_Qt3DAnimation_QAbstractAnimation_setDuration, METH_VARARGS, doc_Qt3DAnimation_QAbstractAnimation_setDuration},
    {sipName_setPosition, meth_Qt3DAnimation_QAbstractAnimation_setPosition, METH_VARARGS, doc_Qt3DAnimation_QAbstractAnimation_setPosition}
};

static sipEnumMemberDef enummembers_Qt3DAnimation_QAbstractAnimation[] = {
    {sipName_KeyframeAnimation, static_cast<int>(::Qt3DAnimation::QAbstractAnimation::KeyframeAnimation), 7},
    {sipName_MorphingAnimation, static_cast<int>(::Qt3DAnimation::QAbstractAnimation::MorphingAnimation), 7},
    {sipName_VertexBlendAnimation, static_cast<int>(::Qt3DAnimation::QAbstractAnimation::VertexBlendAnimation), 7},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DAnimation_QAbstractAnimation[] = {
    {"durationChanged(float)", "\1durationChanged(self, duration: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(float)", "\1positionChanged(self, position: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"animationNameChanged(QString)", "\1animationNameChanged(self, name: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DAnimation_QAbstractAnimation = {
    &::Qt3DAnimation::QAbstractAnimation::staticMetaObject,
    0,
    signals_Qt3DAnimation_QAbstractAnimation,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractAnimation = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DAnimation__QAbstractAnimation,
        SIP_NULLPTR,
        &plugin_Qt3DAnimation_QAbstractAnimation,
    },
    {
        sipNameNr_QAbstractAnimation,
        {0, 0, 1},
        7, methods_Qt3DAnimation_QAbstractAnimation,
        3, enummembers_Qt3DAnimation_QAbstractAnimation,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_Qt3DAnimation_QAbstractAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DAnimation_QAbstractAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_Qt3DAnimation_QAbstractAnimation,
    cast_Qt3DAnimation_QAbstractAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
