/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DAnimation.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 73 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyFrame.cpp"

#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector2d.sip"
#include <qvector2d.h>
#line 77 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyFrame.cpp"


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame_setCoordinates, "setCoordinates(self, coords: QVector2D)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyFrame_setCoordinates(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyFrame_setCoordinates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector2D* a0;
        ::Qt3DAnimation::QKeyFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DAnimation_QKeyFrame, &sipCpp, sipType_QVector2D, &a0))
        {
            sipCpp->setCoordinates(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyFrame, sipName_setCoordinates, doc_Qt3DAnimation_QKeyFrame_setCoordinates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame_coordinates, "coordinates(self) -> QVector2D");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyFrame_coordinates(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyFrame_coordinates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyFrame, &sipCpp))
        {
            ::QVector2D*sipRes;

            sipRes = new ::QVector2D(sipCpp->coordinates());

            return sipConvertFromNewType(sipRes, sipType_QVector2D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyFrame, sipName_coordinates, doc_Qt3DAnimation_QKeyFrame_coordinates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame_setLeftControlPoint, "setLeftControlPoint(self, lh: QVector2D)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyFrame_setLeftControlPoint(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyFrame_setLeftControlPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector2D* a0;
        ::Qt3DAnimation::QKeyFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DAnimation_QKeyFrame, &sipCpp, sipType_QVector2D, &a0))
        {
            sipCpp->setLeftControlPoint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyFrame, sipName_setLeftControlPoint, doc_Qt3DAnimation_QKeyFrame_setLeftControlPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame_leftControlPoint, "leftControlPoint(self) -> QVector2D");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyFrame_leftControlPoint(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyFrame_leftControlPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyFrame, &sipCpp))
        {
            ::QVector2D*sipRes;

            sipRes = new ::QVector2D(sipCpp->leftControlPoint());

            return sipConvertFromNewType(sipRes, sipType_QVector2D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyFrame, sipName_leftControlPoint, doc_Qt3DAnimation_QKeyFrame_leftControlPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame_setRightControlPoint, "setRightControlPoint(self, rh: QVector2D)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyFrame_setRightControlPoint(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyFrame_setRightControlPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector2D* a0;
        ::Qt3DAnimation::QKeyFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DAnimation_QKeyFrame, &sipCpp, sipType_QVector2D, &a0))
        {
            sipCpp->setRightControlPoint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyFrame, sipName_setRightControlPoint, doc_Qt3DAnimation_QKeyFrame_setRightControlPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame_rightControlPoint, "rightControlPoint(self) -> QVector2D");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyFrame_rightControlPoint(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyFrame_rightControlPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyFrame, &sipCpp))
        {
            ::QVector2D*sipRes;

            sipRes = new ::QVector2D(sipCpp->rightControlPoint());

            return sipConvertFromNewType(sipRes, sipType_QVector2D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyFrame, sipName_rightControlPoint, doc_Qt3DAnimation_QKeyFrame_rightControlPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame_setInterpolationType, "setInterpolationType(self, interp: QKeyFrame.InterpolationType)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyFrame_setInterpolationType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyFrame_setInterpolationType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QKeyFrame::InterpolationType a0;
        ::Qt3DAnimation::QKeyFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DAnimation_QKeyFrame, &sipCpp, sipType_Qt3DAnimation_QKeyFrame_InterpolationType, &a0))
        {
            sipCpp->setInterpolationType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyFrame, sipName_setInterpolationType, doc_Qt3DAnimation_QKeyFrame_setInterpolationType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame_interpolationType, "interpolationType(self) -> QKeyFrame.InterpolationType");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyFrame_interpolationType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyFrame_interpolationType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyFrame, &sipCpp))
        {
            ::Qt3DAnimation::QKeyFrame::InterpolationType sipRes;

            sipRes = sipCpp->interpolationType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DAnimation_QKeyFrame_InterpolationType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyFrame, sipName_interpolationType, doc_Qt3DAnimation_QKeyFrame_interpolationType);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_Qt3DAnimation_QKeyFrame___eq__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DAnimation_QKeyFrame___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DAnimation::QKeyFrame *sipCpp = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DAnimation_QKeyFrame));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyFrame* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DAnimation_QKeyFrame, &a0))
        {
            bool sipRes;

            sipRes = ::Qt3DAnimation::operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DAnimation, eq_slot, sipType_Qt3DAnimation_QKeyFrame, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_Qt3DAnimation_QKeyFrame___ne__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DAnimation_QKeyFrame___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DAnimation::QKeyFrame *sipCpp = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DAnimation_QKeyFrame));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyFrame* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DAnimation_QKeyFrame, &a0))
        {
            bool sipRes;

            sipRes = ::Qt3DAnimation::operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DAnimation, ne_slot, sipType_Qt3DAnimation_QKeyFrame, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DAnimation_QKeyFrame(void *, int);}
static void release_Qt3DAnimation_QKeyFrame(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(sipCppV);
}


extern "C" {static void *array_Qt3DAnimation_QKeyFrame(Py_ssize_t);}
static void *array_Qt3DAnimation_QKeyFrame(Py_ssize_t sipNrElem)
{
    return new ::Qt3DAnimation::QKeyFrame[sipNrElem];
}


extern "C" {static void array_delete_Qt3DAnimation_QKeyFrame(void *);}
static void array_delete_Qt3DAnimation_QKeyFrame(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(sipCpp);
}


extern "C" {static void assign_Qt3DAnimation_QKeyFrame(void *, Py_ssize_t, void *);}
static void assign_Qt3DAnimation_QKeyFrame(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(sipSrc);
}


extern "C" {static void *copy_Qt3DAnimation_QKeyFrame(const void *, Py_ssize_t);}
static void *copy_Qt3DAnimation_QKeyFrame(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::Qt3DAnimation::QKeyFrame(reinterpret_cast<const ::Qt3DAnimation::QKeyFrame *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_Qt3DAnimation_QKeyFrame(sipSimpleWrapper *);}
static void dealloc_Qt3DAnimation_QKeyFrame(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DAnimation_QKeyFrame(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_Qt3DAnimation_QKeyFrame(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DAnimation_QKeyFrame(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::Qt3DAnimation::QKeyFrame *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::Qt3DAnimation::QKeyFrame();

            return sipCpp;
        }
    }

    {
        ::QVector2D* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QVector2D, &a0))
        {
            sipCpp = new ::Qt3DAnimation::QKeyFrame(*a0);

            return sipCpp;
        }
    }

    {
        ::QVector2D* a0;
        ::QVector2D* a1;
        ::QVector2D* a2;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J9J9", sipType_QVector2D, &a0, sipType_QVector2D, &a1, sipType_QVector2D, &a2))
        {
            sipCpp = new ::Qt3DAnimation::QKeyFrame(*a0, *a1, *a2);

            return sipCpp;
        }
    }

    {
        const ::Qt3DAnimation::QKeyFrame* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_Qt3DAnimation_QKeyFrame, &a0))
        {
            sipCpp = new ::Qt3DAnimation::QKeyFrame(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_Qt3DAnimation_QKeyFrame[] = {
    {(void *)slot_Qt3DAnimation_QKeyFrame___eq__, eq_slot},
    {(void *)slot_Qt3DAnimation_QKeyFrame___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_Qt3DAnimation_QKeyFrame[] = {
    {sipName_coordinates, meth_Qt3DAnimation_QKeyFrame_coordinates, METH_VARARGS, doc_Qt3DAnimation_QKeyFrame_coordinates},
    {sipName_interpolationType, meth_Qt3DAnimation_QKeyFrame_interpolationType, METH_VARARGS, doc_Qt3DAnimation_QKeyFrame_interpolationType},
    {sipName_leftControlPoint, meth_Qt3DAnimation_QKeyFrame_leftControlPoint, METH_VARARGS, doc_Qt3DAnimation_QKeyFrame_leftControlPoint},
    {sipName_rightControlPoint, meth_Qt3DAnimation_QKeyFrame_rightControlPoint, METH_VARARGS, doc_Qt3DAnimation_QKeyFrame_rightControlPoint},
    {sipName_setCoordinates, meth_Qt3DAnimation_QKeyFrame_setCoordinates, METH_VARARGS, doc_Qt3DAnimation_QKeyFrame_setCoordinates},
    {sipName_setInterpolationType, meth_Qt3DAnimation_QKeyFrame_setInterpolationType, METH_VARARGS, doc_Qt3DAnimation_QKeyFrame_setInterpolationType},
    {sipName_setLeftControlPoint, meth_Qt3DAnimation_QKeyFrame_setLeftControlPoint, METH_VARARGS, doc_Qt3DAnimation_QKeyFrame_setLeftControlPoint},
    {sipName_setRightControlPoint, meth_Qt3DAnimation_QKeyFrame_setRightControlPoint, METH_VARARGS, doc_Qt3DAnimation_QKeyFrame_setRightControlPoint}
};

static sipEnumMemberDef enummembers_Qt3DAnimation_QKeyFrame[] = {
    {sipName_BezierInterpolation, static_cast<int>(::Qt3DAnimation::QKeyFrame::BezierInterpolation), 31},
    {sipName_ConstantInterpolation, static_cast<int>(::Qt3DAnimation::QKeyFrame::ConstantInterpolation), 31},
    {sipName_LinearInterpolation, static_cast<int>(::Qt3DAnimation::QKeyFrame::LinearInterpolation), 31},
};

PyDoc_STRVAR(doc_Qt3DAnimation_QKeyFrame, "\1QKeyFrame()\n"
"QKeyFrame(coords: QVector2D)\n"
"QKeyFrame(coords: QVector2D, lh: QVector2D, rh: QVector2D)\n"
"QKeyFrame(a0: QKeyFrame)");


static pyqt5ClassPluginDef plugin_Qt3DAnimation_QKeyFrame = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QKeyFrame = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DAnimation__QKeyFrame,
        SIP_NULLPTR,
        &plugin_Qt3DAnimation_QKeyFrame,
    },
    {
        sipNameNr_QKeyFrame,
        {0, 0, 1},
        8, methods_Qt3DAnimation_QKeyFrame,
        3, enummembers_Qt3DAnimation_QKeyFrame,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DAnimation_QKeyFrame,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_Qt3DAnimation_QKeyFrame,
    init_type_Qt3DAnimation_QKeyFrame,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DAnimation_QKeyFrame,
    assign_Qt3DAnimation_QKeyFrame,
    array_Qt3DAnimation_QKeyFrame,
    copy_Qt3DAnimation_QKeyFrame,
    release_Qt3DAnimation_QKeyFrame,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DAnimation_QKeyFrame,
    sizeof (::Qt3DAnimation::QKeyFrame),
};
