/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _Qt3DExtrasAPI_H
#define _Qt3DExtrasAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_Qt3DExtras__QNormalDiffuseSpecularMapMaterial 0
#define sipName_Qt3DExtras__QNormalDiffuseSpecularMapMaterial &sipStrings_Qt3DExtras[0]
#define sipNameNr_Qt3DExtras__QNormalDiffuseMapAlphaMaterial 46
#define sipName_Qt3DExtras__QNormalDiffuseMapAlphaMaterial &sipStrings_Qt3DExtras[46]
#define sipNameNr_Qt3DExtras__QFirstPersonCameraController 89
#define sipName_Qt3DExtras__QFirstPersonCameraController &sipStrings_Qt3DExtras[89]
#define sipNameNr_Qt3DExtras__QDiffuseSpecularMapMaterial 130
#define sipName_Qt3DExtras__QDiffuseSpecularMapMaterial &sipStrings_Qt3DExtras[130]
#define sipNameNr_Qt3DExtras__QTexturedMetalRoughMaterial 170
#define sipName_Qt3DExtras__QTexturedMetalRoughMaterial &sipStrings_Qt3DExtras[170]
#define sipNameNr_210 210
#define sipName_210 &sipStrings_Qt3DExtras[210]
#define sipNameNr_Qt3DExtras__QAbstractCameraController 249
#define sipName_Qt3DExtras__QAbstractCameraController &sipStrings_Qt3DExtras[249]
#define sipNameNr_Qt3DExtras__QNormalDiffuseMapMaterial 287
#define sipName_Qt3DExtras__QNormalDiffuseMapMaterial &sipStrings_Qt3DExtras[287]
#define sipNameNr_Qt3DExtras__QDiffuseSpecularMaterial 325
#define sipName_Qt3DExtras__QDiffuseSpecularMaterial &sipStrings_Qt3DExtras[325]
#define sipNameNr_Qt3DExtras__QPerVertexColorMaterial 362
#define sipName_Qt3DExtras__QPerVertexColorMaterial &sipStrings_Qt3DExtras[362]
#define sipNameNr_Qt3DExtras__QOrbitCameraController 398
#define sipName_Qt3DExtras__QOrbitCameraController &sipStrings_Qt3DExtras[398]
#define sipNameNr_QNormalDiffuseSpecularMapMaterial 12
#define sipName_QNormalDiffuseSpecularMapMaterial &sipStrings_Qt3DExtras[12]
#define sipNameNr_Qt3DExtras__QExtrudedTextGeometry 433
#define sipName_Qt3DExtras__QExtrudedTextGeometry &sipStrings_Qt3DExtras[433]
#define sipNameNr_Qt3DExtras__QAbstractSpriteSheet 467
#define sipName_Qt3DExtras__QAbstractSpriteSheet &sipStrings_Qt3DExtras[467]
#define sipNameNr_Qt3DExtras__QDiffuseMapMaterial 500
#define sipName_Qt3DExtras__QDiffuseMapMaterial &sipStrings_Qt3DExtras[500]
#define sipNameNr_Qt3DExtras__QMetalRoughMaterial 532
#define sipName_Qt3DExtras__QMetalRoughMaterial &sipStrings_Qt3DExtras[532]
#define sipNameNr_Qt3DExtras__QMorphPhongMaterial 564
#define sipName_Qt3DExtras__QMorphPhongMaterial &sipStrings_Qt3DExtras[564]
#define sipNameNr_Qt3DExtras__QPhongAlphaMaterial 596
#define sipName_Qt3DExtras__QPhongAlphaMaterial &sipStrings_Qt3DExtras[596]
#define sipNameNr_externalRenderTargetSizeChanged 628
#define sipName_externalRenderTargetSizeChanged &sipStrings_Qt3DExtras[628]
#define sipNameNr_QNormalDiffuseMapAlphaMaterial 58
#define sipName_QNormalDiffuseMapAlphaMaterial &sipStrings_Qt3DExtras[58]
#define sipNameNr_Qt3DExtras__QCylinderGeometry 660
#define sipName_Qt3DExtras__QCylinderGeometry &sipStrings_Qt3DExtras[660]
#define sipNameNr_Qt3DExtras__QExtrudedTextMesh 690
#define sipName_Qt3DExtras__QExtrudedTextMesh &sipStrings_Qt3DExtras[690]
#define sipNameNr_QFirstPersonCameraController 101
#define sipName_QFirstPersonCameraController &sipStrings_Qt3DExtras[101]
#define sipNameNr_Qt3DExtras__QForwardRenderer 720
#define sipName_Qt3DExtras__QForwardRenderer &sipStrings_Qt3DExtras[720]
#define sipNameNr_Qt3DExtras__QSpriteSheetItem 749
#define sipName_Qt3DExtras__QSpriteSheetItem &sipStrings_Qt3DExtras[749]
#define sipNameNr_Qt3DExtras__QTextureMaterial 778
#define sipName_Qt3DExtras__QTextureMaterial &sipStrings_Qt3DExtras[778]
#define sipNameNr_frustumCullingEnabledChanged 807
#define sipName_frustumCullingEnabledChanged &sipStrings_Qt3DExtras[807]
#define sipNameNr_QDiffuseSpecularMapMaterial 142
#define sipName_QDiffuseSpecularMapMaterial &sipStrings_Qt3DExtras[142]
#define sipNameNr_QTexturedMetalRoughMaterial 182
#define sipName_QTexturedMetalRoughMaterial &sipStrings_Qt3DExtras[182]
#define sipNameNr_Qt3DExtras__QCuboidGeometry 836
#define sipName_Qt3DExtras__QCuboidGeometry &sipStrings_Qt3DExtras[836]
#define sipNameNr_Qt3DExtras__QSphereGeometry 864
#define sipName_Qt3DExtras__QSphereGeometry &sipStrings_Qt3DExtras[864]
#define sipNameNr_alphaBlendingEnabledChanged 892
#define sipName_alphaBlendingEnabledChanged &sipStrings_Qt3DExtras[892]
#define sipNameNr_setExternalRenderTargetSize 920
#define sipName_setExternalRenderTargetSize &sipStrings_Qt3DExtras[920]
#define sipNameNr_Qt3DExtras__QGoochMaterial 948
#define sipName_Qt3DExtras__QGoochMaterial &sipStrings_Qt3DExtras[948]
#define sipNameNr_Qt3DExtras__QPhongMaterial 975
#define sipName_Qt3DExtras__QPhongMaterial &sipStrings_Qt3DExtras[975]
#define sipNameNr_Qt3DExtras__QPlaneGeometry 1002
#define sipName_Qt3DExtras__QPlaneGeometry &sipStrings_Qt3DExtras[1002]
#define sipNameNr_Qt3DExtras__QTorusGeometry 1029
#define sipName_Qt3DExtras__QTorusGeometry &sipStrings_Qt3DExtras[1029]
#define sipNameNr_destinationAlphaArgChanged 1056
#define sipName_destinationAlphaArgChanged &sipStrings_Qt3DExtras[1056]
#define sipNameNr_gammaCorrectEnabledChanged 1083
#define sipName_gammaCorrectEnabledChanged &sipStrings_Qt3DExtras[1083]
#define sipNameNr_QAbstractCameraController 261
#define sipName_QAbstractCameraController &sipStrings_Qt3DExtras[261]
#define sipNameNr_QNormalDiffuseMapMaterial 299
#define sipName_QNormalDiffuseMapMaterial &sipStrings_Qt3DExtras[299]
#define sipNameNr_Qt3DExtras__QConeGeometry 1110
#define sipName_Qt3DExtras__QConeGeometry &sipStrings_Qt3DExtras[1110]
#define sipNameNr_Qt3DExtras__QCylinderMesh 1136
#define sipName_Qt3DExtras__QCylinderMesh &sipStrings_Qt3DExtras[1136]
#define sipNameNr_Qt3DExtras__QSkyboxEntity 1162
#define sipName_Qt3DExtras__QSkyboxEntity &sipStrings_Qt3DExtras[1162]
#define sipNameNr_Qt3DExtras__QText2DEntity 1188
#define sipName_Qt3DExtras__QText2DEntity &sipStrings_Qt3DExtras[1188]
#define sipNameNr_QDiffuseSpecularMaterial 337
#define sipName_QDiffuseSpecularMaterial &sipStrings_Qt3DExtras[337]
#define sipNameNr_Qt3DExtras__QSpriteSheet 1214
#define sipName_Qt3DExtras__QSpriteSheet &sipStrings_Qt3DExtras[1214]
#define sipNameNr_destinationRgbArgChanged 1239
#define sipName_destinationRgbArgChanged &sipStrings_Qt3DExtras[1239]
#define sipNameNr_externalRenderTargetSize 1264
#define sipName_externalRenderTargetSize &sipStrings_Qt3DExtras[1264]
#define sipNameNr_setFrustumCullingEnabled 1289
#define sipName_setFrustumCullingEnabled &sipStrings_Qt3DExtras[1289]
#define sipNameNr_QPerVertexColorMaterial 374
#define sipName_QPerVertexColorMaterial &sipStrings_Qt3DExtras[374]
#define sipNameNr_Qt3DExtras__QCuboidMesh 1314
#define sipName_Qt3DExtras__QCuboidMesh &sipStrings_Qt3DExtras[1314]
#define sipNameNr_Qt3DExtras__QSphereMesh 1338
#define sipName_Qt3DExtras__QSphereMesh &sipStrings_Qt3DExtras[1338]
#define sipNameNr_Qt3DExtras__QSpriteGrid 1362
#define sipName_Qt3DExtras__QSpriteGrid &sipStrings_Qt3DExtras[1362]
#define sipNameNr_ambientOcclusionChanged 1386
#define sipName_ambientOcclusionChanged &sipStrings_Qt3DExtras[1386]
#define sipNameNr_blendFunctionArgChanged 1410
#define sipName_blendFunctionArgChanged &sipStrings_Qt3DExtras[1410]
#define sipNameNr_generateTangentsChanged 1434
#define sipName_generateTangentsChanged &sipStrings_Qt3DExtras[1434]
#define sipNameNr_isFrustumCullingEnabled 1458
#define sipName_isFrustumCullingEnabled &sipStrings_Qt3DExtras[1458]
#define sipNameNr_setAlphaBlendingEnabled 1482
#define sipName_setAlphaBlendingEnabled &sipStrings_Qt3DExtras[1482]
#define sipNameNr_showDebugOverlayChanged 1506
#define sipName_showDebugOverlayChanged &sipStrings_Qt3DExtras[1506]
#define sipNameNr_textureTransformChanged 1530
#define sipName_textureTransformChanged &sipStrings_Qt3DExtras[1530]
#define sipNameNr_xyMeshResolutionChanged 1554
#define sipName_xyMeshResolutionChanged &sipStrings_Qt3DExtras[1554]
#define sipNameNr_xzMeshResolutionChanged 1578
#define sipName_xzMeshResolutionChanged &sipStrings_Qt3DExtras[1578]
#define sipNameNr_yzMeshResolutionChanged 1602
#define sipName_yzMeshResolutionChanged &sipStrings_Qt3DExtras[1602]
#define sipNameNr_QOrbitCameraController 410
#define sipName_QOrbitCameraController &sipStrings_Qt3DExtras[410]
#define sipNameNr_Qt3DExtras__QPlaneMesh 1626
#define sipName_Qt3DExtras__QPlaneMesh &sipStrings_Qt3DExtras[1626]
#define sipNameNr_Qt3DExtras__QTorusMesh 1649
#define sipName_Qt3DExtras__QTorusMesh &sipStrings_Qt3DExtras[1649]
#define sipNameNr_Qt3DExtras__Qt3DWindow 1672
#define sipName_Qt3DExtras__Qt3DWindow &sipStrings_Qt3DExtras[1672]
#define sipNameNr_hasBottomEndcapChanged 1695
#define sipName_hasBottomEndcapChanged &sipStrings_Qt3DExtras[1695]
#define sipNameNr_isAlphaBlendingEnabled 1718
#define sipName_isAlphaBlendingEnabled &sipStrings_Qt3DExtras[1718]
#define sipNameNr_setDestinationAlphaArg 1741
#define sipName_setDestinationAlphaArg &sipStrings_Qt3DExtras[1741]
#define sipNameNr_setGammaCorrectEnabled 1764
#define sipName_setGammaCorrectEnabled &sipStrings_Qt3DExtras[1764]
#define sipNameNr_QExtrudedTextGeometry 445
#define sipName_QExtrudedTextGeometry &sipStrings_Qt3DExtras[445]
#define sipNameNr_Qt3DExtras__QConeMesh 1787
#define sipName_Qt3DExtras__QConeMesh &sipStrings_Qt3DExtras[1787]
#define sipNameNr_buffersToClearChanged 1809
#define sipName_buffersToClearChanged &sipStrings_Qt3DExtras[1809]
#define sipNameNr_isGammaCorrectEnabled 1831
#define sipName_isGammaCorrectEnabled &sipStrings_Qt3DExtras[1831]
#define sipNameNr_meshResolutionChanged 1853
#define sipName_meshResolutionChanged &sipStrings_Qt3DExtras[1853]
#define sipNameNr_mouseDoubleClickEvent 1875
#define sipName_mouseDoubleClickEvent &sipStrings_Qt3DExtras[1875]
#define sipNameNr_sourceAlphaArgChanged 1897
#define sipName_sourceAlphaArgChanged &sipStrings_Qt3DExtras[1897]
#define sipNameNr_QAbstractSpriteSheet 479
#define sipName_QAbstractSpriteSheet &sipStrings_Qt3DExtras[479]
#define sipNameNr_setDestinationRgbArg 1919
#define sipName_setDestinationRgbArg &sipStrings_Qt3DExtras[1919]
#define sipNameNr_textureOffsetChanged 1940
#define sipName_textureOffsetChanged &sipStrings_Qt3DExtras[1940]
#define sipNameNr_QDiffuseMapMaterial 512
#define sipName_QDiffuseMapMaterial &sipStrings_Qt3DExtras[512]
#define sipNameNr_QMetalRoughMaterial 544
#define sipName_QMetalRoughMaterial &sipStrings_Qt3DExtras[544]
#define sipNameNr_QMorphPhongMaterial 576
#define sipName_QMorphPhongMaterial &sipStrings_Qt3DExtras[576]
#define sipNameNr_QPhongAlphaMaterial 608
#define sipName_QPhongAlphaMaterial &sipStrings_Qt3DExtras[608]
#define sipNameNr_accelerationChanged 1961
#define sipName_accelerationChanged &sipStrings_Qt3DExtras[1961]
#define sipNameNr_bottomRadiusChanged 1981
#define sipName_bottomRadiusChanged &sipStrings_Qt3DExtras[1981]
#define sipNameNr_currentIndexChanged 2001
#define sipName_currentIndexChanged &sipStrings_Qt3DExtras[2001]
#define sipNameNr_decelerationChanged 2021
#define sipName_decelerationChanged &sipStrings_Qt3DExtras[2021]
#define sipNameNr_destinationAlphaArg 2041
#define sipName_destinationAlphaArg &sipStrings_Qt3DExtras[2041]
#define sipNameNr_hasTopEndcapChanged 2061
#define sipName_hasTopEndcapChanged &sipStrings_Qt3DExtras[2061]
#define sipNameNr_interpolatorChanged 2081
#define sipName_interpolatorChanged &sipStrings_Qt3DExtras[2081]
#define sipNameNr_setActiveFrameGraph 2101
#define sipName_setActiveFrameGraph &sipStrings_Qt3DExtras[2101]
#define sipNameNr_setAmbientOcclusion 2121
#define sipName_setAmbientOcclusion &sipStrings_Qt3DExtras[2121]
#define sipNameNr_setBlendFunctionArg 2141
#define sipName_setBlendFunctionArg &sipStrings_Qt3DExtras[2141]
#define sipNameNr_setGenerateTangents 2161
#define sipName_setGenerateTangents &sipStrings_Qt3DExtras[2161]
#define sipNameNr_setShowDebugOverlay 2181
#define sipName_setShowDebugOverlay &sipStrings_Qt3DExtras[2181]
#define sipNameNr_setTextureTransform 2201
#define sipName_setTextureTransform &sipStrings_Qt3DExtras[2201]
#define sipNameNr_setXYMeshResolution 2221
#define sipName_setXYMeshResolution &sipStrings_Qt3DExtras[2221]
#define sipNameNr_setXZMeshResolution 2241
#define sipName_setXZMeshResolution &sipStrings_Qt3DExtras[2241]
#define sipNameNr_setYZMeshResolution 2261
#define sipName_setYZMeshResolution &sipStrings_Qt3DExtras[2261]
#define sipNameNr_sourceRgbArgChanged 2281
#define sipName_sourceRgbArgChanged &sipStrings_Qt3DExtras[2281]
#define sipNameNr_textureScaleChanged 2301
#define sipName_textureScaleChanged &sipStrings_Qt3DExtras[2301]
#define sipNameNr_viewportRectChanged 2321
#define sipName_viewportRectChanged &sipStrings_Qt3DExtras[2321]
#define sipNameNr_linearSpeedChanged 2341
#define sipName_linearSpeedChanged &sipStrings_Qt3DExtras[2341]
#define sipNameNr_minorRadiusChanged 2360
#define sipName_minorRadiusChanged &sipStrings_Qt3DExtras[2360]
#define sipNameNr_setHasBottomEndcap 2379
#define sipName_setHasBottomEndcap &sipStrings_Qt3DExtras[2379]
#define sipNameNr_zoomInLimitChanged 2398
#define sipName_zoomInLimitChanged &sipStrings_Qt3DExtras[2398]
#define sipNameNr_QCylinderGeometry 672
#define sipName_QCylinderGeometry &sipStrings_Qt3DExtras[672]
#define sipNameNr_QExtrudedTextMesh 702
#define sipName_QExtrudedTextMesh &sipStrings_Qt3DExtras[702]
#define sipNameNr_clearColorChanged 2417
#define sipName_clearColorChanged &sipStrings_Qt3DExtras[2417]
#define sipNameNr_defaultFrameGraph 2435
#define sipName_defaultFrameGraph &sipStrings_Qt3DExtras[2435]
#define sipNameNr_destinationRgbArg 2453
#define sipName_destinationRgbArg &sipStrings_Qt3DExtras[2453]
#define sipNameNr_mouseReleaseEvent 2471
#define sipName_mouseReleaseEvent &sipStrings_Qt3DExtras[2471]
#define sipNameNr_positionAttribute 2489
#define sipName_positionAttribute &sipStrings_Qt3DExtras[2489]
#define sipNameNr_resolutionChanged 2507
#define sipName_resolutionChanged &sipStrings_Qt3DExtras[2507]
#define sipNameNr_setBuffersToClear 2525
#define sipName_setBuffersToClear &sipStrings_Qt3DExtras[2525]
#define sipNameNr_setMeshResolution 2543
#define sipName_setMeshResolution &sipStrings_Qt3DExtras[2543]
#define sipNameNr_setSourceAlphaArg 2561
#define sipName_setSourceAlphaArg &sipStrings_Qt3DExtras[2561]
#define sipNameNr_texCoordAttribute 2579
#define sipName_texCoordAttribute &sipStrings_Qt3DExtras[2579]
#define sipNameNr_PyQt5_Qt3DExtras 2597
#define sipName_PyQt5_Qt3DExtras &sipStrings_Qt3DExtras[2597]
#define sipNameNr_QForwardRenderer 732
#define sipName_QForwardRenderer &sipStrings_Qt3DExtras[732]
#define sipNameNr_QSpriteSheetItem 761
#define sipName_QSpriteSheetItem &sipStrings_Qt3DExtras[761]
#define sipNameNr_QTextureMaterial 790
#define sipName_QTextureMaterial &sipStrings_Qt3DExtras[790]
#define sipNameNr_activeFrameGraph 2614
#define sipName_activeFrameGraph &sipStrings_Qt3DExtras[2614]
#define sipNameNr_ambientOcclusion 2631
#define sipName_ambientOcclusion &sipStrings_Qt3DExtras[2631]
#define sipNameNr_baseColorChanged 2648
#define sipName_baseColorChanged &sipStrings_Qt3DExtras[2648]
#define sipNameNr_blendFunctionArg 2665
#define sipName_blendFunctionArg &sipStrings_Qt3DExtras[2665]
#define sipNameNr_disconnectNotify 2682
#define sipName_disconnectNotify &sipStrings_Qt3DExtras[2682]
#define sipNameNr_extensionChanged 2699
#define sipName_extensionChanged &sipStrings_Qt3DExtras[2699]
#define sipNameNr_generateTangents 2716
#define sipName_generateTangents &sipStrings_Qt3DExtras[2716]
#define sipNameNr_lookSpeedChanged 2733
#define sipName_lookSpeedChanged &sipStrings_Qt3DExtras[2733]
#define sipNameNr_metalnessChanged 2750
#define sipName_metalnessChanged &sipStrings_Qt3DExtras[2750]
#define sipNameNr_roughnessChanged 2767
#define sipName_roughnessChanged &sipStrings_Qt3DExtras[2767]
#define sipNameNr_sceneChangeEvent 2784
#define sipName_sceneChangeEvent &sipStrings_Qt3DExtras[2784]
#define sipNameNr_setTextureOffset 2801
#define sipName_setTextureOffset &sipStrings_Qt3DExtras[2801]
#define sipNameNr_shininessChanged 2818
#define sipName_shininessChanged &sipStrings_Qt3DExtras[2818]
#define sipNameNr_showDebugOverlay 2835
#define sipName_showDebugOverlay &sipStrings_Qt3DExtras[2835]
#define sipNameNr_tangentAttribute 2852
#define sipName_tangentAttribute &sipStrings_Qt3DExtras[2852]
#define sipNameNr_textureTransform 2869
#define sipName_textureTransform &sipStrings_Qt3DExtras[2869]
#define sipNameNr_topRadiusChanged 2886
#define sipName_topRadiusChanged &sipStrings_Qt3DExtras[2886]
#define sipNameNr_xyMeshResolution 2903
#define sipName_xyMeshResolution &sipStrings_Qt3DExtras[2903]
#define sipNameNr_xzMeshResolution 2920
#define sipName_xzMeshResolution &sipStrings_Qt3DExtras[2920]
#define sipNameNr_yzMeshResolution 2937
#define sipName_yzMeshResolution &sipStrings_Qt3DExtras[2937]
#define sipNameNr_QCuboidGeometry 848
#define sipName_QCuboidGeometry &sipStrings_Qt3DExtras[848]
#define sipNameNr_QSphereGeometry 876
#define sipName_QSphereGeometry &sipStrings_Qt3DExtras[876]
#define sipNameNr_baseNameChanged 2954
#define sipName_baseNameChanged &sipStrings_Qt3DExtras[2954]
#define sipNameNr_extrusionLength 2970
#define sipName_extrusionLength &sipStrings_Qt3DExtras[2970]
#define sipNameNr_hasBottomEndcap 2986
#define sipName_hasBottomEndcap &sipStrings_Qt3DExtras[2986]
#define sipNameNr_keyReleaseEvent 3002
#define sipName_keyReleaseEvent &sipStrings_Qt3DExtras[3002]
#define sipNameNr_mirroredChanged 3018
#define sipName_mirroredChanged &sipStrings_Qt3DExtras[3018]
#define sipNameNr_mousePressEvent 3034
#define sipName_mousePressEvent &sipStrings_Qt3DExtras[3034]
#define sipNameNr_normalAttribute 3050
#define sipName_normalAttribute &sipStrings_Qt3DExtras[3050]
#define sipNameNr_setAcceleration 3066
#define sipName_setAcceleration &sipStrings_Qt3DExtras[3066]
#define sipNameNr_setBottomRadius 3082
#define sipName_setBottomRadius &sipStrings_Qt3DExtras[3082]
#define sipNameNr_setCurrentIndex 3098
#define sipName_setCurrentIndex &sipStrings_Qt3DExtras[3098]
#define sipNameNr_setDeceleration 3114
#define sipName_setDeceleration &sipStrings_Qt3DExtras[3114]
#define sipNameNr_setHasTopEndcap 3130
#define sipName_setHasTopEndcap &sipStrings_Qt3DExtras[3130]
#define sipNameNr_setInterpolator 3146
#define sipName_setInterpolator &sipStrings_Qt3DExtras[3146]
#define sipNameNr_setSourceRgbArg 3162
#define sipName_setSourceRgbArg &sipStrings_Qt3DExtras[3162]
#define sipNameNr_setTextureScale 3178
#define sipName_setTextureScale &sipStrings_Qt3DExtras[3178]
#define sipNameNr_setViewportRect 3194
#define sipName_setViewportRect &sipStrings_Qt3DExtras[3194]
#define sipNameNr_specularChanged 3210
#define sipName_specularChanged &sipStrings_Qt3DExtras[3210]
#define sipNameNr_QGoochMaterial 960
#define sipName_QGoochMaterial &sipStrings_Qt3DExtras[960]
#define sipNameNr_QPhongMaterial 987
#define sipName_QPhongMaterial &sipStrings_Qt3DExtras[987]
#define sipNameNr_QPlaneGeometry 1014
#define sipName_QPlaneGeometry &sipStrings_Qt3DExtras[1014]
#define sipNameNr_QTorusGeometry 1041
#define sipName_QTorusGeometry &sipStrings_Qt3DExtras[1041]
#define sipNameNr_ambientChanged 3226
#define sipName_ambientChanged &sipStrings_Qt3DExtras[3226]
#define sipNameNr_buffersToClear 3241
#define sipName_buffersToClear &sipStrings_Qt3DExtras[3241]
#define sipNameNr_columnsChanged 3256
#define sipName_columnsChanged &sipStrings_Qt3DExtras[3256]
#define sipNameNr_diffuseChanged 3271
#define sipName_diffuseChanged &sipStrings_Qt3DExtras[3271]
#define sipNameNr_indexAttribute 3286
#define sipName_indexAttribute &sipStrings_Qt3DExtras[3286]
#define sipNameNr_keyboardDevice 3301
#define sipName_keyboardDevice &sipStrings_Qt3DExtras[3301]
#define sipNameNr_meshResolution 3316
#define sipName_meshResolution &sipStrings_Qt3DExtras[3316]
#define sipNameNr_mouseMoveEvent 3331
#define sipName_mouseMoveEvent &sipStrings_Qt3DExtras[3331]
#define sipNameNr_registerAspect 3346
#define sipName_registerAspect &sipStrings_Qt3DExtras[3346]
#define sipNameNr_renderSettings 3361
#define sipName_renderSettings &sipStrings_Qt3DExtras[3361]
#define sipNameNr_setLinearSpeed 3376
#define sipName_setLinearSpeed &sipStrings_Qt3DExtras[3376]
#define sipNameNr_setMinorRadius 3391
#define sipName_setMinorRadius &sipStrings_Qt3DExtras[3391]
#define sipNameNr_setZoomInLimit 3406
#define sipName_setZoomInLimit &sipStrings_Qt3DExtras[3406]
#define sipNameNr_sourceAlphaArg 3421
#define sipName_sourceAlphaArg &sipStrings_Qt3DExtras[3421]
#define sipNameNr_spritesChanged 3436
#define sipName_spritesChanged &sipStrings_Qt3DExtras[3436]
#define sipNameNr_surfaceChanged 3451
#define sipName_surfaceChanged &sipStrings_Qt3DExtras[3451]
#define sipNameNr_textureChanged 3466
#define sipName_textureChanged &sipStrings_Qt3DExtras[3466]
#define sipNameNr_updateVertices 3481
#define sipName_updateVertices &sipStrings_Qt3DExtras[3481]
#define sipNameNr_xExtentChanged 3496
#define sipName_xExtentChanged &sipStrings_Qt3DExtras[3496]
#define sipNameNr_yExtentChanged 3511
#define sipName_yExtentChanged &sipStrings_Qt3DExtras[3511]
#define sipNameNr_zExtentChanged 3526
#define sipName_zExtentChanged &sipStrings_Qt3DExtras[3526]
#define sipNameNr_QConeGeometry 1122
#define sipName_QConeGeometry &sipStrings_Qt3DExtras[1122]
#define sipNameNr_QCylinderMesh 1148
#define sipName_QCylinderMesh &sipStrings_Qt3DExtras[1148]
#define sipNameNr_QSkyboxEntity 1174
#define sipName_QSkyboxEntity &sipStrings_Qt3DExtras[1174]
#define sipNameNr_QText2DEntity 1200
#define sipName_QText2DEntity &sipStrings_Qt3DExtras[1200]
#define sipNameNr_cameraChanged 3541
#define sipName_cameraChanged &sipStrings_Qt3DExtras[3541]
#define sipNameNr_connectNotify 2685
#define sipName_connectNotify &sipStrings_Qt3DExtras[2685]
#define sipNameNr_focusOutEvent 3555
#define sipName_focusOutEvent &sipStrings_Qt3DExtras[3555]
#define sipNameNr_heightChanged 3569
#define sipName_heightChanged &sipStrings_Qt3DExtras[3569]
#define sipNameNr_keyPressEvent 3583
#define sipName_keyPressEvent &sipStrings_Qt3DExtras[3583]
#define sipNameNr_lengthChanged 3597
#define sipName_lengthChanged &sipStrings_Qt3DExtras[3597]
#define sipNameNr_normalChanged 3611
#define sipName_normalChanged &sipStrings_Qt3DExtras[3611]
#define sipNameNr_radiusChanged 3625
#define sipName_radiusChanged &sipStrings_Qt3DExtras[3625]
#define sipNameNr_setClearColor 3639
#define sipName_setClearColor &sipStrings_Qt3DExtras[3639]
#define sipNameNr_setResolution 3653
#define sipName_setResolution &sipStrings_Qt3DExtras[3653]
#define sipNameNr_setRootEntity 3667
#define sipName_setRootEntity &sipStrings_Qt3DExtras[3667]
#define sipNameNr_slicesChanged 3681
#define sipName_slicesChanged &sipStrings_Qt3DExtras[3681]
#define sipNameNr_textureOffset 3695
#define sipName_textureOffset &sipStrings_Qt3DExtras[3695]
#define sipNameNr_updateIndices 3709
#define sipName_updateIndices &sipStrings_Qt3DExtras[3709]
#define sipNameNr_QSpriteSheet 1226
#define sipName_QSpriteSheet &sipStrings_Qt3DExtras[1226]
#define sipNameNr_acceleration 3723
#define sipName_acceleration &sipStrings_Qt3DExtras[3723]
#define sipNameNr_alphaChanged 3736
#define sipName_alphaChanged &sipStrings_Qt3DExtras[3736]
#define sipNameNr_bottomRadius 3749
#define sipName_bottomRadius &sipStrings_Qt3DExtras[3749]
#define sipNameNr_colorChanged 3762
#define sipName_colorChanged &sipStrings_Qt3DExtras[3762]
#define sipNameNr_currentIndex 3775
#define sipName_currentIndex &sipStrings_Qt3DExtras[3775]
#define sipNameNr_deceleration 3788
#define sipName_deceleration &sipStrings_Qt3DExtras[3788]
#define sipNameNr_depthChanged 3801
#define sipName_depthChanged &sipStrings_Qt3DExtras[3801]
#define sipNameNr_focusInEvent 3814
#define sipName_focusInEvent &sipStrings_Qt3DExtras[3814]
#define sipNameNr_gammaChanged 3827
#define sipName_gammaChanged &sipStrings_Qt3DExtras[3827]
#define sipNameNr_hasTopEndcap 3840
#define sipName_hasTopEndcap &sipStrings_Qt3DExtras[3840]
#define sipNameNr_interpolator 3853
#define sipName_interpolator &sipStrings_Qt3DExtras[3853]
#define sipNameNr_removeSprite 3866
#define sipName_removeSprite &sipStrings_Qt3DExtras[3866]
#define sipNameNr_ringsChanged 3879
#define sipName_ringsChanged &sipStrings_Qt3DExtras[3879]
#define sipNameNr_setBaseColor 3892
#define sipName_setBaseColor &sipStrings_Qt3DExtras[3892]
#define sipNameNr_setExtension 3905
#define sipName_setExtension &sipStrings_Qt3DExtras[3905]
#define sipNameNr_setLookSpeed 3918
#define sipName_setLookSpeed &sipStrings_Qt3DExtras[3918]
#define sipNameNr_setMetalness 3931
#define sipName_setMetalness &sipStrings_Qt3DExtras[3931]
#define sipNameNr_setRoughness 3944
#define sipName_setRoughness &sipStrings_Qt3DExtras[3944]
#define sipNameNr_setShininess 3957
#define sipName_setShininess &sipStrings_Qt3DExtras[3957]
#define sipNameNr_setTopRadius 3970
#define sipName_setTopRadius &sipStrings_Qt3DExtras[3970]
#define sipNameNr_sourceRgbArg 3983
#define sipName_sourceRgbArg &sipStrings_Qt3DExtras[3983]
#define sipNameNr_textureScale 3996
#define sipName_textureScale &sipStrings_Qt3DExtras[3996]
#define sipNameNr_viewportRect 4009
#define sipName_viewportRect &sipStrings_Qt3DExtras[4009]
#define sipNameNr_widthChanged 4022
#define sipName_widthChanged &sipStrings_Qt3DExtras[4022]
#define sipNameNr_QCuboidMesh 1326
#define sipName_QCuboidMesh &sipStrings_Qt3DExtras[1326]
#define sipNameNr_QSphereMesh 1350
#define sipName_QSphereMesh &sipStrings_Qt3DExtras[1350]
#define sipNameNr_QSpriteGrid 1374
#define sipName_QSpriteGrid &sipStrings_Qt3DExtras[1374]
#define sipNameNr_betaChanged 4035
#define sipName_betaChanged &sipStrings_Qt3DExtras[4035]
#define sipNameNr_coolChanged 4047
#define sipName_coolChanged &sipStrings_Qt3DExtras[4047]
#define sipNameNr_customEvent 4059
#define sipName_customEvent &sipStrings_Qt3DExtras[4059]
#define sipNameNr_eventFilter 4071
#define sipName_eventFilter &sipStrings_Qt3DExtras[4071]
#define sipNameNr_exposeEvent 4083
#define sipName_exposeEvent &sipStrings_Qt3DExtras[4083]
#define sipNameNr_focusObject 4095
#define sipName_focusObject &sipStrings_Qt3DExtras[4095]
#define sipNameNr_fontChanged 4107
#define sipName_fontChanged &sipStrings_Qt3DExtras[4107]
#define sipNameNr_linearSpeed 4119
#define sipName_linearSpeed &sipStrings_Qt3DExtras[4119]
#define sipNameNr_minorRadius 4131
#define sipName_minorRadius &sipStrings_Qt3DExtras[4131]
#define sipNameNr_mouseDevice 4143
#define sipName_mouseDevice &sipStrings_Qt3DExtras[4143]
#define sipNameNr_resizeEvent 4155
#define sipName_resizeEvent &sipStrings_Qt3DExtras[4155]
#define sipNameNr_rowsChanged 4167
#define sipName_rowsChanged &sipStrings_Qt3DExtras[4167]
#define sipNameNr_setBaseName 4179
#define sipName_setBaseName &sipStrings_Qt3DExtras[4179]
#define sipNameNr_setMirrored 4191
#define sipName_setMirrored &sipStrings_Qt3DExtras[4191]
#define sipNameNr_setSpecular 4203
#define sipName_setSpecular &sipStrings_Qt3DExtras[4203]
#define sipNameNr_surfaceType 4215
#define sipName_surfaceType &sipStrings_Qt3DExtras[4215]
#define sipNameNr_tabletEvent 4227
#define sipName_tabletEvent &sipStrings_Qt3DExtras[4227]
#define sipNameNr_textChanged 4239
#define sipName_textChanged &sipStrings_Qt3DExtras[4239]
#define sipNameNr_warmChanged 4251
#define sipName_warmChanged &sipStrings_Qt3DExtras[4251]
#define sipNameNr_zoomInLimit 4263
#define sipName_zoomInLimit &sipStrings_Qt3DExtras[4263]
#define sipNameNr_QPlaneMesh 1638
#define sipName_QPlaneMesh &sipStrings_Qt3DExtras[1638]
#define sipNameNr_QTorusMesh 1661
#define sipName_QTorusMesh &sipStrings_Qt3DExtras[1661]
#define sipNameNr_Qt3DExtras 2603
#define sipName_Qt3DExtras &sipStrings_Qt3DExtras[2603]
#define sipNameNr_Qt3DWindow 1684
#define sipName_Qt3DWindow &sipStrings_Qt3DExtras[1684]
#define sipNameNr_childEvent 4275
#define sipName_childEvent &sipStrings_Qt3DExtras[4275]
#define sipNameNr_clearColor 4286
#define sipName_clearColor &sipStrings_Qt3DExtras[4286]
#define sipNameNr_resolution 4297
#define sipName_resolution &sipStrings_Qt3DExtras[4297]
#define sipNameNr_setAmbient 4308
#define sipName_setAmbient &sipStrings_Qt3DExtras[4308]
#define sipNameNr_setColumns 4319
#define sipName_setColumns &sipStrings_Qt3DExtras[4319]
#define sipNameNr_setDiffuse 4330
#define sipName_setDiffuse &sipStrings_Qt3DExtras[4330]
#define sipNameNr_setSprites 4341
#define sipName_setSprites &sipStrings_Qt3DExtras[4341]
#define sipNameNr_setSurface 4352
#define sipName_setSurface &sipStrings_Qt3DExtras[4352]
#define sipNameNr_setTexture 4363
#define sipName_setTexture &sipStrings_Qt3DExtras[4363]
#define sipNameNr_setXExtent 4374
#define sipName_setXExtent &sipStrings_Qt3DExtras[4374]
#define sipNameNr_setYExtent 4385
#define sipName_setYExtent &sipStrings_Qt3DExtras[4385]
#define sipNameNr_setZExtent 4396
#define sipName_setZExtent &sipStrings_Qt3DExtras[4396]
#define sipNameNr_timerEvent 4407
#define sipName_timerEvent &sipStrings_Qt3DExtras[4407]
#define sipNameNr_touchEvent 4418
#define sipName_touchEvent &sipStrings_Qt3DExtras[4418]
#define sipNameNr_wheelEvent 4429
#define sipName_wheelEvent &sipStrings_Qt3DExtras[4429]
#define sipNameNr_QConeMesh 1799
#define sipName_QConeMesh &sipStrings_Qt3DExtras[1799]
#define sipNameNr_addSprite 4440
#define sipName_addSprite &sipStrings_Qt3DExtras[4440]
#define sipNameNr_baseColor 4450
#define sipName_baseColor &sipStrings_Qt3DExtras[4450]
#define sipNameNr_extension 4460
#define sipName_extension &sipStrings_Qt3DExtras[4460]
#define sipNameNr_hideEvent 4470
#define sipName_hideEvent &sipStrings_Qt3DExtras[4470]
#define sipNameNr_lookSpeed 4480
#define sipName_lookSpeed &sipStrings_Qt3DExtras[4480]
#define sipNameNr_metalness 4490
#define sipName_metalness &sipStrings_Qt3DExtras[4490]
#define sipNameNr_moveEvent 4500
#define sipName_moveEvent &sipStrings_Qt3DExtras[4500]
#define sipNameNr_roughness 4510
#define sipName_roughness &sipStrings_Qt3DExtras[4510]
#define sipNameNr_setCamera 4520
#define sipName_setCamera &sipStrings_Qt3DExtras[4520]
#define sipNameNr_setHeight 4530
#define sipName_setHeight &sipStrings_Qt3DExtras[4530]
#define sipNameNr_setLength 4540
#define sipName_setLength &sipStrings_Qt3DExtras[4540]
#define sipNameNr_setNormal 4550
#define sipName_setNormal &sipStrings_Qt3DExtras[4550]
#define sipNameNr_setRadius 4560
#define sipName_setRadius &sipStrings_Qt3DExtras[4560]
#define sipNameNr_setSlices 4570
#define sipName_setSlices &sipStrings_Qt3DExtras[4570]
#define sipNameNr_shininess 4580
#define sipName_shininess &sipStrings_Qt3DExtras[4580]
#define sipNameNr_showEvent 4590
#define sipName_showEvent &sipStrings_Qt3DExtras[4590]
#define sipNameNr_topRadius 4600
#define sipName_topRadius &sipStrings_Qt3DExtras[4600]
#define sipNameNr_baseName 4610
#define sipName_baseName &sipStrings_Qt3DExtras[4610]
#define sipNameNr_mirrored 4619
#define sipName_mirrored &sipStrings_Qt3DExtras[4619]
#define sipNameNr_setAlpha 4628
#define sipName_setAlpha &sipStrings_Qt3DExtras[4628]
#define sipNameNr_setColor 4637
#define sipName_setColor &sipStrings_Qt3DExtras[4637]
#define sipNameNr_setDepth 4646
#define sipName_setDepth &sipStrings_Qt3DExtras[4646]
#define sipNameNr_setGamma 4655
#define sipName_setGamma &sipStrings_Qt3DExtras[4655]
#define sipNameNr_setRings 4664
#define sipName_setRings &sipStrings_Qt3DExtras[4664]
#define sipNameNr_setWidth 4673
#define sipName_setWidth &sipStrings_Qt3DExtras[4673]
#define sipNameNr_specular 4682
#define sipName_specular &sipStrings_Qt3DExtras[4682]
#define sipNameNr_xChanged 2012
#define sipName_xChanged &sipStrings_Qt3DExtras[2012]
#define sipNameNr_yChanged 1521
#define sipName_yChanged &sipStrings_Qt3DExtras[1521]
#define sipNameNr_ambient 4691
#define sipName_ambient &sipStrings_Qt3DExtras[4691]
#define sipNameNr_columns 4699
#define sipName_columns &sipStrings_Qt3DExtras[4699]
#define sipNameNr_diffuse 4707
#define sipName_diffuse &sipStrings_Qt3DExtras[4707]
#define sipNameNr_setBeta 4715
#define sipName_setBeta &sipStrings_Qt3DExtras[4715]
#define sipNameNr_setCool 4723
#define sipName_setCool &sipStrings_Qt3DExtras[4723]
#define sipNameNr_setFont 4731
#define sipName_setFont &sipStrings_Qt3DExtras[4731]
#define sipNameNr_setRows 4739
#define sipName_setRows &sipStrings_Qt3DExtras[4739]
#define sipNameNr_setText 4747
#define sipName_setText &sipStrings_Qt3DExtras[4747]
#define sipNameNr_setWarm 4755
#define sipName_setWarm &sipStrings_Qt3DExtras[4755]
#define sipNameNr_sprites 4763
#define sipName_sprites &sipStrings_Qt3DExtras[4763]
#define sipNameNr_surface 4771
#define sipName_surface &sipStrings_Qt3DExtras[4771]
#define sipNameNr_texture 4779
#define sipName_texture &sipStrings_Qt3DExtras[4779]
#define sipNameNr_xExtent 4787
#define sipName_xExtent &sipStrings_Qt3DExtras[4787]
#define sipNameNr_yExtent 4795
#define sipName_yExtent &sipStrings_Qt3DExtras[4795]
#define sipNameNr_zExtent 4803
#define sipName_zExtent &sipStrings_Qt3DExtras[4803]
#define sipNameNr_camera 4811
#define sipName_camera &sipStrings_Qt3DExtras[4811]
#define sipNameNr_format 4818
#define sipName_format &sipStrings_Qt3DExtras[4818]
#define sipNameNr_height 4825
#define sipName_height &sipStrings_Qt3DExtras[4825]
#define sipNameNr_length 4832
#define sipName_length &sipStrings_Qt3DExtras[4832]
#define sipNameNr_normal 4839
#define sipName_normal &sipStrings_Qt3DExtras[4839]
#define sipNameNr_parent 4846
#define sipName_parent &sipStrings_Qt3DExtras[4846]
#define sipNameNr_radius 4853
#define sipName_radius &sipStrings_Qt3DExtras[4853]
#define sipNameNr_screen 4860
#define sipName_screen &sipStrings_Qt3DExtras[4860]
#define sipNameNr_slices 4867
#define sipName_slices &sipStrings_Qt3DExtras[4867]
#define sipNameNr_alpha 4874
#define sipName_alpha &sipStrings_Qt3DExtras[4874]
#define sipNameNr_color 4880
#define sipName_color &sipStrings_Qt3DExtras[4880]
#define sipNameNr_depth 4886
#define sipName_depth &sipStrings_Qt3DExtras[4886]
#define sipNameNr_event 4892
#define sipName_event &sipStrings_Qt3DExtras[4892]
#define sipNameNr_gamma 4898
#define sipName_gamma &sipStrings_Qt3DExtras[4898]
#define sipNameNr_rings 4904
#define sipName_rings &sipStrings_Qt3DExtras[4904]
#define sipNameNr_width 4910
#define sipName_width &sipStrings_Qt3DExtras[4910]
#define sipNameNr_beta 4916
#define sipName_beta &sipStrings_Qt3DExtras[4916]
#define sipNameNr_cool 4921
#define sipName_cool &sipStrings_Qt3DExtras[4921]
#define sipNameNr_font 4926
#define sipName_font &sipStrings_Qt3DExtras[4926]
#define sipNameNr_rows 4931
#define sipName_rows &sipStrings_Qt3DExtras[4931]
#define sipNameNr_setX 4936
#define sipName_setX &sipStrings_Qt3DExtras[4936]
#define sipNameNr_setY 4941
#define sipName_setY &sipStrings_Qt3DExtras[4941]
#define sipNameNr_size 4946
#define sipName_size &sipStrings_Qt3DExtras[4946]
#define sipNameNr_text 4951
#define sipName_text &sipStrings_Qt3DExtras[4951]
#define sipNameNr_warm 4956
#define sipName_warm &sipStrings_Qt3DExtras[4956]
#define sipNameNr_x 3112
#define sipName_x &sipStrings_Qt3DExtras[3112]
#define sipNameNr_y 465
#define sipName_y &sipStrings_Qt3DExtras[465]

#define sipMalloc                   sipAPI_Qt3DExtras->api_malloc
#define sipFree                     sipAPI_Qt3DExtras->api_free
#define sipBuildResult              sipAPI_Qt3DExtras->api_build_result
#define sipCallMethod               sipAPI_Qt3DExtras->api_call_method
#define sipCallProcedureMethod      sipAPI_Qt3DExtras->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_Qt3DExtras->api_call_error_handler
#define sipParseResultEx            sipAPI_Qt3DExtras->api_parse_result_ex
#define sipParseResult              sipAPI_Qt3DExtras->api_parse_result
#define sipParseArgs                sipAPI_Qt3DExtras->api_parse_args
#define sipParseKwdArgs             sipAPI_Qt3DExtras->api_parse_kwd_args
#define sipParsePair                sipAPI_Qt3DExtras->api_parse_pair
#define sipInstanceDestroyed        sipAPI_Qt3DExtras->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_Qt3DExtras->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_Qt3DExtras->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_Qt3DExtras->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_Qt3DExtras->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_Qt3DExtras->api_convert_to_void_ptr
#define sipAddException             sipAPI_Qt3DExtras->api_add_exception
#define sipNoFunction               sipAPI_Qt3DExtras->api_no_function
#define sipNoMethod                 sipAPI_Qt3DExtras->api_no_method
#define sipAbstractMethod           sipAPI_Qt3DExtras->api_abstract_method
#define sipBadClass                 sipAPI_Qt3DExtras->api_bad_class
#define sipBadCatcherResult         sipAPI_Qt3DExtras->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_Qt3DExtras->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_Qt3DExtras->api_bad_operator_arg
#define sipTrace                    sipAPI_Qt3DExtras->api_trace
#define sipTransferBack             sipAPI_Qt3DExtras->api_transfer_back
#define sipTransferTo               sipAPI_Qt3DExtras->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_Qt3DExtras->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_Qt3DExtras->api_wrapper_type
#define sipWrapperType_Type         sipAPI_Qt3DExtras->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_Qt3DExtras->api_voidptr_type
#define sipGetPyObject              sipAPI_Qt3DExtras->api_get_pyobject
#define sipGetAddress               sipAPI_Qt3DExtras->api_get_address
#define sipGetMixinAddress          sipAPI_Qt3DExtras->api_get_mixin_address
#define sipGetCppPtr                sipAPI_Qt3DExtras->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_Qt3DExtras->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_Qt3DExtras->api_call_hook
#define sipEndThread                sipAPI_Qt3DExtras->api_end_thread
#define sipRaiseUnknownException    sipAPI_Qt3DExtras->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_Qt3DExtras->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_Qt3DExtras->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_Qt3DExtras->api_add_type_instance
#define sipPySlotExtend             sipAPI_Qt3DExtras->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_Qt3DExtras->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_Qt3DExtras->api_can_convert_to_type
#define sipConvertToType            sipAPI_Qt3DExtras->api_convert_to_type
#define sipForceConvertToType       sipAPI_Qt3DExtras->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_Qt3DExtras->api_convert_to_enum
#define sipConvertToBool            sipAPI_Qt3DExtras->api_convert_to_bool
#define sipReleaseType              sipAPI_Qt3DExtras->api_release_type
#define sipConvertFromType          sipAPI_Qt3DExtras->api_convert_from_type
#define sipConvertFromNewType       sipAPI_Qt3DExtras->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_Qt3DExtras->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_Qt3DExtras->api_convert_from_enum
#define sipGetState                 sipAPI_Qt3DExtras->api_get_state
#define sipExportSymbol             sipAPI_Qt3DExtras->api_export_symbol
#define sipImportSymbol             sipAPI_Qt3DExtras->api_import_symbol
#define sipFindType                 sipAPI_Qt3DExtras->api_find_type
#define sipBytes_AsChar             sipAPI_Qt3DExtras->api_bytes_as_char
#define sipBytes_AsString           sipAPI_Qt3DExtras->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_Qt3DExtras->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_Qt3DExtras->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_Qt3DExtras->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_Qt3DExtras->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_Qt3DExtras->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_Qt3DExtras->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_Qt3DExtras->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_Qt3DExtras->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_Qt3DExtras->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_Qt3DExtras->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_Qt3DExtras->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_Qt3DExtras->api_get_reference
#define sipKeepReference            sipAPI_Qt3DExtras->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_Qt3DExtras->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_Qt3DExtras->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_Qt3DExtras->api_type_from_py_type_object
#define sipTypeScope                sipAPI_Qt3DExtras->api_type_scope
#define sipResolveTypedef           sipAPI_Qt3DExtras->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_Qt3DExtras->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_Qt3DExtras->api_enable_autoconversion
#define sipInitMixin                sipAPI_Qt3DExtras->api_init_mixin
#define sipExportModule             sipAPI_Qt3DExtras->api_export_module
#define sipInitModule               sipAPI_Qt3DExtras->api_init_module
#define sipGetInterpreter           sipAPI_Qt3DExtras->api_get_interpreter
#define sipSetTypeUserData          sipAPI_Qt3DExtras->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_Qt3DExtras->api_get_type_user_data
#define sipPyTypeDict               sipAPI_Qt3DExtras->api_py_type_dict
#define sipPyTypeName               sipAPI_Qt3DExtras->api_py_type_name
#define sipGetCFunction             sipAPI_Qt3DExtras->api_get_c_function
#define sipGetMethod                sipAPI_Qt3DExtras->api_get_method
#define sipFromMethod               sipAPI_Qt3DExtras->api_from_method
#define sipGetDate                  sipAPI_Qt3DExtras->api_get_date
#define sipFromDate                 sipAPI_Qt3DExtras->api_from_date
#define sipGetDateTime              sipAPI_Qt3DExtras->api_get_datetime
#define sipFromDateTime             sipAPI_Qt3DExtras->api_from_datetime
#define sipGetTime                  sipAPI_Qt3DExtras->api_get_time
#define sipFromTime                 sipAPI_Qt3DExtras->api_from_time
#define sipIsUserType               sipAPI_Qt3DExtras->api_is_user_type
#define sipCheckPluginForType       sipAPI_Qt3DExtras->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_Qt3DExtras->api_unicode_new
#define sipUnicodeWrite             sipAPI_Qt3DExtras->api_unicode_write
#define sipUnicodeData              sipAPI_Qt3DExtras->api_unicode_data
#define sipGetBufferInfo            sipAPI_Qt3DExtras->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_Qt3DExtras->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_Qt3DExtras->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_Qt3DExtras->api_is_derived_class
#define sipGetUserObject            sipAPI_Qt3DExtras->api_get_user_object
#define sipSetUserObject            sipAPI_Qt3DExtras->api_set_user_object
#define sipRegisterEventHandler     sipAPI_Qt3DExtras->api_register_event_handler
#define sipConvertToArray           sipAPI_Qt3DExtras->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_Qt3DExtras->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_Qt3DExtras->api_enable_gc
#define sipPrintObject              sipAPI_Qt3DExtras->api_print_object
#define sipLong_AsChar              sipAPI_Qt3DExtras->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_Qt3DExtras->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_Qt3DExtras->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_Qt3DExtras->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_Qt3DExtras->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_Qt3DExtras->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_Qt3DExtras->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_Qt3DExtras->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_Qt3DExtras->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_Qt3DExtras->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_Qt3DExtras->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_Qt3DExtras->api_long_as_size_t
#define sipVisitWrappers            sipAPI_Qt3DExtras->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_Qt3DExtras->api_register_exit_notifier
#define sipDeprecated               sipAPI_Qt3DExtras->api_deprecated
#define sipPyTypeDictRef            sipAPI_Qt3DExtras->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_Qt3DExtras->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_Qt3DExtras->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_Qt3DExtras->api_get_frame
#define sipSetDestroyOnExit         sipAPI_Qt3DExtras->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_Qt3DExtras->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_Qt3DExtras->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_Qt3DExtras->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_Qt3DExtras->api_connect_rx
#define sipConvertRx                sipAPI_Qt3DExtras->api_convert_rx
#define sipDisconnectRx             sipAPI_Qt3DExtras->api_disconnect_rx
#define sipFreeSipslot              sipAPI_Qt3DExtras->api_free_sipslot
#define sipInvokeSlot               sipAPI_Qt3DExtras->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_Qt3DExtras->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_Qt3DExtras->api_same_slot
#define sipSaveSlot                 sipAPI_Qt3DExtras->api_save_slot
#define sipVisitSlot                sipAPI_Qt3DExtras->api_visit_slot
#define sipIsPyMethod               sipAPI_Qt3DExtras->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_Qt3DExtras[];


#define sipType_Qt3DExtras_QAbstractCameraController sipExportedTypes_Qt3DExtras[1]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QAbstractCameraController;

#define sipType_Qt3DExtras_QAbstractSpriteSheet sipExportedTypes_Qt3DExtras[2]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QAbstractSpriteSheet;

#define sipType_Qt3DExtras_QConeGeometry sipExportedTypes_Qt3DExtras[3]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QConeGeometry;

#define sipType_Qt3DExtras_QConeMesh sipExportedTypes_Qt3DExtras[4]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QConeMesh;

#define sipType_Qt3DExtras_QCuboidGeometry sipExportedTypes_Qt3DExtras[5]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QCuboidGeometry;

#define sipType_Qt3DExtras_QCuboidMesh sipExportedTypes_Qt3DExtras[6]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QCuboidMesh;

#define sipType_Qt3DExtras_QCylinderGeometry sipExportedTypes_Qt3DExtras[7]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QCylinderGeometry;

#define sipType_Qt3DExtras_QCylinderMesh sipExportedTypes_Qt3DExtras[8]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QCylinderMesh;

#define sipType_Qt3DExtras_QDiffuseMapMaterial sipExportedTypes_Qt3DExtras[9]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QDiffuseMapMaterial;

#define sipType_Qt3DExtras_QDiffuseSpecularMapMaterial sipExportedTypes_Qt3DExtras[10]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QDiffuseSpecularMapMaterial;

#define sipType_Qt3DExtras_QDiffuseSpecularMaterial sipExportedTypes_Qt3DExtras[11]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QDiffuseSpecularMaterial;

#define sipType_Qt3DExtras_QExtrudedTextGeometry sipExportedTypes_Qt3DExtras[12]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QExtrudedTextGeometry;

#define sipType_Qt3DExtras_QExtrudedTextMesh sipExportedTypes_Qt3DExtras[13]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QExtrudedTextMesh;

#define sipType_Qt3DExtras_QFirstPersonCameraController sipExportedTypes_Qt3DExtras[14]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QFirstPersonCameraController;

#define sipType_Qt3DExtras_QForwardRenderer sipExportedTypes_Qt3DExtras[15]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QForwardRenderer;

#define sipType_Qt3DExtras_QGoochMaterial sipExportedTypes_Qt3DExtras[16]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QGoochMaterial;

#define sipType_Qt3DExtras_QMetalRoughMaterial sipExportedTypes_Qt3DExtras[17]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QMetalRoughMaterial;

#define sipType_Qt3DExtras_QMorphPhongMaterial sipExportedTypes_Qt3DExtras[18]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QMorphPhongMaterial;

#define sipType_Qt3DExtras_QNormalDiffuseMapMaterial sipExportedTypes_Qt3DExtras[20]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QNormalDiffuseMapMaterial;

#define sipType_Qt3DExtras_QNormalDiffuseMapAlphaMaterial sipExportedTypes_Qt3DExtras[19]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QNormalDiffuseMapAlphaMaterial;

#define sipType_Qt3DExtras_QNormalDiffuseSpecularMapMaterial sipExportedTypes_Qt3DExtras[21]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QNormalDiffuseSpecularMapMaterial;

#define sipType_Qt3DExtras_QOrbitCameraController sipExportedTypes_Qt3DExtras[22]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QOrbitCameraController;

#define sipType_Qt3DExtras_QPerVertexColorMaterial sipExportedTypes_Qt3DExtras[23]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QPerVertexColorMaterial;

#define sipType_Qt3DExtras_QPhongAlphaMaterial sipExportedTypes_Qt3DExtras[24]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QPhongAlphaMaterial;

#define sipType_Qt3DExtras_QPhongMaterial sipExportedTypes_Qt3DExtras[25]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QPhongMaterial;

#define sipType_Qt3DExtras_QPlaneGeometry sipExportedTypes_Qt3DExtras[26]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QPlaneGeometry;

#define sipType_Qt3DExtras_QPlaneMesh sipExportedTypes_Qt3DExtras[27]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QPlaneMesh;

#define sipType_Qt3DExtras_QSkyboxEntity sipExportedTypes_Qt3DExtras[28]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QSkyboxEntity;

#define sipType_Qt3DExtras_QSphereGeometry sipExportedTypes_Qt3DExtras[29]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QSphereGeometry;

#define sipType_Qt3DExtras_QSphereMesh sipExportedTypes_Qt3DExtras[30]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QSphereMesh;

#define sipType_Qt3DExtras_QSpriteGrid sipExportedTypes_Qt3DExtras[31]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QSpriteGrid;

#define sipType_Qt3DExtras_QSpriteSheet sipExportedTypes_Qt3DExtras[32]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QSpriteSheet;

#define sipType_Qt3DExtras_QSpriteSheetItem sipExportedTypes_Qt3DExtras[33]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QSpriteSheetItem;

#define sipType_Qt3DExtras_Qt3DWindow sipExportedTypes_Qt3DExtras[39]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_Qt3DWindow;

#define sipType_Qt3DExtras_QText2DEntity sipExportedTypes_Qt3DExtras[34]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QText2DEntity;

#define sipType_Qt3DExtras_QTexturedMetalRoughMaterial sipExportedTypes_Qt3DExtras[36]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QTexturedMetalRoughMaterial;

#define sipType_Qt3DExtras_QTextureMaterial sipExportedTypes_Qt3DExtras[35]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QTextureMaterial;

#define sipType_Qt3DExtras_QTorusGeometry sipExportedTypes_Qt3DExtras[37]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QTorusGeometry;

#define sipType_Qt3DExtras_QTorusMesh sipExportedTypes_Qt3DExtras[38]

extern sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QTorusMesh;

#define sipType_QVector_0101Qt3DExtras_QSpriteSheetItem sipExportedTypes_Qt3DExtras[0]

extern sipMappedTypeDef sipTypeDef_Qt3DExtras_QVector_0101Qt3DExtras_QSpriteSheetItem;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_Qt3DExtras;
extern sipExportedModuleDef sipModuleAPI_Qt3DExtras;
extern sipTypeDef *sipExportedTypes_Qt3DExtras[];

#define sipType_QObject sipImportedTypes_Qt3DExtras_QtCore[3].it_td

#define sipType_QEvent sipImportedTypes_Qt3DExtras_QtCore[1].it_td

#define sipType_QTimerEvent sipImportedTypes_Qt3DExtras_QtCore[7].it_td

#define sipType_QChildEvent sipImportedTypes_Qt3DExtras_QtCore[0].it_td

#define sipType_QMetaMethod sipImportedTypes_Qt3DExtras_QtCore[2].it_td

#define sipType_QRectF sipImportedTypes_Qt3DExtras_QtCore[4].it_td

#define sipType_QSize sipImportedTypes_Qt3DExtras_QtCore[5].it_td

#define sipType_QVariant sipImportedTypes_Qt3DExtras_QtCore[8].it_td

#define sipType_QString sipImportedTypes_Qt3DExtras_QtCore[6].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DExtras_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[];

#define sipType_QColor sipImportedTypes_Qt3DExtras_QtGui[0].it_td

#define sipType_QMouseEvent sipImportedTypes_Qt3DExtras_QtGui[7].it_td

#define sipType_QWheelEvent sipImportedTypes_Qt3DExtras_QtGui[18].it_td

#define sipType_QTabletEvent sipImportedTypes_Qt3DExtras_QtGui[15].it_td

#define sipType_QKeyEvent sipImportedTypes_Qt3DExtras_QtGui[5].it_td

#define sipType_QFocusEvent sipImportedTypes_Qt3DExtras_QtGui[2].it_td

#define sipType_QMoveEvent sipImportedTypes_Qt3DExtras_QtGui[8].it_td

#define sipType_QResizeEvent sipImportedTypes_Qt3DExtras_QtGui[9].it_td

#define sipType_QShowEvent sipImportedTypes_Qt3DExtras_QtGui[11].it_td

#define sipType_QHideEvent sipImportedTypes_Qt3DExtras_QtGui[4].it_td

#define sipType_QTouchEvent sipImportedTypes_Qt3DExtras_QtGui[16].it_td

#define sipType_QExposeEvent sipImportedTypes_Qt3DExtras_QtGui[1].it_td

#define sipType_QFont sipImportedTypes_Qt3DExtras_QtGui[3].it_td

#define sipType_QMatrix3x3 sipImportedTypes_Qt3DExtras_QtGui[6].it_td

#define sipType_QSurface sipImportedTypes_Qt3DExtras_QtGui[12].it_td

#define sipType_QSurface_SurfaceType sipImportedTypes_Qt3DExtras_QtGui[13].it_td

#define sipType_QWindow sipImportedTypes_Qt3DExtras_QtGui[19].it_td

#define sipType_QScreen sipImportedTypes_Qt3DExtras_QtGui[10].it_td

#define sipType_QSurfaceFormat sipImportedTypes_Qt3DExtras_QtGui[14].it_td

#define sipType_QVector2D sipImportedTypes_Qt3DExtras_QtGui[17].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DExtras_QtGui[];

#define sipType_Qt3DCore_QAbstractAspect sipImportedTypes_Qt3DExtras_Qt3DCore[1].it_td

#define sipType_Qt3DCore_QNode sipImportedTypes_Qt3DExtras_Qt3DCore[4].it_td

#define sipType_Qt3DCore_QComponent sipImportedTypes_Qt3DExtras_Qt3DCore[2].it_td

#define sipType_Qt3DCore_QEntity sipImportedTypes_Qt3DExtras_Qt3DCore[3].it_td

#define sipType_QSharedPointer_0100Qt3DCore_QSceneChange sipImportedTypes_Qt3DExtras_Qt3DCore[0].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DExtras_Qt3DCore[];

#define sipType_Qt3DInput_QKeyboardDevice sipImportedTypes_Qt3DExtras_Qt3DInput[0].it_td

#define sipType_Qt3DInput_QMouseDevice sipImportedTypes_Qt3DExtras_Qt3DInput[1].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DExtras_Qt3DInput[];

#define sipType_Qt3DRender_QAbstractTexture sipImportedTypes_Qt3DExtras_Qt3DRender[0].it_td

#define sipType_Qt3DRender_QAttribute sipImportedTypes_Qt3DExtras_Qt3DRender[1].it_td

#define sipType_Qt3DRender_QBlendEquation_BlendFunction sipImportedTypes_Qt3DExtras_Qt3DRender[2].it_td

#define sipType_Qt3DRender_QBlendEquationArguments_Blending sipImportedTypes_Qt3DExtras_Qt3DRender[3].it_td

#define sipType_Qt3DRender_QFrameGraphNode sipImportedTypes_Qt3DExtras_Qt3DRender[6].it_td

#define sipType_Qt3DRender_QCamera sipImportedTypes_Qt3DExtras_Qt3DRender[4].it_td

#define sipType_Qt3DRender_QClearBuffers_BufferType sipImportedTypes_Qt3DExtras_Qt3DRender[5].it_td

#define sipType_Qt3DRender_QGeometry sipImportedTypes_Qt3DExtras_Qt3DRender[7].it_td

#define sipType_Qt3DRender_QGeometryRenderer sipImportedTypes_Qt3DExtras_Qt3DRender[8].it_td

#define sipType_Qt3DRender_QMaterial sipImportedTypes_Qt3DExtras_Qt3DRender[9].it_td

#define sipType_Qt3DRender_QRenderSettings sipImportedTypes_Qt3DExtras_Qt3DRender[10].it_td

#define sipType_Qt3DRender_QTechniqueFilter sipImportedTypes_Qt3DExtras_Qt3DRender[11].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DExtras_Qt3DRender[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_Qt3DExtras_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_Qt3DExtras_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_Qt3DExtras_qt_metacast;
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"

#include <qsharedpointer.h>


// The dtor for the saved QSharedPointer.
#if defined(SIP_USE_PYCAPSULE)
template<class T>
void qt3d_QspDtor(PyObject *capsule)
{
    delete reinterpret_cast<QSharedPointer<T> *>(
            PyCapsule_GetPointer(capsule, 0));
}
#else
template<class T>
void qt3d_QspDtor(void *shared)
{
    delete reinterpret_cast<QSharedPointer<T> *>(array);
}
#endif


template<class T>
bool qt3d_SaveQsp(PyObject *py, QSharedPointer<T> *qsp)
{
    // Wrap the copy in a Python object.
#if defined(SIP_USE_PYCAPSULE)
    PyObject *qsp_obj = PyCapsule_New(qsp, 0, qt3d_QspDtor<T>);
#else
    PyObject *qsp_obj = PyCObject_FromVoidPtr(qsp, qt3d_QspDto<T>r);
#endif

    if (!qsp_obj)
        return false;

    sipSetUserObject((sipSimpleWrapper *)py, qsp_obj);

    return true;
}

#line 1220 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipAPIQt3DExtras.h"

#endif
