/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DExtras.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 77 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 105 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 126 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 149 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 152 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 209 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 212 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 319 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 342 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 345 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 348 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 377 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 380 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 383 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 386 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 439 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 442 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 445 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 480 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 485 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 488 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 491 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 494 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 497 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 500 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 503 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 506 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 509 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 512 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 515 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 518 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 521 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 524 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQPhongAlphaMaterial.cpp"


class sipQt3DExtras_QPhongAlphaMaterial : public ::Qt3DExtras::QPhongAlphaMaterial
{
public:
    sipQt3DExtras_QPhongAlphaMaterial(::Qt3DCore::QNode*);
    virtual ~sipQt3DExtras_QPhongAlphaMaterial();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DExtras_QPhongAlphaMaterial(const sipQt3DExtras_QPhongAlphaMaterial &);
    sipQt3DExtras_QPhongAlphaMaterial &operator = (const sipQt3DExtras_QPhongAlphaMaterial &);

    char sipPyMethods[8];
};

sipQt3DExtras_QPhongAlphaMaterial::sipQt3DExtras_QPhongAlphaMaterial(::Qt3DCore::QNode*a0): ::Qt3DExtras::QPhongAlphaMaterial(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DExtras_QPhongAlphaMaterial::~sipQt3DExtras_QPhongAlphaMaterial()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DExtras_QPhongAlphaMaterial::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DExtras_qt_metaobject(sipPySelf, sipType_Qt3DExtras_QPhongAlphaMaterial);

    return ::Qt3DExtras::QPhongAlphaMaterial::metaObject();
}

int sipQt3DExtras_QPhongAlphaMaterial::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DExtras::QPhongAlphaMaterial::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DExtras_qt_metacall(sipPySelf, sipType_Qt3DExtras_QPhongAlphaMaterial, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DExtras_QPhongAlphaMaterial::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DExtras_qt_metacast(sipPySelf, sipType_Qt3DExtras_QPhongAlphaMaterial, _clname, &sipCpp) ? sipCpp : ::Qt3DExtras::QPhongAlphaMaterial::qt_metacast(_clname));
}

void sipQt3DExtras_QPhongAlphaMaterial::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DExtras::QPhongAlphaMaterial::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DExtras_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QPhongAlphaMaterial::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DExtras::QPhongAlphaMaterial::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DExtras_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QPhongAlphaMaterial::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QPhongAlphaMaterial::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DExtras_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QPhongAlphaMaterial::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QPhongAlphaMaterial::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DExtras_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QPhongAlphaMaterial::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QPhongAlphaMaterial::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DExtras_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DExtras_QPhongAlphaMaterial::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DExtras::QPhongAlphaMaterial::eventFilter(a0, a1);

    extern bool sipVH_Qt3DExtras_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DExtras_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQt3DExtras_QPhongAlphaMaterial::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DExtras::QPhongAlphaMaterial::event(a0);

    extern bool sipVH_Qt3DExtras_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DExtras_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QPhongAlphaMaterial::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QPhongAlphaMaterial::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DExtras_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_ambient, "ambient(self) -> QColor");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_ambient(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_ambient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->ambient());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_ambient, doc_Qt3DExtras_QPhongAlphaMaterial_ambient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_diffuse, "diffuse(self) -> QColor");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_diffuse(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_diffuse(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->diffuse());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_diffuse, doc_Qt3DExtras_QPhongAlphaMaterial_diffuse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_specular, "specular(self) -> QColor");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_specular(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_specular(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->specular());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_specular, doc_Qt3DExtras_QPhongAlphaMaterial_specular);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_shininess, "shininess(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_shininess(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_shininess(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->shininess();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_shininess, doc_Qt3DExtras_QPhongAlphaMaterial_shininess);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_alpha, "alpha(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_alpha(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_alpha(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->alpha();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_alpha, doc_Qt3DExtras_QPhongAlphaMaterial_alpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setAmbient, "setAmbient(self, ambient: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setAmbient(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setAmbient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setAmbient(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setAmbient, doc_Qt3DExtras_QPhongAlphaMaterial_setAmbient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setDiffuse, "setDiffuse(self, diffuse: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setDiffuse(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setDiffuse(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setDiffuse(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setDiffuse, doc_Qt3DExtras_QPhongAlphaMaterial_setDiffuse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setSpecular, "setSpecular(self, specular: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setSpecular(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setSpecular(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setSpecular(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setSpecular, doc_Qt3DExtras_QPhongAlphaMaterial_setSpecular);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setShininess, "setShininess(self, shininess: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setShininess(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setShininess(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, &a0))
        {
            sipCpp->setShininess(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setShininess, doc_Qt3DExtras_QPhongAlphaMaterial_setShininess);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setAlpha, "setAlpha(self, alpha: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setAlpha(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setAlpha(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, &a0))
        {
            sipCpp->setAlpha(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setAlpha, doc_Qt3DExtras_QPhongAlphaMaterial_setAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_sourceRgbArg, "sourceRgbArg(self) -> QBlendEquationArguments.Blending");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_sourceRgbArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_sourceRgbArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            ::Qt3DRender::QBlendEquationArguments::Blending sipRes;

            sipRes = sipCpp->sourceRgbArg();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquationArguments_Blending);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_sourceRgbArg, doc_Qt3DExtras_QPhongAlphaMaterial_sourceRgbArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_destinationRgbArg, "destinationRgbArg(self) -> QBlendEquationArguments.Blending");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_destinationRgbArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_destinationRgbArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            ::Qt3DRender::QBlendEquationArguments::Blending sipRes;

            sipRes = sipCpp->destinationRgbArg();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquationArguments_Blending);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_destinationRgbArg, doc_Qt3DExtras_QPhongAlphaMaterial_destinationRgbArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_sourceAlphaArg, "sourceAlphaArg(self) -> QBlendEquationArguments.Blending");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_sourceAlphaArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_sourceAlphaArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            ::Qt3DRender::QBlendEquationArguments::Blending sipRes;

            sipRes = sipCpp->sourceAlphaArg();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquationArguments_Blending);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_sourceAlphaArg, doc_Qt3DExtras_QPhongAlphaMaterial_sourceAlphaArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_destinationAlphaArg, "destinationAlphaArg(self) -> QBlendEquationArguments.Blending");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_destinationAlphaArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_destinationAlphaArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            ::Qt3DRender::QBlendEquationArguments::Blending sipRes;

            sipRes = sipCpp->destinationAlphaArg();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquationArguments_Blending);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_destinationAlphaArg, doc_Qt3DExtras_QPhongAlphaMaterial_destinationAlphaArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_blendFunctionArg, "blendFunctionArg(self) -> QBlendEquation.BlendFunction");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_blendFunctionArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_blendFunctionArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp))
        {
            ::Qt3DRender::QBlendEquation::BlendFunction sipRes;

            sipRes = sipCpp->blendFunctionArg();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquation_BlendFunction);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_blendFunctionArg, doc_Qt3DExtras_QPhongAlphaMaterial_blendFunctionArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setSourceRgbArg, "setSourceRgbArg(self, sourceRgbArg: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setSourceRgbArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setSourceRgbArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setSourceRgbArg(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setSourceRgbArg, doc_Qt3DExtras_QPhongAlphaMaterial_setSourceRgbArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setDestinationRgbArg, "setDestinationRgbArg(self, destinationRgbArg: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setDestinationRgbArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setDestinationRgbArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setDestinationRgbArg(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setDestinationRgbArg, doc_Qt3DExtras_QPhongAlphaMaterial_setDestinationRgbArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setSourceAlphaArg, "setSourceAlphaArg(self, sourceAlphaArg: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setSourceAlphaArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setSourceAlphaArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setSourceAlphaArg(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setSourceAlphaArg, doc_Qt3DExtras_QPhongAlphaMaterial_setSourceAlphaArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setDestinationAlphaArg, "setDestinationAlphaArg(self, destinationAlphaArg: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setDestinationAlphaArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setDestinationAlphaArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setDestinationAlphaArg(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setDestinationAlphaArg, doc_Qt3DExtras_QPhongAlphaMaterial_setDestinationAlphaArg);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial_setBlendFunctionArg, "setBlendFunctionArg(self, blendFunctionArg: QBlendEquation.BlendFunction)");

extern "C" {static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setBlendFunctionArg(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QPhongAlphaMaterial_setBlendFunctionArg(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquation::BlendFunction a0;
        ::Qt3DExtras::QPhongAlphaMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DExtras_QPhongAlphaMaterial, &sipCpp, sipType_Qt3DRender_QBlendEquation_BlendFunction, &a0))
        {
            sipCpp->setBlendFunctionArg(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPhongAlphaMaterial, sipName_setBlendFunctionArg, doc_Qt3DExtras_QPhongAlphaMaterial_setBlendFunctionArg);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DExtras_QPhongAlphaMaterial(void *, const sipTypeDef *);}
static void *cast_Qt3DExtras_QPhongAlphaMaterial(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DExtras::QPhongAlphaMaterial *sipCpp = reinterpret_cast< ::Qt3DExtras::QPhongAlphaMaterial *>(sipCppV);

    if (targetType == sipType_Qt3DExtras_QPhongAlphaMaterial)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DRender_QMaterial)->ctd_cast(static_cast< ::Qt3DRender::QMaterial *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DExtras_QPhongAlphaMaterial(void *, int);}
static void release_Qt3DExtras_QPhongAlphaMaterial(void *sipCppV, int)
{
    ::Qt3DExtras::QPhongAlphaMaterial *sipCpp = reinterpret_cast< ::Qt3DExtras::QPhongAlphaMaterial *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DExtras_QPhongAlphaMaterial(Py_ssize_t);}
static void *array_Qt3DExtras_QPhongAlphaMaterial(Py_ssize_t sipNrElem)
{
    return new ::Qt3DExtras::QPhongAlphaMaterial[sipNrElem];
}


extern "C" {static void array_delete_Qt3DExtras_QPhongAlphaMaterial(void *);}
static void array_delete_Qt3DExtras_QPhongAlphaMaterial(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DExtras::QPhongAlphaMaterial *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DExtras_QPhongAlphaMaterial(sipSimpleWrapper *);}
static void dealloc_Qt3DExtras_QPhongAlphaMaterial(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DExtras_QPhongAlphaMaterial *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DExtras_QPhongAlphaMaterial(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DExtras_QPhongAlphaMaterial(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DExtras_QPhongAlphaMaterial(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DExtras_QPhongAlphaMaterial *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DExtras_QPhongAlphaMaterial(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DExtras_QPhongAlphaMaterial[] = {{9, 4, 1}};


static PyMethodDef methods_Qt3DExtras_QPhongAlphaMaterial[] = {
    {sipName_alpha, meth_Qt3DExtras_QPhongAlphaMaterial_alpha, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_alpha},
    {sipName_ambient, meth_Qt3DExtras_QPhongAlphaMaterial_ambient, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_ambient},
    {sipName_blendFunctionArg, meth_Qt3DExtras_QPhongAlphaMaterial_blendFunctionArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_blendFunctionArg},
    {sipName_destinationAlphaArg, meth_Qt3DExtras_QPhongAlphaMaterial_destinationAlphaArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_destinationAlphaArg},
    {sipName_destinationRgbArg, meth_Qt3DExtras_QPhongAlphaMaterial_destinationRgbArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_destinationRgbArg},
    {sipName_diffuse, meth_Qt3DExtras_QPhongAlphaMaterial_diffuse, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_diffuse},
    {sipName_setAlpha, meth_Qt3DExtras_QPhongAlphaMaterial_setAlpha, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setAlpha},
    {sipName_setAmbient, meth_Qt3DExtras_QPhongAlphaMaterial_setAmbient, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setAmbient},
    {sipName_setBlendFunctionArg, meth_Qt3DExtras_QPhongAlphaMaterial_setBlendFunctionArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setBlendFunctionArg},
    {sipName_setDestinationAlphaArg, meth_Qt3DExtras_QPhongAlphaMaterial_setDestinationAlphaArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setDestinationAlphaArg},
    {sipName_setDestinationRgbArg, meth_Qt3DExtras_QPhongAlphaMaterial_setDestinationRgbArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setDestinationRgbArg},
    {sipName_setDiffuse, meth_Qt3DExtras_QPhongAlphaMaterial_setDiffuse, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setDiffuse},
    {sipName_setShininess, meth_Qt3DExtras_QPhongAlphaMaterial_setShininess, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setShininess},
    {sipName_setSourceAlphaArg, meth_Qt3DExtras_QPhongAlphaMaterial_setSourceAlphaArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setSourceAlphaArg},
    {sipName_setSourceRgbArg, meth_Qt3DExtras_QPhongAlphaMaterial_setSourceRgbArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setSourceRgbArg},
    {sipName_setSpecular, meth_Qt3DExtras_QPhongAlphaMaterial_setSpecular, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_setSpecular},
    {sipName_shininess, meth_Qt3DExtras_QPhongAlphaMaterial_shininess, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_shininess},
    {sipName_sourceAlphaArg, meth_Qt3DExtras_QPhongAlphaMaterial_sourceAlphaArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_sourceAlphaArg},
    {sipName_sourceRgbArg, meth_Qt3DExtras_QPhongAlphaMaterial_sourceRgbArg, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_sourceRgbArg},
    {sipName_specular, meth_Qt3DExtras_QPhongAlphaMaterial_specular, METH_VARARGS, doc_Qt3DExtras_QPhongAlphaMaterial_specular}
};

PyDoc_STRVAR(doc_Qt3DExtras_QPhongAlphaMaterial, "\1QPhongAlphaMaterial(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DExtras_QPhongAlphaMaterial[] = {
    {"blendFunctionArgChanged(Qt3DRender::QBlendEquation::BlendFunction)", "\1blendFunctionArgChanged(self, blendFunctionArg: QBlendEquation.BlendFunction)", SIP_NULLPTR, SIP_NULLPTR},
    {"destinationAlphaArgChanged(Qt3DRender::QBlendEquationArguments::Blending)", "\1destinationAlphaArgChanged(self, destinationAlphaArg: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceAlphaArgChanged(Qt3DRender::QBlendEquationArguments::Blending)", "\1sourceAlphaArgChanged(self, sourceAlphaArg: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"destinationRgbArgChanged(Qt3DRender::QBlendEquationArguments::Blending)", "\1destinationRgbArgChanged(self, destinationRgbArg: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceRgbArgChanged(Qt3DRender::QBlendEquationArguments::Blending)", "\1sourceRgbArgChanged(self, sourceRgbArg: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"alphaChanged(float)", "\1alphaChanged(self, alpha: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"shininessChanged(float)", "\1shininessChanged(self, shininess: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"specularChanged(QColor)", "\1specularChanged(self, specular: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"diffuseChanged(QColor)", "\1diffuseChanged(self, diffuse: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"ambientChanged(QColor)", "\1ambientChanged(self, ambient: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DExtras_QPhongAlphaMaterial = {
    &::Qt3DExtras::QPhongAlphaMaterial::staticMetaObject,
    0,
    signals_Qt3DExtras_QPhongAlphaMaterial,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QPhongAlphaMaterial = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DExtras__QPhongAlphaMaterial,
        SIP_NULLPTR,
        &plugin_Qt3DExtras_QPhongAlphaMaterial,
    },
    {
        sipNameNr_QPhongAlphaMaterial,
        {0, 0, 1},
        20, methods_Qt3DExtras_QPhongAlphaMaterial,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DExtras_QPhongAlphaMaterial,
    -1,
    -1,
    supers_Qt3DExtras_QPhongAlphaMaterial,
    SIP_NULLPTR,
    init_type_Qt3DExtras_QPhongAlphaMaterial,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DExtras_QPhongAlphaMaterial,
    SIP_NULLPTR,
    array_Qt3DExtras_QPhongAlphaMaterial,
    SIP_NULLPTR,
    release_Qt3DExtras_QPhongAlphaMaterial,
    cast_Qt3DExtras_QPhongAlphaMaterial,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DExtras_QPhongAlphaMaterial,
    sizeof (::Qt3DExtras::QPhongAlphaMaterial),
};
