/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DCore.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 61 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNodeId.cpp"



PyDoc_STRVAR(doc_Qt3DCore_QNodeId_createId, "createId() -> QNodeId");

extern "C" {static PyObject *meth_Qt3DCore_QNodeId_createId(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNodeId_createId(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::Qt3DCore::QNodeId*sipRes;

            sipRes = new ::Qt3DCore::QNodeId(::Qt3DCore::QNodeId::createId());

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QNodeId, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNodeId, sipName_createId, doc_Qt3DCore_QNodeId_createId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNodeId_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_Qt3DCore_QNodeId_isNull(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNodeId_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNodeId *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNodeId, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNodeId, sipName_isNull, doc_Qt3DCore_QNodeId_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNodeId_id, "id(self) -> int");

extern "C" {static PyObject *meth_Qt3DCore_QNodeId_id(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNodeId_id(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNodeId *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNodeId, &sipCpp))
        {
            ::quint64 sipRes;

            sipRes = sipCpp->id();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNodeId, sipName_id, doc_Qt3DCore_QNodeId_id);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_Qt3DCore_QNodeId___ge__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QNodeId___ge__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DCore::QNodeId *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QNodeId));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNodeId* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DCore_QNodeId, &a0))
        {
            bool sipRes;

            sipRes = !sipCpp->::Qt3DCore::QNodeId::operator<(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, ge_slot, sipType_Qt3DCore_QNodeId, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_Qt3DCore_QNodeId___le__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QNodeId___le__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DCore::QNodeId *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QNodeId));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNodeId* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DCore_QNodeId, &a0))
        {
            bool sipRes;

            sipRes = !sipCpp->::Qt3DCore::QNodeId::operator>(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, le_slot, sipType_Qt3DCore_QNodeId, sipSelf, sipArg);
}


extern "C" {static long slot_Qt3DCore_QNodeId___hash__(PyObject *);}
static long slot_Qt3DCore_QNodeId___hash__(PyObject *sipSelf)
{
    ::Qt3DCore::QNodeId *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QNodeId));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 47 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
            sipRes = qHash(*sipCpp);
#line 214 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNodeId.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_Qt3DCore_QNodeId___int__(PyObject *);}
static PyObject *slot_Qt3DCore_QNodeId___int__(PyObject *sipSelf)
{
    ::Qt3DCore::QNodeId *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QNodeId));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            bool sipRes;

            sipRes = bool(*sipCpp);

            return PyBool_FromLong(sipRes);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_Qt3DCore_QNodeId___gt__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QNodeId___gt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DCore::QNodeId *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QNodeId));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNodeId* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DCore_QNodeId, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::Qt3DCore::QNodeId::operator>(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, gt_slot, sipType_Qt3DCore_QNodeId, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_Qt3DCore_QNodeId___lt__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QNodeId___lt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DCore::QNodeId *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QNodeId));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNodeId* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DCore_QNodeId, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::Qt3DCore::QNodeId::operator<(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, lt_slot, sipType_Qt3DCore_QNodeId, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_Qt3DCore_QNodeId___ne__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QNodeId___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DCore::QNodeId *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QNodeId));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNodeId* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DCore_QNodeId, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::Qt3DCore::QNodeId::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, ne_slot, sipType_Qt3DCore_QNodeId, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_Qt3DCore_QNodeId___eq__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QNodeId___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DCore::QNodeId *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QNodeId));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNodeId* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_Qt3DCore_QNodeId, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::Qt3DCore::QNodeId::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, eq_slot, sipType_Qt3DCore_QNodeId, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DCore_QNodeId(void *, int);}
static void release_Qt3DCore_QNodeId(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DCore::QNodeId *>(sipCppV);
}


extern "C" {static void *array_Qt3DCore_QNodeId(Py_ssize_t);}
static void *array_Qt3DCore_QNodeId(Py_ssize_t sipNrElem)
{
    return new ::Qt3DCore::QNodeId[sipNrElem];
}


extern "C" {static void array_delete_Qt3DCore_QNodeId(void *);}
static void array_delete_Qt3DCore_QNodeId(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DCore::QNodeId *>(sipCpp);
}


extern "C" {static void assign_Qt3DCore_QNodeId(void *, Py_ssize_t, void *);}
static void assign_Qt3DCore_QNodeId(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::Qt3DCore::QNodeId *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::Qt3DCore::QNodeId *>(sipSrc);
}


extern "C" {static void *copy_Qt3DCore_QNodeId(const void *, Py_ssize_t);}
static void *copy_Qt3DCore_QNodeId(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::Qt3DCore::QNodeId(reinterpret_cast<const ::Qt3DCore::QNodeId *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_Qt3DCore_QNodeId(sipSimpleWrapper *);}
static void dealloc_Qt3DCore_QNodeId(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DCore_QNodeId(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_Qt3DCore_QNodeId(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DCore_QNodeId(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::Qt3DCore::QNodeId *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::Qt3DCore::QNodeId();

            return sipCpp;
        }
    }

    {
        const ::Qt3DCore::QNodeId* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_Qt3DCore_QNodeId, &a0))
        {
            sipCpp = new ::Qt3DCore::QNodeId(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_Qt3DCore_QNodeId[] = {
    {(void *)slot_Qt3DCore_QNodeId___ge__, ge_slot},
    {(void *)slot_Qt3DCore_QNodeId___le__, le_slot},
    {(void *)slot_Qt3DCore_QNodeId___hash__, hash_slot},
    {(void *)slot_Qt3DCore_QNodeId___int__, int_slot},
    {(void *)slot_Qt3DCore_QNodeId___gt__, gt_slot},
    {(void *)slot_Qt3DCore_QNodeId___lt__, lt_slot},
    {(void *)slot_Qt3DCore_QNodeId___ne__, ne_slot},
    {(void *)slot_Qt3DCore_QNodeId___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_Qt3DCore_QNodeId[] = {
    {sipName_createId, meth_Qt3DCore_QNodeId_createId, METH_VARARGS, doc_Qt3DCore_QNodeId_createId},
    {sipName_id, meth_Qt3DCore_QNodeId_id, METH_VARARGS, doc_Qt3DCore_QNodeId_id},
    {sipName_isNull, meth_Qt3DCore_QNodeId_isNull, METH_VARARGS, doc_Qt3DCore_QNodeId_isNull}
};

PyDoc_STRVAR(doc_Qt3DCore_QNodeId, "\1QNodeId()\n"
"QNodeId(a0: QNodeId)");


static pyqt5ClassPluginDef plugin_Qt3DCore_QNodeId = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNodeId = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DCore__QNodeId,
        SIP_NULLPTR,
        &plugin_Qt3DCore_QNodeId,
    },
    {
        sipNameNr_QNodeId,
        {0, 0, 1},
        3, methods_Qt3DCore_QNodeId,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DCore_QNodeId,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_Qt3DCore_QNodeId,
    init_type_Qt3DCore_QNodeId,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DCore_QNodeId,
    assign_Qt3DCore_QNodeId,
    array_Qt3DCore_QNodeId,
    copy_Qt3DCore_QNodeId,
    release_Qt3DCore_QNodeId,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DCore_QNodeId,
    sizeof (::Qt3DCore::QNodeId),
};
