/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 81 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 84 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 87 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 140 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 143 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 172 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 175 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 204 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 207 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 210 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 213 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 216 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 251 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 256 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 259 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 262 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 265 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 268 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 271 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 274 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 277 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 280 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 283 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 286 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 289 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 292 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBuffer.cpp"


class sipQt3DRender_QBuffer : public ::Qt3DRender::QBuffer
{
public:
    sipQt3DRender_QBuffer(::Qt3DCore::QNode*);
    sipQt3DRender_QBuffer(::Qt3DRender::QBuffer::BufferType, ::Qt3DCore::QNode*);
    virtual ~sipQt3DRender_QBuffer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QBuffer(const sipQt3DRender_QBuffer &);
    sipQt3DRender_QBuffer &operator = (const sipQt3DRender_QBuffer &);

    char sipPyMethods[8];
};

sipQt3DRender_QBuffer::sipQt3DRender_QBuffer(::Qt3DCore::QNode*a0): ::Qt3DRender::QBuffer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QBuffer::sipQt3DRender_QBuffer(::Qt3DRender::QBuffer::BufferType a0, ::Qt3DCore::QNode*a1): ::Qt3DRender::QBuffer(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QBuffer::~sipQt3DRender_QBuffer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QBuffer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QBuffer);

    return ::Qt3DRender::QBuffer::metaObject();
}

int sipQt3DRender_QBuffer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QBuffer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QBuffer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QBuffer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QBuffer, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QBuffer::qt_metacast(_clname));
}

void sipQt3DRender_QBuffer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QBuffer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBuffer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QBuffer::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBuffer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QBuffer::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBuffer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QBuffer::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBuffer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QBuffer::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QBuffer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QBuffer::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQt3DRender_QBuffer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QBuffer::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBuffer::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QBuffer::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DRender_7(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_usage, "usage(self) -> QBuffer.UsageType");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_usage(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_usage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp))
        {
            ::Qt3DRender::QBuffer::UsageType sipRes;

            sipRes = sipCpp->usage();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBuffer_UsageType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_usage, doc_Qt3DRender_QBuffer_usage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_type, "type(self) -> QBuffer.BufferType");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_type(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp))
        {
            ::Qt3DRender::QBuffer::BufferType sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBuffer_BufferType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_type, doc_Qt3DRender_QBuffer_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_isSyncData, "isSyncData(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_isSyncData(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_isSyncData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSyncData();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_isSyncData, doc_Qt3DRender_QBuffer_isSyncData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_setData, "setData(self, bytes: QByteArray|bytes|bytearray)");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_setData(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_setData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setData(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_setData, doc_Qt3DRender_QBuffer_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_data, "data(self) -> QByteArray");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_data(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->data());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_data, doc_Qt3DRender_QBuffer_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_setDataGenerator, "setDataGenerator(self, functor: QBufferDataGenerator)");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_setDataGenerator(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_setDataGenerator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBufferDataGeneratorPtr* a0;
        int a0State = 0;
        ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp, sipType_QSharedPointer_0100Qt3DRender_QBufferDataGenerator, &a0, &a0State))
        {
            sipCpp->setDataGenerator(*a0);
            sipReleaseType(const_cast< ::Qt3DRender::QBufferDataGeneratorPtr *>(a0), sipType_QSharedPointer_0100Qt3DRender_QBufferDataGenerator, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_setDataGenerator, doc_Qt3DRender_QBuffer_setDataGenerator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_dataGenerator, "dataGenerator(self) -> QBufferDataGenerator");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_dataGenerator(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_dataGenerator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp))
        {
            ::Qt3DRender::QBufferDataGeneratorPtr*sipRes;

            sipRes = new ::Qt3DRender::QBufferDataGeneratorPtr(sipCpp->dataGenerator());

            return sipConvertFromNewType(sipRes, sipType_QSharedPointer_0100Qt3DRender_QBufferDataGenerator, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_dataGenerator, doc_Qt3DRender_QBuffer_dataGenerator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_setType, "setType(self, type: QBuffer.BufferType)");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_setType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_setType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBuffer::BufferType a0;
        ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp, sipType_Qt3DRender_QBuffer_BufferType, &a0))
        {
            sipCpp->setType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_setType, doc_Qt3DRender_QBuffer_setType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_setUsage, "setUsage(self, usage: QBuffer.UsageType)");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_setUsage(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_setUsage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBuffer::UsageType a0;
        ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp, sipType_Qt3DRender_QBuffer_UsageType, &a0))
        {
            sipCpp->setUsage(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_setUsage, doc_Qt3DRender_QBuffer_setUsage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_setSyncData, "setSyncData(self, syncData: bool)");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_setSyncData(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_setSyncData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp, &a0))
        {
            sipCpp->setSyncData(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_setSyncData, doc_Qt3DRender_QBuffer_setSyncData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_sceneChangeEvent, "sceneChangeEvent(self, change: QSceneChange)");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_sceneChangeEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_sceneChangeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::Qt3DCore::QSceneChangePtr* a0;
        int a0State = 0;
        ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QSceneChange, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::Qt3DRender::QBuffer::sceneChangeEvent(*a0) : sipCpp->sceneChangeEvent(*a0));
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChangePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_sceneChangeEvent, doc_Qt3DRender_QBuffer_sceneChangeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_updateData, "updateData(self, offset: int, bytes: QByteArray|bytes|bytearray)");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_updateData(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_updateData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp, &a0, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->updateData(a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_updateData, doc_Qt3DRender_QBuffer_updateData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_accessType, "accessType(self) -> QBuffer.AccessType");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_accessType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_accessType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp))
        {
            ::Qt3DRender::QBuffer::AccessType sipRes;

            sipRes = sipCpp->accessType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBuffer_AccessType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_accessType, doc_Qt3DRender_QBuffer_accessType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBuffer_setAccessType, "setAccessType(self, access: QBuffer.AccessType)");

extern "C" {static PyObject *meth_Qt3DRender_QBuffer_setAccessType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBuffer_setAccessType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBuffer::AccessType a0;
        ::Qt3DRender::QBuffer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBuffer, &sipCpp, sipType_Qt3DRender_QBuffer_AccessType, &a0))
        {
            sipCpp->setAccessType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBuffer, sipName_setAccessType, doc_Qt3DRender_QBuffer_setAccessType);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QBuffer(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QBuffer(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QBuffer *sipCpp = reinterpret_cast< ::Qt3DRender::QBuffer *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QBuffer)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QNode)->ctd_cast(static_cast< ::Qt3DCore::QNode *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QBuffer(void *, int);}
static void release_Qt3DRender_QBuffer(void *sipCppV, int)
{
    ::Qt3DRender::QBuffer *sipCpp = reinterpret_cast< ::Qt3DRender::QBuffer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QBuffer(Py_ssize_t);}
static void *array_Qt3DRender_QBuffer(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QBuffer[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QBuffer(void *);}
static void array_delete_Qt3DRender_QBuffer(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QBuffer *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QBuffer(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QBuffer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QBuffer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QBuffer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QBuffer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QBuffer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QBuffer *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QBuffer(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::Qt3DRender::QBuffer::BufferType a0;
        ::Qt3DCore::QNode* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_Qt3DRender_QBuffer_BufferType, &a0, sipType_Qt3DCore_QNode, &a1, sipOwner))
        {
            sipCpp = new sipQt3DRender_QBuffer(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QBuffer[] = {{4, 2, 1}};


static PyMethodDef methods_Qt3DRender_QBuffer[] = {
    {sipName_accessType, meth_Qt3DRender_QBuffer_accessType, METH_VARARGS, doc_Qt3DRender_QBuffer_accessType},
    {sipName_data, meth_Qt3DRender_QBuffer_data, METH_VARARGS, doc_Qt3DRender_QBuffer_data},
    {sipName_dataGenerator, meth_Qt3DRender_QBuffer_dataGenerator, METH_VARARGS, doc_Qt3DRender_QBuffer_dataGenerator},
    {sipName_isSyncData, meth_Qt3DRender_QBuffer_isSyncData, METH_VARARGS, doc_Qt3DRender_QBuffer_isSyncData},
    {sipName_sceneChangeEvent, meth_Qt3DRender_QBuffer_sceneChangeEvent, METH_VARARGS, doc_Qt3DRender_QBuffer_sceneChangeEvent},
    {sipName_setAccessType, meth_Qt3DRender_QBuffer_setAccessType, METH_VARARGS, doc_Qt3DRender_QBuffer_setAccessType},
    {sipName_setData, meth_Qt3DRender_QBuffer_setData, METH_VARARGS, doc_Qt3DRender_QBuffer_setData},
    {sipName_setDataGenerator, meth_Qt3DRender_QBuffer_setDataGenerator, METH_VARARGS, doc_Qt3DRender_QBuffer_setDataGenerator},
    {sipName_setSyncData, meth_Qt3DRender_QBuffer_setSyncData, METH_VARARGS, doc_Qt3DRender_QBuffer_setSyncData},
    {sipName_setType, meth_Qt3DRender_QBuffer_setType, METH_VARARGS, doc_Qt3DRender_QBuffer_setType},
    {sipName_setUsage, meth_Qt3DRender_QBuffer_setUsage, METH_VARARGS, doc_Qt3DRender_QBuffer_setUsage},
    {sipName_type, meth_Qt3DRender_QBuffer_type, METH_VARARGS, doc_Qt3DRender_QBuffer_type},
    {sipName_updateData, meth_Qt3DRender_QBuffer_updateData, METH_VARARGS, doc_Qt3DRender_QBuffer_updateData},
    {sipName_usage, meth_Qt3DRender_QBuffer_usage, METH_VARARGS, doc_Qt3DRender_QBuffer_usage}
};

static sipEnumMemberDef enummembers_Qt3DRender_QBuffer[] = {
    {sipName_DrawIndirectBuffer, static_cast<int>(::Qt3DRender::QBuffer::DrawIndirectBuffer), 51},
    {sipName_DynamicCopy, static_cast<int>(::Qt3DRender::QBuffer::DynamicCopy), 52},
    {sipName_DynamicDraw, static_cast<int>(::Qt3DRender::QBuffer::DynamicDraw), 52},
    {sipName_DynamicRead, static_cast<int>(::Qt3DRender::QBuffer::DynamicRead), 52},
    {sipName_IndexBuffer, static_cast<int>(::Qt3DRender::QBuffer::IndexBuffer), 51},
    {sipName_PixelPackBuffer, static_cast<int>(::Qt3DRender::QBuffer::PixelPackBuffer), 51},
    {sipName_PixelUnpackBuffer, static_cast<int>(::Qt3DRender::QBuffer::PixelUnpackBuffer), 51},
    {sipName_Read, static_cast<int>(::Qt3DRender::QBuffer::Read), 50},
    {sipName_ReadWrite, static_cast<int>(::Qt3DRender::QBuffer::ReadWrite), 50},
    {sipName_ShaderStorageBuffer, static_cast<int>(::Qt3DRender::QBuffer::ShaderStorageBuffer), 51},
    {sipName_StaticCopy, static_cast<int>(::Qt3DRender::QBuffer::StaticCopy), 52},
    {sipName_StaticDraw, static_cast<int>(::Qt3DRender::QBuffer::StaticDraw), 52},
    {sipName_StaticRead, static_cast<int>(::Qt3DRender::QBuffer::StaticRead), 52},
    {sipName_StreamCopy, static_cast<int>(::Qt3DRender::QBuffer::StreamCopy), 52},
    {sipName_StreamDraw, static_cast<int>(::Qt3DRender::QBuffer::StreamDraw), 52},
    {sipName_StreamRead, static_cast<int>(::Qt3DRender::QBuffer::StreamRead), 52},
    {sipName_UniformBuffer, static_cast<int>(::Qt3DRender::QBuffer::UniformBuffer), 51},
    {sipName_VertexBuffer, static_cast<int>(::Qt3DRender::QBuffer::VertexBuffer), 51},
    {sipName_Write, static_cast<int>(::Qt3DRender::QBuffer::Write), 50},
};

PyDoc_STRVAR(doc_Qt3DRender_QBuffer, "\1QBuffer(parent: QNode|None = None)\n"
"QBuffer(ty: QBuffer.BufferType, parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QBuffer[] = {
    {"dataAvailable()", "\1dataAvailable(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"accessTypeChanged(AccessType)|(Qt3DRender::QBuffer::AccessType)", "\1accessTypeChanged(self, access: QBuffer.AccessType)", SIP_NULLPTR, SIP_NULLPTR},
    {"syncDataChanged(bool)", "\1syncDataChanged(self, syncData: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"usageChanged(UsageType)|(Qt3DRender::QBuffer::UsageType)", "\1usageChanged(self, usage: QBuffer.UsageType)", SIP_NULLPTR, SIP_NULLPTR},
    {"typeChanged(BufferType)|(Qt3DRender::QBuffer::BufferType)", "\1typeChanged(self, type: QBuffer.BufferType)", SIP_NULLPTR, SIP_NULLPTR},
    {"dataChanged(QByteArray)", "\1dataChanged(self, bytes: QByteArray|bytes|bytearray)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QBuffer = {
    &::Qt3DRender::QBuffer::staticMetaObject,
    0,
    signals_Qt3DRender_QBuffer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QBuffer = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QBuffer,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QBuffer,
    },
    {
        sipNameNr_QBuffer,
        {0, 0, 1},
        14, methods_Qt3DRender_QBuffer,
        19, enummembers_Qt3DRender_QBuffer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QBuffer,
    -1,
    -1,
    supers_Qt3DRender_QBuffer,
    SIP_NULLPTR,
    init_type_Qt3DRender_QBuffer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QBuffer,
    SIP_NULLPTR,
    array_Qt3DRender_QBuffer,
    SIP_NULLPTR,
    release_Qt3DRender_QBuffer,
    cast_Qt3DRender_QBuffer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QBuffer,
    sizeof (::Qt3DRender::QBuffer),
};
