/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 209 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 215 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 218 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 221 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 224 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 227 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 230 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 233 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 236 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 239 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 242 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 245 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 248 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 251 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 254 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 257 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 260 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 263 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQStencilOperationArguments.cpp"


PyDoc_STRVAR(doc_Qt3DRender_QStencilOperationArguments_faceMode, "faceMode(self) -> QStencilOperationArguments.FaceMode");

extern "C" {static PyObject *meth_Qt3DRender_QStencilOperationArguments_faceMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QStencilOperationArguments_faceMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QStencilOperationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QStencilOperationArguments, &sipCpp))
        {
            ::Qt3DRender::QStencilOperationArguments::FaceMode sipRes;

            sipRes = sipCpp->faceMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QStencilOperationArguments_FaceMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStencilOperationArguments, sipName_faceMode, doc_Qt3DRender_QStencilOperationArguments_faceMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QStencilOperationArguments_stencilTestFailureOperation, "stencilTestFailureOperation(self) -> QStencilOperationArguments.Operation");

extern "C" {static PyObject *meth_Qt3DRender_QStencilOperationArguments_stencilTestFailureOperation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QStencilOperationArguments_stencilTestFailureOperation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QStencilOperationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QStencilOperationArguments, &sipCpp))
        {
            ::Qt3DRender::QStencilOperationArguments::Operation sipRes;

            sipRes = sipCpp->stencilTestFailureOperation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QStencilOperationArguments_Operation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStencilOperationArguments, sipName_stencilTestFailureOperation, doc_Qt3DRender_QStencilOperationArguments_stencilTestFailureOperation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QStencilOperationArguments_depthTestFailureOperation, "depthTestFailureOperation(self) -> QStencilOperationArguments.Operation");

extern "C" {static PyObject *meth_Qt3DRender_QStencilOperationArguments_depthTestFailureOperation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QStencilOperationArguments_depthTestFailureOperation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QStencilOperationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QStencilOperationArguments, &sipCpp))
        {
            ::Qt3DRender::QStencilOperationArguments::Operation sipRes;

            sipRes = sipCpp->depthTestFailureOperation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QStencilOperationArguments_Operation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStencilOperationArguments, sipName_depthTestFailureOperation, doc_Qt3DRender_QStencilOperationArguments_depthTestFailureOperation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QStencilOperationArguments_allTestsPassOperation, "allTestsPassOperation(self) -> QStencilOperationArguments.Operation");

extern "C" {static PyObject *meth_Qt3DRender_QStencilOperationArguments_allTestsPassOperation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QStencilOperationArguments_allTestsPassOperation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QStencilOperationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QStencilOperationArguments, &sipCpp))
        {
            ::Qt3DRender::QStencilOperationArguments::Operation sipRes;

            sipRes = sipCpp->allTestsPassOperation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QStencilOperationArguments_Operation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStencilOperationArguments, sipName_allTestsPassOperation, doc_Qt3DRender_QStencilOperationArguments_allTestsPassOperation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QStencilOperationArguments_setStencilTestFailureOperation, "setStencilTestFailureOperation(self, operation: QStencilOperationArguments.Operation)");

extern "C" {static PyObject *meth_Qt3DRender_QStencilOperationArguments_setStencilTestFailureOperation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QStencilOperationArguments_setStencilTestFailureOperation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QStencilOperationArguments::Operation a0;
        ::Qt3DRender::QStencilOperationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QStencilOperationArguments, &sipCpp, sipType_Qt3DRender_QStencilOperationArguments_Operation, &a0))
        {
            sipCpp->setStencilTestFailureOperation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStencilOperationArguments, sipName_setStencilTestFailureOperation, doc_Qt3DRender_QStencilOperationArguments_setStencilTestFailureOperation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QStencilOperationArguments_setDepthTestFailureOperation, "setDepthTestFailureOperation(self, operation: QStencilOperationArguments.Operation)");

extern "C" {static PyObject *meth_Qt3DRender_QStencilOperationArguments_setDepthTestFailureOperation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QStencilOperationArguments_setDepthTestFailureOperation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QStencilOperationArguments::Operation a0;
        ::Qt3DRender::QStencilOperationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QStencilOperationArguments, &sipCpp, sipType_Qt3DRender_QStencilOperationArguments_Operation, &a0))
        {
            sipCpp->setDepthTestFailureOperation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStencilOperationArguments, sipName_setDepthTestFailureOperation, doc_Qt3DRender_QStencilOperationArguments_setDepthTestFailureOperation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QStencilOperationArguments_setAllTestsPassOperation, "setAllTestsPassOperation(self, operation: QStencilOperationArguments.Operation)");

extern "C" {static PyObject *meth_Qt3DRender_QStencilOperationArguments_setAllTestsPassOperation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QStencilOperationArguments_setAllTestsPassOperation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QStencilOperationArguments::Operation a0;
        ::Qt3DRender::QStencilOperationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QStencilOperationArguments, &sipCpp, sipType_Qt3DRender_QStencilOperationArguments_Operation, &a0))
        {
            sipCpp->setAllTestsPassOperation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStencilOperationArguments, sipName_setAllTestsPassOperation, doc_Qt3DRender_QStencilOperationArguments_setAllTestsPassOperation);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QStencilOperationArguments(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QStencilOperationArguments(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QStencilOperationArguments *sipCpp = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QStencilOperationArguments)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QStencilOperationArguments(void *, int);}
static void release_Qt3DRender_QStencilOperationArguments(void *sipCppV, int)
{
    ::Qt3DRender::QStencilOperationArguments *sipCpp = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_Qt3DRender_QStencilOperationArguments(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QStencilOperationArguments(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QStencilOperationArguments(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QStencilOperationArguments[] = {{4, 0, 1}};


static PyMethodDef methods_Qt3DRender_QStencilOperationArguments[] = {
    {sipName_allTestsPassOperation, meth_Qt3DRender_QStencilOperationArguments_allTestsPassOperation, METH_VARARGS, doc_Qt3DRender_QStencilOperationArguments_allTestsPassOperation},
    {sipName_depthTestFailureOperation, meth_Qt3DRender_QStencilOperationArguments_depthTestFailureOperation, METH_VARARGS, doc_Qt3DRender_QStencilOperationArguments_depthTestFailureOperation},
    {sipName_faceMode, meth_Qt3DRender_QStencilOperationArguments_faceMode, METH_VARARGS, doc_Qt3DRender_QStencilOperationArguments_faceMode},
    {sipName_setAllTestsPassOperation, meth_Qt3DRender_QStencilOperationArguments_setAllTestsPassOperation, METH_VARARGS, doc_Qt3DRender_QStencilOperationArguments_setAllTestsPassOperation},
    {sipName_setDepthTestFailureOperation, meth_Qt3DRender_QStencilOperationArguments_setDepthTestFailureOperation, METH_VARARGS, doc_Qt3DRender_QStencilOperationArguments_setDepthTestFailureOperation},
    {sipName_setStencilTestFailureOperation, meth_Qt3DRender_QStencilOperationArguments_setStencilTestFailureOperation, METH_VARARGS, doc_Qt3DRender_QStencilOperationArguments_setStencilTestFailureOperation},
    {sipName_stencilTestFailureOperation, meth_Qt3DRender_QStencilOperationArguments_stencilTestFailureOperation, METH_VARARGS, doc_Qt3DRender_QStencilOperationArguments_stencilTestFailureOperation}
};

static sipEnumMemberDef enummembers_Qt3DRender_QStencilOperationArguments[] = {
    {sipName_Back, static_cast<int>(::Qt3DRender::QStencilOperationArguments::Back), 172},
    {sipName_Decrement, static_cast<int>(::Qt3DRender::QStencilOperationArguments::Decrement), 173},
    {sipName_DecrementWrap, static_cast<int>(::Qt3DRender::QStencilOperationArguments::DecrementWrap), 173},
    {sipName_Front, static_cast<int>(::Qt3DRender::QStencilOperationArguments::Front), 172},
    {sipName_FrontAndBack, static_cast<int>(::Qt3DRender::QStencilOperationArguments::FrontAndBack), 172},
    {sipName_Increment, static_cast<int>(::Qt3DRender::QStencilOperationArguments::Increment), 173},
    {sipName_IncrementWrap, static_cast<int>(::Qt3DRender::QStencilOperationArguments::IncrementWrap), 173},
    {sipName_Invert, static_cast<int>(::Qt3DRender::QStencilOperationArguments::Invert), 173},
    {sipName_Keep, static_cast<int>(::Qt3DRender::QStencilOperationArguments::Keep), 173},
    {sipName_Replace, static_cast<int>(::Qt3DRender::QStencilOperationArguments::Replace), 173},
    {sipName_Zero, static_cast<int>(::Qt3DRender::QStencilOperationArguments::Zero), 173},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QStencilOperationArguments[] = {
    {"faceModeChanged(FaceMode)|(Qt3DRender::QStencilOperationArguments::FaceMode)", "\1faceModeChanged(self, faceMode: QStencilOperationArguments.FaceMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"allTestsPassOperationChanged(Operation)|(Qt3DRender::QStencilOperationArguments::Operation)", "\1allTestsPassOperationChanged(self, stencilDepthPass: QStencilOperationArguments.Operation)", SIP_NULLPTR, SIP_NULLPTR},
    {"depthTestFailureOperationChanged(Operation)|(Qt3DRender::QStencilOperationArguments::Operation)", "\1depthTestFailureOperationChanged(self, depthFail: QStencilOperationArguments.Operation)", SIP_NULLPTR, SIP_NULLPTR},
    {"stencilTestFailureOperationChanged(Operation)|(Qt3DRender::QStencilOperationArguments::Operation)", "\1stencilTestFailureOperationChanged(self, stencilFail: QStencilOperationArguments.Operation)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QStencilOperationArguments = {
    &::Qt3DRender::QStencilOperationArguments::staticMetaObject,
    0,
    signals_Qt3DRender_QStencilOperationArguments,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QStencilOperationArguments = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QStencilOperationArguments,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QStencilOperationArguments,
    },
    {
        sipNameNr_QStencilOperationArguments,
        {0, 0, 1},
        7, methods_Qt3DRender_QStencilOperationArguments,
        11, enummembers_Qt3DRender_QStencilOperationArguments,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_Qt3DRender_QStencilOperationArguments,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QStencilOperationArguments,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_Qt3DRender_QStencilOperationArguments,
    cast_Qt3DRender_QStencilOperationArguments,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
