/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 161 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 165 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 168 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 36 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 171 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 176 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 179 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 182 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 185 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 188 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 191 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 194 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 197 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 200 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 203 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 206 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 209 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 212 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 215 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 218 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQRenderCapabilities.cpp"


class sipQt3DRender_QRenderCapabilities : public ::Qt3DRender::QRenderCapabilities
{
public:
    sipQt3DRender_QRenderCapabilities(::QObject*);
    virtual ~sipQt3DRender_QRenderCapabilities();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QRenderCapabilities(const sipQt3DRender_QRenderCapabilities &);
    sipQt3DRender_QRenderCapabilities &operator = (const sipQt3DRender_QRenderCapabilities &);

    char sipPyMethods[7];
};

sipQt3DRender_QRenderCapabilities::sipQt3DRender_QRenderCapabilities(::QObject*a0): ::Qt3DRender::QRenderCapabilities(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QRenderCapabilities::~sipQt3DRender_QRenderCapabilities()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QRenderCapabilities::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QRenderCapabilities);

    return ::Qt3DRender::QRenderCapabilities::metaObject();
}

int sipQt3DRender_QRenderCapabilities::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QRenderCapabilities::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QRenderCapabilities, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QRenderCapabilities::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QRenderCapabilities, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QRenderCapabilities::qt_metacast(_clname));
}

bool sipQt3DRender_QRenderCapabilities::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QRenderCapabilities::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QRenderCapabilities::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QRenderCapabilities::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DRender_QRenderCapabilities::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QRenderCapabilities::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QRenderCapabilities::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QRenderCapabilities::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QRenderCapabilities::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QRenderCapabilities::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QRenderCapabilities::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QRenderCapabilities::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QRenderCapabilities::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QRenderCapabilities::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_isValid(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_isValid, doc_Qt3DRender_QRenderCapabilities_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_api, "api(self) -> QRenderCapabilities.API");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_api(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_api(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            ::Qt3DRender::QRenderCapabilities::API sipRes;

            sipRes = sipCpp->api();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QRenderCapabilities_API);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_api, doc_Qt3DRender_QRenderCapabilities_api);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_profile, "profile(self) -> QRenderCapabilities.Profile");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_profile(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_profile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            ::Qt3DRender::QRenderCapabilities::Profile sipRes;

            sipRes = sipCpp->profile();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QRenderCapabilities_Profile);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_profile, doc_Qt3DRender_QRenderCapabilities_profile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_majorVersion, "majorVersion(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_majorVersion(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_majorVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->majorVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_majorVersion, doc_Qt3DRender_QRenderCapabilities_majorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_minorVersion, "minorVersion(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_minorVersion(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_minorVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minorVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_minorVersion, doc_Qt3DRender_QRenderCapabilities_minorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_extensions, "extensions(self) -> list[str]");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_extensions(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_extensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->extensions());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_extensions, doc_Qt3DRender_QRenderCapabilities_extensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_vendor, "vendor(self) -> str");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_vendor(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_vendor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->vendor());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_vendor, doc_Qt3DRender_QRenderCapabilities_vendor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_renderer, "renderer(self) -> str");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_renderer(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_renderer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->renderer());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_renderer, doc_Qt3DRender_QRenderCapabilities_renderer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_driverVersion, "driverVersion(self) -> str");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_driverVersion(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_driverVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->driverVersion());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_driverVersion, doc_Qt3DRender_QRenderCapabilities_driverVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_glslVersion, "glslVersion(self) -> str");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_glslVersion(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_glslVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->glslVersion());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_glslVersion, doc_Qt3DRender_QRenderCapabilities_glslVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxSamples, "maxSamples(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxSamples(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxSamples(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxSamples();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxSamples, doc_Qt3DRender_QRenderCapabilities_maxSamples);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxTextureSize, "maxTextureSize(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxTextureSize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxTextureSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxTextureSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxTextureSize, doc_Qt3DRender_QRenderCapabilities_maxTextureSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxTextureUnits, "maxTextureUnits(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxTextureUnits(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxTextureUnits(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxTextureUnits();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxTextureUnits, doc_Qt3DRender_QRenderCapabilities_maxTextureUnits);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxTextureLayers, "maxTextureLayers(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxTextureLayers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxTextureLayers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxTextureLayers();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxTextureLayers, doc_Qt3DRender_QRenderCapabilities_maxTextureLayers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_supportsUBO, "supportsUBO(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_supportsUBO(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_supportsUBO(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->supportsUBO();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_supportsUBO, doc_Qt3DRender_QRenderCapabilities_supportsUBO);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxUBOSize, "maxUBOSize(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxUBOSize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxUBOSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxUBOSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxUBOSize, doc_Qt3DRender_QRenderCapabilities_maxUBOSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxUBOBindings, "maxUBOBindings(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxUBOBindings(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxUBOBindings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxUBOBindings();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxUBOBindings, doc_Qt3DRender_QRenderCapabilities_maxUBOBindings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_supportsSSBO, "supportsSSBO(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_supportsSSBO(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_supportsSSBO(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->supportsSSBO();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_supportsSSBO, doc_Qt3DRender_QRenderCapabilities_supportsSSBO);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxSSBOSize, "maxSSBOSize(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxSSBOSize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxSSBOSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxSSBOSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxSSBOSize, doc_Qt3DRender_QRenderCapabilities_maxSSBOSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxSSBOBindings, "maxSSBOBindings(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxSSBOBindings(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxSSBOBindings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxSSBOBindings();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxSSBOBindings, doc_Qt3DRender_QRenderCapabilities_maxSSBOBindings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_supportsImageStore, "supportsImageStore(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_supportsImageStore(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_supportsImageStore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->supportsImageStore();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_supportsImageStore, doc_Qt3DRender_QRenderCapabilities_supportsImageStore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxImageUnits, "maxImageUnits(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxImageUnits(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxImageUnits(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxImageUnits();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxImageUnits, doc_Qt3DRender_QRenderCapabilities_maxImageUnits);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_supportsCompute, "supportsCompute(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_supportsCompute(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_supportsCompute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->supportsCompute();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_supportsCompute, doc_Qt3DRender_QRenderCapabilities_supportsCompute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountX, "maxWorkGroupCountX(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountX(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxWorkGroupCountX();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxWorkGroupCountX, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountY, "maxWorkGroupCountY(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountY(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxWorkGroupCountY();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxWorkGroupCountY, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountZ, "maxWorkGroupCountZ(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountZ(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountZ(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxWorkGroupCountZ();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxWorkGroupCountZ, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountZ);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeX, "maxWorkGroupSizeX(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeX(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxWorkGroupSizeX();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxWorkGroupSizeX, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeY, "maxWorkGroupSizeY(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeY(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxWorkGroupSizeY();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxWorkGroupSizeY, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeZ, "maxWorkGroupSizeZ(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeZ(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeZ(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxWorkGroupSizeZ();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxWorkGroupSizeZ, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeZ);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxComputeInvocations, "maxComputeInvocations(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxComputeInvocations(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxComputeInvocations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxComputeInvocations();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxComputeInvocations, doc_Qt3DRender_QRenderCapabilities_maxComputeInvocations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities_maxComputeSharedMemorySize, "maxComputeSharedMemorySize(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QRenderCapabilities_maxComputeSharedMemorySize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QRenderCapabilities_maxComputeSharedMemorySize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QRenderCapabilities *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QRenderCapabilities, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxComputeSharedMemorySize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRenderCapabilities, sipName_maxComputeSharedMemorySize, doc_Qt3DRender_QRenderCapabilities_maxComputeSharedMemorySize);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QRenderCapabilities(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QRenderCapabilities(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QRenderCapabilities *sipCpp = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QRenderCapabilities)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QRenderCapabilities(void *, int);}
static void release_Qt3DRender_QRenderCapabilities(void *sipCppV, int)
{
    ::Qt3DRender::QRenderCapabilities *sipCpp = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QRenderCapabilities(Py_ssize_t);}
static void *array_Qt3DRender_QRenderCapabilities(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QRenderCapabilities[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QRenderCapabilities(void *);}
static void array_delete_Qt3DRender_QRenderCapabilities(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QRenderCapabilities(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QRenderCapabilities(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QRenderCapabilities *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QRenderCapabilities(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QRenderCapabilities(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QRenderCapabilities(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QRenderCapabilities *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QRenderCapabilities(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QRenderCapabilities[] = {{4, 0, 1}};


static PyMethodDef methods_Qt3DRender_QRenderCapabilities[] = {
    {sipName_api, meth_Qt3DRender_QRenderCapabilities_api, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_api},
    {sipName_driverVersion, meth_Qt3DRender_QRenderCapabilities_driverVersion, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_driverVersion},
    {sipName_extensions, meth_Qt3DRender_QRenderCapabilities_extensions, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_extensions},
    {sipName_glslVersion, meth_Qt3DRender_QRenderCapabilities_glslVersion, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_glslVersion},
    {sipName_isValid, meth_Qt3DRender_QRenderCapabilities_isValid, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_isValid},
    {sipName_majorVersion, meth_Qt3DRender_QRenderCapabilities_majorVersion, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_majorVersion},
    {sipName_maxComputeInvocations, meth_Qt3DRender_QRenderCapabilities_maxComputeInvocations, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxComputeInvocations},
    {sipName_maxComputeSharedMemorySize, meth_Qt3DRender_QRenderCapabilities_maxComputeSharedMemorySize, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxComputeSharedMemorySize},
    {sipName_maxImageUnits, meth_Qt3DRender_QRenderCapabilities_maxImageUnits, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxImageUnits},
    {sipName_maxSSBOBindings, meth_Qt3DRender_QRenderCapabilities_maxSSBOBindings, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxSSBOBindings},
    {sipName_maxSSBOSize, meth_Qt3DRender_QRenderCapabilities_maxSSBOSize, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxSSBOSize},
    {sipName_maxSamples, meth_Qt3DRender_QRenderCapabilities_maxSamples, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxSamples},
    {sipName_maxTextureLayers, meth_Qt3DRender_QRenderCapabilities_maxTextureLayers, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxTextureLayers},
    {sipName_maxTextureSize, meth_Qt3DRender_QRenderCapabilities_maxTextureSize, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxTextureSize},
    {sipName_maxTextureUnits, meth_Qt3DRender_QRenderCapabilities_maxTextureUnits, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxTextureUnits},
    {sipName_maxUBOBindings, meth_Qt3DRender_QRenderCapabilities_maxUBOBindings, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxUBOBindings},
    {sipName_maxUBOSize, meth_Qt3DRender_QRenderCapabilities_maxUBOSize, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxUBOSize},
    {sipName_maxWorkGroupCountX, meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountX, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountX},
    {sipName_maxWorkGroupCountY, meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountY, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountY},
    {sipName_maxWorkGroupCountZ, meth_Qt3DRender_QRenderCapabilities_maxWorkGroupCountZ, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupCountZ},
    {sipName_maxWorkGroupSizeX, meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeX, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeX},
    {sipName_maxWorkGroupSizeY, meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeY, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeY},
    {sipName_maxWorkGroupSizeZ, meth_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeZ, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_maxWorkGroupSizeZ},
    {sipName_minorVersion, meth_Qt3DRender_QRenderCapabilities_minorVersion, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_minorVersion},
    {sipName_profile, meth_Qt3DRender_QRenderCapabilities_profile, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_profile},
    {sipName_renderer, meth_Qt3DRender_QRenderCapabilities_renderer, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_renderer},
    {sipName_supportsCompute, meth_Qt3DRender_QRenderCapabilities_supportsCompute, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_supportsCompute},
    {sipName_supportsImageStore, meth_Qt3DRender_QRenderCapabilities_supportsImageStore, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_supportsImageStore},
    {sipName_supportsSSBO, meth_Qt3DRender_QRenderCapabilities_supportsSSBO, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_supportsSSBO},
    {sipName_supportsUBO, meth_Qt3DRender_QRenderCapabilities_supportsUBO, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_supportsUBO},
    {sipName_vendor, meth_Qt3DRender_QRenderCapabilities_vendor, METH_VARARGS, doc_Qt3DRender_QRenderCapabilities_vendor}
};

static sipEnumMemberDef enummembers_Qt3DRender_QRenderCapabilities[] = {
    {sipName_CompatibilityProfile, static_cast<int>(::Qt3DRender::QRenderCapabilities::CompatibilityProfile), 134},
    {sipName_CoreProfile, static_cast<int>(::Qt3DRender::QRenderCapabilities::CoreProfile), 134},
    {sipName_DirectX, static_cast<int>(::Qt3DRender::QRenderCapabilities::DirectX), 133},
    {sipName_NoProfile, static_cast<int>(::Qt3DRender::QRenderCapabilities::NoProfile), 134},
    {sipName_OpenGL, static_cast<int>(::Qt3DRender::QRenderCapabilities::OpenGL), 133},
    {sipName_OpenGLES, static_cast<int>(::Qt3DRender::QRenderCapabilities::OpenGLES), 133},
    {sipName_RHI, static_cast<int>(::Qt3DRender::QRenderCapabilities::RHI), 133},
    {sipName_Vulkan, static_cast<int>(::Qt3DRender::QRenderCapabilities::Vulkan), 133},
};

PyDoc_STRVAR(doc_Qt3DRender_QRenderCapabilities, "\1QRenderCapabilities(parent: QObject|None = None)");


static pyqt5ClassPluginDef plugin_Qt3DRender_QRenderCapabilities = {
    &::Qt3DRender::QRenderCapabilities::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QRenderCapabilities = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QRenderCapabilities,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QRenderCapabilities,
    },
    {
        sipNameNr_QRenderCapabilities,
        {0, 0, 1},
        31, methods_Qt3DRender_QRenderCapabilities,
        8, enummembers_Qt3DRender_QRenderCapabilities,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QRenderCapabilities,
    -1,
    -1,
    supers_Qt3DRender_QRenderCapabilities,
    SIP_NULLPTR,
    init_type_Qt3DRender_QRenderCapabilities,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QRenderCapabilities,
    SIP_NULLPTR,
    array_Qt3DRender_QRenderCapabilities,
    SIP_NULLPTR,
    release_Qt3DRender_QRenderCapabilities,
    cast_Qt3DRender_QRenderCapabilities,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QRenderCapabilities,
    sizeof (::Qt3DRender::QRenderCapabilities),
};
