/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 49 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 77 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 80 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 109 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 112 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 115 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 118 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 171 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 174 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 177 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 212 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 217 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 220 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 223 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 226 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 229 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 232 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 235 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 238 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 241 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 244 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 247 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 250 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 253 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 256 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQBlendEquationArguments.cpp"


class sipQt3DRender_QBlendEquationArguments : public ::Qt3DRender::QBlendEquationArguments
{
public:
    sipQt3DRender_QBlendEquationArguments(::Qt3DCore::QNode*);
    virtual ~sipQt3DRender_QBlendEquationArguments();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QBlendEquationArguments(const sipQt3DRender_QBlendEquationArguments &);
    sipQt3DRender_QBlendEquationArguments &operator = (const sipQt3DRender_QBlendEquationArguments &);

    char sipPyMethods[8];
};

sipQt3DRender_QBlendEquationArguments::sipQt3DRender_QBlendEquationArguments(::Qt3DCore::QNode*a0): ::Qt3DRender::QBlendEquationArguments(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QBlendEquationArguments::~sipQt3DRender_QBlendEquationArguments()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QBlendEquationArguments::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QBlendEquationArguments);

    return ::Qt3DRender::QBlendEquationArguments::metaObject();
}

int sipQt3DRender_QBlendEquationArguments::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QBlendEquationArguments::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QBlendEquationArguments, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QBlendEquationArguments::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QBlendEquationArguments, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QBlendEquationArguments::qt_metacast(_clname));
}

void sipQt3DRender_QBlendEquationArguments::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QBlendEquationArguments::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DRender_7(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QBlendEquationArguments::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QBlendEquationArguments::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QBlendEquationArguments::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QBlendEquationArguments::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DRender_QBlendEquationArguments::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QBlendEquationArguments::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBlendEquationArguments::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QBlendEquationArguments::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBlendEquationArguments::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QBlendEquationArguments::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBlendEquationArguments::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QBlendEquationArguments::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QBlendEquationArguments::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QBlendEquationArguments::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_sourceRgb, "sourceRgb(self) -> QBlendEquationArguments.Blending");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_sourceRgb(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_sourceRgb(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp))
        {
            ::Qt3DRender::QBlendEquationArguments::Blending sipRes;

            sipRes = sipCpp->sourceRgb();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquationArguments_Blending);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_sourceRgb, doc_Qt3DRender_QBlendEquationArguments_sourceRgb);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_destinationRgb, "destinationRgb(self) -> QBlendEquationArguments.Blending");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_destinationRgb(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_destinationRgb(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp))
        {
            ::Qt3DRender::QBlendEquationArguments::Blending sipRes;

            sipRes = sipCpp->destinationRgb();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquationArguments_Blending);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_destinationRgb, doc_Qt3DRender_QBlendEquationArguments_destinationRgb);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_sourceAlpha, "sourceAlpha(self) -> QBlendEquationArguments.Blending");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_sourceAlpha(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_sourceAlpha(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp))
        {
            ::Qt3DRender::QBlendEquationArguments::Blending sipRes;

            sipRes = sipCpp->sourceAlpha();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquationArguments_Blending);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_sourceAlpha, doc_Qt3DRender_QBlendEquationArguments_sourceAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_destinationAlpha, "destinationAlpha(self) -> QBlendEquationArguments.Blending");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_destinationAlpha(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_destinationAlpha(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp))
        {
            ::Qt3DRender::QBlendEquationArguments::Blending sipRes;

            sipRes = sipCpp->destinationAlpha();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QBlendEquationArguments_Blending);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_destinationAlpha, doc_Qt3DRender_QBlendEquationArguments_destinationAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_bufferIndex, "bufferIndex(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_bufferIndex(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_bufferIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->bufferIndex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_bufferIndex, doc_Qt3DRender_QBlendEquationArguments_bufferIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_setSourceRgb, "setSourceRgb(self, sourceRgb: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_setSourceRgb(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_setSourceRgb(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setSourceRgb(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_setSourceRgb, doc_Qt3DRender_QBlendEquationArguments_setSourceRgb);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_setDestinationRgb, "setDestinationRgb(self, destinationRgb: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_setDestinationRgb(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_setDestinationRgb(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setDestinationRgb(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_setDestinationRgb, doc_Qt3DRender_QBlendEquationArguments_setDestinationRgb);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_setSourceAlpha, "setSourceAlpha(self, sourceAlpha: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_setSourceAlpha(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_setSourceAlpha(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setSourceAlpha(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_setSourceAlpha, doc_Qt3DRender_QBlendEquationArguments_setSourceAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_setDestinationAlpha, "setDestinationAlpha(self, destinationAlpha: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_setDestinationAlpha(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_setDestinationAlpha(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setDestinationAlpha(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_setDestinationAlpha, doc_Qt3DRender_QBlendEquationArguments_setDestinationAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_setSourceRgba, "setSourceRgba(self, sourceRgba: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_setSourceRgba(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_setSourceRgba(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setSourceRgba(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_setSourceRgba, doc_Qt3DRender_QBlendEquationArguments_setSourceRgba);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_setDestinationRgba, "setDestinationRgba(self, destinationRgba: QBlendEquationArguments.Blending)");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_setDestinationRgba(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_setDestinationRgba(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QBlendEquationArguments::Blending a0;
        ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp, sipType_Qt3DRender_QBlendEquationArguments_Blending, &a0))
        {
            sipCpp->setDestinationRgba(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_setDestinationRgba, doc_Qt3DRender_QBlendEquationArguments_setDestinationRgba);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments_setBufferIndex, "setBufferIndex(self, index: int)");

extern "C" {static PyObject *meth_Qt3DRender_QBlendEquationArguments_setBufferIndex(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QBlendEquationArguments_setBufferIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QBlendEquationArguments *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QBlendEquationArguments, &sipCpp, &a0))
        {
            sipCpp->setBufferIndex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBlendEquationArguments, sipName_setBufferIndex, doc_Qt3DRender_QBlendEquationArguments_setBufferIndex);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QBlendEquationArguments(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QBlendEquationArguments(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QBlendEquationArguments *sipCpp = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QBlendEquationArguments)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DRender_QRenderState)->ctd_cast(static_cast< ::Qt3DRender::QRenderState *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QBlendEquationArguments(void *, int);}
static void release_Qt3DRender_QBlendEquationArguments(void *sipCppV, int)
{
    ::Qt3DRender::QBlendEquationArguments *sipCpp = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QBlendEquationArguments(Py_ssize_t);}
static void *array_Qt3DRender_QBlendEquationArguments(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QBlendEquationArguments[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QBlendEquationArguments(void *);}
static void array_delete_Qt3DRender_QBlendEquationArguments(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QBlendEquationArguments(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QBlendEquationArguments(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QBlendEquationArguments *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QBlendEquationArguments(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QBlendEquationArguments(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QBlendEquationArguments(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QBlendEquationArguments *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QBlendEquationArguments(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QBlendEquationArguments[] = {{141, 255, 1}};


static PyMethodDef methods_Qt3DRender_QBlendEquationArguments[] = {
    {sipName_bufferIndex, meth_Qt3DRender_QBlendEquationArguments_bufferIndex, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_bufferIndex},
    {sipName_destinationAlpha, meth_Qt3DRender_QBlendEquationArguments_destinationAlpha, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_destinationAlpha},
    {sipName_destinationRgb, meth_Qt3DRender_QBlendEquationArguments_destinationRgb, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_destinationRgb},
    {sipName_setBufferIndex, meth_Qt3DRender_QBlendEquationArguments_setBufferIndex, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_setBufferIndex},
    {sipName_setDestinationAlpha, meth_Qt3DRender_QBlendEquationArguments_setDestinationAlpha, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_setDestinationAlpha},
    {sipName_setDestinationRgb, meth_Qt3DRender_QBlendEquationArguments_setDestinationRgb, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_setDestinationRgb},
    {sipName_setDestinationRgba, meth_Qt3DRender_QBlendEquationArguments_setDestinationRgba, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_setDestinationRgba},
    {sipName_setSourceAlpha, meth_Qt3DRender_QBlendEquationArguments_setSourceAlpha, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_setSourceAlpha},
    {sipName_setSourceRgb, meth_Qt3DRender_QBlendEquationArguments_setSourceRgb, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_setSourceRgb},
    {sipName_setSourceRgba, meth_Qt3DRender_QBlendEquationArguments_setSourceRgba, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_setSourceRgba},
    {sipName_sourceAlpha, meth_Qt3DRender_QBlendEquationArguments_sourceAlpha, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_sourceAlpha},
    {sipName_sourceRgb, meth_Qt3DRender_QBlendEquationArguments_sourceRgb, METH_VARARGS, doc_Qt3DRender_QBlendEquationArguments_sourceRgb}
};

static sipEnumMemberDef enummembers_Qt3DRender_QBlendEquationArguments[] = {
    {sipName_ConstantAlpha, static_cast<int>(::Qt3DRender::QBlendEquationArguments::ConstantAlpha), 46},
    {sipName_ConstantColor, static_cast<int>(::Qt3DRender::QBlendEquationArguments::ConstantColor), 46},
    {sipName_DestinationAlpha, static_cast<int>(::Qt3DRender::QBlendEquationArguments::DestinationAlpha), 46},
    {sipName_DestinationColor, static_cast<int>(::Qt3DRender::QBlendEquationArguments::DestinationColor), 46},
    {sipName_One, static_cast<int>(::Qt3DRender::QBlendEquationArguments::One), 46},
    {sipName_OneMinusConstantAlpha, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusConstantAlpha), 46},
    {sipName_OneMinusConstantColor, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusConstantColor), 46},
    {sipName_OneMinusDestinationAlpha, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusDestinationAlpha), 46},
    {sipName_OneMinusDestinationColor, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusDestinationColor), 46},
    {sipName_OneMinusSource1Alpha, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusSource1Alpha), 46},
    {sipName_OneMinusSource1Color, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusSource1Color), 46},
    {sipName_OneMinusSource1Color0, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusSource1Color0), 46},
    {sipName_OneMinusSourceAlpha, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusSourceAlpha), 46},
    {sipName_OneMinusSourceColor, static_cast<int>(::Qt3DRender::QBlendEquationArguments::OneMinusSourceColor), 46},
    {sipName_Source1Alpha, static_cast<int>(::Qt3DRender::QBlendEquationArguments::Source1Alpha), 46},
    {sipName_Source1Color, static_cast<int>(::Qt3DRender::QBlendEquationArguments::Source1Color), 46},
    {sipName_SourceAlpha, static_cast<int>(::Qt3DRender::QBlendEquationArguments::SourceAlpha), 46},
    {sipName_SourceAlphaSaturate, static_cast<int>(::Qt3DRender::QBlendEquationArguments::SourceAlphaSaturate), 46},
    {sipName_SourceColor, static_cast<int>(::Qt3DRender::QBlendEquationArguments::SourceColor), 46},
    {sipName_Zero, static_cast<int>(::Qt3DRender::QBlendEquationArguments::Zero), 46},
};

PyDoc_STRVAR(doc_Qt3DRender_QBlendEquationArguments, "\1QBlendEquationArguments(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QBlendEquationArguments[] = {
    {"bufferIndexChanged(int)", "\1bufferIndexChanged(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"destinationRgbaChanged(Blending)|(Qt3DRender::QBlendEquationArguments::Blending)", "\1destinationRgbaChanged(self, destinationRgba: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceRgbaChanged(Blending)|(Qt3DRender::QBlendEquationArguments::Blending)", "\1sourceRgbaChanged(self, sourceRgba: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"destinationAlphaChanged(Blending)|(Qt3DRender::QBlendEquationArguments::Blending)", "\1destinationAlphaChanged(self, destinationAlpha: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"destinationRgbChanged(Blending)|(Qt3DRender::QBlendEquationArguments::Blending)", "\1destinationRgbChanged(self, destinationRgb: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceAlphaChanged(Blending)|(Qt3DRender::QBlendEquationArguments::Blending)", "\1sourceAlphaChanged(self, sourceAlpha: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceRgbChanged(Blending)|(Qt3DRender::QBlendEquationArguments::Blending)", "\1sourceRgbChanged(self, sourceRgb: QBlendEquationArguments.Blending)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QBlendEquationArguments = {
    &::Qt3DRender::QBlendEquationArguments::staticMetaObject,
    0,
    signals_Qt3DRender_QBlendEquationArguments,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QBlendEquationArguments = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QBlendEquationArguments,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QBlendEquationArguments,
    },
    {
        sipNameNr_QBlendEquationArguments,
        {0, 0, 1},
        12, methods_Qt3DRender_QBlendEquationArguments,
        20, enummembers_Qt3DRender_QBlendEquationArguments,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QBlendEquationArguments,
    -1,
    -1,
    supers_Qt3DRender_QBlendEquationArguments,
    SIP_NULLPTR,
    init_type_Qt3DRender_QBlendEquationArguments,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QBlendEquationArguments,
    SIP_NULLPTR,
    array_Qt3DRender_QBlendEquationArguments,
    SIP_NULLPTR,
    release_Qt3DRender_QBlendEquationArguments,
    cast_Qt3DRender_QBlendEquationArguments,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QBlendEquationArguments,
    sizeof (::Qt3DRender::QBlendEquationArguments),
};
