/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DCore.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 33 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 37 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 40 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 43 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 46 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 51 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 54 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 77 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 82 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 85 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 88 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 91 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 94 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 97 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 103 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 106 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 109 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 112 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 115 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 118 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 121 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQAspectEngine.cpp"


class sipQt3DCore_QAspectEngine : public ::Qt3DCore::QAspectEngine
{
public:
    sipQt3DCore_QAspectEngine(::QObject*);
    virtual ~sipQt3DCore_QAspectEngine();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DCore_QAspectEngine(const sipQt3DCore_QAspectEngine &);
    sipQt3DCore_QAspectEngine &operator = (const sipQt3DCore_QAspectEngine &);

    char sipPyMethods[7];
};

sipQt3DCore_QAspectEngine::sipQt3DCore_QAspectEngine(::QObject*a0): ::Qt3DCore::QAspectEngine(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DCore_QAspectEngine::~sipQt3DCore_QAspectEngine()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DCore_QAspectEngine::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DCore_qt_metaobject(sipPySelf, sipType_Qt3DCore_QAspectEngine);

    return ::Qt3DCore::QAspectEngine::metaObject();
}

int sipQt3DCore_QAspectEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DCore::QAspectEngine::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DCore_qt_metacall(sipPySelf, sipType_Qt3DCore_QAspectEngine, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DCore_QAspectEngine::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DCore_qt_metacast(sipPySelf, sipType_Qt3DCore_QAspectEngine, _clname, &sipCpp) ? sipCpp : ::Qt3DCore::QAspectEngine::qt_metacast(_clname));
}

bool sipQt3DCore_QAspectEngine::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DCore::QAspectEngine::event(a0);

    extern bool sipVH_Qt3DCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DCore_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DCore_QAspectEngine::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DCore::QAspectEngine::eventFilter(a0, a1);

    extern bool sipVH_Qt3DCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DCore_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DCore_QAspectEngine::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DCore::QAspectEngine::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DCore_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DCore_QAspectEngine::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DCore::QAspectEngine::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DCore_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DCore_QAspectEngine::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DCore::QAspectEngine::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DCore_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DCore_QAspectEngine::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DCore::QAspectEngine::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DCore_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DCore_QAspectEngine::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DCore::QAspectEngine::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DCore_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_setRootEntity, "setRootEntity(self, root: QEntity)");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_setRootEntity(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_setRootEntity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QEntityPtr* a0;
        int a0State = 0;
        ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QEntity, &a0, &a0State))
        {
            sipCpp->setRootEntity(*a0);
            sipReleaseType(a0, sipType_QSharedPointer_0100Qt3DCore_QEntity, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_setRootEntity, doc_Qt3DCore_QAspectEngine_setRootEntity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_rootEntity, "rootEntity(self) -> QEntity");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_rootEntity(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_rootEntity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp))
        {
            ::Qt3DCore::QEntityPtr*sipRes;

            sipRes = new ::Qt3DCore::QEntityPtr(sipCpp->rootEntity());

            return sipConvertFromNewType(sipRes, sipType_QSharedPointer_0100Qt3DCore_QEntity, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_rootEntity, doc_Qt3DCore_QAspectEngine_rootEntity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_registerAspect, "registerAspect(self, aspect: QAbstractAspect|None)\n"
"registerAspect(self, name: str|None)");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_registerAspect(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_registerAspect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QAbstractAspect* a0;
        ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp, sipType_Qt3DCore_QAbstractAspect, &a0))
        {
            sipCpp->registerAspect(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->registerAspect(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_registerAspect, doc_Qt3DCore_QAspectEngine_registerAspect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_unregisterAspect, "unregisterAspect(self, aspect: QAbstractAspect|None)\n"
"unregisterAspect(self, name: str|None)");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_unregisterAspect(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_unregisterAspect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QAbstractAspect* a0;
        ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp, sipType_Qt3DCore_QAbstractAspect, &a0))
        {
            sipCpp->unregisterAspect(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->unregisterAspect(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_unregisterAspect, doc_Qt3DCore_QAspectEngine_unregisterAspect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_aspects, "aspects(self) -> list[QAbstractAspect]");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_aspects(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_aspects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp))
        {
            QVector< ::Qt3DCore::QAbstractAspect*>*sipRes;

            sipRes = new QVector< ::Qt3DCore::QAbstractAspect*>(sipCpp->aspects());

            return sipConvertFromNewType(sipRes, sipType_QVector_0101Qt3DCore_QAbstractAspect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_aspects, doc_Qt3DCore_QAspectEngine_aspects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_executeCommand, "executeCommand(self, command: str|None) -> Any");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_executeCommand(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_executeCommand(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = new ::QVariant(sipCpp->executeCommand(*a0));
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_executeCommand, doc_Qt3DCore_QAspectEngine_executeCommand);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_setRunMode, "setRunMode(self, mode: QAspectEngine.RunMode)");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_setRunMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_setRunMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QAspectEngine::RunMode a0;
        ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp, sipType_Qt3DCore_QAspectEngine_RunMode, &a0))
        {
            sipCpp->setRunMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_setRunMode, doc_Qt3DCore_QAspectEngine_setRunMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_runMode, "runMode(self) -> QAspectEngine.RunMode");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_runMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_runMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp))
        {
            ::Qt3DCore::QAspectEngine::RunMode sipRes;

            sipRes = sipCpp->runMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DCore_QAspectEngine_RunMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_runMode, doc_Qt3DCore_QAspectEngine_runMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine_processFrame, "processFrame(self)");

extern "C" {static PyObject *meth_Qt3DCore_QAspectEngine_processFrame(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QAspectEngine_processFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QAspectEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QAspectEngine, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->processFrame();
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAspectEngine, sipName_processFrame, doc_Qt3DCore_QAspectEngine_processFrame);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DCore_QAspectEngine(void *, const sipTypeDef *);}
static void *cast_Qt3DCore_QAspectEngine(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DCore::QAspectEngine *sipCpp = reinterpret_cast< ::Qt3DCore::QAspectEngine *>(sipCppV);

    if (targetType == sipType_Qt3DCore_QAspectEngine)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DCore_QAspectEngine(void *, int);}
static void release_Qt3DCore_QAspectEngine(void *sipCppV, int)
{
    ::Qt3DCore::QAspectEngine *sipCpp = reinterpret_cast< ::Qt3DCore::QAspectEngine *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DCore_QAspectEngine(Py_ssize_t);}
static void *array_Qt3DCore_QAspectEngine(Py_ssize_t sipNrElem)
{
    return new ::Qt3DCore::QAspectEngine[sipNrElem];
}


extern "C" {static void array_delete_Qt3DCore_QAspectEngine(void *);}
static void array_delete_Qt3DCore_QAspectEngine(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DCore::QAspectEngine *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DCore_QAspectEngine(sipSimpleWrapper *);}
static void dealloc_Qt3DCore_QAspectEngine(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DCore_QAspectEngine *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DCore_QAspectEngine(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DCore_QAspectEngine(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DCore_QAspectEngine(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DCore_QAspectEngine *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQt3DCore_QAspectEngine(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DCore_QAspectEngine[] = {{5, 0, 1}};


static PyMethodDef methods_Qt3DCore_QAspectEngine[] = {
    {sipName_aspects, meth_Qt3DCore_QAspectEngine_aspects, METH_VARARGS, doc_Qt3DCore_QAspectEngine_aspects},
    {sipName_executeCommand, meth_Qt3DCore_QAspectEngine_executeCommand, METH_VARARGS, doc_Qt3DCore_QAspectEngine_executeCommand},
    {sipName_processFrame, meth_Qt3DCore_QAspectEngine_processFrame, METH_VARARGS, doc_Qt3DCore_QAspectEngine_processFrame},
    {sipName_registerAspect, meth_Qt3DCore_QAspectEngine_registerAspect, METH_VARARGS, doc_Qt3DCore_QAspectEngine_registerAspect},
    {sipName_rootEntity, meth_Qt3DCore_QAspectEngine_rootEntity, METH_VARARGS, doc_Qt3DCore_QAspectEngine_rootEntity},
    {sipName_runMode, meth_Qt3DCore_QAspectEngine_runMode, METH_VARARGS, doc_Qt3DCore_QAspectEngine_runMode},
    {sipName_setRootEntity, meth_Qt3DCore_QAspectEngine_setRootEntity, METH_VARARGS, doc_Qt3DCore_QAspectEngine_setRootEntity},
    {sipName_setRunMode, meth_Qt3DCore_QAspectEngine_setRunMode, METH_VARARGS, doc_Qt3DCore_QAspectEngine_setRunMode},
    {sipName_unregisterAspect, meth_Qt3DCore_QAspectEngine_unregisterAspect, METH_VARARGS, doc_Qt3DCore_QAspectEngine_unregisterAspect}
};

static sipEnumMemberDef enummembers_Qt3DCore_QAspectEngine[] = {
    {sipName_Automatic, static_cast<int>(::Qt3DCore::QAspectEngine::Automatic), 18},
    {sipName_Manual, static_cast<int>(::Qt3DCore::QAspectEngine::Manual), 18},
};

PyDoc_STRVAR(doc_Qt3DCore_QAspectEngine, "\1QAspectEngine(parent: QObject|None = None)");


static pyqt5ClassPluginDef plugin_Qt3DCore_QAspectEngine = {
    &::Qt3DCore::QAspectEngine::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QAspectEngine = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DCore__QAspectEngine,
        SIP_NULLPTR,
        &plugin_Qt3DCore_QAspectEngine,
    },
    {
        sipNameNr_QAspectEngine,
        {0, 0, 1},
        9, methods_Qt3DCore_QAspectEngine,
        2, enummembers_Qt3DCore_QAspectEngine,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DCore_QAspectEngine,
    -1,
    -1,
    supers_Qt3DCore_QAspectEngine,
    SIP_NULLPTR,
    init_type_Qt3DCore_QAspectEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DCore_QAspectEngine,
    SIP_NULLPTR,
    array_Qt3DCore_QAspectEngine,
    SIP_NULLPTR,
    release_Qt3DCore_QAspectEngine,
    cast_Qt3DCore_QAspectEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DCore_QAspectEngine,
    sizeof (::Qt3DCore::QAspectEngine),
};
