/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DInput.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboardhandler.sip"
#include <qkeyboardhandler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyevent.sip"
#include <qkeyevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qlogicaldevice.sip"
#include <qlogicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmousedevice.sip"
#include <qmousedevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmouseevent.sip"
#include <qmouseevent.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmouseevent.sip"
#include <qmouseevent.h>
#line 69 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"

#line 205 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 73 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 76 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 81 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 84 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 87 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 90 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 93 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 96 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 99 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 102 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 105 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 108 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 111 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 114 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 117 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 120 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 123 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 126 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQMouseEvent.cpp"


class sipQt3DInput_QMouseEvent : public ::Qt3DInput::QMouseEvent
{
public:
    sipQt3DInput_QMouseEvent(const ::QMouseEvent&);
    virtual ~sipQt3DInput_QMouseEvent();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DInput_QMouseEvent(const sipQt3DInput_QMouseEvent &);
    sipQt3DInput_QMouseEvent &operator = (const sipQt3DInput_QMouseEvent &);

    char sipPyMethods[7];
};

sipQt3DInput_QMouseEvent::sipQt3DInput_QMouseEvent(const ::QMouseEvent& a0): ::Qt3DInput::QMouseEvent(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DInput_QMouseEvent::~sipQt3DInput_QMouseEvent()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DInput_QMouseEvent::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DInput_qt_metaobject(sipPySelf, sipType_Qt3DInput_QMouseEvent);

    return ::Qt3DInput::QMouseEvent::metaObject();
}

int sipQt3DInput_QMouseEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DInput::QMouseEvent::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DInput_qt_metacall(sipPySelf, sipType_Qt3DInput_QMouseEvent, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DInput_QMouseEvent::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DInput_qt_metacast(sipPySelf, sipType_Qt3DInput_QMouseEvent, _clname, &sipCpp) ? sipCpp : ::Qt3DInput::QMouseEvent::qt_metacast(_clname));
}

bool sipQt3DInput_QMouseEvent::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DInput::QMouseEvent::event(a0);

    extern bool sipVH_Qt3DInput_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DInput_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DInput_QMouseEvent::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DInput::QMouseEvent::eventFilter(a0, a1);

    extern bool sipVH_Qt3DInput_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DInput_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DInput_QMouseEvent::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DInput::QMouseEvent::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DInput_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DInput_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DInput_QMouseEvent::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DInput::QMouseEvent::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DInput_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DInput_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DInput_QMouseEvent::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DInput::QMouseEvent::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DInput_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DInput_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DInput_QMouseEvent::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DInput::QMouseEvent::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DInput_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DInput_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DInput_QMouseEvent::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DInput::QMouseEvent::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DInput_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DInput_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_x, "x(self) -> int");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_x(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_x(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->x();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_x, doc_Qt3DInput_QMouseEvent_x);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_y, "y(self) -> int");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_y(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_y(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->y();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_y, doc_Qt3DInput_QMouseEvent_y);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_wasHeld, "wasHeld(self) -> bool");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_wasHeld(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_wasHeld(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->wasHeld();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_wasHeld, doc_Qt3DInput_QMouseEvent_wasHeld);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_button, "button(self) -> QMouseEvent.Buttons");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_button(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_button(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp))
        {
            ::Qt3DInput::QMouseEvent::Buttons sipRes;

            sipRes = sipCpp->button();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DInput_QMouseEvent_Buttons);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_button, doc_Qt3DInput_QMouseEvent_button);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_buttons, "buttons(self) -> int");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_buttons(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_buttons(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->buttons();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_buttons, doc_Qt3DInput_QMouseEvent_buttons);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_modifiers, "modifiers(self) -> QMouseEvent.Modifiers");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_modifiers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_modifiers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp))
        {
            ::Qt3DInput::QMouseEvent::Modifiers sipRes;

            sipRes = sipCpp->modifiers();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DInput_QMouseEvent_Modifiers);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_modifiers, doc_Qt3DInput_QMouseEvent_modifiers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_isAccepted, "isAccepted(self) -> bool");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_isAccepted(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_isAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAccepted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_isAccepted, doc_Qt3DInput_QMouseEvent_isAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_setAccepted, "setAccepted(self, accepted: bool)");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_setAccepted(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_setAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp, &a0))
        {
            sipCpp->setAccepted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_setAccepted, doc_Qt3DInput_QMouseEvent_setAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent_type, "type(self) -> QEvent.Type");

extern "C" {static PyObject *meth_Qt3DInput_QMouseEvent_type(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QMouseEvent_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QMouseEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QMouseEvent, &sipCpp))
        {
            ::QEvent::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QEvent_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMouseEvent, sipName_type, doc_Qt3DInput_QMouseEvent_type);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DInput_QMouseEvent(void *, const sipTypeDef *);}
static void *cast_Qt3DInput_QMouseEvent(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DInput::QMouseEvent *sipCpp = reinterpret_cast< ::Qt3DInput::QMouseEvent *>(sipCppV);

    if (targetType == sipType_Qt3DInput_QMouseEvent)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DInput_QMouseEvent(void *, int);}
static void release_Qt3DInput_QMouseEvent(void *sipCppV, int)
{
    ::Qt3DInput::QMouseEvent *sipCpp = reinterpret_cast< ::Qt3DInput::QMouseEvent *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_Qt3DInput_QMouseEvent(sipSimpleWrapper *);}
static void dealloc_Qt3DInput_QMouseEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DInput_QMouseEvent *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DInput_QMouseEvent(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DInput_QMouseEvent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DInput_QMouseEvent(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQt3DInput_QMouseEvent *sipCpp = SIP_NULLPTR;

    {
        const ::QMouseEvent* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QMouseEvent, &a0))
        {
            sipCpp = new sipQt3DInput_QMouseEvent(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DInput_QMouseEvent[] = {{4, 0, 1}};


static PyMethodDef methods_Qt3DInput_QMouseEvent[] = {
    {sipName_button, meth_Qt3DInput_QMouseEvent_button, METH_VARARGS, doc_Qt3DInput_QMouseEvent_button},
    {sipName_buttons, meth_Qt3DInput_QMouseEvent_buttons, METH_VARARGS, doc_Qt3DInput_QMouseEvent_buttons},
    {sipName_isAccepted, meth_Qt3DInput_QMouseEvent_isAccepted, METH_VARARGS, doc_Qt3DInput_QMouseEvent_isAccepted},
    {sipName_modifiers, meth_Qt3DInput_QMouseEvent_modifiers, METH_VARARGS, doc_Qt3DInput_QMouseEvent_modifiers},
    {sipName_setAccepted, meth_Qt3DInput_QMouseEvent_setAccepted, METH_VARARGS, doc_Qt3DInput_QMouseEvent_setAccepted},
    {sipName_type, meth_Qt3DInput_QMouseEvent_type, METH_VARARGS, doc_Qt3DInput_QMouseEvent_type},
    {sipName_wasHeld, meth_Qt3DInput_QMouseEvent_wasHeld, METH_VARARGS, doc_Qt3DInput_QMouseEvent_wasHeld},
    {sipName_x, meth_Qt3DInput_QMouseEvent_x, METH_VARARGS, doc_Qt3DInput_QMouseEvent_x},
    {sipName_y, meth_Qt3DInput_QMouseEvent_y, METH_VARARGS, doc_Qt3DInput_QMouseEvent_y}
};

static sipEnumMemberDef enummembers_Qt3DInput_QMouseEvent[] = {
    {sipName_AltModifier, static_cast<int>(::Qt3DInput::QMouseEvent::AltModifier), 28},
    {sipName_BackButton, static_cast<int>(::Qt3DInput::QMouseEvent::BackButton), 27},
    {sipName_ControlModifier, static_cast<int>(::Qt3DInput::QMouseEvent::ControlModifier), 28},
    {sipName_KeypadModifier, static_cast<int>(::Qt3DInput::QMouseEvent::KeypadModifier), 28},
    {sipName_LeftButton, static_cast<int>(::Qt3DInput::QMouseEvent::LeftButton), 27},
    {sipName_MetaModifier, static_cast<int>(::Qt3DInput::QMouseEvent::MetaModifier), 28},
    {sipName_MiddleButton, static_cast<int>(::Qt3DInput::QMouseEvent::MiddleButton), 27},
    {sipName_NoButton, static_cast<int>(::Qt3DInput::QMouseEvent::NoButton), 27},
    {sipName_NoModifier, static_cast<int>(::Qt3DInput::QMouseEvent::NoModifier), 28},
    {sipName_RightButton, static_cast<int>(::Qt3DInput::QMouseEvent::RightButton), 27},
    {sipName_ShiftModifier, static_cast<int>(::Qt3DInput::QMouseEvent::ShiftModifier), 28},
};

PyDoc_STRVAR(doc_Qt3DInput_QMouseEvent, "\1QMouseEvent(e: QMouseEvent)");


static pyqt5ClassPluginDef plugin_Qt3DInput_QMouseEvent = {
    &::Qt3DInput::QMouseEvent::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QMouseEvent = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DInput__QMouseEvent,
        SIP_NULLPTR,
        &plugin_Qt3DInput_QMouseEvent,
    },
    {
        sipNameNr_QMouseEvent,
        {0, 0, 1},
        9, methods_Qt3DInput_QMouseEvent,
        11, enummembers_Qt3DInput_QMouseEvent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DInput_QMouseEvent,
    -1,
    -1,
    supers_Qt3DInput_QMouseEvent,
    SIP_NULLPTR,
    init_type_Qt3DInput_QMouseEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DInput_QMouseEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_Qt3DInput_QMouseEvent,
    cast_Qt3DInput_QMouseEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::Qt3DInput::QMouseEvent),
};
