/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _Qt3DAnimationAPI_H
#define _Qt3DAnimationAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_Qt3DAnimation[0]
#define sipNameNr_63 63
#define sipName_63 &sipStrings_Qt3DAnimation[63]
#define sipNameNr_Qt3DAnimation__QAbstractAnimation__AnimationType 112
#define sipName_Qt3DAnimation__QAbstractAnimation__AnimationType &sipStrings_Qt3DAnimation[112]
#define sipNameNr_Qt3DAnimation__QClipBlendNodeCreatedChangeBase 161
#define sipName_Qt3DAnimation__QClipBlendNodeCreatedChangeBase &sipStrings_Qt3DAnimation[161]
#define sipNameNr_Qt3DAnimation__QKeyframeAnimation__RepeatMode 208
#define sipName_Qt3DAnimation__QKeyframeAnimation__RepeatMode &sipStrings_Qt3DAnimation[208]
#define sipNameNr_254 254
#define sipName_254 &sipStrings_Qt3DAnimation[254]
#define sipNameNr_Qt3DAnimation__QAbstractClipAnimator__Loops 298
#define sipName_Qt3DAnimation__QAbstractClipAnimator__Loops &sipStrings_Qt3DAnimation[298]
#define sipNameNr_Qt3DAnimation__QAnimationClipLoader__Status 342
#define sipName_Qt3DAnimation__QAnimationClipLoader__Status &sipStrings_Qt3DAnimation[342]
#define sipNameNr_Qt3DAnimation__QKeyFrame__InterpolationType 386
#define sipName_Qt3DAnimation__QKeyFrame__InterpolationType &sipStrings_Qt3DAnimation[386]
#define sipNameNr_Qt3DAnimation__QMorphingAnimation__Method 430
#define sipName_Qt3DAnimation__QMorphingAnimation__Method &sipStrings_Qt3DAnimation[430]
#define sipNameNr_472 472
#define sipName_472 &sipStrings_Qt3DAnimation[472]
#define sipNameNr_Qt3DAnimation__QAbstractChannelMapping 513
#define sipName_Qt3DAnimation__QAbstractChannelMapping &sipStrings_Qt3DAnimation[513]
#define sipNameNr_552 552
#define sipName_552 &sipStrings_Qt3DAnimation[552]
#define sipNameNr_Qt3DAnimation__QAbstractAnimationClip 590
#define sipName_Qt3DAnimation__QAbstractAnimationClip &sipStrings_Qt3DAnimation[590]
#define sipNameNr_Qt3DAnimation__QAbstractClipBlendNode 628
#define sipName_Qt3DAnimation__QAbstractClipBlendNode &sipStrings_Qt3DAnimation[628]
#define sipNameNr_Qt3DAnimation__QAbstractClipAnimator 666
#define sipName_Qt3DAnimation__QAbstractClipAnimator &sipStrings_Qt3DAnimation[666]
#define sipNameNr_Qt3DAnimation__QVertexBlendAnimation 703
#define sipName_Qt3DAnimation__QVertexBlendAnimation &sipStrings_Qt3DAnimation[703]
#define sipNameNr_Qt3DAnimation__QAnimationClipLoader 740
#define sipName_Qt3DAnimation__QAnimationClipLoader &sipStrings_Qt3DAnimation[740]
#define sipNameNr_Qt3DAnimation__QAnimationController 776
#define sipName_Qt3DAnimation__QAnimationController &sipStrings_Qt3DAnimation[776]
#define sipNameNr_Qt3DAnimation__QBlendedClipAnimator 812
#define sipName_Qt3DAnimation__QBlendedClipAnimator &sipStrings_Qt3DAnimation[812]
#define sipNameNr_Qt3DAnimation__QAbstractAnimation 848
#define sipName_Qt3DAnimation__QAbstractAnimation &sipStrings_Qt3DAnimation[848]
#define sipNameNr_Qt3DAnimation__QAdditiveClipBlend 882
#define sipName_Qt3DAnimation__QAdditiveClipBlend &sipStrings_Qt3DAnimation[882]
#define sipNameNr_Qt3DAnimation__QAnimationClipData 916
#define sipName_Qt3DAnimation__QAnimationClipData &sipStrings_Qt3DAnimation[916]
#define sipNameNr_Qt3DAnimation__QKeyframeAnimation 950
#define sipName_Qt3DAnimation__QKeyframeAnimation &sipStrings_Qt3DAnimation[950]
#define sipNameNr_Qt3DAnimation__QMorphingAnimation 984
#define sipName_Qt3DAnimation__QMorphingAnimation &sipStrings_Qt3DAnimation[984]
#define sipNameNr_Qt3DAnimation__QChannelComponent 1018
#define sipName_Qt3DAnimation__QChannelComponent &sipStrings_Qt3DAnimation[1018]
#define sipNameNr_QClipBlendNodeCreatedChangeBase 176
#define sipName_QClipBlendNodeCreatedChangeBase &sipStrings_Qt3DAnimation[176]
#define sipNameNr_Qt3DAnimation__QAnimationAspect 1051
#define sipName_Qt3DAnimation__QAnimationAspect &sipStrings_Qt3DAnimation[1051]
#define sipNameNr_Qt3DAnimation__QSkeletonMapping 1083
#define sipName_Qt3DAnimation__QSkeletonMapping &sipStrings_Qt3DAnimation[1083]
#define sipNameNr_1115 1115
#define sipName_1115 &sipStrings_Qt3DAnimation[1115]
#define sipNameNr_Qt3DAnimation__QAnimationGroup 1146
#define sipName_Qt3DAnimation__QAnimationGroup &sipStrings_Qt3DAnimation[1146]
#define sipNameNr_Qt3DAnimation__QChannelMapping 1177
#define sipName_Qt3DAnimation__QChannelMapping &sipStrings_Qt3DAnimation[1177]
#define sipNameNr_Qt3DAnimation__QClipBlendValue 1208
#define sipName_Qt3DAnimation__QClipBlendValue &sipStrings_Qt3DAnimation[1208]
#define sipNameNr_Qt3DAnimation__QAnimationClip 1239
#define sipName_Qt3DAnimation__QAnimationClip &sipStrings_Qt3DAnimation[1239]
#define sipNameNr_Qt3DAnimation__QChannelMapper 1269
#define sipName_Qt3DAnimation__QChannelMapper &sipStrings_Qt3DAnimation[1269]
#define sipNameNr_Qt3DAnimation__QLerpClipBlend 1299
#define sipName_Qt3DAnimation__QLerpClipBlend &sipStrings_Qt3DAnimation[1299]
#define sipNameNr_Qt3DAnimation__QClipAnimator 1329
#define sipName_Qt3DAnimation__QClipAnimator &sipStrings_Qt3DAnimation[1329]
#define sipNameNr_Qt3DAnimation__QMorphTarget 1358
#define sipName_Qt3DAnimation__QMorphTarget &sipStrings_Qt3DAnimation[1358]
#define sipNameNr_activeAnimationGroupChanged 1386
#define sipName_activeAnimationGroupChanged &sipStrings_Qt3DAnimation[1386]
#define sipNameNr_Qt3DAnimation__QKeyFrame 1414
#define sipName_Qt3DAnimation__QKeyFrame &sipStrings_Qt3DAnimation[1414]
#define sipNameNr_QAbstractChannelMapping 528
#define sipName_QAbstractChannelMapping &sipStrings_Qt3DAnimation[528]
#define sipNameNr_Qt3DAnimation__QChannel 1439
#define sipName_Qt3DAnimation__QChannel &sipStrings_Qt3DAnimation[1439]
#define sipNameNr_setActiveAnimationGroup 1463
#define sipName_setActiveAnimationGroup &sipStrings_Qt3DAnimation[1463]
#define sipNameNr_QAbstractAnimationClip 605
#define sipName_QAbstractAnimationClip &sipStrings_Qt3DAnimation[605]
#define sipNameNr_QAbstractClipBlendNode 643
#define sipName_QAbstractClipBlendNode &sipStrings_Qt3DAnimation[643]
#define sipNameNr_appendChannelComponent 1487
#define sipName_appendChannelComponent &sipStrings_Qt3DAnimation[1487]
#define sipNameNr_clearChannelComponents 1510
#define sipName_clearChannelComponents &sipStrings_Qt3DAnimation[1510]
#define sipNameNr_insertChannelComponent 1533
#define sipName_insertChannelComponent &sipStrings_Qt3DAnimation[1533]
#define sipNameNr_removeChannelComponent 1556
#define sipName_removeChannelComponent &sipStrings_Qt3DAnimation[1556]
#define sipNameNr_targetPositionsChanged 1579
#define sipName_targetPositionsChanged &sipStrings_Qt3DAnimation[1579]
#define sipNameNr_ConstantInterpolation 1602
#define sipName_ConstantInterpolation &sipStrings_Qt3DAnimation[1602]
#define sipNameNr_QAbstractClipAnimator 681
#define sipName_QAbstractClipAnimator &sipStrings_Qt3DAnimation[681]
#define sipNameNr_QVertexBlendAnimation 718
#define sipName_QVertexBlendAnimation &sipStrings_Qt3DAnimation[718]
#define sipNameNr_Qt3DAnimation__QClock 1624
#define sipName_Qt3DAnimation__QClock &sipStrings_Qt3DAnimation[1624]
#define sipNameNr_additiveFactorChanged 1646
#define sipName_additiveFactorChanged &sipStrings_Qt3DAnimation[1646]
#define sipNameNr_attributeNamesChanged 1668
#define sipName_attributeNamesChanged &sipStrings_Qt3DAnimation[1668]
#define sipNameNr_channelComponentCount 1690
#define sipName_channelComponentCount &sipStrings_Qt3DAnimation[1690]
#define sipNameNr_framePositionsChanged 1712
#define sipName_framePositionsChanged &sipStrings_Qt3DAnimation[1712]
#define sipNameNr_normalizedTimeChanged 1734
#define sipName_normalizedTimeChanged &sipStrings_Qt3DAnimation[1734]
#define sipNameNr_positionOffsetChanged 1756
#define sipName_positionOffsetChanged &sipStrings_Qt3DAnimation[1756]
#define sipNameNr_QAnimationClipLoader 755
#define sipName_QAnimationClipLoader &sipStrings_Qt3DAnimation[755]
#define sipNameNr_QAnimationController 791
#define sipName_QAnimationController &sipStrings_Qt3DAnimation[791]
#define sipNameNr_QBlendedClipAnimator 827
#define sipName_QBlendedClipAnimator &sipStrings_Qt3DAnimation[827]
#define sipNameNr_VertexBlendAnimation 719
#define sipName_VertexBlendAnimation &sipStrings_Qt3DAnimation[719]
#define sipNameNr_activeAnimationGroup 1778
#define sipName_activeAnimationGroup &sipStrings_Qt3DAnimation[1778]
#define sipNameNr_animationNameChanged 1799
#define sipName_animationNameChanged &sipStrings_Qt3DAnimation[1799]
#define sipNameNr_channelMapperChanged 1820
#define sipName_channelMapperChanged &sipStrings_Qt3DAnimation[1820]
#define sipNameNr_positionScaleChanged 1841
#define sipName_positionScaleChanged &sipStrings_Qt3DAnimation[1841]
#define sipNameNr_removeAnimationGroup 1862
#define sipName_removeAnimationGroup &sipStrings_Qt3DAnimation[1862]
#define sipNameNr_setInterpolationType 1883
#define sipName_setInterpolationType &sipStrings_Qt3DAnimation[1883]
#define sipNameNr_setRightControlPoint 1904
#define sipName_setRightControlPoint &sipStrings_Qt3DAnimation[1904]
#define sipNameNr_BezierInterpolation 1925
#define sipName_BezierInterpolation &sipStrings_Qt3DAnimation[1925]
#define sipNameNr_LinearInterpolation 1945
#define sipName_LinearInterpolation &sipStrings_Qt3DAnimation[1945]
#define sipNameNr_PyQt5_Qt3DAnimation 1965
#define sipName_PyQt5_Qt3DAnimation &sipStrings_Qt3DAnimation[1965]
#define sipNameNr_additiveClipChanged 1985
#define sipName_additiveClipChanged &sipStrings_Qt3DAnimation[1985]
#define sipNameNr_interpolatorChanged 2005
#define sipName_interpolatorChanged &sipStrings_Qt3DAnimation[2005]
#define sipNameNr_playbackRateChanged 2025
#define sipName_playbackRateChanged &sipStrings_Qt3DAnimation[2025]
#define sipNameNr_setLeftControlPoint 2045
#define sipName_setLeftControlPoint &sipStrings_Qt3DAnimation[2045]
#define sipNameNr_QAbstractAnimation 863
#define sipName_QAbstractAnimation &sipStrings_Qt3DAnimation[863]
#define sipNameNr_QAdditiveClipBlend 897
#define sipName_QAdditiveClipBlend &sipStrings_Qt3DAnimation[897]
#define sipNameNr_QAnimationClipData 931
#define sipName_QAnimationClipData &sipStrings_Qt3DAnimation[931]
#define sipNameNr_QKeyframeAnimation 965
#define sipName_QKeyframeAnimation &sipStrings_Qt3DAnimation[965]
#define sipNameNr_QMorphingAnimation 999
#define sipName_QMorphingAnimation &sipStrings_Qt3DAnimation[999]
#define sipNameNr_animationGroupList 2065
#define sipName_animationGroupList &sipStrings_Qt3DAnimation[2065]
#define sipNameNr_blendFactorChanged 2084
#define sipName_blendFactorChanged &sipStrings_Qt3DAnimation[2084]
#define sipNameNr_channelNameChanged 2103
#define sipName_channelNameChanged &sipStrings_Qt3DAnimation[2103]
#define sipNameNr_setAnimationGroups 2122
#define sipName_setAnimationGroups &sipStrings_Qt3DAnimation[2122]
#define sipNameNr_setTargetPositions 2141
#define sipName_setTargetPositions &sipStrings_Qt3DAnimation[2141]
#define sipNameNr_InterpolationType 412
#define sipName_InterpolationType &sipStrings_Qt3DAnimation[412]
#define sipNameNr_KeyframeAnimation 966
#define sipName_KeyframeAnimation &sipStrings_Qt3DAnimation[966]
#define sipNameNr_MorphingAnimation 1000
#define sipName_MorphingAnimation &sipStrings_Qt3DAnimation[1000]
#define sipNameNr_QChannelComponent 1033
#define sipName_QChannelComponent &sipStrings_Qt3DAnimation[1033]
#define sipNameNr_addAnimationGroup 2160
#define sipName_addAnimationGroup &sipStrings_Qt3DAnimation[2160]
#define sipNameNr_getAnimationIndex 2178
#define sipName_getAnimationIndex &sipStrings_Qt3DAnimation[2178]
#define sipNameNr_interpolationType 2196
#define sipName_interpolationType &sipStrings_Qt3DAnimation[2196]
#define sipNameNr_removeMorphTarget 2214
#define sipName_removeMorphTarget &sipStrings_Qt3DAnimation[2214]
#define sipNameNr_rightControlPoint 2232
#define sipName_rightControlPoint &sipStrings_Qt3DAnimation[2232]
#define sipNameNr_setAdditiveFactor 2250
#define sipName_setAdditiveFactor &sipStrings_Qt3DAnimation[2250]
#define sipNameNr_setFramePositions 2268
#define sipName_setFramePositions &sipStrings_Qt3DAnimation[2268]
#define sipNameNr_setNormalizedTime 2286
#define sipName_setNormalizedTime &sipStrings_Qt3DAnimation[2286]
#define sipNameNr_setPositionOffset 2304
#define sipName_setPositionOffset &sipStrings_Qt3DAnimation[2304]
#define sipNameNr_sip_simplewrapper 2322
#define sipName_sip_simplewrapper &sipStrings_Qt3DAnimation[2322]
#define sipNameNr_targetNameChanged 2340
#define sipName_targetNameChanged &sipStrings_Qt3DAnimation[2340]
#define sipNameNr_QAnimationAspect 1066
#define sipName_QAnimationAspect &sipStrings_Qt3DAnimation[1066]
#define sipNameNr_QSkeletonMapping 1098
#define sipName_QSkeletonMapping &sipStrings_Qt3DAnimation[1098]
#define sipNameNr_blendTreeChanged 2358
#define sipName_blendTreeChanged &sipStrings_Qt3DAnimation[2358]
#define sipNameNr_disconnectNotify 2375
#define sipName_disconnectNotify &sipStrings_Qt3DAnimation[2375]
#define sipNameNr_leftControlPoint 2392
#define sipName_leftControlPoint &sipStrings_Qt3DAnimation[2392]
#define sipNameNr_loopCountChanged 2409
#define sipName_loopCountChanged &sipStrings_Qt3DAnimation[2409]
#define sipNameNr_recursiveChanged 2426
#define sipName_recursiveChanged &sipStrings_Qt3DAnimation[2426]
#define sipNameNr_sceneChangeEvent 2443
#define sipName_sceneChangeEvent &sipStrings_Qt3DAnimation[2443]
#define sipNameNr_setAnimationName 2460
#define sipName_setAnimationName &sipStrings_Qt3DAnimation[2460]
#define sipNameNr_setChannelMapper 2477
#define sipName_setChannelMapper &sipStrings_Qt3DAnimation[2477]
#define sipNameNr_setPositionScale 2494
#define sipName_setPositionScale &sipStrings_Qt3DAnimation[2494]
#define sipNameNr_startClipChanged 2511
#define sipName_startClipChanged &sipStrings_Qt3DAnimation[2511]
#define sipNameNr_startModeChanged 2528
#define sipName_startModeChanged &sipStrings_Qt3DAnimation[2528]
#define sipNameNr_QAnimationGroup 1161
#define sipName_QAnimationGroup &sipStrings_Qt3DAnimation[1161]
#define sipNameNr_QChannelMapping 1192
#define sipName_QChannelMapping &sipStrings_Qt3DAnimation[1192]
#define sipNameNr_QClipBlendValue 1223
#define sipName_QClipBlendValue &sipStrings_Qt3DAnimation[1223]
#define sipNameNr_baseClipChanged 2545
#define sipName_baseClipChanged &sipStrings_Qt3DAnimation[2545]
#define sipNameNr_clipDataChanged 2561
#define sipName_clipDataChanged &sipStrings_Qt3DAnimation[2561]
#define sipNameNr_durationChanged 2577
#define sipName_durationChanged &sipStrings_Qt3DAnimation[2577]
#define sipNameNr_morphTargetList 2593
#define sipName_morphTargetList &sipStrings_Qt3DAnimation[2593]
#define sipNameNr_positionChanged 2609
#define sipName_positionChanged &sipStrings_Qt3DAnimation[2609]
#define sipNameNr_propertyChanged 2625
#define sipName_propertyChanged &sipStrings_Qt3DAnimation[2625]
#define sipNameNr_removeAnimation 2641
#define sipName_removeAnimation &sipStrings_Qt3DAnimation[2641]
#define sipNameNr_removeAttribute 2657
#define sipName_removeAttribute &sipStrings_Qt3DAnimation[2657]
#define sipNameNr_setAdditiveClip 2673
#define sipName_setAdditiveClip &sipStrings_Qt3DAnimation[2673]
#define sipNameNr_setMorphTargets 2689
#define sipName_setMorphTargets &sipStrings_Qt3DAnimation[2689]
#define sipNameNr_setPlaybackRate 2705
#define sipName_setPlaybackRate &sipStrings_Qt3DAnimation[2705]
#define sipNameNr_skeletonChanged 2721
#define sipName_skeletonChanged &sipStrings_Qt3DAnimation[2721]
#define sipNameNr_targetPositions 2737
#define sipName_targetPositions &sipStrings_Qt3DAnimation[2737]
#define sipNameNr_QAnimationClip 1254
#define sipName_QAnimationClip &sipStrings_Qt3DAnimation[1254]
#define sipNameNr_QChannelMapper 1284
#define sipName_QChannelMapper &sipStrings_Qt3DAnimation[1284]
#define sipNameNr_QLerpClipBlend 1314
#define sipName_QLerpClipBlend &sipStrings_Qt3DAnimation[1314]
#define sipNameNr_addMorphTarget 2753
#define sipName_addMorphTarget &sipStrings_Qt3DAnimation[2753]
#define sipNameNr_additiveFactor 2768
#define sipName_additiveFactor &sipStrings_Qt3DAnimation[2768]
#define sipNameNr_appendKeyFrame 2783
#define sipName_appendKeyFrame &sipStrings_Qt3DAnimation[2783]
#define sipNameNr_attributeNames 2798
#define sipName_attributeNames &sipStrings_Qt3DAnimation[2798]
#define sipNameNr_clearKeyFrames 2813
#define sipName_clearKeyFrames &sipStrings_Qt3DAnimation[2813]
#define sipNameNr_endClipChanged 2828
#define sipName_endClipChanged &sipStrings_Qt3DAnimation[2828]
#define sipNameNr_endModeChanged 2843
#define sipName_endModeChanged &sipStrings_Qt3DAnimation[2843]
#define sipNameNr_framePositions 2858
#define sipName_framePositions &sipStrings_Qt3DAnimation[2858]
#define sipNameNr_insertKeyFrame 2873
#define sipName_insertKeyFrame &sipStrings_Qt3DAnimation[2873]
#define sipNameNr_normalizedTime 2888
#define sipName_normalizedTime &sipStrings_Qt3DAnimation[2888]
#define sipNameNr_positionOffset 2903
#define sipName_positionOffset &sipStrings_Qt3DAnimation[2903]
#define sipNameNr_removeKeyFrame 2918
#define sipName_removeKeyFrame &sipStrings_Qt3DAnimation[2918]
#define sipNameNr_removeKeyframe 2933
#define sipName_removeKeyframe &sipStrings_Qt3DAnimation[2933]
#define sipNameNr_runningChanged 2948
#define sipName_runningChanged &sipStrings_Qt3DAnimation[2948]
#define sipNameNr_setBlendFactor 2963
#define sipName_setBlendFactor &sipStrings_Qt3DAnimation[2963]
#define sipNameNr_setChannelName 2978
#define sipName_setChannelName &sipStrings_Qt3DAnimation[2978]
#define sipNameNr_setCoordinates 2993
#define sipName_setCoordinates &sipStrings_Qt3DAnimation[2993]
#define sipNameNr_AnimationType 147
#define sipName_AnimationType &sipStrings_Qt3DAnimation[147]
#define sipNameNr_QClipAnimator 1344
#define sipName_QClipAnimator &sipStrings_Qt3DAnimation[1344]
#define sipNameNr_Qt3DAnimation 1971
#define sipName_Qt3DAnimation &sipStrings_Qt3DAnimation[1971]
#define sipNameNr_animationList 3008
#define sipName_animationList &sipStrings_Qt3DAnimation[3008]
#define sipNameNr_animationName 3022
#define sipName_animationName &sipStrings_Qt3DAnimation[3022]
#define sipNameNr_animationType 3036
#define sipName_animationType &sipStrings_Qt3DAnimation[3036]
#define sipNameNr_appendChannel 3050
#define sipName_appendChannel &sipStrings_Qt3DAnimation[3050]
#define sipNameNr_attributeList 3064
#define sipName_attributeList &sipStrings_Qt3DAnimation[3064]
#define sipNameNr_channelMapper 3078
#define sipName_channelMapper &sipStrings_Qt3DAnimation[3078]
#define sipNameNr_clearChannels 3092
#define sipName_clearChannels &sipStrings_Qt3DAnimation[3092]
#define sipNameNr_connectNotify 2378
#define sipName_connectNotify &sipStrings_Qt3DAnimation[2378]
#define sipNameNr_easingChanged 3106
#define sipName_easingChanged &sipStrings_Qt3DAnimation[3106]
#define sipNameNr_entityChanged 3120
#define sipName_entityChanged &sipStrings_Qt3DAnimation[3120]
#define sipNameNr_insertChannel 3134
#define sipName_insertChannel &sipStrings_Qt3DAnimation[3134]
#define sipNameNr_keyFrameCount 3148
#define sipName_keyFrameCount &sipStrings_Qt3DAnimation[3148]
#define sipNameNr_methodChanged 3162
#define sipName_methodChanged &sipStrings_Qt3DAnimation[3162]
#define sipNameNr_positionScale 3176
#define sipName_positionScale &sipStrings_Qt3DAnimation[3176]
#define sipNameNr_removeChannel 3190
#define sipName_removeChannel &sipStrings_Qt3DAnimation[3190]
#define sipNameNr_removeMapping 3204
#define sipName_removeMapping &sipStrings_Qt3DAnimation[3204]
#define sipNameNr_setAnimations 3218
#define sipName_setAnimations &sipStrings_Qt3DAnimation[3218]
#define sipNameNr_setAttributes 3232
#define sipName_setAttributes &sipStrings_Qt3DAnimation[3232]
#define sipNameNr_setJointIndex 3246
#define sipName_setJointIndex &sipStrings_Qt3DAnimation[3246]
#define sipNameNr_setTargetName 3260
#define sipName_setTargetName &sipStrings_Qt3DAnimation[3260]
#define sipNameNr_sourceChanged 3274
#define sipName_sourceChanged &sipStrings_Qt3DAnimation[3274]
#define sipNameNr_statusChanged 3288
#define sipName_statusChanged &sipStrings_Qt3DAnimation[3288]
#define sipNameNr_targetChanged 3302
#define sipName_targetChanged &sipStrings_Qt3DAnimation[3302]
#define sipNameNr_QMorphTarget 1373
#define sipName_QMorphTarget &sipStrings_Qt3DAnimation[1373]
#define sipNameNr_addAnimation 3316
#define sipName_addAnimation &sipStrings_Qt3DAnimation[3316]
#define sipNameNr_addAttribute 3329
#define sipName_addAttribute &sipStrings_Qt3DAnimation[3329]
#define sipNameNr_additiveClip 3342
#define sipName_additiveClip &sipStrings_Qt3DAnimation[3342]
#define sipNameNr_channelCount 3355
#define sipName_channelCount &sipStrings_Qt3DAnimation[3355]
#define sipNameNr_clockChanged 3368
#define sipName_clockChanged &sipStrings_Qt3DAnimation[3368]
#define sipNameNr_fromGeometry 3381
#define sipName_fromGeometry &sipStrings_Qt3DAnimation[3381]
#define sipNameNr_interpolator 3394
#define sipName_interpolator &sipStrings_Qt3DAnimation[3394]
#define sipNameNr_keyframeList 3407
#define sipName_keyframeList &sipStrings_Qt3DAnimation[3407]
#define sipNameNr_playbackRate 3420
#define sipName_playbackRate &sipStrings_Qt3DAnimation[3420]
#define sipNameNr_setBlendTree 3433
#define sipName_setBlendTree &sipStrings_Qt3DAnimation[3433]
#define sipNameNr_setKeyframes 3446
#define sipName_setKeyframes &sipStrings_Qt3DAnimation[3446]
#define sipNameNr_setLoopCount 3459
#define sipName_setLoopCount &sipStrings_Qt3DAnimation[3459]
#define sipNameNr_setRecursive 3472
#define sipName_setRecursive &sipStrings_Qt3DAnimation[3472]
#define sipNameNr_setStartClip 3485
#define sipName_setStartClip &sipStrings_Qt3DAnimation[3485]
#define sipNameNr_setStartMode 3498
#define sipName_setStartMode &sipStrings_Qt3DAnimation[3498]
#define sipNameNr_addKeyframe 3511
#define sipName_addKeyframe &sipStrings_Qt3DAnimation[3511]
#define sipNameNr_blendFactor 3523
#define sipName_blendFactor &sipStrings_Qt3DAnimation[3523]
#define sipNameNr_channelName 3535
#define sipName_channelName &sipStrings_Qt3DAnimation[3535]
#define sipNameNr_clipChanged 3547
#define sipName_clipChanged &sipStrings_Qt3DAnimation[3547]
#define sipNameNr_coordinates 3559
#define sipName_coordinates &sipStrings_Qt3DAnimation[3559]
#define sipNameNr_customEvent 3571
#define sipName_customEvent &sipStrings_Qt3DAnimation[3571]
#define sipNameNr_eventFilter 3583
#define sipName_eventFilter &sipStrings_Qt3DAnimation[3583]
#define sipNameNr_nameChanged 3595
#define sipName_nameChanged &sipStrings_Qt3DAnimation[3595]
#define sipNameNr_setBaseClip 3607
#define sipName_setBaseClip &sipStrings_Qt3DAnimation[3607]
#define sipNameNr_setClipData 3619
#define sipName_setClipData &sipStrings_Qt3DAnimation[3619]
#define sipNameNr_setDuration 3631
#define sipName_setDuration &sipStrings_Qt3DAnimation[3631]
#define sipNameNr_setPosition 3643
#define sipName_setPosition &sipStrings_Qt3DAnimation[3643]
#define sipNameNr_setProperty 3655
#define sipName_setProperty &sipStrings_Qt3DAnimation[3655]
#define sipNameNr_setSkeleton 3667
#define sipName_setSkeleton &sipStrings_Qt3DAnimation[3667]
#define sipNameNr_Normalized 3679
#define sipName_Normalized &sipStrings_Qt3DAnimation[3679]
#define sipNameNr_RepeatMode 243
#define sipName_RepeatMode &sipStrings_Qt3DAnimation[243]
#define sipNameNr_addMapping 3690
#define sipName_addMapping &sipStrings_Qt3DAnimation[3690]
#define sipNameNr_childEvent 3701
#define sipName_childEvent &sipStrings_Qt3DAnimation[3701]
#define sipNameNr_getWeights 3712
#define sipName_getWeights &sipStrings_Qt3DAnimation[3712]
#define sipNameNr_jointIndex 3723
#define sipName_jointIndex &sipStrings_Qt3DAnimation[3723]
#define sipNameNr_setEndClip 3734
#define sipName_setEndClip &sipStrings_Qt3DAnimation[3734]
#define sipNameNr_setEndMode 3745
#define sipName_setEndMode &sipStrings_Qt3DAnimation[3745]
#define sipNameNr_setRunning 3756
#define sipName_setRunning &sipStrings_Qt3DAnimation[3756]
#define sipNameNr_setWeights 3767
#define sipName_setWeights &sipStrings_Qt3DAnimation[3767]
#define sipNameNr_targetName 3778
#define sipName_targetName &sipStrings_Qt3DAnimation[3778]
#define sipNameNr_timerEvent 3789
#define sipName_timerEvent &sipStrings_Qt3DAnimation[3789]
#define sipNameNr_QKeyFrame 1429
#define sipName_QKeyFrame &sipStrings_Qt3DAnimation[1429]
#define sipNameNr_blendTree 3800
#define sipName_blendTree &sipStrings_Qt3DAnimation[3800]
#define sipNameNr_isRunning 3810
#define sipName_isRunning &sipStrings_Qt3DAnimation[3810]
#define sipNameNr_loopCount 3820
#define sipName_loopCount &sipStrings_Qt3DAnimation[3820]
#define sipNameNr_recursive 3830
#define sipName_recursive &sipStrings_Qt3DAnimation[3830]
#define sipNameNr_setEasing 3840
#define sipName_setEasing &sipStrings_Qt3DAnimation[3840]
#define sipNameNr_setEntity 3850
#define sipName_setEntity &sipStrings_Qt3DAnimation[3850]
#define sipNameNr_setMethod 3860
#define sipName_setMethod &sipStrings_Qt3DAnimation[3860]
#define sipNameNr_setSource 3870
#define sipName_setSource &sipStrings_Qt3DAnimation[3870]
#define sipNameNr_setTarget 3880
#define sipName_setTarget &sipStrings_Qt3DAnimation[3880]
#define sipNameNr_startClip 3890
#define sipName_startClip &sipStrings_Qt3DAnimation[3890]
#define sipNameNr_startMode 3900
#define sipName_startMode &sipStrings_Qt3DAnimation[3900]
#define sipNameNr_Constant 3910
#define sipName_Constant &sipStrings_Qt3DAnimation[3910]
#define sipNameNr_Infinite 3919
#define sipName_Infinite &sipStrings_Qt3DAnimation[3919]
#define sipNameNr_NotReady 3928
#define sipName_NotReady &sipStrings_Qt3DAnimation[3928]
#define sipNameNr_QChannel 1454
#define sipName_QChannel &sipStrings_Qt3DAnimation[1454]
#define sipNameNr_Relative 3937
#define sipName_Relative &sipStrings_Qt3DAnimation[3937]
#define sipNameNr_baseClip 3946
#define sipName_baseClip &sipStrings_Qt3DAnimation[3946]
#define sipNameNr_clipData 3955
#define sipName_clipData &sipStrings_Qt3DAnimation[3955]
#define sipNameNr_duration 3964
#define sipName_duration &sipStrings_Qt3DAnimation[3964]
#define sipNameNr_getGroup 3973
#define sipName_getGroup &sipStrings_Qt3DAnimation[3973]
#define sipNameNr_mappings 3982
#define sipName_mappings &sipStrings_Qt3DAnimation[3982]
#define sipNameNr_position 3991
#define sipName_position &sipStrings_Qt3DAnimation[3991]
#define sipNameNr_property 4000
#define sipName_property &sipStrings_Qt3DAnimation[4000]
#define sipNameNr_setClock 4009
#define sipName_setClock &sipStrings_Qt3DAnimation[4009]
#define sipNameNr_skeleton 4018
#define sipName_skeleton &sipStrings_Qt3DAnimation[4018]
#define sipNameNr_endClip 4027
#define sipName_endClip &sipStrings_Qt3DAnimation[4027]
#define sipNameNr_endMode 4035
#define sipName_endMode &sipStrings_Qt3DAnimation[4035]
#define sipNameNr_isValid 4043
#define sipName_isValid &sipStrings_Qt3DAnimation[4043]
#define sipNameNr_setClip 4051
#define sipName_setClip &sipStrings_Qt3DAnimation[4051]
#define sipNameNr_setName 4059
#define sipName_setName &sipStrings_Qt3DAnimation[4059]
#define sipNameNr_Method 465
#define sipName_Method &sipStrings_Qt3DAnimation[465]
#define sipNameNr_QClock 1639
#define sipName_QClock &sipStrings_Qt3DAnimation[1639]
#define sipNameNr_Repeat 4067
#define sipName_Repeat &sipStrings_Qt3DAnimation[4067]
#define sipNameNr_Status 379
#define sipName_Status &sipStrings_Qt3DAnimation[379]
#define sipNameNr___eq__ 4074
#define sipName___eq__ &sipStrings_Qt3DAnimation[4074]
#define sipNameNr___ne__ 4081
#define sipName___ne__ &sipStrings_Qt3DAnimation[4081]
#define sipNameNr_easing 4088
#define sipName_easing &sipStrings_Qt3DAnimation[4088]
#define sipNameNr_entity 4095
#define sipName_entity &sipStrings_Qt3DAnimation[4095]
#define sipNameNr_method 4102
#define sipName_method &sipStrings_Qt3DAnimation[4102]
#define sipNameNr_parent 4109
#define sipName_parent &sipStrings_Qt3DAnimation[4109]
#define sipNameNr_source 4116
#define sipName_source &sipStrings_Qt3DAnimation[4116]
#define sipNameNr_status 4123
#define sipName_status &sipStrings_Qt3DAnimation[4123]
#define sipNameNr_target 4130
#define sipName_target &sipStrings_Qt3DAnimation[4130]
#define sipNameNr_Error 4137
#define sipName_Error &sipStrings_Qt3DAnimation[4137]
#define sipNameNr_Loops 336
#define sipName_Loops &sipStrings_Qt3DAnimation[336]
#define sipNameNr_None_ 4143
#define sipName_None_ &sipStrings_Qt3DAnimation[4143]
#define sipNameNr_Ready 3931
#define sipName_Ready &sipStrings_Qt3DAnimation[3931]
#define sipNameNr_clock 4149
#define sipName_clock &sipStrings_Qt3DAnimation[4149]
#define sipNameNr_event 4155
#define sipName_event &sipStrings_Qt3DAnimation[4155]
#define sipNameNr_start 4161
#define sipName_start &sipStrings_Qt3DAnimation[4161]
#define sipNameNr_clip 4167
#define sipName_clip &sipStrings_Qt3DAnimation[4167]
#define sipNameNr_name 4172
#define sipName_name &sipStrings_Qt3DAnimation[4172]
#define sipNameNr_stop 4177
#define sipName_stop &sipStrings_Qt3DAnimation[4177]

#define sipMalloc                   sipAPI_Qt3DAnimation->api_malloc
#define sipFree                     sipAPI_Qt3DAnimation->api_free
#define sipBuildResult              sipAPI_Qt3DAnimation->api_build_result
#define sipCallMethod               sipAPI_Qt3DAnimation->api_call_method
#define sipCallProcedureMethod      sipAPI_Qt3DAnimation->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_Qt3DAnimation->api_call_error_handler
#define sipParseResultEx            sipAPI_Qt3DAnimation->api_parse_result_ex
#define sipParseResult              sipAPI_Qt3DAnimation->api_parse_result
#define sipParseArgs                sipAPI_Qt3DAnimation->api_parse_args
#define sipParseKwdArgs             sipAPI_Qt3DAnimation->api_parse_kwd_args
#define sipParsePair                sipAPI_Qt3DAnimation->api_parse_pair
#define sipInstanceDestroyed        sipAPI_Qt3DAnimation->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_Qt3DAnimation->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_Qt3DAnimation->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_Qt3DAnimation->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_Qt3DAnimation->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_Qt3DAnimation->api_convert_to_void_ptr
#define sipAddException             sipAPI_Qt3DAnimation->api_add_exception
#define sipNoFunction               sipAPI_Qt3DAnimation->api_no_function
#define sipNoMethod                 sipAPI_Qt3DAnimation->api_no_method
#define sipAbstractMethod           sipAPI_Qt3DAnimation->api_abstract_method
#define sipBadClass                 sipAPI_Qt3DAnimation->api_bad_class
#define sipBadCatcherResult         sipAPI_Qt3DAnimation->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_Qt3DAnimation->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_Qt3DAnimation->api_bad_operator_arg
#define sipTrace                    sipAPI_Qt3DAnimation->api_trace
#define sipTransferBack             sipAPI_Qt3DAnimation->api_transfer_back
#define sipTransferTo               sipAPI_Qt3DAnimation->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_Qt3DAnimation->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_Qt3DAnimation->api_wrapper_type
#define sipWrapperType_Type         sipAPI_Qt3DAnimation->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_Qt3DAnimation->api_voidptr_type
#define sipGetPyObject              sipAPI_Qt3DAnimation->api_get_pyobject
#define sipGetAddress               sipAPI_Qt3DAnimation->api_get_address
#define sipGetMixinAddress          sipAPI_Qt3DAnimation->api_get_mixin_address
#define sipGetCppPtr                sipAPI_Qt3DAnimation->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_Qt3DAnimation->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_Qt3DAnimation->api_call_hook
#define sipEndThread                sipAPI_Qt3DAnimation->api_end_thread
#define sipRaiseUnknownException    sipAPI_Qt3DAnimation->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_Qt3DAnimation->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_Qt3DAnimation->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_Qt3DAnimation->api_add_type_instance
#define sipPySlotExtend             sipAPI_Qt3DAnimation->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_Qt3DAnimation->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_Qt3DAnimation->api_can_convert_to_type
#define sipConvertToType            sipAPI_Qt3DAnimation->api_convert_to_type
#define sipForceConvertToType       sipAPI_Qt3DAnimation->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_Qt3DAnimation->api_convert_to_enum
#define sipConvertToBool            sipAPI_Qt3DAnimation->api_convert_to_bool
#define sipReleaseType              sipAPI_Qt3DAnimation->api_release_type
#define sipConvertFromType          sipAPI_Qt3DAnimation->api_convert_from_type
#define sipConvertFromNewType       sipAPI_Qt3DAnimation->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_Qt3DAnimation->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_Qt3DAnimation->api_convert_from_enum
#define sipGetState                 sipAPI_Qt3DAnimation->api_get_state
#define sipExportSymbol             sipAPI_Qt3DAnimation->api_export_symbol
#define sipImportSymbol             sipAPI_Qt3DAnimation->api_import_symbol
#define sipFindType                 sipAPI_Qt3DAnimation->api_find_type
#define sipBytes_AsChar             sipAPI_Qt3DAnimation->api_bytes_as_char
#define sipBytes_AsString           sipAPI_Qt3DAnimation->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_Qt3DAnimation->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_Qt3DAnimation->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_Qt3DAnimation->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_Qt3DAnimation->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_Qt3DAnimation->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_Qt3DAnimation->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_Qt3DAnimation->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_Qt3DAnimation->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_Qt3DAnimation->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_Qt3DAnimation->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_Qt3DAnimation->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_Qt3DAnimation->api_get_reference
#define sipKeepReference            sipAPI_Qt3DAnimation->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_Qt3DAnimation->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_Qt3DAnimation->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_Qt3DAnimation->api_type_from_py_type_object
#define sipTypeScope                sipAPI_Qt3DAnimation->api_type_scope
#define sipResolveTypedef           sipAPI_Qt3DAnimation->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_Qt3DAnimation->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_Qt3DAnimation->api_enable_autoconversion
#define sipInitMixin                sipAPI_Qt3DAnimation->api_init_mixin
#define sipExportModule             sipAPI_Qt3DAnimation->api_export_module
#define sipInitModule               sipAPI_Qt3DAnimation->api_init_module
#define sipGetInterpreter           sipAPI_Qt3DAnimation->api_get_interpreter
#define sipSetTypeUserData          sipAPI_Qt3DAnimation->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_Qt3DAnimation->api_get_type_user_data
#define sipPyTypeDict               sipAPI_Qt3DAnimation->api_py_type_dict
#define sipPyTypeName               sipAPI_Qt3DAnimation->api_py_type_name
#define sipGetCFunction             sipAPI_Qt3DAnimation->api_get_c_function
#define sipGetMethod                sipAPI_Qt3DAnimation->api_get_method
#define sipFromMethod               sipAPI_Qt3DAnimation->api_from_method
#define sipGetDate                  sipAPI_Qt3DAnimation->api_get_date
#define sipFromDate                 sipAPI_Qt3DAnimation->api_from_date
#define sipGetDateTime              sipAPI_Qt3DAnimation->api_get_datetime
#define sipFromDateTime             sipAPI_Qt3DAnimation->api_from_datetime
#define sipGetTime                  sipAPI_Qt3DAnimation->api_get_time
#define sipFromTime                 sipAPI_Qt3DAnimation->api_from_time
#define sipIsUserType               sipAPI_Qt3DAnimation->api_is_user_type
#define sipCheckPluginForType       sipAPI_Qt3DAnimation->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_Qt3DAnimation->api_unicode_new
#define sipUnicodeWrite             sipAPI_Qt3DAnimation->api_unicode_write
#define sipUnicodeData              sipAPI_Qt3DAnimation->api_unicode_data
#define sipGetBufferInfo            sipAPI_Qt3DAnimation->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_Qt3DAnimation->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_Qt3DAnimation->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_Qt3DAnimation->api_is_derived_class
#define sipGetUserObject            sipAPI_Qt3DAnimation->api_get_user_object
#define sipSetUserObject            sipAPI_Qt3DAnimation->api_set_user_object
#define sipRegisterEventHandler     sipAPI_Qt3DAnimation->api_register_event_handler
#define sipConvertToArray           sipAPI_Qt3DAnimation->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_Qt3DAnimation->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_Qt3DAnimation->api_enable_gc
#define sipPrintObject              sipAPI_Qt3DAnimation->api_print_object
#define sipLong_AsChar              sipAPI_Qt3DAnimation->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_Qt3DAnimation->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_Qt3DAnimation->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_Qt3DAnimation->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_Qt3DAnimation->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_Qt3DAnimation->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_Qt3DAnimation->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_Qt3DAnimation->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_Qt3DAnimation->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_Qt3DAnimation->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_Qt3DAnimation->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_Qt3DAnimation->api_long_as_size_t
#define sipVisitWrappers            sipAPI_Qt3DAnimation->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_Qt3DAnimation->api_register_exit_notifier
#define sipDeprecated               sipAPI_Qt3DAnimation->api_deprecated
#define sipPyTypeDictRef            sipAPI_Qt3DAnimation->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_Qt3DAnimation->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_Qt3DAnimation->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_Qt3DAnimation->api_get_frame
#define sipSetDestroyOnExit         sipAPI_Qt3DAnimation->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_Qt3DAnimation->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_Qt3DAnimation->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_Qt3DAnimation->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_Qt3DAnimation->api_connect_rx
#define sipConvertRx                sipAPI_Qt3DAnimation->api_convert_rx
#define sipDisconnectRx             sipAPI_Qt3DAnimation->api_disconnect_rx
#define sipFreeSipslot              sipAPI_Qt3DAnimation->api_free_sipslot
#define sipInvokeSlot               sipAPI_Qt3DAnimation->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_Qt3DAnimation->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_Qt3DAnimation->api_same_slot
#define sipSaveSlot                 sipAPI_Qt3DAnimation->api_save_slot
#define sipVisitSlot                sipAPI_Qt3DAnimation->api_visit_slot
#define sipIsPyMethod               sipAPI_Qt3DAnimation->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_Qt3DAnimation[];


#define sipType_Qt3DAnimation_QAbstractAnimation sipExportedTypes_Qt3DAnimation[6]

#define sipType_Qt3DAnimation_QAbstractAnimation_AnimationType sipExportedTypes_Qt3DAnimation[7]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractAnimation;

#define sipType_Qt3DAnimation_QAbstractAnimationClip sipExportedTypes_Qt3DAnimation[8]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractAnimationClip;

#define sipType_Qt3DAnimation_QAbstractChannelMapping sipExportedTypes_Qt3DAnimation[9]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractChannelMapping;

#define sipType_Qt3DAnimation_QAbstractClipAnimator sipExportedTypes_Qt3DAnimation[10]

#define sipType_Qt3DAnimation_QAbstractClipAnimator_Loops sipExportedTypes_Qt3DAnimation[11]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractClipAnimator;

#define sipType_Qt3DAnimation_QAbstractClipBlendNode sipExportedTypes_Qt3DAnimation[12]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractClipBlendNode;

#define sipType_Qt3DAnimation_QAdditiveClipBlend sipExportedTypes_Qt3DAnimation[13]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAdditiveClipBlend;

#define sipType_Qt3DAnimation_QAnimationAspect sipExportedTypes_Qt3DAnimation[14]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationAspect;

#define sipType_Qt3DAnimation_QAnimationClip sipExportedTypes_Qt3DAnimation[15]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationClip;

#define sipType_Qt3DAnimation_QAnimationClipData sipExportedTypes_Qt3DAnimation[16]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationClipData;

#define sipType_Qt3DAnimation_QAnimationClipLoader sipExportedTypes_Qt3DAnimation[17]

#define sipType_Qt3DAnimation_QAnimationClipLoader_Status sipExportedTypes_Qt3DAnimation[18]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationClipLoader;

#define sipType_Qt3DAnimation_QAnimationController sipExportedTypes_Qt3DAnimation[19]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationController;

#define sipType_Qt3DAnimation_QAnimationGroup sipExportedTypes_Qt3DAnimation[20]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAnimationGroup;

#define sipType_Qt3DAnimation_QBlendedClipAnimator sipExportedTypes_Qt3DAnimation[21]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QBlendedClipAnimator;

#define sipType_Qt3DAnimation_QChannel sipExportedTypes_Qt3DAnimation[22]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QChannel;

#define sipType_Qt3DAnimation_QChannelComponent sipExportedTypes_Qt3DAnimation[23]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QChannelComponent;

#define sipType_Qt3DAnimation_QChannelMapper sipExportedTypes_Qt3DAnimation[24]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QChannelMapper;

#define sipType_Qt3DAnimation_QChannelMapping sipExportedTypes_Qt3DAnimation[25]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QChannelMapping;

#define sipType_Qt3DAnimation_QClipAnimator sipExportedTypes_Qt3DAnimation[26]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QClipAnimator;

#define sipType_Qt3DAnimation_QClipBlendNodeCreatedChangeBase sipExportedTypes_Qt3DAnimation[27]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QClipBlendNodeCreatedChangeBase;

#define sipType_Qt3DAnimation_QClipBlendValue sipExportedTypes_Qt3DAnimation[28]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QClipBlendValue;

#define sipType_Qt3DAnimation_QClock sipExportedTypes_Qt3DAnimation[29]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QClock;

#define sipType_Qt3DAnimation_QKeyFrame sipExportedTypes_Qt3DAnimation[30]

#define sipType_Qt3DAnimation_QKeyFrame_InterpolationType sipExportedTypes_Qt3DAnimation[31]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QKeyFrame;

#define sipType_Qt3DAnimation_QKeyframeAnimation sipExportedTypes_Qt3DAnimation[32]

#define sipType_Qt3DAnimation_QKeyframeAnimation_RepeatMode sipExportedTypes_Qt3DAnimation[33]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QKeyframeAnimation;

#define sipType_Qt3DAnimation_QLerpClipBlend sipExportedTypes_Qt3DAnimation[34]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QLerpClipBlend;

#define sipType_Qt3DAnimation_QMorphingAnimation sipExportedTypes_Qt3DAnimation[36]

#define sipType_Qt3DAnimation_QMorphingAnimation_Method sipExportedTypes_Qt3DAnimation[37]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QMorphingAnimation;

#define sipType_Qt3DAnimation_QMorphTarget sipExportedTypes_Qt3DAnimation[35]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QMorphTarget;

#define sipType_Qt3DAnimation_QSkeletonMapping sipExportedTypes_Qt3DAnimation[38]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QSkeletonMapping;

#define sipType_Qt3DAnimation_QVertexBlendAnimation sipExportedTypes_Qt3DAnimation[39]

extern sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QVertexBlendAnimation;

#define sipType_QVector_0101Qt3DAnimation_QMorphTarget sipExportedTypes_Qt3DAnimation[4]

extern sipMappedTypeDef sipTypeDef_Qt3DAnimation_QVector_0101Qt3DAnimation_QMorphTarget;

#define sipType_QVector_0101Qt3DCore_QTransform sipExportedTypes_Qt3DAnimation[5]

extern sipMappedTypeDef sipTypeDef_Qt3DAnimation_QVector_0101Qt3DCore_QTransform;

#define sipType_QVector_0101Qt3DAnimation_QAbstractChannelMapping sipExportedTypes_Qt3DAnimation[2]

extern sipMappedTypeDef sipTypeDef_Qt3DAnimation_QVector_0101Qt3DAnimation_QAbstractChannelMapping;

#define sipType_QVector_0101Qt3DAnimation_QAbstractAnimation sipExportedTypes_Qt3DAnimation[1]

extern sipMappedTypeDef sipTypeDef_Qt3DAnimation_QVector_0101Qt3DAnimation_QAbstractAnimation;

#define sipType_QVector_0101Qt3DAnimation_QAnimationGroup sipExportedTypes_Qt3DAnimation[3]

extern sipMappedTypeDef sipTypeDef_Qt3DAnimation_QVector_0101Qt3DAnimation_QAnimationGroup;

#define sipType_QSharedPointer_0100Qt3DAnimation_QClipBlendNodeCreatedChangeBase sipExportedTypes_Qt3DAnimation[0]

extern sipMappedTypeDef sipTypeDef_Qt3DAnimation_QSharedPointer_0100Qt3DAnimation_QClipBlendNodeCreatedChangeBase;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_Qt3DAnimation;
extern sipExportedModuleDef sipModuleAPI_Qt3DAnimation;
extern sipTypeDef *sipExportedTypes_Qt3DAnimation[];

#define sipType_QObject sipImportedTypes_Qt3DAnimation_QtCore[4].it_td

#define sipType_QEvent sipImportedTypes_Qt3DAnimation_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_Qt3DAnimation_QtCore[7].it_td

#define sipType_QChildEvent sipImportedTypes_Qt3DAnimation_QtCore[0].it_td

#define sipType_QEasingCurve sipImportedTypes_Qt3DAnimation_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_Qt3DAnimation_QtCore[3].it_td

#define sipType_QUrl sipImportedTypes_Qt3DAnimation_QtCore[8].it_td

#define sipType_QStringList sipImportedTypes_Qt3DAnimation_QtCore[6].it_td

#define sipType_QString sipImportedTypes_Qt3DAnimation_QtCore[5].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DAnimation_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[];

#define sipType_QVector2D sipImportedTypes_Qt3DAnimation_QtGui[0].it_td

#define sipType_QVector_2200 sipImportedTypes_Qt3DAnimation_QtGui[1].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DAnimation_QtGui[];

#define sipType_Qt3DCore_QAbstractAspect sipImportedTypes_Qt3DAnimation_Qt3DCore[1].it_td

#define sipType_Qt3DCore_QNode sipImportedTypes_Qt3DAnimation_Qt3DCore[5].it_td

#define sipType_Qt3DCore_QAbstractSkeleton sipImportedTypes_Qt3DAnimation_Qt3DCore[2].it_td

#define sipType_Qt3DCore_QComponent sipImportedTypes_Qt3DAnimation_Qt3DCore[3].it_td

#define sipType_Qt3DCore_QSceneChange sipImportedTypes_Qt3DAnimation_Qt3DCore[7].it_td

#define sipType_Qt3DCore_QEntity sipImportedTypes_Qt3DAnimation_Qt3DCore[4].it_td

#define sipType_Qt3DCore_QNodeCreatedChangeBase sipImportedTypes_Qt3DAnimation_Qt3DCore[6].it_td

#define sipType_Qt3DCore_QTransform sipImportedTypes_Qt3DAnimation_Qt3DCore[8].it_td

#define sipType_QSharedPointer_0100Qt3DCore_QSceneChange sipImportedTypes_Qt3DAnimation_Qt3DCore[0].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DAnimation_Qt3DCore[];

#define sipType_Qt3DRender_QAttribute sipImportedTypes_Qt3DAnimation_Qt3DRender[1].it_td

#define sipType_Qt3DRender_QGeometry sipImportedTypes_Qt3DAnimation_Qt3DRender[2].it_td

#define sipType_Qt3DRender_QGeometryRenderer sipImportedTypes_Qt3DAnimation_Qt3DRender[3].it_td

#define sipType_QVector_0101Qt3DRender_QAttribute sipImportedTypes_Qt3DAnimation_Qt3DRender[0].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DAnimation_Qt3DRender[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_Qt3DAnimation_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_Qt3DAnimation_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_Qt3DAnimation_qt_metacast;
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"

#include <qsharedpointer.h>


// The dtor for the saved QSharedPointer.
#if defined(SIP_USE_PYCAPSULE)
template<class T>
void qt3d_QspDtor(PyObject *capsule)
{
    delete reinterpret_cast<QSharedPointer<T> *>(
            PyCapsule_GetPointer(capsule, 0));
}
#else
template<class T>
void qt3d_QspDtor(void *shared)
{
    delete reinterpret_cast<QSharedPointer<T> *>(array);
}
#endif


template<class T>
bool qt3d_SaveQsp(PyObject *py, QSharedPointer<T> *qsp)
{
    // Wrap the copy in a Python object.
#if defined(SIP_USE_PYCAPSULE)
    PyObject *qsp_obj = PyCapsule_New(qsp, 0, qt3d_QspDtor<T>);
#else
    PyObject *qsp_obj = PyCObject_FromVoidPtr(qsp, qt3d_QspDto<T>r);
#endif

    if (!qsp_obj)
        return false;

    sipSetUserObject((sipSimpleWrapper *)py, qsp_obj);

    return true;
}

#line 1017 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipAPIQt3DAnimation.h"

#endif
