/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DAnimation.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qlerpclipblend.sip"
#include <qlerpclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphinganimation.sip"
#include <qmorphinganimation.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphinganimation.sip"
#include <qmorphinganimation.h>
#line 79 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 83 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qeasingcurve.sip"
#include <qeasingcurve.h>
#line 86 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 89 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 162 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 134 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpygui_qvector.sip"
#include <qvector.h>
#line 165 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 168 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qlerpclipblend.sip"
#include <qlerpclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphinganimation.sip"
#include <qmorphinganimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphtarget.sip"
#include <qmorphtarget.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qmorphtarget.sip"
#include <qmorphtarget.h>
#line 223 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 228 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 233 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 236 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 239 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 242 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 245 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 248 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 251 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 254 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 257 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 260 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 263 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 266 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 269 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 272 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 275 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQMorphingAnimation.cpp"


class sipQt3DAnimation_QMorphingAnimation : public ::Qt3DAnimation::QMorphingAnimation
{
public:
    sipQt3DAnimation_QMorphingAnimation(::QObject*);
    virtual ~sipQt3DAnimation_QMorphingAnimation();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DAnimation_QMorphingAnimation(const sipQt3DAnimation_QMorphingAnimation &);
    sipQt3DAnimation_QMorphingAnimation &operator = (const sipQt3DAnimation_QMorphingAnimation &);

    char sipPyMethods[7];
};

sipQt3DAnimation_QMorphingAnimation::sipQt3DAnimation_QMorphingAnimation(::QObject*a0): ::Qt3DAnimation::QMorphingAnimation(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DAnimation_QMorphingAnimation::~sipQt3DAnimation_QMorphingAnimation()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DAnimation_QMorphingAnimation::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DAnimation_qt_metaobject(sipPySelf, sipType_Qt3DAnimation_QMorphingAnimation);

    return ::Qt3DAnimation::QMorphingAnimation::metaObject();
}

int sipQt3DAnimation_QMorphingAnimation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DAnimation::QMorphingAnimation::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DAnimation_qt_metacall(sipPySelf, sipType_Qt3DAnimation_QMorphingAnimation, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DAnimation_QMorphingAnimation::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DAnimation_qt_metacast(sipPySelf, sipType_Qt3DAnimation_QMorphingAnimation, _clname, &sipCpp) ? sipCpp : ::Qt3DAnimation::QMorphingAnimation::qt_metacast(_clname));
}

void sipQt3DAnimation_QMorphingAnimation::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QMorphingAnimation::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DAnimation_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QMorphingAnimation::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QMorphingAnimation::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DAnimation_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QMorphingAnimation::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QMorphingAnimation::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DAnimation_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QMorphingAnimation::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QMorphingAnimation::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DAnimation_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QMorphingAnimation::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QMorphingAnimation::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DAnimation_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DAnimation_QMorphingAnimation::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DAnimation::QMorphingAnimation::eventFilter(a0, a1);

    extern bool sipVH_Qt3DAnimation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DAnimation_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQt3DAnimation_QMorphingAnimation::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DAnimation::QMorphingAnimation::event(a0);

    extern bool sipVH_Qt3DAnimation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DAnimation_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_targetPositions, "targetPositions(self) -> list[float]");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_targetPositions(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_targetPositions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp))
        {
            ::QVector<float>*sipRes;

            sipRes = new ::QVector<float>(sipCpp->targetPositions());

            return sipConvertFromNewType(sipRes, sipType_QVector_2200, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_targetPositions, doc_Qt3DAnimation_QMorphingAnimation_targetPositions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_interpolator, "interpolator(self) -> float");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_interpolator(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_interpolator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->interpolator();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_interpolator, doc_Qt3DAnimation_QMorphingAnimation_interpolator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_target, "target(self) -> QGeometryRenderer|None");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_target(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_target(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp))
        {
            ::Qt3DRender::QGeometryRenderer*sipRes;

            sipRes = sipCpp->target();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QGeometryRenderer, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_target, doc_Qt3DAnimation_QMorphingAnimation_target);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_targetName, "targetName(self) -> str");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_targetName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_targetName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->targetName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_targetName, doc_Qt3DAnimation_QMorphingAnimation_targetName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_method, "method(self) -> QMorphingAnimation.Method");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_method(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_method(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp))
        {
            ::Qt3DAnimation::QMorphingAnimation::Method sipRes;

            sipRes = sipCpp->method();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DAnimation_QMorphingAnimation_Method);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_method, doc_Qt3DAnimation_QMorphingAnimation_method);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_easing, "easing(self) -> QEasingCurve");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_easing(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_easing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp))
        {
            ::QEasingCurve*sipRes;

            sipRes = new ::QEasingCurve(sipCpp->easing());

            return sipConvertFromNewType(sipRes, sipType_QEasingCurve, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_easing, doc_Qt3DAnimation_QMorphingAnimation_easing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_setMorphTargets, "setMorphTargets(self, targets: Iterable[QMorphTarget])");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setMorphTargets(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setMorphTargets(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QVector< ::Qt3DAnimation::QMorphTarget*>* a0;
        int a0State = 0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, sipType_QVector_0101Qt3DAnimation_QMorphTarget, &a0, &a0State))
        {
            sipCpp->setMorphTargets(*a0);
            sipReleaseType(const_cast<QVector< ::Qt3DAnimation::QMorphTarget*> *>(a0), sipType_QVector_0101Qt3DAnimation_QMorphTarget, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_setMorphTargets, doc_Qt3DAnimation_QMorphingAnimation_setMorphTargets);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_addMorphTarget, "addMorphTarget(self, target: QMorphTarget|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_addMorphTarget(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_addMorphTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QMorphTarget* a0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, sipType_Qt3DAnimation_QMorphTarget, &a0))
        {
            sipCpp->addMorphTarget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_addMorphTarget, doc_Qt3DAnimation_QMorphingAnimation_addMorphTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_removeMorphTarget, "removeMorphTarget(self, target: QMorphTarget|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_removeMorphTarget(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_removeMorphTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QMorphTarget* a0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, sipType_Qt3DAnimation_QMorphTarget, &a0))
        {
            sipCpp->removeMorphTarget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_removeMorphTarget, doc_Qt3DAnimation_QMorphingAnimation_removeMorphTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_setWeights, "setWeights(self, positionIndex: int, weights: Iterable[float])");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setWeights(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setWeights(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QVector<float>* a1;
        int a1State = 0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, &a0, sipType_QVector_2200, &a1, &a1State))
        {
            sipCpp->setWeights(a0, *a1);
            sipReleaseType(const_cast< ::QVector<float> *>(a1), sipType_QVector_2200, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_setWeights, doc_Qt3DAnimation_QMorphingAnimation_setWeights);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_getWeights, "getWeights(self, positionIndex: int) -> list[float]");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_getWeights(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_getWeights(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, &a0))
        {
            ::QVector<float>*sipRes;

            sipRes = new ::QVector<float>(sipCpp->getWeights(a0));

            return sipConvertFromNewType(sipRes, sipType_QVector_2200, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_getWeights, doc_Qt3DAnimation_QMorphingAnimation_getWeights);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_morphTargetList, "morphTargetList(self) -> list[QMorphTarget]");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_morphTargetList(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_morphTargetList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp))
        {
            QVector< ::Qt3DAnimation::QMorphTarget*>*sipRes;

            sipRes = new QVector< ::Qt3DAnimation::QMorphTarget*>(sipCpp->morphTargetList());

            return sipConvertFromNewType(sipRes, sipType_QVector_0101Qt3DAnimation_QMorphTarget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_morphTargetList, doc_Qt3DAnimation_QMorphingAnimation_morphTargetList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_setTargetPositions, "setTargetPositions(self, targetPositions: Iterable[float])");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setTargetPositions(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setTargetPositions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector<float>* a0;
        int a0State = 0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, sipType_QVector_2200, &a0, &a0State))
        {
            sipCpp->setTargetPositions(*a0);
            sipReleaseType(const_cast< ::QVector<float> *>(a0), sipType_QVector_2200, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_setTargetPositions, doc_Qt3DAnimation_QMorphingAnimation_setTargetPositions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_setTarget, "setTarget(self, target: QGeometryRenderer|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setTarget(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QGeometryRenderer* a0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, sipType_Qt3DRender_QGeometryRenderer, &a0))
        {
            sipCpp->setTarget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_setTarget, doc_Qt3DAnimation_QMorphingAnimation_setTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_setTargetName, "setTargetName(self, name: str|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setTargetName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setTargetName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTargetName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_setTargetName, doc_Qt3DAnimation_QMorphingAnimation_setTargetName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_setMethod, "setMethod(self, method: QMorphingAnimation.Method)");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setMethod(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setMethod(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QMorphingAnimation::Method a0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, sipType_Qt3DAnimation_QMorphingAnimation_Method, &a0))
        {
            sipCpp->setMethod(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_setMethod, doc_Qt3DAnimation_QMorphingAnimation_setMethod);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation_setEasing, "setEasing(self, easing: QEasingCurve|QEasingCurve.Type)");

extern "C" {static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setEasing(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QMorphingAnimation_setEasing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEasingCurve* a0;
        int a0State = 0;
        ::Qt3DAnimation::QMorphingAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QMorphingAnimation, &sipCpp, sipType_QEasingCurve, &a0, &a0State))
        {
            sipCpp->setEasing(*a0);
            sipReleaseType(const_cast< ::QEasingCurve *>(a0), sipType_QEasingCurve, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMorphingAnimation, sipName_setEasing, doc_Qt3DAnimation_QMorphingAnimation_setEasing);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DAnimation_QMorphingAnimation(void *, const sipTypeDef *);}
static void *cast_Qt3DAnimation_QMorphingAnimation(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DAnimation::QMorphingAnimation *sipCpp = reinterpret_cast< ::Qt3DAnimation::QMorphingAnimation *>(sipCppV);

    if (targetType == sipType_Qt3DAnimation_QMorphingAnimation)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DAnimation_QAbstractAnimation)->ctd_cast(static_cast< ::Qt3DAnimation::QAbstractAnimation *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DAnimation_QMorphingAnimation(void *, int);}
static void release_Qt3DAnimation_QMorphingAnimation(void *sipCppV, int)
{
    ::Qt3DAnimation::QMorphingAnimation *sipCpp = reinterpret_cast< ::Qt3DAnimation::QMorphingAnimation *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DAnimation_QMorphingAnimation(Py_ssize_t);}
static void *array_Qt3DAnimation_QMorphingAnimation(Py_ssize_t sipNrElem)
{
    return new ::Qt3DAnimation::QMorphingAnimation[sipNrElem];
}


extern "C" {static void array_delete_Qt3DAnimation_QMorphingAnimation(void *);}
static void array_delete_Qt3DAnimation_QMorphingAnimation(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DAnimation::QMorphingAnimation *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DAnimation_QMorphingAnimation(sipSimpleWrapper *);}
static void dealloc_Qt3DAnimation_QMorphingAnimation(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DAnimation_QMorphingAnimation *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DAnimation_QMorphingAnimation(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DAnimation_QMorphingAnimation(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DAnimation_QMorphingAnimation(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DAnimation_QMorphingAnimation *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQt3DAnimation_QMorphingAnimation(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DAnimation_QMorphingAnimation[] = {{6, 255, 1}};


static PyMethodDef methods_Qt3DAnimation_QMorphingAnimation[] = {
    {sipName_addMorphTarget, meth_Qt3DAnimation_QMorphingAnimation_addMorphTarget, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_addMorphTarget},
    {sipName_easing, meth_Qt3DAnimation_QMorphingAnimation_easing, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_easing},
    {sipName_getWeights, meth_Qt3DAnimation_QMorphingAnimation_getWeights, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_getWeights},
    {sipName_interpolator, meth_Qt3DAnimation_QMorphingAnimation_interpolator, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_interpolator},
    {sipName_method, meth_Qt3DAnimation_QMorphingAnimation_method, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_method},
    {sipName_morphTargetList, meth_Qt3DAnimation_QMorphingAnimation_morphTargetList, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_morphTargetList},
    {sipName_removeMorphTarget, meth_Qt3DAnimation_QMorphingAnimation_removeMorphTarget, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_removeMorphTarget},
    {sipName_setEasing, meth_Qt3DAnimation_QMorphingAnimation_setEasing, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_setEasing},
    {sipName_setMethod, meth_Qt3DAnimation_QMorphingAnimation_setMethod, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_setMethod},
    {sipName_setMorphTargets, meth_Qt3DAnimation_QMorphingAnimation_setMorphTargets, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_setMorphTargets},
    {sipName_setTarget, meth_Qt3DAnimation_QMorphingAnimation_setTarget, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_setTarget},
    {sipName_setTargetName, meth_Qt3DAnimation_QMorphingAnimation_setTargetName, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_setTargetName},
    {sipName_setTargetPositions, meth_Qt3DAnimation_QMorphingAnimation_setTargetPositions, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_setTargetPositions},
    {sipName_setWeights, meth_Qt3DAnimation_QMorphingAnimation_setWeights, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_setWeights},
    {sipName_target, meth_Qt3DAnimation_QMorphingAnimation_target, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_target},
    {sipName_targetName, meth_Qt3DAnimation_QMorphingAnimation_targetName, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_targetName},
    {sipName_targetPositions, meth_Qt3DAnimation_QMorphingAnimation_targetPositions, METH_VARARGS, doc_Qt3DAnimation_QMorphingAnimation_targetPositions}
};

static sipEnumMemberDef enummembers_Qt3DAnimation_QMorphingAnimation[] = {
    {sipName_Normalized, static_cast<int>(::Qt3DAnimation::QMorphingAnimation::Normalized), 37},
    {sipName_Relative, static_cast<int>(::Qt3DAnimation::QMorphingAnimation::Relative), 37},
};

PyDoc_STRVAR(doc_Qt3DAnimation_QMorphingAnimation, "\1QMorphingAnimation(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DAnimation_QMorphingAnimation[] = {
    {"easingChanged(QEasingCurve)", "\1easingChanged(self, easing: QEasingCurve|QEasingCurve.Type)", SIP_NULLPTR, SIP_NULLPTR},
    {"methodChanged(QMorphingAnimation::Method)|(Qt3DAnimation::QMorphingAnimation::Method)", "\1methodChanged(self, method: QMorphingAnimation.Method)", SIP_NULLPTR, SIP_NULLPTR},
    {"targetNameChanged(QString)", "\1targetNameChanged(self, name: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"targetChanged(Qt3DRender::QGeometryRenderer*)", "\1targetChanged(self, target: QGeometryRenderer|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"interpolatorChanged(float)", "\1interpolatorChanged(self, interpolator: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"targetPositionsChanged(QVector<float>)", "\1targetPositionsChanged(self, targetPositions: Iterable[float])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DAnimation_QMorphingAnimation = {
    &::Qt3DAnimation::QMorphingAnimation::staticMetaObject,
    0,
    signals_Qt3DAnimation_QMorphingAnimation,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QMorphingAnimation = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DAnimation__QMorphingAnimation,
        SIP_NULLPTR,
        &plugin_Qt3DAnimation_QMorphingAnimation,
    },
    {
        sipNameNr_QMorphingAnimation,
        {0, 0, 1},
        17, methods_Qt3DAnimation_QMorphingAnimation,
        2, enummembers_Qt3DAnimation_QMorphingAnimation,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DAnimation_QMorphingAnimation,
    -1,
    -1,
    supers_Qt3DAnimation_QMorphingAnimation,
    SIP_NULLPTR,
    init_type_Qt3DAnimation_QMorphingAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DAnimation_QMorphingAnimation,
    SIP_NULLPTR,
    array_Qt3DAnimation_QMorphingAnimation,
    SIP_NULLPTR,
    release_Qt3DAnimation_QMorphingAnimation,
    cast_Qt3DAnimation_QMorphingAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DAnimation_QMorphingAnimation,
    sizeof (::Qt3DAnimation::QMorphingAnimation),
};
