/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DAnimation.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframe.sip"
#include <qkeyframe.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qkeyframeanimation.sip"
#include <qkeyframeanimation.h>
#line 75 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 79 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 82 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qeasingcurve.sip"
#include <qeasingcurve.h>
#line 85 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeleton.sip"
#include <qskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeletonloader.sip"
#include <qskeletonloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyupdatedchangebase.sip"
#include <qstaticpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyvalueaddedchangebase.sip"
#include <qstaticpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyvalueremovedchangebase.sip"
#include <qstaticpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qtransform.sip"
#include <qtransform.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qtransform.sip"
#include <qtransform.h>
#line 150 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 134 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpygui_qvector.sip"
#include <qvector.h>
#line 153 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 156 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 161 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 166 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 169 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 172 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 175 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 178 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 181 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 184 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 187 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 190 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 193 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 196 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 199 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 202 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 205 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 208 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQKeyframeAnimation.cpp"


class sipQt3DAnimation_QKeyframeAnimation : public ::Qt3DAnimation::QKeyframeAnimation
{
public:
    sipQt3DAnimation_QKeyframeAnimation(::QObject*);
    virtual ~sipQt3DAnimation_QKeyframeAnimation();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DAnimation_QKeyframeAnimation(const sipQt3DAnimation_QKeyframeAnimation &);
    sipQt3DAnimation_QKeyframeAnimation &operator = (const sipQt3DAnimation_QKeyframeAnimation &);

    char sipPyMethods[7];
};

sipQt3DAnimation_QKeyframeAnimation::sipQt3DAnimation_QKeyframeAnimation(::QObject*a0): ::Qt3DAnimation::QKeyframeAnimation(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DAnimation_QKeyframeAnimation::~sipQt3DAnimation_QKeyframeAnimation()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DAnimation_QKeyframeAnimation::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DAnimation_qt_metaobject(sipPySelf, sipType_Qt3DAnimation_QKeyframeAnimation);

    return ::Qt3DAnimation::QKeyframeAnimation::metaObject();
}

int sipQt3DAnimation_QKeyframeAnimation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DAnimation::QKeyframeAnimation::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DAnimation_qt_metacall(sipPySelf, sipType_Qt3DAnimation_QKeyframeAnimation, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DAnimation_QKeyframeAnimation::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DAnimation_qt_metacast(sipPySelf, sipType_Qt3DAnimation_QKeyframeAnimation, _clname, &sipCpp) ? sipCpp : ::Qt3DAnimation::QKeyframeAnimation::qt_metacast(_clname));
}

void sipQt3DAnimation_QKeyframeAnimation::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QKeyframeAnimation::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DAnimation_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QKeyframeAnimation::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QKeyframeAnimation::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DAnimation_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QKeyframeAnimation::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QKeyframeAnimation::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DAnimation_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QKeyframeAnimation::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QKeyframeAnimation::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DAnimation_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QKeyframeAnimation::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QKeyframeAnimation::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DAnimation_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DAnimation_QKeyframeAnimation::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DAnimation::QKeyframeAnimation::eventFilter(a0, a1);

    extern bool sipVH_Qt3DAnimation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DAnimation_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQt3DAnimation_QKeyframeAnimation::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DAnimation::QKeyframeAnimation::event(a0);

    extern bool sipVH_Qt3DAnimation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DAnimation_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_framePositions, "framePositions(self) -> list[float]");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_framePositions(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_framePositions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp))
        {
            ::QVector<float>*sipRes;

            sipRes = new ::QVector<float>(sipCpp->framePositions());

            return sipConvertFromNewType(sipRes, sipType_QVector_2200, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_framePositions, doc_Qt3DAnimation_QKeyframeAnimation_framePositions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_keyframeList, "keyframeList(self) -> list[QTransform]");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_keyframeList(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_keyframeList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp))
        {
            QVector< ::Qt3DCore::QTransform*>*sipRes;

            sipRes = new QVector< ::Qt3DCore::QTransform*>(sipCpp->keyframeList());

            return sipConvertFromNewType(sipRes, sipType_QVector_0101Qt3DCore_QTransform, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_keyframeList, doc_Qt3DAnimation_QKeyframeAnimation_keyframeList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_target, "target(self) -> QTransform|None");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_target(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_target(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp))
        {
            ::Qt3DCore::QTransform*sipRes;

            sipRes = sipCpp->target();

            return sipConvertFromType(sipRes, sipType_Qt3DCore_QTransform, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_target, doc_Qt3DAnimation_QKeyframeAnimation_target);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_easing, "easing(self) -> QEasingCurve");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_easing(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_easing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp))
        {
            ::QEasingCurve*sipRes;

            sipRes = new ::QEasingCurve(sipCpp->easing());

            return sipConvertFromNewType(sipRes, sipType_QEasingCurve, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_easing, doc_Qt3DAnimation_QKeyframeAnimation_easing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_targetName, "targetName(self) -> str");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_targetName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_targetName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->targetName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_targetName, doc_Qt3DAnimation_QKeyframeAnimation_targetName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_startMode, "startMode(self) -> QKeyframeAnimation.RepeatMode");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_startMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_startMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp))
        {
            ::Qt3DAnimation::QKeyframeAnimation::RepeatMode sipRes;

            sipRes = sipCpp->startMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DAnimation_QKeyframeAnimation_RepeatMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_startMode, doc_Qt3DAnimation_QKeyframeAnimation_startMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_endMode, "endMode(self) -> QKeyframeAnimation.RepeatMode");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_endMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_endMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp))
        {
            ::Qt3DAnimation::QKeyframeAnimation::RepeatMode sipRes;

            sipRes = sipCpp->endMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DAnimation_QKeyframeAnimation_RepeatMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_endMode, doc_Qt3DAnimation_QKeyframeAnimation_endMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_setKeyframes, "setKeyframes(self, keyframes: Iterable[QTransform])");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setKeyframes(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setKeyframes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QVector< ::Qt3DCore::QTransform*>* a0;
        int a0State = 0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_QVector_0101Qt3DCore_QTransform, &a0, &a0State))
        {
            sipCpp->setKeyframes(*a0);
            sipReleaseType(const_cast<QVector< ::Qt3DCore::QTransform*> *>(a0), sipType_QVector_0101Qt3DCore_QTransform, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_setKeyframes, doc_Qt3DAnimation_QKeyframeAnimation_setKeyframes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_addKeyframe, "addKeyframe(self, keyframe: QTransform|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_addKeyframe(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_addKeyframe(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QTransform* a0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_Qt3DCore_QTransform, &a0))
        {
            sipCpp->addKeyframe(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_addKeyframe, doc_Qt3DAnimation_QKeyframeAnimation_addKeyframe);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_removeKeyframe, "removeKeyframe(self, keyframe: QTransform|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_removeKeyframe(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_removeKeyframe(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QTransform* a0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_Qt3DCore_QTransform, &a0))
        {
            sipCpp->removeKeyframe(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_removeKeyframe, doc_Qt3DAnimation_QKeyframeAnimation_removeKeyframe);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_setFramePositions, "setFramePositions(self, positions: Iterable[float])");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setFramePositions(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setFramePositions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector<float>* a0;
        int a0State = 0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_QVector_2200, &a0, &a0State))
        {
            sipCpp->setFramePositions(*a0);
            sipReleaseType(const_cast< ::QVector<float> *>(a0), sipType_QVector_2200, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_setFramePositions, doc_Qt3DAnimation_QKeyframeAnimation_setFramePositions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_setTarget, "setTarget(self, target: QTransform|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setTarget(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QTransform* a0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_Qt3DCore_QTransform, &a0))
        {
            sipCpp->setTarget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_setTarget, doc_Qt3DAnimation_QKeyframeAnimation_setTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_setEasing, "setEasing(self, easing: QEasingCurve|QEasingCurve.Type)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setEasing(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setEasing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEasingCurve* a0;
        int a0State = 0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_QEasingCurve, &a0, &a0State))
        {
            sipCpp->setEasing(*a0);
            sipReleaseType(const_cast< ::QEasingCurve *>(a0), sipType_QEasingCurve, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_setEasing, doc_Qt3DAnimation_QKeyframeAnimation_setEasing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_setTargetName, "setTargetName(self, name: str|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setTargetName(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setTargetName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTargetName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_setTargetName, doc_Qt3DAnimation_QKeyframeAnimation_setTargetName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_setStartMode, "setStartMode(self, mode: QKeyframeAnimation.RepeatMode)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setStartMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setStartMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QKeyframeAnimation::RepeatMode a0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_Qt3DAnimation_QKeyframeAnimation_RepeatMode, &a0))
        {
            sipCpp->setStartMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_setStartMode, doc_Qt3DAnimation_QKeyframeAnimation_setStartMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation_setEndMode, "setEndMode(self, mode: QKeyframeAnimation.RepeatMode)");

extern "C" {static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setEndMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QKeyframeAnimation_setEndMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QKeyframeAnimation::RepeatMode a0;
        ::Qt3DAnimation::QKeyframeAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DAnimation_QKeyframeAnimation, &sipCpp, sipType_Qt3DAnimation_QKeyframeAnimation_RepeatMode, &a0))
        {
            sipCpp->setEndMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyframeAnimation, sipName_setEndMode, doc_Qt3DAnimation_QKeyframeAnimation_setEndMode);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DAnimation_QKeyframeAnimation(void *, const sipTypeDef *);}
static void *cast_Qt3DAnimation_QKeyframeAnimation(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DAnimation::QKeyframeAnimation *sipCpp = reinterpret_cast< ::Qt3DAnimation::QKeyframeAnimation *>(sipCppV);

    if (targetType == sipType_Qt3DAnimation_QKeyframeAnimation)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DAnimation_QAbstractAnimation)->ctd_cast(static_cast< ::Qt3DAnimation::QAbstractAnimation *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DAnimation_QKeyframeAnimation(void *, int);}
static void release_Qt3DAnimation_QKeyframeAnimation(void *sipCppV, int)
{
    ::Qt3DAnimation::QKeyframeAnimation *sipCpp = reinterpret_cast< ::Qt3DAnimation::QKeyframeAnimation *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DAnimation_QKeyframeAnimation(Py_ssize_t);}
static void *array_Qt3DAnimation_QKeyframeAnimation(Py_ssize_t sipNrElem)
{
    return new ::Qt3DAnimation::QKeyframeAnimation[sipNrElem];
}


extern "C" {static void array_delete_Qt3DAnimation_QKeyframeAnimation(void *);}
static void array_delete_Qt3DAnimation_QKeyframeAnimation(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DAnimation::QKeyframeAnimation *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DAnimation_QKeyframeAnimation(sipSimpleWrapper *);}
static void dealloc_Qt3DAnimation_QKeyframeAnimation(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DAnimation_QKeyframeAnimation *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DAnimation_QKeyframeAnimation(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DAnimation_QKeyframeAnimation(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DAnimation_QKeyframeAnimation(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DAnimation_QKeyframeAnimation *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQt3DAnimation_QKeyframeAnimation(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DAnimation_QKeyframeAnimation[] = {{6, 255, 1}};


static PyMethodDef methods_Qt3DAnimation_QKeyframeAnimation[] = {
    {sipName_addKeyframe, meth_Qt3DAnimation_QKeyframeAnimation_addKeyframe, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_addKeyframe},
    {sipName_easing, meth_Qt3DAnimation_QKeyframeAnimation_easing, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_easing},
    {sipName_endMode, meth_Qt3DAnimation_QKeyframeAnimation_endMode, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_endMode},
    {sipName_framePositions, meth_Qt3DAnimation_QKeyframeAnimation_framePositions, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_framePositions},
    {sipName_keyframeList, meth_Qt3DAnimation_QKeyframeAnimation_keyframeList, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_keyframeList},
    {sipName_removeKeyframe, meth_Qt3DAnimation_QKeyframeAnimation_removeKeyframe, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_removeKeyframe},
    {sipName_setEasing, meth_Qt3DAnimation_QKeyframeAnimation_setEasing, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_setEasing},
    {sipName_setEndMode, meth_Qt3DAnimation_QKeyframeAnimation_setEndMode, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_setEndMode},
    {sipName_setFramePositions, meth_Qt3DAnimation_QKeyframeAnimation_setFramePositions, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_setFramePositions},
    {sipName_setKeyframes, meth_Qt3DAnimation_QKeyframeAnimation_setKeyframes, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_setKeyframes},
    {sipName_setStartMode, meth_Qt3DAnimation_QKeyframeAnimation_setStartMode, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_setStartMode},
    {sipName_setTarget, meth_Qt3DAnimation_QKeyframeAnimation_setTarget, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_setTarget},
    {sipName_setTargetName, meth_Qt3DAnimation_QKeyframeAnimation_setTargetName, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_setTargetName},
    {sipName_startMode, meth_Qt3DAnimation_QKeyframeAnimation_startMode, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_startMode},
    {sipName_target, meth_Qt3DAnimation_QKeyframeAnimation_target, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_target},
    {sipName_targetName, meth_Qt3DAnimation_QKeyframeAnimation_targetName, METH_VARARGS, doc_Qt3DAnimation_QKeyframeAnimation_targetName}
};

static sipEnumMemberDef enummembers_Qt3DAnimation_QKeyframeAnimation[] = {
    {sipName_Constant, static_cast<int>(::Qt3DAnimation::QKeyframeAnimation::Constant), 33},
    {sipName_None_, static_cast<int>(::Qt3DAnimation::QKeyframeAnimation::None), 33},
    {sipName_Repeat, static_cast<int>(::Qt3DAnimation::QKeyframeAnimation::Repeat), 33},
};

PyDoc_STRVAR(doc_Qt3DAnimation_QKeyframeAnimation, "\1QKeyframeAnimation(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DAnimation_QKeyframeAnimation[] = {
    {"endModeChanged(QKeyframeAnimation::RepeatMode)|(Qt3DAnimation::QKeyframeAnimation::RepeatMode)", "\1endModeChanged(self, endMode: QKeyframeAnimation.RepeatMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"startModeChanged(QKeyframeAnimation::RepeatMode)|(Qt3DAnimation::QKeyframeAnimation::RepeatMode)", "\1startModeChanged(self, startMode: QKeyframeAnimation.RepeatMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"targetNameChanged(QString)", "\1targetNameChanged(self, name: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"easingChanged(QEasingCurve)", "\1easingChanged(self, easing: QEasingCurve|QEasingCurve.Type)", SIP_NULLPTR, SIP_NULLPTR},
    {"targetChanged(Qt3DCore::QTransform*)", "\1targetChanged(self, target: QTransform|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"framePositionsChanged(QVector<float>)", "\1framePositionsChanged(self, positions: Iterable[float])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DAnimation_QKeyframeAnimation = {
    &::Qt3DAnimation::QKeyframeAnimation::staticMetaObject,
    0,
    signals_Qt3DAnimation_QKeyframeAnimation,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QKeyframeAnimation = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DAnimation__QKeyframeAnimation,
        SIP_NULLPTR,
        &plugin_Qt3DAnimation_QKeyframeAnimation,
    },
    {
        sipNameNr_QKeyframeAnimation,
        {0, 0, 1},
        16, methods_Qt3DAnimation_QKeyframeAnimation,
        3, enummembers_Qt3DAnimation_QKeyframeAnimation,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DAnimation_QKeyframeAnimation,
    -1,
    -1,
    supers_Qt3DAnimation_QKeyframeAnimation,
    SIP_NULLPTR,
    init_type_Qt3DAnimation_QKeyframeAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DAnimation_QKeyframeAnimation,
    SIP_NULLPTR,
    array_Qt3DAnimation_QKeyframeAnimation,
    SIP_NULLPTR,
    release_Qt3DAnimation_QKeyframeAnimation,
    cast_Qt3DAnimation_QKeyframeAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DAnimation_QKeyframeAnimation,
    sizeof (::Qt3DAnimation::QKeyframeAnimation),
};
