/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DCore.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 169 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNodeIdTypePair.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 89 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNodeIdTypePair.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNodeIdTypePair.cpp"


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DCore_QNodeIdTypePair(void *, int);}
static void release_Qt3DCore_QNodeIdTypePair(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DCore::QNodeIdTypePair *>(sipCppV);
}


extern "C" {static void *array_Qt3DCore_QNodeIdTypePair(Py_ssize_t);}
static void *array_Qt3DCore_QNodeIdTypePair(Py_ssize_t sipNrElem)
{
    return new ::Qt3DCore::QNodeIdTypePair[sipNrElem];
}


extern "C" {static void array_delete_Qt3DCore_QNodeIdTypePair(void *);}
static void array_delete_Qt3DCore_QNodeIdTypePair(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DCore::QNodeIdTypePair *>(sipCpp);
}


extern "C" {static void assign_Qt3DCore_QNodeIdTypePair(void *, Py_ssize_t, void *);}
static void assign_Qt3DCore_QNodeIdTypePair(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::Qt3DCore::QNodeIdTypePair *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::Qt3DCore::QNodeIdTypePair *>(sipSrc);
}


extern "C" {static void *copy_Qt3DCore_QNodeIdTypePair(const void *, Py_ssize_t);}
static void *copy_Qt3DCore_QNodeIdTypePair(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::Qt3DCore::QNodeIdTypePair(reinterpret_cast<const ::Qt3DCore::QNodeIdTypePair *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_Qt3DCore_QNodeIdTypePair(sipSimpleWrapper *);}
static void dealloc_Qt3DCore_QNodeIdTypePair(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DCore_QNodeIdTypePair(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_Qt3DCore_QNodeIdTypePair(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DCore_QNodeIdTypePair(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::Qt3DCore::QNodeIdTypePair *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::Qt3DCore::QNodeIdTypePair();

            return sipCpp;
        }
    }

    {
        ::Qt3DCore::QNodeId* a0;
        const ::QMetaObject* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J8", sipType_Qt3DCore_QNodeId, &a0, sipType_QMetaObject, &a1))
        {
            sipCpp = new ::Qt3DCore::QNodeIdTypePair(*a0, a1);

            return sipCpp;
        }
    }

    {
        const ::Qt3DCore::QNodeIdTypePair* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_Qt3DCore_QNodeIdTypePair, &a0))
        {
            sipCpp = new ::Qt3DCore::QNodeIdTypePair(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static PyObject *varget_Qt3DCore_QNodeIdTypePair_id(void *, PyObject *, PyObject *);}
static PyObject *varget_Qt3DCore_QNodeIdTypePair_id(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
    ::Qt3DCore::QNodeId*sipVal;
    ::Qt3DCore::QNodeIdTypePair *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeIdTypePair *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -2);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->id;

    sipPy = sipConvertFromType(sipVal, sipType_Qt3DCore_QNodeId, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -1, sipPySelf);
        sipKeepReference(sipPySelf, -2, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_Qt3DCore_QNodeIdTypePair_id(void *, PyObject *, PyObject *);}
static int varset_Qt3DCore_QNodeIdTypePair_id(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::Qt3DCore::QNodeId*sipVal;
    ::Qt3DCore::QNodeIdTypePair *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeIdTypePair *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::Qt3DCore::QNodeId *>(sipForceConvertToType(sipPy, sipType_Qt3DCore_QNodeId, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->id = *sipVal;

    return 0;
}


extern "C" {static PyObject *varget_Qt3DCore_QNodeIdTypePair_type(void *, PyObject *, PyObject *);}
static PyObject *varget_Qt3DCore_QNodeIdTypePair_type(void *sipSelf, PyObject *, PyObject *)
{
    const ::QMetaObject*sipVal;
    ::Qt3DCore::QNodeIdTypePair *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeIdTypePair *>(sipSelf);

    sipVal = sipCpp->type;

    return sipConvertFromType(const_cast< ::QMetaObject *>(sipVal), sipType_QMetaObject, SIP_NULLPTR);
}


extern "C" {static int varset_Qt3DCore_QNodeIdTypePair_type(void *, PyObject *, PyObject *);}
static int varset_Qt3DCore_QNodeIdTypePair_type(void *sipSelf, PyObject *sipPy, PyObject *)
{
    const ::QMetaObject*sipVal;
    ::Qt3DCore::QNodeIdTypePair *sipCpp = reinterpret_cast< ::Qt3DCore::QNodeIdTypePair *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::QMetaObject *>(sipForceConvertToType(sipPy, sipType_QMetaObject, SIP_NULLPTR, 0, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->type = sipVal;

    return 0;
}

sipVariableDef variables_Qt3DCore_QNodeIdTypePair[] = {
    {InstanceVariable, sipName_id, (PyMethodDef *)varget_Qt3DCore_QNodeIdTypePair_id, (PyMethodDef *)varset_Qt3DCore_QNodeIdTypePair_id, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_type, (PyMethodDef *)varget_Qt3DCore_QNodeIdTypePair_type, (PyMethodDef *)varset_Qt3DCore_QNodeIdTypePair_type, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_Qt3DCore_QNodeIdTypePair, "\1QNodeIdTypePair()\n"
"QNodeIdTypePair(_id: QNodeId, _type: QMetaObject|None)\n"
"QNodeIdTypePair(a0: QNodeIdTypePair)");


static pyqt5ClassPluginDef plugin_Qt3DCore_QNodeIdTypePair = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNodeIdTypePair = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DCore__QNodeIdTypePair,
        SIP_NULLPTR,
        &plugin_Qt3DCore_QNodeIdTypePair,
    },
    {
        sipNameNr_QNodeIdTypePair,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        2, variables_Qt3DCore_QNodeIdTypePair,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DCore_QNodeIdTypePair,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_Qt3DCore_QNodeIdTypePair,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DCore_QNodeIdTypePair,
    assign_Qt3DCore_QNodeIdTypePair,
    array_Qt3DCore_QNodeIdTypePair,
    copy_Qt3DCore_QNodeIdTypePair,
    release_Qt3DCore_QNodeIdTypePair,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DCore_QNodeIdTypePair,
    sizeof (::Qt3DCore::QNodeIdTypePair),
};
