/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 223 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureData.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 227 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureData.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 432 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureData.cpp"
#line 39 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qvector.sip"
#include <QTextureImageData>
#line 435 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureData.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 446 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureData.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedatagenerator.sip"
#include <qtextureimagedatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturewrapmode.sip"
#include <qtexturewrapmode.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturewrapmode.sip"
#include <qtexturewrapmode.h>
#line 655 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQTextureData.cpp"


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_target, "target(self) -> QAbstractTexture.Target");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_target(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_target(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::Target sipRes;

            sipRes = sipCpp->target();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_Target);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_target, doc_Qt3DRender_QTextureData_target);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setTarget, "setTarget(self, target: QAbstractTexture.Target)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setTarget(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::Target a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QAbstractTexture_Target, &a0))
        {
            sipCpp->setTarget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setTarget, doc_Qt3DRender_QTextureData_setTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_format, "format(self) -> QAbstractTexture.TextureFormat");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_format(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::TextureFormat sipRes;

            sipRes = sipCpp->format();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_TextureFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_format, doc_Qt3DRender_QTextureData_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setFormat, "setFormat(self, a0: QAbstractTexture.TextureFormat)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setFormat(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::TextureFormat a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QAbstractTexture_TextureFormat, &a0))
        {
            sipCpp->setFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setFormat, doc_Qt3DRender_QTextureData_setFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_width, "width(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_width(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_width(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->width();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_width, doc_Qt3DRender_QTextureData_width);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setWidth, "setWidth(self, width: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setWidth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, &a0))
        {
            sipCpp->setWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setWidth, doc_Qt3DRender_QTextureData_setWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_height, "height(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_height(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_height(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->height();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_height, doc_Qt3DRender_QTextureData_height);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setHeight, "setHeight(self, height: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setHeight(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, &a0))
        {
            sipCpp->setHeight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setHeight, doc_Qt3DRender_QTextureData_setHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_depth, "depth(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_depth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_depth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->depth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_depth, doc_Qt3DRender_QTextureData_depth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setDepth, "setDepth(self, depth: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setDepth(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, &a0))
        {
            sipCpp->setDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setDepth, doc_Qt3DRender_QTextureData_setDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_layers, "layers(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_layers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_layers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->layers();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_layers, doc_Qt3DRender_QTextureData_layers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setLayers, "setLayers(self, layers: int)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setLayers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setLayers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, &a0))
        {
            sipCpp->setLayers(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setLayers, doc_Qt3DRender_QTextureData_setLayers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_isAutoMipMapGenerationEnabled, "isAutoMipMapGenerationEnabled(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_isAutoMipMapGenerationEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_isAutoMipMapGenerationEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAutoMipMapGenerationEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_isAutoMipMapGenerationEnabled, doc_Qt3DRender_QTextureData_isAutoMipMapGenerationEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setAutoMipMapGenerationEnabled, "setAutoMipMapGenerationEnabled(self, isAutoMipMapGenerationEnabled: bool)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setAutoMipMapGenerationEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setAutoMipMapGenerationEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, &a0))
        {
            sipCpp->setAutoMipMapGenerationEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setAutoMipMapGenerationEnabled, doc_Qt3DRender_QTextureData_setAutoMipMapGenerationEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_maximumAnisotropy, "maximumAnisotropy(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_maximumAnisotropy(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_maximumAnisotropy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->maximumAnisotropy();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_maximumAnisotropy, doc_Qt3DRender_QTextureData_maximumAnisotropy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setMaximumAnisotropy, "setMaximumAnisotropy(self, maximumAnisotropy: float)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setMaximumAnisotropy(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setMaximumAnisotropy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, &a0))
        {
            sipCpp->setMaximumAnisotropy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setMaximumAnisotropy, doc_Qt3DRender_QTextureData_setMaximumAnisotropy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_minificationFilter, "minificationFilter(self) -> QAbstractTexture.Filter");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_minificationFilter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_minificationFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::Filter sipRes;

            sipRes = sipCpp->minificationFilter();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_Filter);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_minificationFilter, doc_Qt3DRender_QTextureData_minificationFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setMinificationFilter, "setMinificationFilter(self, filter: QAbstractTexture.Filter)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setMinificationFilter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setMinificationFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::Filter a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QAbstractTexture_Filter, &a0))
        {
            sipCpp->setMinificationFilter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setMinificationFilter, doc_Qt3DRender_QTextureData_setMinificationFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_magnificationFilter, "magnificationFilter(self) -> QAbstractTexture.Filter");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_magnificationFilter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_magnificationFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::Filter sipRes;

            sipRes = sipCpp->magnificationFilter();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_Filter);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_magnificationFilter, doc_Qt3DRender_QTextureData_magnificationFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setMagnificationFilter, "setMagnificationFilter(self, filter: QAbstractTexture.Filter)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setMagnificationFilter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setMagnificationFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::Filter a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QAbstractTexture_Filter, &a0))
        {
            sipCpp->setMagnificationFilter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setMagnificationFilter, doc_Qt3DRender_QTextureData_setMagnificationFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_wrapModeX, "wrapModeX(self) -> QTextureWrapMode.WrapMode");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_wrapModeX(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_wrapModeX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QTextureWrapMode::WrapMode sipRes;

            sipRes = sipCpp->wrapModeX();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QTextureWrapMode_WrapMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_wrapModeX, doc_Qt3DRender_QTextureData_wrapModeX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setWrapModeX, "setWrapModeX(self, wrapModeX: QTextureWrapMode.WrapMode)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setWrapModeX(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setWrapModeX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QTextureWrapMode::WrapMode a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QTextureWrapMode_WrapMode, &a0))
        {
            sipCpp->setWrapModeX(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setWrapModeX, doc_Qt3DRender_QTextureData_setWrapModeX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_wrapModeY, "wrapModeY(self) -> QTextureWrapMode.WrapMode");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_wrapModeY(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_wrapModeY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QTextureWrapMode::WrapMode sipRes;

            sipRes = sipCpp->wrapModeY();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QTextureWrapMode_WrapMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_wrapModeY, doc_Qt3DRender_QTextureData_wrapModeY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setWrapModeY, "setWrapModeY(self, wrapModeY: QTextureWrapMode.WrapMode)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setWrapModeY(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setWrapModeY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QTextureWrapMode::WrapMode a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QTextureWrapMode_WrapMode, &a0))
        {
            sipCpp->setWrapModeY(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setWrapModeY, doc_Qt3DRender_QTextureData_setWrapModeY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_wrapModeZ, "wrapModeZ(self) -> QTextureWrapMode.WrapMode");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_wrapModeZ(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_wrapModeZ(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QTextureWrapMode::WrapMode sipRes;

            sipRes = sipCpp->wrapModeZ();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QTextureWrapMode_WrapMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_wrapModeZ, doc_Qt3DRender_QTextureData_wrapModeZ);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setWrapModeZ, "setWrapModeZ(self, wrapModeZ: QTextureWrapMode.WrapMode)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setWrapModeZ(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setWrapModeZ(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QTextureWrapMode::WrapMode a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QTextureWrapMode_WrapMode, &a0))
        {
            sipCpp->setWrapModeZ(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setWrapModeZ, doc_Qt3DRender_QTextureData_setWrapModeZ);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_comparisonFunction, "comparisonFunction(self) -> QAbstractTexture.ComparisonFunction");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_comparisonFunction(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_comparisonFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::ComparisonFunction sipRes;

            sipRes = sipCpp->comparisonFunction();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_ComparisonFunction);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_comparisonFunction, doc_Qt3DRender_QTextureData_comparisonFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setComparisonFunction, "setComparisonFunction(self, comparisonFunction: QAbstractTexture.ComparisonFunction)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setComparisonFunction(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setComparisonFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::ComparisonFunction a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QAbstractTexture_ComparisonFunction, &a0))
        {
            sipCpp->setComparisonFunction(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setComparisonFunction, doc_Qt3DRender_QTextureData_setComparisonFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_comparisonMode, "comparisonMode(self) -> QAbstractTexture.ComparisonMode");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_comparisonMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_comparisonMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::Qt3DRender::QAbstractTexture::ComparisonMode sipRes;

            sipRes = sipCpp->comparisonMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QAbstractTexture_ComparisonMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_comparisonMode, doc_Qt3DRender_QTextureData_comparisonMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_setComparisonMode, "setComparisonMode(self, comparisonMode: QAbstractTexture.ComparisonMode)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_setComparisonMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_setComparisonMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QAbstractTexture::ComparisonMode a0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_Qt3DRender_QAbstractTexture_ComparisonMode, &a0))
        {
            sipCpp->setComparisonMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_setComparisonMode, doc_Qt3DRender_QTextureData_setComparisonMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_imageData, "imageData(self) -> list[QTextureImageData]");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_imageData(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_imageData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp))
        {
            ::QVector< ::Qt3DRender::QTextureImageDataPtr>*sipRes;

            sipRes = new ::QVector< ::Qt3DRender::QTextureImageDataPtr>(sipCpp->imageData());

            return sipConvertFromNewType(sipRes, sipType_QVector_0100Qt3DRender_QTextureImageDataPtr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_imageData, doc_Qt3DRender_QTextureData_imageData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QTextureData_addImageData, "addImageData(self, imageData: QTextureImageData)");

extern "C" {static PyObject *meth_Qt3DRender_QTextureData_addImageData(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QTextureData_addImageData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QTextureImageDataPtr* a0;
        int a0State = 0;
        ::Qt3DRender::QTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DRender_QTextureData, &sipCpp, sipType_QSharedPointer_0100Qt3DRender_QTextureImageData, &a0, &a0State))
        {
            sipCpp->addImageData(*a0);
            sipReleaseType(const_cast< ::Qt3DRender::QTextureImageDataPtr *>(a0), sipType_QSharedPointer_0100Qt3DRender_QTextureImageData, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextureData, sipName_addImageData, doc_Qt3DRender_QTextureData_addImageData);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QTextureData(void *, int);}
static void release_Qt3DRender_QTextureData(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DRender::QTextureData *>(sipCppV);
}


extern "C" {static void *array_Qt3DRender_QTextureData(Py_ssize_t);}
static void *array_Qt3DRender_QTextureData(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QTextureData[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QTextureData(void *);}
static void array_delete_Qt3DRender_QTextureData(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QTextureData *>(sipCpp);
}


extern "C" {static void assign_Qt3DRender_QTextureData(void *, Py_ssize_t, void *);}
static void assign_Qt3DRender_QTextureData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::Qt3DRender::QTextureData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::Qt3DRender::QTextureData *>(sipSrc);
}


extern "C" {static void *copy_Qt3DRender_QTextureData(const void *, Py_ssize_t);}
static void *copy_Qt3DRender_QTextureData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::Qt3DRender::QTextureData(reinterpret_cast<const ::Qt3DRender::QTextureData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_Qt3DRender_QTextureData(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QTextureData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QTextureData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_Qt3DRender_QTextureData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QTextureData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::Qt3DRender::QTextureData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::Qt3DRender::QTextureData();

            return sipCpp;
        }
    }

    {
        const ::Qt3DRender::QTextureData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_Qt3DRender_QTextureData, &a0))
        {
            sipCpp = new ::Qt3DRender::QTextureData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_Qt3DRender_QTextureData[] = {
    {sipName_addImageData, meth_Qt3DRender_QTextureData_addImageData, METH_VARARGS, doc_Qt3DRender_QTextureData_addImageData},
    {sipName_comparisonFunction, meth_Qt3DRender_QTextureData_comparisonFunction, METH_VARARGS, doc_Qt3DRender_QTextureData_comparisonFunction},
    {sipName_comparisonMode, meth_Qt3DRender_QTextureData_comparisonMode, METH_VARARGS, doc_Qt3DRender_QTextureData_comparisonMode},
    {sipName_depth, meth_Qt3DRender_QTextureData_depth, METH_VARARGS, doc_Qt3DRender_QTextureData_depth},
    {sipName_format, meth_Qt3DRender_QTextureData_format, METH_VARARGS, doc_Qt3DRender_QTextureData_format},
    {sipName_height, meth_Qt3DRender_QTextureData_height, METH_VARARGS, doc_Qt3DRender_QTextureData_height},
    {sipName_imageData, meth_Qt3DRender_QTextureData_imageData, METH_VARARGS, doc_Qt3DRender_QTextureData_imageData},
    {sipName_isAutoMipMapGenerationEnabled, meth_Qt3DRender_QTextureData_isAutoMipMapGenerationEnabled, METH_VARARGS, doc_Qt3DRender_QTextureData_isAutoMipMapGenerationEnabled},
    {sipName_layers, meth_Qt3DRender_QTextureData_layers, METH_VARARGS, doc_Qt3DRender_QTextureData_layers},
    {sipName_magnificationFilter, meth_Qt3DRender_QTextureData_magnificationFilter, METH_VARARGS, doc_Qt3DRender_QTextureData_magnificationFilter},
    {sipName_maximumAnisotropy, meth_Qt3DRender_QTextureData_maximumAnisotropy, METH_VARARGS, doc_Qt3DRender_QTextureData_maximumAnisotropy},
    {sipName_minificationFilter, meth_Qt3DRender_QTextureData_minificationFilter, METH_VARARGS, doc_Qt3DRender_QTextureData_minificationFilter},
    {sipName_setAutoMipMapGenerationEnabled, meth_Qt3DRender_QTextureData_setAutoMipMapGenerationEnabled, METH_VARARGS, doc_Qt3DRender_QTextureData_setAutoMipMapGenerationEnabled},
    {sipName_setComparisonFunction, meth_Qt3DRender_QTextureData_setComparisonFunction, METH_VARARGS, doc_Qt3DRender_QTextureData_setComparisonFunction},
    {sipName_setComparisonMode, meth_Qt3DRender_QTextureData_setComparisonMode, METH_VARARGS, doc_Qt3DRender_QTextureData_setComparisonMode},
    {sipName_setDepth, meth_Qt3DRender_QTextureData_setDepth, METH_VARARGS, doc_Qt3DRender_QTextureData_setDepth},
    {sipName_setFormat, meth_Qt3DRender_QTextureData_setFormat, METH_VARARGS, doc_Qt3DRender_QTextureData_setFormat},
    {sipName_setHeight, meth_Qt3DRender_QTextureData_setHeight, METH_VARARGS, doc_Qt3DRender_QTextureData_setHeight},
    {sipName_setLayers, meth_Qt3DRender_QTextureData_setLayers, METH_VARARGS, doc_Qt3DRender_QTextureData_setLayers},
    {sipName_setMagnificationFilter, meth_Qt3DRender_QTextureData_setMagnificationFilter, METH_VARARGS, doc_Qt3DRender_QTextureData_setMagnificationFilter},
    {sipName_setMaximumAnisotropy, meth_Qt3DRender_QTextureData_setMaximumAnisotropy, METH_VARARGS, doc_Qt3DRender_QTextureData_setMaximumAnisotropy},
    {sipName_setMinificationFilter, meth_Qt3DRender_QTextureData_setMinificationFilter, METH_VARARGS, doc_Qt3DRender_QTextureData_setMinificationFilter},
    {sipName_setTarget, meth_Qt3DRender_QTextureData_setTarget, METH_VARARGS, doc_Qt3DRender_QTextureData_setTarget},
    {sipName_setWidth, meth_Qt3DRender_QTextureData_setWidth, METH_VARARGS, doc_Qt3DRender_QTextureData_setWidth},
    {sipName_setWrapModeX, meth_Qt3DRender_QTextureData_setWrapModeX, METH_VARARGS, doc_Qt3DRender_QTextureData_setWrapModeX},
    {sipName_setWrapModeY, meth_Qt3DRender_QTextureData_setWrapModeY, METH_VARARGS, doc_Qt3DRender_QTextureData_setWrapModeY},
    {sipName_setWrapModeZ, meth_Qt3DRender_QTextureData_setWrapModeZ, METH_VARARGS, doc_Qt3DRender_QTextureData_setWrapModeZ},
    {sipName_target, meth_Qt3DRender_QTextureData_target, METH_VARARGS, doc_Qt3DRender_QTextureData_target},
    {sipName_width, meth_Qt3DRender_QTextureData_width, METH_VARARGS, doc_Qt3DRender_QTextureData_width},
    {sipName_wrapModeX, meth_Qt3DRender_QTextureData_wrapModeX, METH_VARARGS, doc_Qt3DRender_QTextureData_wrapModeX},
    {sipName_wrapModeY, meth_Qt3DRender_QTextureData_wrapModeY, METH_VARARGS, doc_Qt3DRender_QTextureData_wrapModeY},
    {sipName_wrapModeZ, meth_Qt3DRender_QTextureData_wrapModeZ, METH_VARARGS, doc_Qt3DRender_QTextureData_wrapModeZ}
};

PyDoc_STRVAR(doc_Qt3DRender_QTextureData, "\1QTextureData()\n"
"QTextureData(a0: QTextureData)");


static pyqt5ClassPluginDef plugin_Qt3DRender_QTextureData = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QTextureData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QTextureData,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QTextureData,
    },
    {
        sipNameNr_QTextureData,
        {0, 0, 1},
        32, methods_Qt3DRender_QTextureData,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QTextureData,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_Qt3DRender_QTextureData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QTextureData,
    assign_Qt3DRender_QTextureData,
    array_Qt3DRender_QTextureData,
    copy_Qt3DRender_QTextureData,
    release_Qt3DRender_QTextureData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QTextureData,
    sizeof (::Qt3DRender::QTextureData),
};
