/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DAnimation.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 37 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 65 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 68 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 121 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapping.sip"
#include <qchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipanimator.sip"
#include <qclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendnodecreatedchange.sip"
#include <qclipblendnodecreatedchange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclipblendvalue.sip"
#include <qclipblendvalue.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qclock.sip"
#include <qclock.h>
#line 166 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractanimationclip.sip"
#include <qabstractanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractchannelmapping.sip"
#include <qabstractchannelmapping.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipanimator.sip"
#include <qabstractclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qabstractclipblendnode.sip"
#include <qabstractclipblendnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qadditiveclipblend.sip"
#include <qadditiveclipblend.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationaspect.sip"
#include <qanimationaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclip.sip"
#include <qanimationclip.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationclipdata.sip"
#include <qanimationclipdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcliploader.sip"
#include <qanimationcliploader.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationcontroller.sip"
#include <qanimationcontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qblendedclipanimator.sip"
#include <qblendedclipanimator.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannel.sip"
#include <qchannel.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelcomponent.sip"
#include <qchannelcomponent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DAnimation/qchannelmapper.sip"
#include <qchannelmapper.h>
#line 201 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 224 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 227 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 230 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 259 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 262 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 265 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 268 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 271 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 306 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 311 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 314 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 317 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 320 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 323 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 326 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 329 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 332 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 335 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 338 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 341 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 344 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 347 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 350 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DAnimation/sipQt3DAnimationQt3DAnimationQAbstractClipAnimator.cpp"


class sipQt3DAnimation_QAbstractClipAnimator : public ::Qt3DAnimation::QAbstractClipAnimator
{
public:
    sipQt3DAnimation_QAbstractClipAnimator(::Qt3DCore::QNode*);
    virtual ~sipQt3DAnimation_QAbstractClipAnimator();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DAnimation_QAbstractClipAnimator(const sipQt3DAnimation_QAbstractClipAnimator &);
    sipQt3DAnimation_QAbstractClipAnimator &operator = (const sipQt3DAnimation_QAbstractClipAnimator &);

    char sipPyMethods[8];
};

sipQt3DAnimation_QAbstractClipAnimator::sipQt3DAnimation_QAbstractClipAnimator(::Qt3DCore::QNode*a0): ::Qt3DAnimation::QAbstractClipAnimator(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DAnimation_QAbstractClipAnimator::~sipQt3DAnimation_QAbstractClipAnimator()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DAnimation_QAbstractClipAnimator::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DAnimation_qt_metaobject(sipPySelf, sipType_Qt3DAnimation_QAbstractClipAnimator);

    return ::Qt3DAnimation::QAbstractClipAnimator::metaObject();
}

int sipQt3DAnimation_QAbstractClipAnimator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DAnimation::QAbstractClipAnimator::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DAnimation_qt_metacall(sipPySelf, sipType_Qt3DAnimation_QAbstractClipAnimator, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DAnimation_QAbstractClipAnimator::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DAnimation_qt_metacast(sipPySelf, sipType_Qt3DAnimation_QAbstractClipAnimator, _clname, &sipCpp) ? sipCpp : ::Qt3DAnimation::QAbstractClipAnimator::qt_metacast(_clname));
}

void sipQt3DAnimation_QAbstractClipAnimator::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAbstractClipAnimator::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DAnimation_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DAnimation_QAbstractClipAnimator::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DAnimation::QAbstractClipAnimator::event(a0);

    extern bool sipVH_Qt3DAnimation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DAnimation_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DAnimation_QAbstractClipAnimator::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DAnimation::QAbstractClipAnimator::eventFilter(a0, a1);

    extern bool sipVH_Qt3DAnimation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DAnimation_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DAnimation_QAbstractClipAnimator::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAbstractClipAnimator::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DAnimation_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QAbstractClipAnimator::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAbstractClipAnimator::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DAnimation_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QAbstractClipAnimator::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAbstractClipAnimator::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DAnimation_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QAbstractClipAnimator::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAbstractClipAnimator::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DAnimation_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DAnimation_QAbstractClipAnimator::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DAnimation::QAbstractClipAnimator::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DAnimation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DAnimation_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DAnimation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_isRunning, "isRunning(self) -> bool");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_isRunning(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_isRunning(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRunning();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_isRunning, doc_Qt3DAnimation_QAbstractClipAnimator_isRunning);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_channelMapper, "channelMapper(self) -> QChannelMapper|None");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_channelMapper(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_channelMapper(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp))
        {
            ::Qt3DAnimation::QChannelMapper*sipRes;

            sipRes = sipCpp->channelMapper();

            return sipConvertFromType(sipRes, sipType_Qt3DAnimation_QChannelMapper, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_channelMapper, doc_Qt3DAnimation_QAbstractClipAnimator_channelMapper);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_loopCount, "loopCount(self) -> int");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_loopCount(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_loopCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->loopCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_loopCount, doc_Qt3DAnimation_QAbstractClipAnimator_loopCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_clock, "clock(self) -> QClock|None");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_clock(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_clock(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp))
        {
            ::Qt3DAnimation::QClock*sipRes;

            sipRes = sipCpp->clock();

            return sipConvertFromType(sipRes, sipType_Qt3DAnimation_QClock, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_clock, doc_Qt3DAnimation_QAbstractClipAnimator_clock);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_normalizedTime, "normalizedTime(self) -> float");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_normalizedTime(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_normalizedTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->normalizedTime();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_normalizedTime, doc_Qt3DAnimation_QAbstractClipAnimator_normalizedTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_setRunning, "setRunning(self, running: bool)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setRunning(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setRunning(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp, &a0))
        {
            sipCpp->setRunning(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_setRunning, doc_Qt3DAnimation_QAbstractClipAnimator_setRunning);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_setChannelMapper, "setChannelMapper(self, channelMapper: QChannelMapper|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setChannelMapper(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setChannelMapper(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QChannelMapper* a0;
        ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp, sipType_Qt3DAnimation_QChannelMapper, &a0))
        {
            sipCpp->setChannelMapper(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_setChannelMapper, doc_Qt3DAnimation_QAbstractClipAnimator_setChannelMapper);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_setLoopCount, "setLoopCount(self, loops: int)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setLoopCount(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setLoopCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp, &a0))
        {
            sipCpp->setLoopCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_setLoopCount, doc_Qt3DAnimation_QAbstractClipAnimator_setLoopCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_setClock, "setClock(self, clock: QClock|None)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setClock(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setClock(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QClock* a0;
        ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp, sipType_Qt3DAnimation_QClock, &a0))
        {
            sipCpp->setClock(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_setClock, doc_Qt3DAnimation_QAbstractClipAnimator_setClock);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_setNormalizedTime, "setNormalizedTime(self, timeFraction: float)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setNormalizedTime(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_setNormalizedTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp, &a0))
        {
            sipCpp->setNormalizedTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_setNormalizedTime, doc_Qt3DAnimation_QAbstractClipAnimator_setNormalizedTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_start, "start(self)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_start(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp))
        {
            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_start, doc_Qt3DAnimation_QAbstractClipAnimator_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_stop, "stop(self)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_stop(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_stop, doc_Qt3DAnimation_QAbstractClipAnimator_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator_sceneChangeEvent, "sceneChangeEvent(self, change: QSceneChange)");

extern "C" {static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_sceneChangeEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DAnimation_QAbstractClipAnimator_sceneChangeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::Qt3DCore::QSceneChangePtr* a0;
        int a0State = 0;
        ::Qt3DAnimation::QAbstractClipAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DAnimation_QAbstractClipAnimator, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QSceneChange, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::Qt3DAnimation::QAbstractClipAnimator::sceneChangeEvent(*a0) : sipCpp->sceneChangeEvent(*a0));
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChangePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractClipAnimator, sipName_sceneChangeEvent, doc_Qt3DAnimation_QAbstractClipAnimator_sceneChangeEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DAnimation_QAbstractClipAnimator(void *, const sipTypeDef *);}
static void *cast_Qt3DAnimation_QAbstractClipAnimator(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DAnimation::QAbstractClipAnimator *sipCpp = reinterpret_cast< ::Qt3DAnimation::QAbstractClipAnimator *>(sipCppV);

    if (targetType == sipType_Qt3DAnimation_QAbstractClipAnimator)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QComponent)->ctd_cast(static_cast< ::Qt3DCore::QComponent *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DAnimation_QAbstractClipAnimator(void *, int);}
static void release_Qt3DAnimation_QAbstractClipAnimator(void *sipCppV, int)
{
    ::Qt3DAnimation::QAbstractClipAnimator *sipCpp = reinterpret_cast< ::Qt3DAnimation::QAbstractClipAnimator *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DAnimation_QAbstractClipAnimator(Py_ssize_t);}
static void *array_Qt3DAnimation_QAbstractClipAnimator(Py_ssize_t sipNrElem)
{
    return new ::Qt3DAnimation::QAbstractClipAnimator[sipNrElem];
}


extern "C" {static void array_delete_Qt3DAnimation_QAbstractClipAnimator(void *);}
static void array_delete_Qt3DAnimation_QAbstractClipAnimator(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DAnimation::QAbstractClipAnimator *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DAnimation_QAbstractClipAnimator(sipSimpleWrapper *);}
static void dealloc_Qt3DAnimation_QAbstractClipAnimator(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DAnimation_QAbstractClipAnimator *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DAnimation_QAbstractClipAnimator(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DAnimation_QAbstractClipAnimator(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DAnimation_QAbstractClipAnimator(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DAnimation_QAbstractClipAnimator *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DAnimation_QAbstractClipAnimator(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DAnimation_QAbstractClipAnimator[] = {{3, 2, 1}};


static PyMethodDef methods_Qt3DAnimation_QAbstractClipAnimator[] = {
    {sipName_channelMapper, meth_Qt3DAnimation_QAbstractClipAnimator_channelMapper, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_channelMapper},
    {sipName_clock, meth_Qt3DAnimation_QAbstractClipAnimator_clock, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_clock},
    {sipName_isRunning, meth_Qt3DAnimation_QAbstractClipAnimator_isRunning, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_isRunning},
    {sipName_loopCount, meth_Qt3DAnimation_QAbstractClipAnimator_loopCount, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_loopCount},
    {sipName_normalizedTime, meth_Qt3DAnimation_QAbstractClipAnimator_normalizedTime, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_normalizedTime},
    {sipName_sceneChangeEvent, meth_Qt3DAnimation_QAbstractClipAnimator_sceneChangeEvent, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_sceneChangeEvent},
    {sipName_setChannelMapper, meth_Qt3DAnimation_QAbstractClipAnimator_setChannelMapper, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_setChannelMapper},
    {sipName_setClock, meth_Qt3DAnimation_QAbstractClipAnimator_setClock, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_setClock},
    {sipName_setLoopCount, meth_Qt3DAnimation_QAbstractClipAnimator_setLoopCount, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_setLoopCount},
    {sipName_setNormalizedTime, meth_Qt3DAnimation_QAbstractClipAnimator_setNormalizedTime, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_setNormalizedTime},
    {sipName_setRunning, meth_Qt3DAnimation_QAbstractClipAnimator_setRunning, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_setRunning},
    {sipName_start, meth_Qt3DAnimation_QAbstractClipAnimator_start, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_start},
    {sipName_stop, meth_Qt3DAnimation_QAbstractClipAnimator_stop, METH_VARARGS, doc_Qt3DAnimation_QAbstractClipAnimator_stop}
};

static sipEnumMemberDef enummembers_Qt3DAnimation_QAbstractClipAnimator[] = {
    {sipName_Infinite, static_cast<int>(::Qt3DAnimation::QAbstractClipAnimator::Infinite), 11},
};

PyDoc_STRVAR(doc_Qt3DAnimation_QAbstractClipAnimator, "\1QAbstractClipAnimator(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DAnimation_QAbstractClipAnimator[] = {
    {"normalizedTimeChanged(float)", "\1normalizedTimeChanged(self, index: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"clockChanged(Qt3DAnimation::QClock*)", "\1clockChanged(self, clock: QClock|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"loopCountChanged(int)", "\1loopCountChanged(self, loops: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"channelMapperChanged(Qt3DAnimation::QChannelMapper*)", "\1channelMapperChanged(self, channelMapper: QChannelMapper|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"runningChanged(bool)", "\1runningChanged(self, running: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DAnimation_QAbstractClipAnimator = {
    &::Qt3DAnimation::QAbstractClipAnimator::staticMetaObject,
    0,
    signals_Qt3DAnimation_QAbstractClipAnimator,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DAnimation_Qt3DAnimation_QAbstractClipAnimator = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DAnimation__QAbstractClipAnimator,
        SIP_NULLPTR,
        &plugin_Qt3DAnimation_QAbstractClipAnimator,
    },
    {
        sipNameNr_QAbstractClipAnimator,
        {0, 0, 1},
        13, methods_Qt3DAnimation_QAbstractClipAnimator,
        1, enummembers_Qt3DAnimation_QAbstractClipAnimator,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DAnimation_QAbstractClipAnimator,
    -1,
    -1,
    supers_Qt3DAnimation_QAbstractClipAnimator,
    SIP_NULLPTR,
    init_type_Qt3DAnimation_QAbstractClipAnimator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DAnimation_QAbstractClipAnimator,
    SIP_NULLPTR,
    array_Qt3DAnimation_QAbstractClipAnimator,
    SIP_NULLPTR,
    release_Qt3DAnimation_QAbstractClipAnimator,
    cast_Qt3DAnimation_QAbstractClipAnimator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DAnimation_QAbstractClipAnimator,
    sizeof (::Qt3DAnimation::QAbstractClipAnimator),
};
