/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DCore.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 79 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 133 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"


extern "C" {static long slot_Qt3DCore_QSceneChange_DeliveryFlags___hash__(PyObject *);}
static long slot_Qt3DCore_QSceneChange_DeliveryFlags___hash__(PyObject *sipSelf)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 122 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = sipCpp->operator Qt3DCore::QSceneChange::DeliveryFlags::Int();
#line 151 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static int slot_Qt3DCore_QSceneChange_DeliveryFlags___bool__(PyObject *);}
static int slot_Qt3DCore_QSceneChange_DeliveryFlags___bool__(PyObject *sipSelf)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return -1;


    {
        {
            int sipRes = 0;

#line 117 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator Qt3DCore::QSceneChange::DeliveryFlags::Int() != 0);
#line 176 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___ne__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QSceneChange::DeliveryFlags* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_Qt3DCore_QSceneChange_DeliveryFlags, &a0, &a0State))
        {
            bool sipRes = 0;

#line 112 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator Qt3DCore::QSceneChange::DeliveryFlags::Int() != a0->operator Qt3DCore::QSceneChange::DeliveryFlags::Int());
#line 206 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(a0), sipType_Qt3DCore_QSceneChange_DeliveryFlags, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, ne_slot, sipType_Qt3DCore_QSceneChange_DeliveryFlags, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___eq__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QSceneChange::DeliveryFlags* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_Qt3DCore_QSceneChange_DeliveryFlags, &a0, &a0State))
        {
            bool sipRes = 0;

#line 107 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator Qt3DCore::QSceneChange::DeliveryFlags::Int() == a0->operator Qt3DCore::QSceneChange::DeliveryFlags::Int());
#line 239 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(a0), sipType_Qt3DCore_QSceneChange_DeliveryFlags, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, eq_slot, sipType_Qt3DCore_QSceneChange_DeliveryFlags, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___ixor__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___ixor__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_Qt3DCore_QSceneChange_DeliveryFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 101 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        *sipCpp = Qt3DCore::QSceneChange::DeliveryFlags(*sipCpp ^ a0);
#line 275 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___xor__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___xor__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QSceneChange::DeliveryFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_Qt3DCore_QSceneChange_DeliveryFlags, &a0, &a0State, &a1))
        {
            ::Qt3DCore::QSceneChange::DeliveryFlags*sipRes;

            sipRes = new ::Qt3DCore::QSceneChange::DeliveryFlags((*a0 ^ a1));
            sipReleaseType(a0, sipType_Qt3DCore_QSceneChange_DeliveryFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QSceneChange_DeliveryFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, xor_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___ior__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___ior__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_Qt3DCore_QSceneChange_DeliveryFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 95 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        *sipCpp = Qt3DCore::QSceneChange::DeliveryFlags(*sipCpp | a0);
#line 347 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___or__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QSceneChange::DeliveryFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_Qt3DCore_QSceneChange_DeliveryFlags, &a0, &a0State, &a1))
        {
            ::Qt3DCore::QSceneChange::DeliveryFlags*sipRes;

            sipRes = new ::Qt3DCore::QSceneChange::DeliveryFlags((*a0 | a1));
            sipReleaseType(a0, sipType_Qt3DCore_QSceneChange_DeliveryFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QSceneChange_DeliveryFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___iand__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___iand__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_Qt3DCore_QSceneChange_DeliveryFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            sipCpp->::Qt3DCore::QSceneChange::DeliveryFlags::operator&=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___and__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___and__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QSceneChange::DeliveryFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_Qt3DCore_QSceneChange_DeliveryFlags, &a0, &a0State, &a1))
        {
            ::Qt3DCore::QSceneChange::DeliveryFlags*sipRes;

            sipRes = new ::Qt3DCore::QSceneChange::DeliveryFlags((*a0 & a1));
            sipReleaseType(a0, sipType_Qt3DCore_QSceneChange_DeliveryFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QSceneChange_DeliveryFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_Qt3DCore, and_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___invert__(PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___invert__(PyObject *sipSelf)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            ::Qt3DCore::QSceneChange::DeliveryFlags*sipRes;

            sipRes = new ::Qt3DCore::QSceneChange::DeliveryFlags(~(*sipCpp));

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QSceneChange_DeliveryFlags, SIP_NULLPTR);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___index__(PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___index__(PyObject *sipSelf)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes = 0;

#line 84 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = sipCpp->operator Qt3DCore::QSceneChange::DeliveryFlags::Int();
#line 504 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___int__(PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlags___int__(PyObject *sipSelf)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_Qt3DCore_QSceneChange_DeliveryFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes;

            sipRes = int(*sipCpp);

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DCore_QSceneChange_DeliveryFlags(void *, int);}
static void release_Qt3DCore_QSceneChange_DeliveryFlags(void *sipCppV, int)
{
    delete reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipCppV);
}


extern "C" {static void *array_Qt3DCore_QSceneChange_DeliveryFlags(Py_ssize_t);}
static void *array_Qt3DCore_QSceneChange_DeliveryFlags(Py_ssize_t sipNrElem)
{
    return new ::Qt3DCore::QSceneChange::DeliveryFlags[sipNrElem];
}


extern "C" {static void array_delete_Qt3DCore_QSceneChange_DeliveryFlags(void *);}
static void array_delete_Qt3DCore_QSceneChange_DeliveryFlags(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipCpp);
}


extern "C" {static void assign_Qt3DCore_QSceneChange_DeliveryFlags(void *, Py_ssize_t, void *);}
static void assign_Qt3DCore_QSceneChange_DeliveryFlags(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipSrc);
}


extern "C" {static void *copy_Qt3DCore_QSceneChange_DeliveryFlags(const void *, Py_ssize_t);}
static void *copy_Qt3DCore_QSceneChange_DeliveryFlags(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::Qt3DCore::QSceneChange::DeliveryFlags(reinterpret_cast<const ::Qt3DCore::QSceneChange::DeliveryFlags *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_Qt3DCore_QSceneChange_DeliveryFlags(sipSimpleWrapper *);}
static void dealloc_Qt3DCore_QSceneChange_DeliveryFlags(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DCore_QSceneChange_DeliveryFlags(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_Qt3DCore_QSceneChange_DeliveryFlags(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DCore_QSceneChange_DeliveryFlags(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::Qt3DCore::QSceneChange::DeliveryFlags();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new ::Qt3DCore::QSceneChange::DeliveryFlags(a0);

            return sipCpp;
        }
    }

    {
        const ::Qt3DCore::QSceneChange::DeliveryFlags* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_Qt3DCore_QSceneChange_DeliveryFlags, &a0, &a0State))
        {
            sipCpp = new ::Qt3DCore::QSceneChange::DeliveryFlags(*a0);
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChange::DeliveryFlags *>(a0), sipType_Qt3DCore_QSceneChange_DeliveryFlags, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static int convertTo_Qt3DCore_QSceneChange_DeliveryFlags(PyObject *, void **, int *, PyObject *);}
static int convertTo_Qt3DCore_QSceneChange_DeliveryFlags(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj)
{
    ::Qt3DCore::QSceneChange::DeliveryFlags **sipCppPtr = reinterpret_cast< ::Qt3DCore::QSceneChange::DeliveryFlags **>(sipCppPtrV);

#line 127 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
// Allow an instance of the base enum whenever a Qt3DCore::QSceneChange::DeliveryFlags is expected.

if (sipIsErr == NULL)
    return (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_Qt3DCore_QSceneChange_DeliveryFlag)) ||
            sipCanConvertToType(sipPy, sipType_Qt3DCore_QSceneChange_DeliveryFlags, SIP_NO_CONVERTORS));

if (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_Qt3DCore_QSceneChange_DeliveryFlag)))
{
    *sipCppPtr = new Qt3DCore::QSceneChange::DeliveryFlags(int(SIPLong_AsLong(sipPy)));

    return sipGetState(sipTransferObj);
}

*sipCppPtr = reinterpret_cast<Qt3DCore::QSceneChange::DeliveryFlags *>(sipConvertToType(sipPy, sipType_Qt3DCore_QSceneChange_DeliveryFlags, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));

return 0;
#line 647 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQSceneChangeDeliveryFlags.cpp"
}


/* Define this type's Python slots. */
static sipPySlotDef slots_Qt3DCore_QSceneChange_DeliveryFlags[] = {
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___hash__, hash_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___bool__, bool_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___ne__, ne_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___eq__, eq_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___ixor__, ixor_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___xor__, xor_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___ior__, ior_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___or__, or_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___iand__, iand_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___and__, and_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___invert__, invert_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___index__, index_slot},
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlags___int__, int_slot},
    {0, (sipPySlotType)0}
};

PyDoc_STRVAR(doc_Qt3DCore_QSceneChange_DeliveryFlags, "\1QSceneChange.DeliveryFlags()\n"
"QSceneChange.DeliveryFlags(f: QSceneChange.DeliveryFlags|QSceneChange.DeliveryFlag)\n"
"QSceneChange.DeliveryFlags(a0: QSceneChange.DeliveryFlags)");


static pyqt5ClassPluginDef plugin_Qt3DCore_QSceneChange_DeliveryFlags = {
    SIP_NULLPTR,
    1,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QSceneChange_DeliveryFlags = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DCore__QSceneChange__DeliveryFlags,
        SIP_NULLPTR,
        &plugin_Qt3DCore_QSceneChange_DeliveryFlags,
    },
    {
        sipNameNr_DeliveryFlags,
        {43, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DCore_QSceneChange_DeliveryFlags,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_Qt3DCore_QSceneChange_DeliveryFlags,
    init_type_Qt3DCore_QSceneChange_DeliveryFlags,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DCore_QSceneChange_DeliveryFlags,
    assign_Qt3DCore_QSceneChange_DeliveryFlags,
    array_Qt3DCore_QSceneChange_DeliveryFlags,
    copy_Qt3DCore_QSceneChange_DeliveryFlags,
    release_Qt3DCore_QSceneChange_DeliveryFlags,
    SIP_NULLPTR,
    convertTo_Qt3DCore_QSceneChange_DeliveryFlags,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DCore_QSceneChange_DeliveryFlags,
    sizeof (::Qt3DCore::QSceneChange::DeliveryFlags),
};
