/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DExtras.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 59 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 87 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 124 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 127 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 130 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 153 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 156 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 164 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 159 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 162 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 269 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 330 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 333 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 396 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 399 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 428 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 431 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 434 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 437 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 490 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 493 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 528 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 533 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 536 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 539 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 542 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 545 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 548 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 551 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 554 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 557 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 560 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 563 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 566 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 569 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 572 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQForwardRenderer.cpp"


class sipQt3DExtras_QForwardRenderer : public ::Qt3DExtras::QForwardRenderer
{
public:
    sipQt3DExtras_QForwardRenderer(::Qt3DCore::QNode*);
    virtual ~sipQt3DExtras_QForwardRenderer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DExtras_QForwardRenderer(const sipQt3DExtras_QForwardRenderer &);
    sipQt3DExtras_QForwardRenderer &operator = (const sipQt3DExtras_QForwardRenderer &);

    char sipPyMethods[8];
};

sipQt3DExtras_QForwardRenderer::sipQt3DExtras_QForwardRenderer(::Qt3DCore::QNode*a0): ::Qt3DExtras::QForwardRenderer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DExtras_QForwardRenderer::~sipQt3DExtras_QForwardRenderer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DExtras_QForwardRenderer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DExtras_qt_metaobject(sipPySelf, sipType_Qt3DExtras_QForwardRenderer);

    return ::Qt3DExtras::QForwardRenderer::metaObject();
}

int sipQt3DExtras_QForwardRenderer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DExtras::QForwardRenderer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DExtras_qt_metacall(sipPySelf, sipType_Qt3DExtras_QForwardRenderer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DExtras_QForwardRenderer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DExtras_qt_metacast(sipPySelf, sipType_Qt3DExtras_QForwardRenderer, _clname, &sipCpp) ? sipCpp : ::Qt3DExtras::QForwardRenderer::qt_metacast(_clname));
}

void sipQt3DExtras_QForwardRenderer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DExtras::QForwardRenderer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DExtras_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QForwardRenderer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DExtras::QForwardRenderer::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DExtras_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QForwardRenderer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QForwardRenderer::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DExtras_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QForwardRenderer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QForwardRenderer::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DExtras_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QForwardRenderer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QForwardRenderer::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DExtras_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DExtras_QForwardRenderer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DExtras::QForwardRenderer::eventFilter(a0, a1);

    extern bool sipVH_Qt3DExtras_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DExtras_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQt3DExtras_QForwardRenderer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DExtras::QForwardRenderer::event(a0);

    extern bool sipVH_Qt3DExtras_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DExtras_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QForwardRenderer::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QForwardRenderer::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DExtras_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_viewportRect, "viewportRect(self) -> QRectF");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_viewportRect(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_viewportRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->viewportRect());

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_viewportRect, doc_Qt3DExtras_QForwardRenderer_viewportRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_clearColor, "clearColor(self) -> QColor");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_clearColor(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_clearColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->clearColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_clearColor, doc_Qt3DExtras_QForwardRenderer_clearColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_camera, "camera(self) -> QEntity|None");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_camera(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_camera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            ::Qt3DCore::QEntity*sipRes;

            sipRes = sipCpp->camera();

            return sipConvertFromType(sipRes, sipType_Qt3DCore_QEntity, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_camera, doc_Qt3DExtras_QForwardRenderer_camera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_surface, "surface(self) -> QObject|None");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_surface(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_surface(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->surface();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_surface, doc_Qt3DExtras_QForwardRenderer_surface);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_externalRenderTargetSize, "externalRenderTargetSize(self) -> QSize");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_externalRenderTargetSize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_externalRenderTargetSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->externalRenderTargetSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_externalRenderTargetSize, doc_Qt3DExtras_QForwardRenderer_externalRenderTargetSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setViewportRect, "setViewportRect(self, viewportRect: QRectF)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setViewportRect(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setViewportRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRectF* a0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, sipType_QRectF, &a0))
        {
            sipCpp->setViewportRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setViewportRect, doc_Qt3DExtras_QForwardRenderer_setViewportRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setClearColor, "setClearColor(self, clearColor: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setClearColor(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setClearColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setClearColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setClearColor, doc_Qt3DExtras_QForwardRenderer_setClearColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setCamera, "setCamera(self, camera: QEntity|None)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setCamera(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setCamera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QEntity* a0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, sipType_Qt3DCore_QEntity, &a0))
        {
            sipCpp->setCamera(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setCamera, doc_Qt3DExtras_QForwardRenderer_setCamera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setSurface, "setSurface(self, surface: QObject|None)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setSurface(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setSurface(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, sipType_QObject, &a0))
        {
            sipCpp->setSurface(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setSurface, doc_Qt3DExtras_QForwardRenderer_setSurface);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setExternalRenderTargetSize, "setExternalRenderTargetSize(self, size: QSize)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setExternalRenderTargetSize(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setExternalRenderTargetSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setExternalRenderTargetSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setExternalRenderTargetSize, doc_Qt3DExtras_QForwardRenderer_setExternalRenderTargetSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_isFrustumCullingEnabled, "isFrustumCullingEnabled(self) -> bool");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_isFrustumCullingEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_isFrustumCullingEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFrustumCullingEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_isFrustumCullingEnabled, doc_Qt3DExtras_QForwardRenderer_isFrustumCullingEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_gamma, "gamma(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_gamma(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_gamma(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->gamma();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_gamma, doc_Qt3DExtras_QForwardRenderer_gamma);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setFrustumCullingEnabled, "setFrustumCullingEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setFrustumCullingEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setFrustumCullingEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, &a0))
        {
            sipCpp->setFrustumCullingEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setFrustumCullingEnabled, doc_Qt3DExtras_QForwardRenderer_setFrustumCullingEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setGamma, "setGamma(self, gamma: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setGamma(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setGamma(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, &a0))
        {
            sipCpp->setGamma(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setGamma, doc_Qt3DExtras_QForwardRenderer_setGamma);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_buffersToClear, "buffersToClear(self) -> QClearBuffers.BufferType");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_buffersToClear(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_buffersToClear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            ::Qt3DRender::QClearBuffers::BufferType sipRes;

            sipRes = sipCpp->buffersToClear();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QClearBuffers_BufferType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_buffersToClear, doc_Qt3DExtras_QForwardRenderer_buffersToClear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setBuffersToClear, "setBuffersToClear(self, a0: QClearBuffers.BufferType)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setBuffersToClear(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setBuffersToClear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QClearBuffers::BufferType a0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, sipType_Qt3DRender_QClearBuffers_BufferType, &a0))
        {
            sipCpp->setBuffersToClear(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setBuffersToClear, doc_Qt3DExtras_QForwardRenderer_setBuffersToClear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_showDebugOverlay, "showDebugOverlay(self) -> bool");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_showDebugOverlay(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_showDebugOverlay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showDebugOverlay();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_showDebugOverlay, doc_Qt3DExtras_QForwardRenderer_showDebugOverlay);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer_setShowDebugOverlay, "setShowDebugOverlay(self, showDebugOverlay: bool)");

extern "C" {static PyObject *meth_Qt3DExtras_QForwardRenderer_setShowDebugOverlay(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QForwardRenderer_setShowDebugOverlay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DExtras::QForwardRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DExtras_QForwardRenderer, &sipCpp, &a0))
        {
            sipCpp->setShowDebugOverlay(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QForwardRenderer, sipName_setShowDebugOverlay, doc_Qt3DExtras_QForwardRenderer_setShowDebugOverlay);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DExtras_QForwardRenderer(void *, const sipTypeDef *);}
static void *cast_Qt3DExtras_QForwardRenderer(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DExtras::QForwardRenderer *sipCpp = reinterpret_cast< ::Qt3DExtras::QForwardRenderer *>(sipCppV);

    if (targetType == sipType_Qt3DExtras_QForwardRenderer)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DRender_QTechniqueFilter)->ctd_cast(static_cast< ::Qt3DRender::QTechniqueFilter *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DExtras_QForwardRenderer(void *, int);}
static void release_Qt3DExtras_QForwardRenderer(void *sipCppV, int)
{
    ::Qt3DExtras::QForwardRenderer *sipCpp = reinterpret_cast< ::Qt3DExtras::QForwardRenderer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DExtras_QForwardRenderer(Py_ssize_t);}
static void *array_Qt3DExtras_QForwardRenderer(Py_ssize_t sipNrElem)
{
    return new ::Qt3DExtras::QForwardRenderer[sipNrElem];
}


extern "C" {static void array_delete_Qt3DExtras_QForwardRenderer(void *);}
static void array_delete_Qt3DExtras_QForwardRenderer(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DExtras::QForwardRenderer *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DExtras_QForwardRenderer(sipSimpleWrapper *);}
static void dealloc_Qt3DExtras_QForwardRenderer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DExtras_QForwardRenderer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DExtras_QForwardRenderer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DExtras_QForwardRenderer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DExtras_QForwardRenderer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DExtras_QForwardRenderer *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DExtras_QForwardRenderer(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DExtras_QForwardRenderer[] = {{11, 4, 1}};


static PyMethodDef methods_Qt3DExtras_QForwardRenderer[] = {
    {sipName_buffersToClear, meth_Qt3DExtras_QForwardRenderer_buffersToClear, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_buffersToClear},
    {sipName_camera, meth_Qt3DExtras_QForwardRenderer_camera, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_camera},
    {sipName_clearColor, meth_Qt3DExtras_QForwardRenderer_clearColor, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_clearColor},
    {sipName_externalRenderTargetSize, meth_Qt3DExtras_QForwardRenderer_externalRenderTargetSize, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_externalRenderTargetSize},
    {sipName_gamma, meth_Qt3DExtras_QForwardRenderer_gamma, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_gamma},
    {sipName_isFrustumCullingEnabled, meth_Qt3DExtras_QForwardRenderer_isFrustumCullingEnabled, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_isFrustumCullingEnabled},
    {sipName_setBuffersToClear, meth_Qt3DExtras_QForwardRenderer_setBuffersToClear, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setBuffersToClear},
    {sipName_setCamera, meth_Qt3DExtras_QForwardRenderer_setCamera, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setCamera},
    {sipName_setClearColor, meth_Qt3DExtras_QForwardRenderer_setClearColor, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setClearColor},
    {sipName_setExternalRenderTargetSize, meth_Qt3DExtras_QForwardRenderer_setExternalRenderTargetSize, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setExternalRenderTargetSize},
    {sipName_setFrustumCullingEnabled, meth_Qt3DExtras_QForwardRenderer_setFrustumCullingEnabled, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setFrustumCullingEnabled},
    {sipName_setGamma, meth_Qt3DExtras_QForwardRenderer_setGamma, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setGamma},
    {sipName_setShowDebugOverlay, meth_Qt3DExtras_QForwardRenderer_setShowDebugOverlay, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setShowDebugOverlay},
    {sipName_setSurface, meth_Qt3DExtras_QForwardRenderer_setSurface, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setSurface},
    {sipName_setViewportRect, meth_Qt3DExtras_QForwardRenderer_setViewportRect, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_setViewportRect},
    {sipName_showDebugOverlay, meth_Qt3DExtras_QForwardRenderer_showDebugOverlay, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_showDebugOverlay},
    {sipName_surface, meth_Qt3DExtras_QForwardRenderer_surface, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_surface},
    {sipName_viewportRect, meth_Qt3DExtras_QForwardRenderer_viewportRect, METH_VARARGS, doc_Qt3DExtras_QForwardRenderer_viewportRect}
};

PyDoc_STRVAR(doc_Qt3DExtras_QForwardRenderer, "\1QForwardRenderer(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DExtras_QForwardRenderer[] = {
    {"showDebugOverlayChanged(bool)", "\1showDebugOverlayChanged(self, showDebugOverlay: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"buffersToClearChanged(Qt3DRender::QClearBuffers::BufferType)", "\1buffersToClearChanged(self, a0: QClearBuffers.BufferType)", SIP_NULLPTR, SIP_NULLPTR},
    {"gammaChanged(float)", "\1gammaChanged(self, gamma: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"frustumCullingEnabledChanged(bool)", "\1frustumCullingEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"externalRenderTargetSizeChanged(QSize)", "\1externalRenderTargetSizeChanged(self, size: QSize)", SIP_NULLPTR, SIP_NULLPTR},
    {"surfaceChanged(QObject*)", "\1surfaceChanged(self, surface: QObject|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"cameraChanged(Qt3DCore::QEntity*)", "\1cameraChanged(self, camera: QEntity|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"clearColorChanged(QColor)", "\1clearColorChanged(self, clearColor: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"viewportRectChanged(QRectF)", "\1viewportRectChanged(self, viewportRect: QRectF)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DExtras_QForwardRenderer = {
    &::Qt3DExtras::QForwardRenderer::staticMetaObject,
    0,
    signals_Qt3DExtras_QForwardRenderer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QForwardRenderer = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DExtras__QForwardRenderer,
        SIP_NULLPTR,
        &plugin_Qt3DExtras_QForwardRenderer,
    },
    {
        sipNameNr_QForwardRenderer,
        {0, 0, 1},
        18, methods_Qt3DExtras_QForwardRenderer,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DExtras_QForwardRenderer,
    -1,
    -1,
    supers_Qt3DExtras_QForwardRenderer,
    SIP_NULLPTR,
    init_type_Qt3DExtras_QForwardRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DExtras_QForwardRenderer,
    SIP_NULLPTR,
    array_Qt3DExtras_QForwardRenderer,
    SIP_NULLPTR,
    release_Qt3DExtras_QForwardRenderer,
    cast_Qt3DExtras_QForwardRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DExtras_QForwardRenderer,
    sizeof (::Qt3DExtras::QForwardRenderer),
};
