/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DExtras.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtext2dentity.sip"
#include <qtext2dentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturedmetalroughmaterial.sip"
#include <qtexturedmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturematerial.sip"
#include <qtexturematerial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtorusgeometry.sip"
#include <qtorusgeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtorusgeometry.sip"
#include <qtorusgeometry.h>
#line 105 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 133 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 152 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 155 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 208 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 211 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 214 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 217 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 246 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 249 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 252 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 255 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 258 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 293 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 298 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 301 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 304 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 307 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 310 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 313 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 316 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 319 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 322 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 325 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 328 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 331 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 334 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 337 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQTorusGeometry.cpp"


class sipQt3DExtras_QTorusGeometry : public ::Qt3DExtras::QTorusGeometry
{
public:
    sipQt3DExtras_QTorusGeometry(::Qt3DCore::QNode*);
    virtual ~sipQt3DExtras_QTorusGeometry();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DExtras_QTorusGeometry(const sipQt3DExtras_QTorusGeometry &);
    sipQt3DExtras_QTorusGeometry &operator = (const sipQt3DExtras_QTorusGeometry &);

    char sipPyMethods[8];
};

sipQt3DExtras_QTorusGeometry::sipQt3DExtras_QTorusGeometry(::Qt3DCore::QNode*a0): ::Qt3DExtras::QTorusGeometry(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DExtras_QTorusGeometry::~sipQt3DExtras_QTorusGeometry()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DExtras_QTorusGeometry::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DExtras_qt_metaobject(sipPySelf, sipType_Qt3DExtras_QTorusGeometry);

    return ::Qt3DExtras::QTorusGeometry::metaObject();
}

int sipQt3DExtras_QTorusGeometry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DExtras::QTorusGeometry::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DExtras_qt_metacall(sipPySelf, sipType_Qt3DExtras_QTorusGeometry, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DExtras_QTorusGeometry::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DExtras_qt_metacast(sipPySelf, sipType_Qt3DExtras_QTorusGeometry, _clname, &sipCpp) ? sipCpp : ::Qt3DExtras::QTorusGeometry::qt_metacast(_clname));
}

void sipQt3DExtras_QTorusGeometry::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QTorusGeometry::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DExtras_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DExtras_QTorusGeometry::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DExtras::QTorusGeometry::event(a0);

    extern bool sipVH_Qt3DExtras_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DExtras_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DExtras_QTorusGeometry::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DExtras::QTorusGeometry::eventFilter(a0, a1);

    extern bool sipVH_Qt3DExtras_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DExtras_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DExtras_QTorusGeometry::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QTorusGeometry::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DExtras_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QTorusGeometry::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QTorusGeometry::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DExtras_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QTorusGeometry::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DExtras::QTorusGeometry::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DExtras_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QTorusGeometry::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DExtras::QTorusGeometry::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DExtras_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DExtras_QTorusGeometry::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DExtras::QTorusGeometry::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DExtras_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DExtras_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_updateVertices, "updateVertices(self)");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_updateVertices(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_updateVertices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            sipCpp->updateVertices();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_updateVertices, doc_Qt3DExtras_QTorusGeometry_updateVertices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_updateIndices, "updateIndices(self)");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_updateIndices(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_updateIndices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            sipCpp->updateIndices();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_updateIndices, doc_Qt3DExtras_QTorusGeometry_updateIndices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_rings, "rings(self) -> int");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_rings(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_rings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->rings();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_rings, doc_Qt3DExtras_QTorusGeometry_rings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_slices, "slices(self) -> int");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_slices(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_slices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->slices();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_slices, doc_Qt3DExtras_QTorusGeometry_slices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_radius, "radius(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_radius(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_radius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->radius();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_radius, doc_Qt3DExtras_QTorusGeometry_radius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_minorRadius, "minorRadius(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_minorRadius(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_minorRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->minorRadius();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_minorRadius, doc_Qt3DExtras_QTorusGeometry_minorRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_positionAttribute, "positionAttribute(self) -> QAttribute|None");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_positionAttribute(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_positionAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            ::Qt3DRender::QAttribute*sipRes;

            sipRes = sipCpp->positionAttribute();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QAttribute, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_positionAttribute, doc_Qt3DExtras_QTorusGeometry_positionAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_normalAttribute, "normalAttribute(self) -> QAttribute|None");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_normalAttribute(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_normalAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            ::Qt3DRender::QAttribute*sipRes;

            sipRes = sipCpp->normalAttribute();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QAttribute, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_normalAttribute, doc_Qt3DExtras_QTorusGeometry_normalAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_texCoordAttribute, "texCoordAttribute(self) -> QAttribute|None");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_texCoordAttribute(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_texCoordAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            ::Qt3DRender::QAttribute*sipRes;

            sipRes = sipCpp->texCoordAttribute();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QAttribute, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_texCoordAttribute, doc_Qt3DExtras_QTorusGeometry_texCoordAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_indexAttribute, "indexAttribute(self) -> QAttribute|None");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_indexAttribute(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_indexAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp))
        {
            ::Qt3DRender::QAttribute*sipRes;

            sipRes = sipCpp->indexAttribute();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QAttribute, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_indexAttribute, doc_Qt3DExtras_QTorusGeometry_indexAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_setRings, "setRings(self, rings: int)");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_setRings(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_setRings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp, &a0))
        {
            sipCpp->setRings(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_setRings, doc_Qt3DExtras_QTorusGeometry_setRings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_setSlices, "setSlices(self, slices: int)");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_setSlices(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_setSlices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp, &a0))
        {
            sipCpp->setSlices(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_setSlices, doc_Qt3DExtras_QTorusGeometry_setSlices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_setRadius, "setRadius(self, radius: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_setRadius(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_setRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp, &a0))
        {
            sipCpp->setRadius(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_setRadius, doc_Qt3DExtras_QTorusGeometry_setRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry_setMinorRadius, "setMinorRadius(self, minorRadius: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QTorusGeometry_setMinorRadius(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QTorusGeometry_setMinorRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QTorusGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QTorusGeometry, &sipCpp, &a0))
        {
            sipCpp->setMinorRadius(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTorusGeometry, sipName_setMinorRadius, doc_Qt3DExtras_QTorusGeometry_setMinorRadius);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DExtras_QTorusGeometry(void *, const sipTypeDef *);}
static void *cast_Qt3DExtras_QTorusGeometry(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DExtras::QTorusGeometry *sipCpp = reinterpret_cast< ::Qt3DExtras::QTorusGeometry *>(sipCppV);

    if (targetType == sipType_Qt3DExtras_QTorusGeometry)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DRender_QGeometry)->ctd_cast(static_cast< ::Qt3DRender::QGeometry *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DExtras_QTorusGeometry(void *, int);}
static void release_Qt3DExtras_QTorusGeometry(void *sipCppV, int)
{
    ::Qt3DExtras::QTorusGeometry *sipCpp = reinterpret_cast< ::Qt3DExtras::QTorusGeometry *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DExtras_QTorusGeometry(Py_ssize_t);}
static void *array_Qt3DExtras_QTorusGeometry(Py_ssize_t sipNrElem)
{
    return new ::Qt3DExtras::QTorusGeometry[sipNrElem];
}


extern "C" {static void array_delete_Qt3DExtras_QTorusGeometry(void *);}
static void array_delete_Qt3DExtras_QTorusGeometry(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DExtras::QTorusGeometry *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DExtras_QTorusGeometry(sipSimpleWrapper *);}
static void dealloc_Qt3DExtras_QTorusGeometry(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DExtras_QTorusGeometry *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DExtras_QTorusGeometry(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DExtras_QTorusGeometry(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DExtras_QTorusGeometry(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DExtras_QTorusGeometry *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DExtras_QTorusGeometry(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DExtras_QTorusGeometry[] = {{7, 4, 1}};


static PyMethodDef methods_Qt3DExtras_QTorusGeometry[] = {
    {sipName_indexAttribute, meth_Qt3DExtras_QTorusGeometry_indexAttribute, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_indexAttribute},
    {sipName_minorRadius, meth_Qt3DExtras_QTorusGeometry_minorRadius, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_minorRadius},
    {sipName_normalAttribute, meth_Qt3DExtras_QTorusGeometry_normalAttribute, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_normalAttribute},
    {sipName_positionAttribute, meth_Qt3DExtras_QTorusGeometry_positionAttribute, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_positionAttribute},
    {sipName_radius, meth_Qt3DExtras_QTorusGeometry_radius, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_radius},
    {sipName_rings, meth_Qt3DExtras_QTorusGeometry_rings, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_rings},
    {sipName_setMinorRadius, meth_Qt3DExtras_QTorusGeometry_setMinorRadius, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_setMinorRadius},
    {sipName_setRadius, meth_Qt3DExtras_QTorusGeometry_setRadius, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_setRadius},
    {sipName_setRings, meth_Qt3DExtras_QTorusGeometry_setRings, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_setRings},
    {sipName_setSlices, meth_Qt3DExtras_QTorusGeometry_setSlices, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_setSlices},
    {sipName_slices, meth_Qt3DExtras_QTorusGeometry_slices, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_slices},
    {sipName_texCoordAttribute, meth_Qt3DExtras_QTorusGeometry_texCoordAttribute, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_texCoordAttribute},
    {sipName_updateIndices, meth_Qt3DExtras_QTorusGeometry_updateIndices, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_updateIndices},
    {sipName_updateVertices, meth_Qt3DExtras_QTorusGeometry_updateVertices, METH_VARARGS, doc_Qt3DExtras_QTorusGeometry_updateVertices}
};

PyDoc_STRVAR(doc_Qt3DExtras_QTorusGeometry, "\1QTorusGeometry(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DExtras_QTorusGeometry[] = {
    {"minorRadiusChanged(float)", "\1minorRadiusChanged(self, minorRadius: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"slicesChanged(int)", "\1slicesChanged(self, slices: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"ringsChanged(int)", "\1ringsChanged(self, rings: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"radiusChanged(float)", "\1radiusChanged(self, radius: float)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DExtras_QTorusGeometry = {
    &::Qt3DExtras::QTorusGeometry::staticMetaObject,
    0,
    signals_Qt3DExtras_QTorusGeometry,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QTorusGeometry = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DExtras__QTorusGeometry,
        SIP_NULLPTR,
        &plugin_Qt3DExtras_QTorusGeometry,
    },
    {
        sipNameNr_QTorusGeometry,
        {0, 0, 1},
        14, methods_Qt3DExtras_QTorusGeometry,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DExtras_QTorusGeometry,
    -1,
    -1,
    supers_Qt3DExtras_QTorusGeometry,
    SIP_NULLPTR,
    init_type_Qt3DExtras_QTorusGeometry,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DExtras_QTorusGeometry,
    SIP_NULLPTR,
    array_Qt3DExtras_QTorusGeometry,
    SIP_NULLPTR,
    release_Qt3DExtras_QTorusGeometry,
    cast_Qt3DExtras_QTorusGeometry,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DExtras_QTorusGeometry,
    sizeof (::Qt3DExtras::QTorusGeometry),
};
