/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 101 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 105 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 108 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 36 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 111 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 116 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 119 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 122 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 125 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 128 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 131 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 134 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 137 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 140 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 143 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 146 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 149 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 152 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 155 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 158 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGraphicsApiFilter.cpp"


class sipQt3DRender_QGraphicsApiFilter : public ::Qt3DRender::QGraphicsApiFilter
{
public:
    sipQt3DRender_QGraphicsApiFilter(::QObject*);
    virtual ~sipQt3DRender_QGraphicsApiFilter();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QGraphicsApiFilter(const sipQt3DRender_QGraphicsApiFilter &);
    sipQt3DRender_QGraphicsApiFilter &operator = (const sipQt3DRender_QGraphicsApiFilter &);

    char sipPyMethods[7];
};

sipQt3DRender_QGraphicsApiFilter::sipQt3DRender_QGraphicsApiFilter(::QObject*a0): ::Qt3DRender::QGraphicsApiFilter(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QGraphicsApiFilter::~sipQt3DRender_QGraphicsApiFilter()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QGraphicsApiFilter::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QGraphicsApiFilter);

    return ::Qt3DRender::QGraphicsApiFilter::metaObject();
}

int sipQt3DRender_QGraphicsApiFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QGraphicsApiFilter::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QGraphicsApiFilter, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QGraphicsApiFilter::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QGraphicsApiFilter, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QGraphicsApiFilter::qt_metacast(_clname));
}

bool sipQt3DRender_QGraphicsApiFilter::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QGraphicsApiFilter::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QGraphicsApiFilter::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QGraphicsApiFilter::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DRender_QGraphicsApiFilter::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QGraphicsApiFilter::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QGraphicsApiFilter::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QGraphicsApiFilter::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QGraphicsApiFilter::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QGraphicsApiFilter::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QGraphicsApiFilter::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QGraphicsApiFilter::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QGraphicsApiFilter::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QGraphicsApiFilter::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_api, "api(self) -> QGraphicsApiFilter.Api");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_api(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_api(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp))
        {
            ::Qt3DRender::QGraphicsApiFilter::Api sipRes;

            sipRes = sipCpp->api();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QGraphicsApiFilter_Api);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_api, doc_Qt3DRender_QGraphicsApiFilter_api);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_profile, "profile(self) -> QGraphicsApiFilter.OpenGLProfile");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_profile(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_profile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp))
        {
            ::Qt3DRender::QGraphicsApiFilter::OpenGLProfile sipRes;

            sipRes = sipCpp->profile();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QGraphicsApiFilter_OpenGLProfile);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_profile, doc_Qt3DRender_QGraphicsApiFilter_profile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_minorVersion, "minorVersion(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_minorVersion(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_minorVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minorVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_minorVersion, doc_Qt3DRender_QGraphicsApiFilter_minorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_majorVersion, "majorVersion(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_majorVersion(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_majorVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->majorVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_majorVersion, doc_Qt3DRender_QGraphicsApiFilter_majorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_extensions, "extensions(self) -> list[str]");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_extensions(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_extensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->extensions());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_extensions, doc_Qt3DRender_QGraphicsApiFilter_extensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_vendor, "vendor(self) -> str");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_vendor(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_vendor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->vendor());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_vendor, doc_Qt3DRender_QGraphicsApiFilter_vendor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_setApi, "setApi(self, api: QGraphicsApiFilter.Api)");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setApi(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setApi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QGraphicsApiFilter::Api a0;
        ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp, sipType_Qt3DRender_QGraphicsApiFilter_Api, &a0))
        {
            sipCpp->setApi(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_setApi, doc_Qt3DRender_QGraphicsApiFilter_setApi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_setProfile, "setProfile(self, profile: QGraphicsApiFilter.OpenGLProfile)");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setProfile(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setProfile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QGraphicsApiFilter::OpenGLProfile a0;
        ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp, sipType_Qt3DRender_QGraphicsApiFilter_OpenGLProfile, &a0))
        {
            sipCpp->setProfile(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_setProfile, doc_Qt3DRender_QGraphicsApiFilter_setProfile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_setMinorVersion, "setMinorVersion(self, minorVersion: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setMinorVersion(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setMinorVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp, &a0))
        {
            sipCpp->setMinorVersion(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_setMinorVersion, doc_Qt3DRender_QGraphicsApiFilter_setMinorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_setMajorVersion, "setMajorVersion(self, majorVersion: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setMajorVersion(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setMajorVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp, &a0))
        {
            sipCpp->setMajorVersion(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_setMajorVersion, doc_Qt3DRender_QGraphicsApiFilter_setMajorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_setExtensions, "setExtensions(self, extensions: Iterable[str|None])");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setExtensions(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setExtensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setExtensions(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_setExtensions, doc_Qt3DRender_QGraphicsApiFilter_setExtensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter_setVendor, "setVendor(self, vendor: str|None)");

extern "C" {static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setVendor(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGraphicsApiFilter_setVendor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DRender::QGraphicsApiFilter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DRender_QGraphicsApiFilter, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setVendor(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsApiFilter, sipName_setVendor, doc_Qt3DRender_QGraphicsApiFilter_setVendor);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QGraphicsApiFilter(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QGraphicsApiFilter(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QGraphicsApiFilter *sipCpp = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QGraphicsApiFilter)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QGraphicsApiFilter(void *, int);}
static void release_Qt3DRender_QGraphicsApiFilter(void *sipCppV, int)
{
    ::Qt3DRender::QGraphicsApiFilter *sipCpp = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QGraphicsApiFilter(Py_ssize_t);}
static void *array_Qt3DRender_QGraphicsApiFilter(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QGraphicsApiFilter[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QGraphicsApiFilter(void *);}
static void array_delete_Qt3DRender_QGraphicsApiFilter(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QGraphicsApiFilter(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QGraphicsApiFilter(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QGraphicsApiFilter *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QGraphicsApiFilter(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QGraphicsApiFilter(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QGraphicsApiFilter(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QGraphicsApiFilter *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QGraphicsApiFilter(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QGraphicsApiFilter[] = {{4, 0, 1}};


static PyMethodDef methods_Qt3DRender_QGraphicsApiFilter[] = {
    {sipName_api, meth_Qt3DRender_QGraphicsApiFilter_api, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_api},
    {sipName_extensions, meth_Qt3DRender_QGraphicsApiFilter_extensions, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_extensions},
    {sipName_majorVersion, meth_Qt3DRender_QGraphicsApiFilter_majorVersion, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_majorVersion},
    {sipName_minorVersion, meth_Qt3DRender_QGraphicsApiFilter_minorVersion, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_minorVersion},
    {sipName_profile, meth_Qt3DRender_QGraphicsApiFilter_profile, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_profile},
    {sipName_setApi, meth_Qt3DRender_QGraphicsApiFilter_setApi, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_setApi},
    {sipName_setExtensions, meth_Qt3DRender_QGraphicsApiFilter_setExtensions, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_setExtensions},
    {sipName_setMajorVersion, meth_Qt3DRender_QGraphicsApiFilter_setMajorVersion, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_setMajorVersion},
    {sipName_setMinorVersion, meth_Qt3DRender_QGraphicsApiFilter_setMinorVersion, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_setMinorVersion},
    {sipName_setProfile, meth_Qt3DRender_QGraphicsApiFilter_setProfile, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_setProfile},
    {sipName_setVendor, meth_Qt3DRender_QGraphicsApiFilter_setVendor, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_setVendor},
    {sipName_vendor, meth_Qt3DRender_QGraphicsApiFilter_vendor, METH_VARARGS, doc_Qt3DRender_QGraphicsApiFilter_vendor}
};

static sipEnumMemberDef enummembers_Qt3DRender_QGraphicsApiFilter[] = {
    {sipName_CompatibilityProfile, static_cast<int>(::Qt3DRender::QGraphicsApiFilter::CompatibilityProfile), 87},
    {sipName_CoreProfile, static_cast<int>(::Qt3DRender::QGraphicsApiFilter::CoreProfile), 87},
    {sipName_DirectX, static_cast<int>(::Qt3DRender::QGraphicsApiFilter::DirectX), 86},
    {sipName_NoProfile, static_cast<int>(::Qt3DRender::QGraphicsApiFilter::NoProfile), 87},
    {sipName_OpenGL, static_cast<int>(::Qt3DRender::QGraphicsApiFilter::OpenGL), 86},
    {sipName_OpenGLES, static_cast<int>(::Qt3DRender::QGraphicsApiFilter::OpenGLES), 86},
    {sipName_RHI, static_cast<int>(::Qt3DRender::QGraphicsApiFilter::RHI), 86},
    {sipName_Vulkan, static_cast<int>(::Qt3DRender::QGraphicsApiFilter::Vulkan), 86},
};

PyDoc_STRVAR(doc_Qt3DRender_QGraphicsApiFilter, "\1QGraphicsApiFilter(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QGraphicsApiFilter[] = {
    {"graphicsApiFilterChanged()", "\1graphicsApiFilterChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"vendorChanged(QString)", "\1vendorChanged(self, vendor: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"extensionsChanged(QStringList)", "\1extensionsChanged(self, extensions: Iterable[str|None])", SIP_NULLPTR, SIP_NULLPTR},
    {"majorVersionChanged(int)", "\1majorVersionChanged(self, majorVersion: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"minorVersionChanged(int)", "\1minorVersionChanged(self, minorVersion: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"profileChanged(Qt3DRender::QGraphicsApiFilter::OpenGLProfile)", "\1profileChanged(self, profile: QGraphicsApiFilter.OpenGLProfile)", SIP_NULLPTR, SIP_NULLPTR},
    {"apiChanged(Qt3DRender::QGraphicsApiFilter::Api)", "\1apiChanged(self, api: QGraphicsApiFilter.Api)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QGraphicsApiFilter = {
    &::Qt3DRender::QGraphicsApiFilter::staticMetaObject,
    0,
    signals_Qt3DRender_QGraphicsApiFilter,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QGraphicsApiFilter = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QGraphicsApiFilter,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QGraphicsApiFilter,
    },
    {
        sipNameNr_QGraphicsApiFilter,
        {0, 0, 1},
        12, methods_Qt3DRender_QGraphicsApiFilter,
        8, enummembers_Qt3DRender_QGraphicsApiFilter,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QGraphicsApiFilter,
    -1,
    -1,
    supers_Qt3DRender_QGraphicsApiFilter,
    SIP_NULLPTR,
    init_type_Qt3DRender_QGraphicsApiFilter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QGraphicsApiFilter,
    SIP_NULLPTR,
    array_Qt3DRender_QGraphicsApiFilter,
    SIP_NULLPTR,
    release_Qt3DRender_QGraphicsApiFilter,
    cast_Qt3DRender_QGraphicsApiFilter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QGraphicsApiFilter,
    sizeof (::Qt3DRender::QGraphicsApiFilter),
};
