/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DCore.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 39 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNodeMapper.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 75 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNodeMapper.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 45 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 88 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNodeMapper.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 91 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNodeMapper.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 122 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNodeMapper.cpp"


class sipQt3DCore_QBackendNodeMapper : public ::Qt3DCore::QBackendNodeMapper
{
public:
    sipQt3DCore_QBackendNodeMapper();
    sipQt3DCore_QBackendNodeMapper(const ::Qt3DCore::QBackendNodeMapper&);
    virtual ~sipQt3DCore_QBackendNodeMapper();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void destroy(::Qt3DCore::QNodeId) const SIP_OVERRIDE;
    ::Qt3DCore::QBackendNode* get(::Qt3DCore::QNodeId) const SIP_OVERRIDE;
    ::Qt3DCore::QBackendNode* create(const ::Qt3DCore::QNodeCreatedChangeBasePtr&) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DCore_QBackendNodeMapper(const sipQt3DCore_QBackendNodeMapper &);
    sipQt3DCore_QBackendNodeMapper &operator = (const sipQt3DCore_QBackendNodeMapper &);

    char sipPyMethods[3];
};

sipQt3DCore_QBackendNodeMapper::sipQt3DCore_QBackendNodeMapper(): ::Qt3DCore::QBackendNodeMapper(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DCore_QBackendNodeMapper::sipQt3DCore_QBackendNodeMapper(const ::Qt3DCore::QBackendNodeMapper& a0): ::Qt3DCore::QBackendNodeMapper(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DCore_QBackendNodeMapper::~sipQt3DCore_QBackendNodeMapper()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQt3DCore_QBackendNodeMapper::destroy(::Qt3DCore::QNodeId a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QBackendNodeMapper, sipName_destroy);

    if (!sipMeth)
        return;

    extern void sipVH_Qt3DCore_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt3DCore::QNodeId);

    sipVH_Qt3DCore_9(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::Qt3DCore::QBackendNode* sipQt3DCore_QBackendNodeMapper::get(::Qt3DCore::QNodeId a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QBackendNodeMapper, sipName_get);

    if (!sipMeth)
        return 0;

    extern ::Qt3DCore::QBackendNode* sipVH_Qt3DCore_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt3DCore::QNodeId);

    return sipVH_Qt3DCore_8(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::Qt3DCore::QBackendNode* sipQt3DCore_QBackendNodeMapper::create(const ::Qt3DCore::QNodeCreatedChangeBasePtr& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QBackendNodeMapper, sipName_create);

    if (!sipMeth)
        return 0;

    extern ::Qt3DCore::QBackendNode* sipVH_Qt3DCore_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QNodeCreatedChangeBasePtr&);

    return sipVH_Qt3DCore_7(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNodeMapper_create, "create(self, change: QNodeCreatedChangeBase) -> QBackendNode|None");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNodeMapper_create(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNodeMapper_create(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::Qt3DCore::QNodeCreatedChangeBasePtr* a0;
        int a0State = 0;
        const ::Qt3DCore::QBackendNodeMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DCore_QBackendNodeMapper, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QNodeCreatedChangeBase, &a0, &a0State))
        {
            ::Qt3DCore::QBackendNode*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QBackendNodeMapper, sipName_create);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->create(*a0);
            sipReleaseType(const_cast< ::Qt3DCore::QNodeCreatedChangeBasePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QNodeCreatedChangeBase, a0State);

            return sipConvertFromType(sipRes, sipType_Qt3DCore_QBackendNode, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNodeMapper, sipName_create, doc_Qt3DCore_QBackendNodeMapper_create);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNodeMapper_get, "get(self, id: QNodeId) -> QBackendNode|None");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNodeMapper_get(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNodeMapper_get(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::Qt3DCore::QNodeId* a0;
        const ::Qt3DCore::QBackendNodeMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DCore_QBackendNodeMapper, &sipCpp, sipType_Qt3DCore_QNodeId, &a0))
        {
            ::Qt3DCore::QBackendNode*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QBackendNodeMapper, sipName_get);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->get(*a0);

            return sipConvertFromType(sipRes, sipType_Qt3DCore_QBackendNode, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNodeMapper, sipName_get, doc_Qt3DCore_QBackendNodeMapper_get);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNodeMapper_destroy, "destroy(self, id: QNodeId)");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNodeMapper_destroy(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNodeMapper_destroy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::Qt3DCore::QNodeId* a0;
        const ::Qt3DCore::QBackendNodeMapper *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DCore_QBackendNodeMapper, &sipCpp, sipType_Qt3DCore_QNodeId, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QBackendNodeMapper, sipName_destroy);
                return SIP_NULLPTR;
            }

            sipCpp->destroy(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNodeMapper, sipName_destroy, doc_Qt3DCore_QBackendNodeMapper_destroy);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DCore_QBackendNodeMapper(void *, int);}
static void release_Qt3DCore_QBackendNodeMapper(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQt3DCore_QBackendNodeMapper *>(sipCppV);
    else
        delete reinterpret_cast< ::Qt3DCore::QBackendNodeMapper *>(sipCppV);
}


extern "C" {static void dealloc_Qt3DCore_QBackendNodeMapper(sipSimpleWrapper *);}
static void dealloc_Qt3DCore_QBackendNodeMapper(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DCore_QBackendNodeMapper *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DCore_QBackendNodeMapper(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DCore_QBackendNodeMapper(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DCore_QBackendNodeMapper(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQt3DCore_QBackendNodeMapper *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQt3DCore_QBackendNodeMapper();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::Qt3DCore::QBackendNodeMapper* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_Qt3DCore_QBackendNodeMapper, &a0))
        {
            sipCpp = new sipQt3DCore_QBackendNodeMapper(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_Qt3DCore_QBackendNodeMapper[] = {
    {sipName_create, meth_Qt3DCore_QBackendNodeMapper_create, METH_VARARGS, doc_Qt3DCore_QBackendNodeMapper_create},
    {sipName_destroy, meth_Qt3DCore_QBackendNodeMapper_destroy, METH_VARARGS, doc_Qt3DCore_QBackendNodeMapper_destroy},
    {sipName_get, meth_Qt3DCore_QBackendNodeMapper_get, METH_VARARGS, doc_Qt3DCore_QBackendNodeMapper_get}
};

PyDoc_STRVAR(doc_Qt3DCore_QBackendNodeMapper, "\1QBackendNodeMapper()\n"
"QBackendNodeMapper(a0: QBackendNodeMapper)");


static pyqt5ClassPluginDef plugin_Qt3DCore_QBackendNodeMapper = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QBackendNodeMapper = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DCore__QBackendNodeMapper,
        SIP_NULLPTR,
        &plugin_Qt3DCore_QBackendNodeMapper,
    },
    {
        sipNameNr_QBackendNodeMapper,
        {0, 0, 1},
        3, methods_Qt3DCore_QBackendNodeMapper,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DCore_QBackendNodeMapper,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_Qt3DCore_QBackendNodeMapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DCore_QBackendNodeMapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_Qt3DCore_QBackendNodeMapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::Qt3DCore::QBackendNodeMapper),
};
