/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DInput.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 55 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 83 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 86 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 91 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 94 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 123 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 126 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 129 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 132 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 185 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 188 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 191 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 226 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 231 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 234 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 237 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 240 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 243 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 246 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 249 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 252 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 255 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 258 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 261 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 264 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 267 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 270 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"


class sipQt3DInput_QInputSequence : public ::Qt3DInput::QInputSequence
{
public:
    sipQt3DInput_QInputSequence(::Qt3DCore::QNode*);
    virtual ~sipQt3DInput_QInputSequence();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DInput_QInputSequence(const sipQt3DInput_QInputSequence &);
    sipQt3DInput_QInputSequence &operator = (const sipQt3DInput_QInputSequence &);

    char sipPyMethods[8];
};

sipQt3DInput_QInputSequence::sipQt3DInput_QInputSequence(::Qt3DCore::QNode*a0): ::Qt3DInput::QInputSequence(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DInput_QInputSequence::~sipQt3DInput_QInputSequence()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DInput_QInputSequence::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DInput_qt_metaobject(sipPySelf, sipType_Qt3DInput_QInputSequence);

    return ::Qt3DInput::QInputSequence::metaObject();
}

int sipQt3DInput_QInputSequence::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DInput::QInputSequence::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DInput_qt_metacall(sipPySelf, sipType_Qt3DInput_QInputSequence, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DInput_QInputSequence::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DInput_qt_metacast(sipPySelf, sipType_Qt3DInput_QInputSequence, _clname, &sipCpp) ? sipCpp : ::Qt3DInput::QInputSequence::qt_metacast(_clname));
}

void sipQt3DInput_QInputSequence::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DInput::QInputSequence::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DInput_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DInput_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DInput_QInputSequence::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DInput::QInputSequence::event(a0);

    extern bool sipVH_Qt3DInput_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DInput_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DInput_QInputSequence::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DInput::QInputSequence::eventFilter(a0, a1);

    extern bool sipVH_Qt3DInput_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DInput_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DInput_QInputSequence::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DInput::QInputSequence::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DInput_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DInput_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DInput_QInputSequence::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DInput::QInputSequence::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DInput_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DInput_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DInput_QInputSequence::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DInput::QInputSequence::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DInput_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DInput_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DInput_QInputSequence::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DInput::QInputSequence::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DInput_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DInput_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DInput_QInputSequence::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DInput::QInputSequence::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DInput_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DInput_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DInput_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DInput_QInputSequence_timeout, "timeout(self) -> int");

extern "C" {static PyObject *meth_Qt3DInput_QInputSequence_timeout(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QInputSequence_timeout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QInputSequence *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QInputSequence, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->timeout();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputSequence, sipName_timeout, doc_Qt3DInput_QInputSequence_timeout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QInputSequence_buttonInterval, "buttonInterval(self) -> int");

extern "C" {static PyObject *meth_Qt3DInput_QInputSequence_buttonInterval(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QInputSequence_buttonInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QInputSequence *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QInputSequence, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->buttonInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputSequence, sipName_buttonInterval, doc_Qt3DInput_QInputSequence_buttonInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QInputSequence_addSequence, "addSequence(self, input: QAbstractActionInput|None)");

extern "C" {static PyObject *meth_Qt3DInput_QInputSequence_addSequence(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QInputSequence_addSequence(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DInput::QAbstractActionInput* a0;
        PyObject *a0Wrapper;
        ::Qt3DInput::QInputSequence *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_Qt3DInput_QInputSequence, &sipCpp, &a0Wrapper, sipType_Qt3DInput_QAbstractActionInput, &a0))
        {
#line 42 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
            // This takes ownership only if it doesn't already have a parent.
            if (!a0->parent())
                sipTransferTo(a0Wrapper, sipSelf);
            
            sipCpp->addSequence(a0);
#line 557 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipQt3DInputQt3DInputQInputSequence.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputSequence, sipName_addSequence, doc_Qt3DInput_QInputSequence_addSequence);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QInputSequence_removeSequence, "removeSequence(self, input: QAbstractActionInput|None)");

extern "C" {static PyObject *meth_Qt3DInput_QInputSequence_removeSequence(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QInputSequence_removeSequence(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DInput::QAbstractActionInput* a0;
        ::Qt3DInput::QInputSequence *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DInput_QInputSequence, &sipCpp, sipType_Qt3DInput_QAbstractActionInput, &a0))
        {
            sipCpp->removeSequence(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputSequence, sipName_removeSequence, doc_Qt3DInput_QInputSequence_removeSequence);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QInputSequence_sequences, "sequences(self) -> list[QAbstractActionInput]");

extern "C" {static PyObject *meth_Qt3DInput_QInputSequence_sequences(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QInputSequence_sequences(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DInput::QInputSequence *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DInput_QInputSequence, &sipCpp))
        {
            QVector< ::Qt3DInput::QAbstractActionInput*>*sipRes;

            sipRes = new QVector< ::Qt3DInput::QAbstractActionInput*>(sipCpp->sequences());

            return sipConvertFromNewType(sipRes, sipType_QVector_0101Qt3DInput_QAbstractActionInput, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputSequence, sipName_sequences, doc_Qt3DInput_QInputSequence_sequences);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QInputSequence_setTimeout, "setTimeout(self, timeout: int)");

extern "C" {static PyObject *meth_Qt3DInput_QInputSequence_setTimeout(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QInputSequence_setTimeout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DInput::QInputSequence *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DInput_QInputSequence, &sipCpp, &a0))
        {
            sipCpp->setTimeout(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputSequence, sipName_setTimeout, doc_Qt3DInput_QInputSequence_setTimeout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DInput_QInputSequence_setButtonInterval, "setButtonInterval(self, buttonInterval: int)");

extern "C" {static PyObject *meth_Qt3DInput_QInputSequence_setButtonInterval(PyObject *, PyObject *);}
static PyObject *meth_Qt3DInput_QInputSequence_setButtonInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DInput::QInputSequence *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DInput_QInputSequence, &sipCpp, &a0))
        {
            sipCpp->setButtonInterval(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputSequence, sipName_setButtonInterval, doc_Qt3DInput_QInputSequence_setButtonInterval);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DInput_QInputSequence(void *, const sipTypeDef *);}
static void *cast_Qt3DInput_QInputSequence(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DInput::QInputSequence *sipCpp = reinterpret_cast< ::Qt3DInput::QInputSequence *>(sipCppV);

    if (targetType == sipType_Qt3DInput_QInputSequence)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DInput_QAbstractActionInput)->ctd_cast(static_cast< ::Qt3DInput::QAbstractActionInput *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DInput_QInputSequence(void *, int);}
static void release_Qt3DInput_QInputSequence(void *sipCppV, int)
{
    ::Qt3DInput::QInputSequence *sipCpp = reinterpret_cast< ::Qt3DInput::QInputSequence *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DInput_QInputSequence(Py_ssize_t);}
static void *array_Qt3DInput_QInputSequence(Py_ssize_t sipNrElem)
{
    return new ::Qt3DInput::QInputSequence[sipNrElem];
}


extern "C" {static void array_delete_Qt3DInput_QInputSequence(void *);}
static void array_delete_Qt3DInput_QInputSequence(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DInput::QInputSequence *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DInput_QInputSequence(sipSimpleWrapper *);}
static void dealloc_Qt3DInput_QInputSequence(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DInput_QInputSequence *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DInput_QInputSequence(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DInput_QInputSequence(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DInput_QInputSequence(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DInput_QInputSequence *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DInput_QInputSequence(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DInput_QInputSequence[] = {{5, 255, 1}};


static PyMethodDef methods_Qt3DInput_QInputSequence[] = {
    {sipName_addSequence, meth_Qt3DInput_QInputSequence_addSequence, METH_VARARGS, doc_Qt3DInput_QInputSequence_addSequence},
    {sipName_buttonInterval, meth_Qt3DInput_QInputSequence_buttonInterval, METH_VARARGS, doc_Qt3DInput_QInputSequence_buttonInterval},
    {sipName_removeSequence, meth_Qt3DInput_QInputSequence_removeSequence, METH_VARARGS, doc_Qt3DInput_QInputSequence_removeSequence},
    {sipName_sequences, meth_Qt3DInput_QInputSequence_sequences, METH_VARARGS, doc_Qt3DInput_QInputSequence_sequences},
    {sipName_setButtonInterval, meth_Qt3DInput_QInputSequence_setButtonInterval, METH_VARARGS, doc_Qt3DInput_QInputSequence_setButtonInterval},
    {sipName_setTimeout, meth_Qt3DInput_QInputSequence_setTimeout, METH_VARARGS, doc_Qt3DInput_QInputSequence_setTimeout},
    {sipName_timeout, meth_Qt3DInput_QInputSequence_timeout, METH_VARARGS, doc_Qt3DInput_QInputSequence_timeout}
};

PyDoc_STRVAR(doc_Qt3DInput_QInputSequence, "\1QInputSequence(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DInput_QInputSequence[] = {
    {"buttonIntervalChanged(int)", "\1buttonIntervalChanged(self, buttonInterval: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"timeoutChanged(int)", "\1timeoutChanged(self, timeout: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DInput_QInputSequence = {
    &::Qt3DInput::QInputSequence::staticMetaObject,
    0,
    signals_Qt3DInput_QInputSequence,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QInputSequence = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DInput__QInputSequence,
        SIP_NULLPTR,
        &plugin_Qt3DInput_QInputSequence,
    },
    {
        sipNameNr_QInputSequence,
        {0, 0, 1},
        7, methods_Qt3DInput_QInputSequence,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DInput_QInputSequence,
    -1,
    -1,
    supers_Qt3DInput_QInputSequence,
    SIP_NULLPTR,
    init_type_Qt3DInput_QInputSequence,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DInput_QInputSequence,
    SIP_NULLPTR,
    array_Qt3DInput_QInputSequence,
    SIP_NULLPTR,
    release_Qt3DInput_QInputSequence,
    cast_Qt3DInput_QInputSequence,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DInput_QInputSequence,
    sizeof (::Qt3DInput::QInputSequence),
};
