/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DCore.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 57 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 86 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 89 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 92 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 95 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 148 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 151 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 154 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 189 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 194 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 197 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 200 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 203 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 206 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 209 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 212 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 215 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 218 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 221 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 224 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 227 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 230 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 233 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQNode.cpp"


class sipQt3DCore_QNode : public ::Qt3DCore::QNode
{
public:
    sipQt3DCore_QNode(::Qt3DCore::QNode*);
    virtual ~sipQt3DCore_QNode();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DCore_QNode(const sipQt3DCore_QNode &);
    sipQt3DCore_QNode &operator = (const sipQt3DCore_QNode &);

    char sipPyMethods[8];
};

sipQt3DCore_QNode::sipQt3DCore_QNode(::Qt3DCore::QNode*a0): ::Qt3DCore::QNode(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DCore_QNode::~sipQt3DCore_QNode()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DCore_QNode::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DCore_qt_metaobject(sipPySelf, sipType_Qt3DCore_QNode);

    return ::Qt3DCore::QNode::metaObject();
}

int sipQt3DCore_QNode::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DCore::QNode::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DCore_qt_metacall(sipPySelf, sipType_Qt3DCore_QNode, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DCore_QNode::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DCore_qt_metacast(sipPySelf, sipType_Qt3DCore_QNode, _clname, &sipCpp) ? sipCpp : ::Qt3DCore::QNode::qt_metacast(_clname));
}

void sipQt3DCore_QNode::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DCore::QNode::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DCore_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DCore_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DCore_QNode::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DCore::QNode::event(a0);

    extern bool sipVH_Qt3DCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DCore_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DCore_QNode::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DCore::QNode::eventFilter(a0, a1);

    extern bool sipVH_Qt3DCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DCore_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DCore_QNode::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DCore::QNode::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DCore_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DCore_QNode::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DCore::QNode::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DCore_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DCore_QNode::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DCore::QNode::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DCore_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DCore_QNode::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DCore::QNode::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DCore_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DCore_QNode::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DCore::QNode::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DCore_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_id, "id(self) -> QNodeId");

extern "C" {static PyObject *meth_Qt3DCore_QNode_id(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_id(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp))
        {
            ::Qt3DCore::QNodeId*sipRes;

            sipRes = new ::Qt3DCore::QNodeId(sipCpp->id());

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QNodeId, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_id, doc_Qt3DCore_QNode_id);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_parentNode, "parentNode(self) -> QNode|None");

extern "C" {static PyObject *meth_Qt3DCore_QNode_parentNode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_parentNode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp))
        {
            ::Qt3DCore::QNode*sipRes;

            sipRes = sipCpp->parentNode();

            return sipConvertFromType(sipRes, sipType_Qt3DCore_QNode, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_parentNode, doc_Qt3DCore_QNode_parentNode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_notificationsBlocked, "notificationsBlocked(self) -> bool");

extern "C" {static PyObject *meth_Qt3DCore_QNode_notificationsBlocked(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_notificationsBlocked(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->notificationsBlocked();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_notificationsBlocked, doc_Qt3DCore_QNode_notificationsBlocked);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_blockNotifications, "blockNotifications(self, block: bool) -> bool");

extern "C" {static PyObject *meth_Qt3DCore_QNode_blockNotifications(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_blockNotifications(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->blockNotifications(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_blockNotifications, doc_Qt3DCore_QNode_blockNotifications);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_childNodes, "childNodes(self) -> list[QNode]");

extern "C" {static PyObject *meth_Qt3DCore_QNode_childNodes(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_childNodes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp))
        {
            ::Qt3DCore::QNodeVector*sipRes;

            sipRes = new ::Qt3DCore::QNodeVector(sipCpp->childNodes());

            return sipConvertFromNewType(sipRes, sipType_QVector_0101Qt3DCore_QNode, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_childNodes, doc_Qt3DCore_QNode_childNodes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_isEnabled, "isEnabled(self) -> bool");

extern "C" {static PyObject *meth_Qt3DCore_QNode_isEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_isEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_isEnabled, doc_Qt3DCore_QNode_isEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_setParent, "setParent(self, parent: QNode|None)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_setParent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_setParent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0;
        sipWrapper *sipOwner = SIP_NULLPTR;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJH", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_Qt3DCore_QNode, &a0, &sipOwner))
        {
            sipCpp->setParent(a0);

            if (sipOwner)
                sipTransferTo(sipSelf, (PyObject *)sipOwner);
            else
                sipTransferBack(sipSelf);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_setParent, doc_Qt3DCore_QNode_setParent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_setEnabled, "setEnabled(self, isEnabled: bool)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_setEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_setEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, &a0))
        {
            sipCpp->setEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_setEnabled, doc_Qt3DCore_QNode_setEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_notifyObservers, "notifyObservers(self, change: QSceneChange)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_notifyObservers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_notifyObservers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QSceneChangePtr* a0;
        int a0State = 0;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QSceneChange, &a0, &a0State))
        {
            sipCpp->notifyObservers(*a0);
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChangePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_notifyObservers, doc_Qt3DCore_QNode_notifyObservers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_sceneChangeEvent, "sceneChangeEvent(self, change: QSceneChange)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_sceneChangeEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_sceneChangeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::Qt3DCore::QSceneChangePtr* a0;
        int a0State = 0;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QSceneChange, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::Qt3DCore::QNode::sceneChangeEvent(*a0) : sipCpp->sceneChangeEvent(*a0));
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChangePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_sceneChangeEvent, doc_Qt3DCore_QNode_sceneChangeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_defaultPropertyTrackingMode, "defaultPropertyTrackingMode(self) -> QNode.PropertyTrackingMode");

extern "C" {static PyObject *meth_Qt3DCore_QNode_defaultPropertyTrackingMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_defaultPropertyTrackingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp))
        {
            ::Qt3DCore::QNode::PropertyTrackingMode sipRes;

            sipRes = sipCpp->defaultPropertyTrackingMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DCore_QNode_PropertyTrackingMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_defaultPropertyTrackingMode, doc_Qt3DCore_QNode_defaultPropertyTrackingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_setPropertyTracking, "setPropertyTracking(self, propertyName: str|None, trackMode: QNode.PropertyTrackingMode)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_setPropertyTracking(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_setPropertyTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DCore::QNode::PropertyTrackingMode a1;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1E", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_QString, &a0, &a0State, sipType_Qt3DCore_QNode_PropertyTrackingMode, &a1))
        {
            sipCpp->setPropertyTracking(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_setPropertyTracking, doc_Qt3DCore_QNode_setPropertyTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_propertyTracking, "propertyTracking(self, propertyName: str|None) -> QNode.PropertyTrackingMode");

extern "C" {static PyObject *meth_Qt3DCore_QNode_propertyTracking(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_propertyTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::Qt3DCore::QNode::PropertyTrackingMode sipRes;

            sipRes = sipCpp->propertyTracking(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DCore_QNode_PropertyTrackingMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_propertyTracking, doc_Qt3DCore_QNode_propertyTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_clearPropertyTracking, "clearPropertyTracking(self, propertyName: str|None)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_clearPropertyTracking(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_clearPropertyTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->clearPropertyTracking(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_clearPropertyTracking, doc_Qt3DCore_QNode_clearPropertyTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_clearPropertyTrackings, "clearPropertyTrackings(self)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_clearPropertyTrackings(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_clearPropertyTrackings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp))
        {
            sipCpp->clearPropertyTrackings();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_clearPropertyTrackings, doc_Qt3DCore_QNode_clearPropertyTrackings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_setDefaultPropertyTrackingMode, "setDefaultPropertyTrackingMode(self, mode: QNode.PropertyTrackingMode)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_setDefaultPropertyTrackingMode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_setDefaultPropertyTrackingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode::PropertyTrackingMode a0;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_Qt3DCore_QNode_PropertyTrackingMode, &a0))
        {
            sipCpp->setDefaultPropertyTrackingMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_setDefaultPropertyTrackingMode, doc_Qt3DCore_QNode_setDefaultPropertyTrackingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_sendCommand, "sendCommand(self, name: str|None, data: Any = None, replyTo: int = Qt3DCore.QNodeCommand.CommandId()) -> int");

extern "C" {static PyObject *meth_Qt3DCore_QNode_sendCommand(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_sendCommand(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant& a1def = QVariant();
        const ::QVariant* a1 = &a1def;
        int a1State = 0;
        ::Qt3DCore::QNodeCommand::CommandId a2 = Qt3DCore::QNodeCommand::CommandId();
        ::Qt3DCore::QNode *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_data,
            sipName_replyTo,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1o", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State, &a2))
        {
            ::Qt3DCore::QNodeCommand::CommandId sipRes;

            sipRes = sipCpp->sendCommand(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_sendCommand, doc_Qt3DCore_QNode_sendCommand);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QNode_sendReply, "sendReply(self, command: QNodeCommand)");

extern "C" {static PyObject *meth_Qt3DCore_QNode_sendReply(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QNode_sendReply(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNodeCommandPtr* a0;
        int a0State = 0;
        ::Qt3DCore::QNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DCore_QNode, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QNodeCommand, &a0, &a0State))
        {
            sipCpp->sendReply(*a0);
            sipReleaseType(const_cast< ::Qt3DCore::QNodeCommandPtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QNodeCommand, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNode, sipName_sendReply, doc_Qt3DCore_QNode_sendReply);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DCore_QNode(void *, const sipTypeDef *);}
static void *cast_Qt3DCore_QNode(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DCore::QNode *sipCpp = reinterpret_cast< ::Qt3DCore::QNode *>(sipCppV);

    if (targetType == sipType_Qt3DCore_QNode)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DCore_QNode(void *, int);}
static void release_Qt3DCore_QNode(void *sipCppV, int)
{
    ::Qt3DCore::QNode *sipCpp = reinterpret_cast< ::Qt3DCore::QNode *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DCore_QNode(Py_ssize_t);}
static void *array_Qt3DCore_QNode(Py_ssize_t sipNrElem)
{
    return new ::Qt3DCore::QNode[sipNrElem];
}


extern "C" {static void array_delete_Qt3DCore_QNode(void *);}
static void array_delete_Qt3DCore_QNode(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DCore::QNode *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DCore_QNode(sipSimpleWrapper *);}
static void dealloc_Qt3DCore_QNode(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DCore_QNode *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DCore_QNode(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DCore_QNode(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DCore_QNode(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DCore_QNode *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DCore_QNode(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DCore_QNode[] = {{5, 0, 1}};


static PyMethodDef methods_Qt3DCore_QNode[] = {
    {sipName_blockNotifications, meth_Qt3DCore_QNode_blockNotifications, METH_VARARGS, doc_Qt3DCore_QNode_blockNotifications},
    {sipName_childNodes, meth_Qt3DCore_QNode_childNodes, METH_VARARGS, doc_Qt3DCore_QNode_childNodes},
    {sipName_clearPropertyTracking, meth_Qt3DCore_QNode_clearPropertyTracking, METH_VARARGS, doc_Qt3DCore_QNode_clearPropertyTracking},
    {sipName_clearPropertyTrackings, meth_Qt3DCore_QNode_clearPropertyTrackings, METH_VARARGS, doc_Qt3DCore_QNode_clearPropertyTrackings},
    {sipName_defaultPropertyTrackingMode, meth_Qt3DCore_QNode_defaultPropertyTrackingMode, METH_VARARGS, doc_Qt3DCore_QNode_defaultPropertyTrackingMode},
    {sipName_id, meth_Qt3DCore_QNode_id, METH_VARARGS, doc_Qt3DCore_QNode_id},
    {sipName_isEnabled, meth_Qt3DCore_QNode_isEnabled, METH_VARARGS, doc_Qt3DCore_QNode_isEnabled},
    {sipName_notificationsBlocked, meth_Qt3DCore_QNode_notificationsBlocked, METH_VARARGS, doc_Qt3DCore_QNode_notificationsBlocked},
    {sipName_notifyObservers, meth_Qt3DCore_QNode_notifyObservers, METH_VARARGS, doc_Qt3DCore_QNode_notifyObservers},
    {sipName_parentNode, meth_Qt3DCore_QNode_parentNode, METH_VARARGS, doc_Qt3DCore_QNode_parentNode},
    {sipName_propertyTracking, meth_Qt3DCore_QNode_propertyTracking, METH_VARARGS, doc_Qt3DCore_QNode_propertyTracking},
    {sipName_sceneChangeEvent, meth_Qt3DCore_QNode_sceneChangeEvent, METH_VARARGS, doc_Qt3DCore_QNode_sceneChangeEvent},
    {sipName_sendCommand, SIP_MLMETH_CAST(meth_Qt3DCore_QNode_sendCommand), METH_VARARGS|METH_KEYWORDS, doc_Qt3DCore_QNode_sendCommand},
    {sipName_sendReply, meth_Qt3DCore_QNode_sendReply, METH_VARARGS, doc_Qt3DCore_QNode_sendReply},
    {sipName_setDefaultPropertyTrackingMode, meth_Qt3DCore_QNode_setDefaultPropertyTrackingMode, METH_VARARGS, doc_Qt3DCore_QNode_setDefaultPropertyTrackingMode},
    {sipName_setEnabled, meth_Qt3DCore_QNode_setEnabled, METH_VARARGS, doc_Qt3DCore_QNode_setEnabled},
    {sipName_setParent, meth_Qt3DCore_QNode_setParent, METH_VARARGS, doc_Qt3DCore_QNode_setParent},
    {sipName_setPropertyTracking, meth_Qt3DCore_QNode_setPropertyTracking, METH_VARARGS, doc_Qt3DCore_QNode_setPropertyTracking}
};

static sipEnumMemberDef enummembers_Qt3DCore_QNode[] = {
    {sipName_DontTrackValues, static_cast<int>(::Qt3DCore::QNode::DontTrackValues), 29},
    {sipName_TrackAllValues, static_cast<int>(::Qt3DCore::QNode::TrackAllValues), 29},
    {sipName_TrackFinalValues, static_cast<int>(::Qt3DCore::QNode::TrackFinalValues), 29},
};

PyDoc_STRVAR(doc_Qt3DCore_QNode, "\1QNode(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DCore_QNode[] = {
    {"defaultPropertyTrackingModeChanged(PropertyTrackingMode)|(Qt3DCore::QNode::PropertyTrackingMode)", "\1defaultPropertyTrackingModeChanged(self, mode: QNode.PropertyTrackingMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"nodeDestroyed()", "\1nodeDestroyed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"enabledChanged(bool)", "\1enabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"parentChanged(QObject*)", "\1parentChanged(self, parent: QObject|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DCore_QNode = {
    &::Qt3DCore::QNode::staticMetaObject,
    0,
    signals_Qt3DCore_QNode,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNode = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DCore__QNode,
        SIP_NULLPTR,
        &plugin_Qt3DCore_QNode,
    },
    {
        sipNameNr_QNode,
        {0, 0, 1},
        18, methods_Qt3DCore_QNode,
        3, enummembers_Qt3DCore_QNode,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DCore_QNode,
    -1,
    -1,
    supers_Qt3DCore_QNode,
    SIP_NULLPTR,
    init_type_Qt3DCore_QNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DCore_QNode,
    SIP_NULLPTR,
    array_Qt3DCore_QNode,
    SIP_NULLPTR,
    release_Qt3DCore_QNode,
    cast_Qt3DCore_QNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DCore_QNode,
    sizeof (::Qt3DCore::QNode),
};
