/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _Qt3DInputAPI_H
#define _Qt3DInputAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_Qt3DInput__QAxisAccumulator__SourceAxisType 0
#define sipName_Qt3DInput__QAxisAccumulator__SourceAxisType &sipStrings_Qt3DInput[0]
#define sipNameNr_Qt3DInput__QPhysicalDeviceCreatedChangeBase 44
#define sipName_Qt3DInput__QPhysicalDeviceCreatedChangeBase &sipStrings_Qt3DInput[44]
#define sipNameNr_88 88
#define sipName_88 &sipStrings_Qt3DInput[88]
#define sipNameNr_130 130
#define sipName_130 &sipStrings_Qt3DInput[130]
#define sipNameNr_Qt3DInput__QAbstractPhysicalDevice 170
#define sipName_Qt3DInput__QAbstractPhysicalDevice &sipStrings_Qt3DInput[170]
#define sipNameNr_205 205
#define sipName_205 &sipStrings_Qt3DInput[205]
#define sipNameNr_Qt3DInput__QMouseEvent__Modifiers 239
#define sipName_Qt3DInput__QMouseEvent__Modifiers &sipStrings_Qt3DInput[239]
#define sipNameNr_Qt3DInput__QWheelEvent__Modifiers 273
#define sipName_Qt3DInput__QWheelEvent__Modifiers &sipStrings_Qt3DInput[273]
#define sipNameNr_QPhysicalDeviceCreatedChangeBase 55
#define sipName_QPhysicalDeviceCreatedChangeBase &sipStrings_Qt3DInput[55]
#define sipNameNr_Qt3DInput__QAbstractActionInput 307
#define sipName_Qt3DInput__QAbstractActionInput &sipStrings_Qt3DInput[307]
#define sipNameNr_Qt3DInput__QMouseEvent__Buttons 339
#define sipName_Qt3DInput__QMouseEvent__Buttons &sipStrings_Qt3DInput[339]
#define sipNameNr_Qt3DInput__QWheelEvent__Buttons 371
#define sipName_Qt3DInput__QWheelEvent__Buttons &sipStrings_Qt3DInput[371]
#define sipNameNr_Qt3DInput__QAbstractAxisInput 403
#define sipName_Qt3DInput__QAbstractAxisInput &sipStrings_Qt3DInput[403]
#define sipNameNr_Qt3DInput__QMouseDevice__Axis 433
#define sipName_Qt3DInput__QMouseDevice__Axis &sipStrings_Qt3DInput[433]
#define sipNameNr_updateAxesContinuouslyChanged 463
#define sipName_updateAxesContinuouslyChanged &sipStrings_Qt3DInput[463]
#define sipNameNr_493 493
#define sipName_493 &sipStrings_Qt3DInput[493]
#define sipNameNr_Qt3DInput__QAnalogAxisInput 522
#define sipName_Qt3DInput__QAnalogAxisInput &sipStrings_Qt3DInput[522]
#define sipNameNr_Qt3DInput__QAxisAccumulator 550
#define sipName_Qt3DInput__QAxisAccumulator &sipStrings_Qt3DInput[550]
#define sipNameNr_Qt3DInput__QButtonAxisInput 578
#define sipName_Qt3DInput__QButtonAxisInput &sipStrings_Qt3DInput[578]
#define sipNameNr_Qt3DInput__QKeyboardHandler 606
#define sipName_Qt3DInput__QKeyboardHandler &sipStrings_Qt3DInput[606]
#define sipNameNr_634 634
#define sipName_634 &sipStrings_Qt3DInput[634]
#define sipNameNr_Qt3DInput__QKeyboardDevice 661
#define sipName_Qt3DInput__QKeyboardDevice &sipStrings_Qt3DInput[661]
#define sipNameNr_Qt3DInput__QInputSequence 688
#define sipName_Qt3DInput__QInputSequence &sipStrings_Qt3DInput[688]
#define sipNameNr_Qt3DInput__QInputSettings 714
#define sipName_Qt3DInput__QInputSettings &sipStrings_Qt3DInput[714]
#define sipNameNr_Qt3DInput__QLogicalDevice 740
#define sipName_Qt3DInput__QLogicalDevice &sipStrings_Qt3DInput[740]
#define sipNameNr_setUpdateAxesContinuously 766
#define sipName_setUpdateAxesContinuously &sipStrings_Qt3DInput[766]
#define sipNameNr_Qt3DInput__QMouseHandler 792
#define sipName_Qt3DInput__QMouseHandler &sipStrings_Qt3DInput[792]
#define sipNameNr_availablePhysicalDevices 817
#define sipName_availablePhysicalDevices &sipStrings_Qt3DInput[817]
#define sipNameNr_QAbstractPhysicalDevice 181
#define sipName_QAbstractPhysicalDevice &sipStrings_Qt3DInput[181]
#define sipNameNr_Qt3DInput__QActionInput 842
#define sipName_Qt3DInput__QActionInput &sipStrings_Qt3DInput[842]
#define sipNameNr_Qt3DInput__QAxisSetting 866
#define sipName_Qt3DInput__QAxisSetting &sipStrings_Qt3DInput[866]
#define sipNameNr_Qt3DInput__QInputAspect 890
#define sipName_Qt3DInput__QInputAspect &sipStrings_Qt3DInput[890]
#define sipNameNr_Qt3DInput__QMouseDevice 914
#define sipName_Qt3DInput__QMouseDevice &sipStrings_Qt3DInput[914]
#define sipNameNr_Qt3DInput__QInputChord 938
#define sipName_Qt3DInput__QInputChord &sipStrings_Qt3DInput[938]
#define sipNameNr_Qt3DInput__QMouseEvent 961
#define sipName_Qt3DInput__QMouseEvent &sipStrings_Qt3DInput[961]
#define sipNameNr_Qt3DInput__QWheelEvent 984
#define sipName_Qt3DInput__QWheelEvent &sipStrings_Qt3DInput[984]
#define sipNameNr_updateAxesContinuously 1007
#define sipName_updateAxesContinuously &sipStrings_Qt3DInput[1007]
#define sipNameNr_buttonIntervalChanged 1030
#define sipName_buttonIntervalChanged &sipStrings_Qt3DInput[1030]
#define sipNameNr_deadZoneRadiusChanged 1052
#define sipName_deadZoneRadiusChanged &sipStrings_Qt3DInput[1052]
#define sipNameNr_sourceAxisTypeChanged 1074
#define sipName_sourceAxisTypeChanged &sipStrings_Qt3DInput[1074]
#define sipNameNr_QAbstractActionInput 318
#define sipName_QAbstractActionInput &sipStrings_Qt3DInput[318]
#define sipNameNr_Qt3DInput__QKeyEvent 1096
#define sipName_Qt3DInput__QKeyEvent &sipStrings_Qt3DInput[1096]
#define sipNameNr_containsMouseChanged 1117
#define sipName_containsMouseChanged &sipStrings_Qt3DInput[1117]
#define sipNameNr_createPhysicalDevice 1138
#define sipName_createPhysicalDevice &sipStrings_Qt3DInput[1138]
#define sipNameNr_accelerationChanged 1159
#define sipName_accelerationChanged &sipStrings_Qt3DInput[1159]
#define sipNameNr_decelerationChanged 1179
#define sipName_decelerationChanged &sipStrings_Qt3DInput[1179]
#define sipNameNr_sourceDeviceChanged 1199
#define sipName_sourceDeviceChanged &sipStrings_Qt3DInput[1199]
#define sipNameNr_QAbstractAxisInput 414
#define sipName_QAbstractAxisInput &sipStrings_Qt3DInput[414]
#define sipNameNr_Qt3DInput__QAction 1219
#define sipName_Qt3DInput__QAction &sipStrings_Qt3DInput[1219]
#define sipNameNr_activeInputChanged 1238
#define sipName_activeInputChanged &sipStrings_Qt3DInput[1238]
#define sipNameNr_eventSourceChanged 1257
#define sipName_eventSourceChanged &sipStrings_Qt3DInput[1257]
#define sipNameNr_sensitivityChanged 1276
#define sipName_sensitivityChanged &sipStrings_Qt3DInput[1276]
#define sipNameNr_numberSignPressed 1295
#define sipName_numberSignPressed &sipStrings_Qt3DInput[1295]
#define sipNameNr_removeAxisSetting 1313
#define sipName_removeAxisSetting &sipStrings_Qt3DInput[1313]
#define sipNameNr_setButtonInterval 1331
#define sipName_setButtonInterval &sipStrings_Qt3DInput[1331]
#define sipNameNr_setDeadZoneRadius 1349
#define sipName_setDeadZoneRadius &sipStrings_Qt3DInput[1349]
#define sipNameNr_setSourceAxisType 1367
#define sipName_setSourceAxisType &sipStrings_Qt3DInput[1367]
#define sipNameNr_sourceAxisChanged 1385
#define sipName_sourceAxisChanged &sipStrings_Qt3DInput[1385]
#define sipNameNr_volumeDownPressed 1403
#define sipName_volumeDownPressed &sipStrings_Qt3DInput[1403]
#define sipNameNr_QAnalogAxisInput 533
#define sipName_QAnalogAxisInput &sipStrings_Qt3DInput[533]
#define sipNameNr_QAxisAccumulator 561
#define sipName_QAxisAccumulator &sipStrings_Qt3DInput[561]
#define sipNameNr_QButtonAxisInput 589
#define sipName_QButtonAxisInput &sipStrings_Qt3DInput[589]
#define sipNameNr_QKeyboardHandler 617
#define sipName_QKeyboardHandler &sipStrings_Qt3DInput[617]
#define sipNameNr_Qt3DInput__QAxis 1421
#define sipName_Qt3DInput__QAxis &sipStrings_Qt3DInput[1421]
#define sipNameNr_buttonIdentifier 1438
#define sipName_buttonIdentifier &sipStrings_Qt3DInput[1438]
#define sipNameNr_disconnectNotify 1455
#define sipName_disconnectNotify &sipStrings_Qt3DInput[1455]
#define sipNameNr_sceneChangeEvent 1472
#define sipName_sceneChangeEvent &sipStrings_Qt3DInput[1472]
#define sipNameNr_setSmoothEnabled 1489
#define sipName_setSmoothEnabled &sipStrings_Qt3DInput[1489]
#define sipNameNr_ControlModifier 1506
#define sipName_ControlModifier &sipStrings_Qt3DInput[1506]
#define sipNameNr_PyQt5_Qt3DInput 1522
#define sipName_PyQt5_Qt3DInput &sipStrings_Qt3DInput[1522]
#define sipNameNr_QKeyboardDevice 672
#define sipName_QKeyboardDevice &sipStrings_Qt3DInput[672]
#define sipNameNr_asteriskPressed 1538
#define sipName_asteriskPressed &sipStrings_Qt3DInput[1538]
#define sipNameNr_context1Pressed 1554
#define sipName_context1Pressed &sipStrings_Qt3DInput[1554]
#define sipNameNr_context2Pressed 1570
#define sipName_context2Pressed &sipStrings_Qt3DInput[1570]
#define sipNameNr_context3Pressed 1586
#define sipName_context3Pressed &sipStrings_Qt3DInput[1586]
#define sipNameNr_context4Pressed 1602
#define sipName_context4Pressed &sipStrings_Qt3DInput[1602]
#define sipNameNr_isSmoothEnabled 1618
#define sipName_isSmoothEnabled &sipStrings_Qt3DInput[1618]
#define sipNameNr_positionChanged 1634
#define sipName_positionChanged &sipStrings_Qt3DInput[1634]
#define sipNameNr_setAcceleration 1650
#define sipName_setAcceleration &sipStrings_Qt3DInput[1650]
#define sipNameNr_setDeceleration 1666
#define sipName_setDeceleration &sipStrings_Qt3DInput[1666]
#define sipNameNr_setSourceDevice 1682
#define sipName_setSourceDevice &sipStrings_Qt3DInput[1682]
#define sipNameNr_velocityChanged 1698
#define sipName_velocityChanged &sipStrings_Qt3DInput[1698]
#define sipNameNr_volumeUpPressed 1714
#define sipName_volumeUpPressed &sipStrings_Qt3DInput[1714]
#define sipNameNr_KeypadModifier 1730
#define sipName_KeypadModifier &sipStrings_Qt3DInput[1730]
#define sipNameNr_QInputSequence 699
#define sipName_QInputSequence &sipStrings_Qt3DInput[699]
#define sipNameNr_QInputSettings 725
#define sipName_QInputSettings &sipStrings_Qt3DInput[725]
#define sipNameNr_QLogicalDevice 751
#define sipName_QLogicalDevice &sipStrings_Qt3DInput[751]
#define sipNameNr_SourceAxisType 29
#define sipName_SourceAxisType &sipStrings_Qt3DInput[29]
#define sipNameNr_addAxisSetting 1745
#define sipName_addAxisSetting &sipStrings_Qt3DInput[1745]
#define sipNameNr_axisIdentifier 1760
#define sipName_axisIdentifier &sipStrings_Qt3DInput[1760]
#define sipNameNr_axisSettingIds 1775
#define sipName_axisSettingIds &sipStrings_Qt3DInput[1775]
#define sipNameNr_backtabPressed 1790
#define sipName_backtabPressed &sipStrings_Qt3DInput[1790]
#define sipNameNr_buttonInterval 1805
#define sipName_buttonInterval &sipStrings_Qt3DInput[1805]
#define sipNameNr_buttonsChanged 1820
#define sipName_buttonsChanged &sipStrings_Qt3DInput[1820]
#define sipNameNr_deadZoneRadius 1835
#define sipName_deadZoneRadius &sipStrings_Qt3DInput[1835]
#define sipNameNr_nativeScanCode 1850
#define sipName_nativeScanCode &sipStrings_Qt3DInput[1850]
#define sipNameNr_removeSequence 1865
#define sipName_removeSequence &sipStrings_Qt3DInput[1865]
#define sipNameNr_setEventSource 1880
#define sipName_setEventSource &sipStrings_Qt3DInput[1880]
#define sipNameNr_setSensitivity 1895
#define sipName_setSensitivity &sipStrings_Qt3DInput[1895]
#define sipNameNr_sourceAxisType 1910
#define sipName_sourceAxisType &sipStrings_Qt3DInput[1910]
#define sipNameNr_timeoutChanged 1925
#define sipName_timeoutChanged &sipStrings_Qt3DInput[1925]
#define sipNameNr_QMouseHandler 803
#define sipName_QMouseHandler &sipStrings_Qt3DInput[803]
#define sipNameNr_ShiftModifier 1940
#define sipName_ShiftModifier &sipStrings_Qt3DInput[1940]
#define sipNameNr_activeChanged 1954
#define sipName_activeChanged &sipStrings_Qt3DInput[1954]
#define sipNameNr_cancelPressed 1968
#define sipName_cancelPressed &sipStrings_Qt3DInput[1968]
#define sipNameNr_connectNotify 1458
#define sipName_connectNotify &sipStrings_Qt3DInput[1458]
#define sipNameNr_containsMouse 1982
#define sipName_containsMouse &sipStrings_Qt3DInput[1982]
#define sipNameNr_deletePressed 1996
#define sipName_deletePressed &sipStrings_Qt3DInput[1996]
#define sipNameNr_digit0Pressed 2010
#define sipName_digit0Pressed &sipStrings_Qt3DInput[2010]
#define sipNameNr_digit1Pressed 2024
#define sipName_digit1Pressed &sipStrings_Qt3DInput[2024]
#define sipNameNr_digit2Pressed 2038
#define sipName_digit2Pressed &sipStrings_Qt3DInput[2038]
#define sipNameNr_digit3Pressed 2052
#define sipName_digit3Pressed &sipStrings_Qt3DInput[2052]
#define sipNameNr_digit4Pressed 2066
#define sipName_digit4Pressed &sipStrings_Qt3DInput[2066]
#define sipNameNr_digit5Pressed 2080
#define sipName_digit5Pressed &sipStrings_Qt3DInput[2080]
#define sipNameNr_digit6Pressed 2094
#define sipName_digit6Pressed &sipStrings_Qt3DInput[2094]
#define sipNameNr_digit7Pressed 2108
#define sipName_digit7Pressed &sipStrings_Qt3DInput[2108]
#define sipNameNr_digit8Pressed 2122
#define sipName_digit8Pressed &sipStrings_Qt3DInput[2122]
#define sipNameNr_digit9Pressed 2136
#define sipName_digit9Pressed &sipStrings_Qt3DInput[2136]
#define sipNameNr_doubleClicked 2150
#define sipName_doubleClicked &sipStrings_Qt3DInput[2150]
#define sipNameNr_escapePressed 2164
#define sipName_escapePressed &sipStrings_Qt3DInput[2164]
#define sipNameNr_hangupPressed 2178
#define sipName_hangupPressed &sipStrings_Qt3DInput[2178]
#define sipNameNr_returnPressed 2192
#define sipName_returnPressed &sipStrings_Qt3DInput[2192]
#define sipNameNr_selectPressed 2206
#define sipName_selectPressed &sipStrings_Qt3DInput[2206]
#define sipNameNr_setSourceAxis 2220
#define sipName_setSourceAxis &sipStrings_Qt3DInput[2220]
#define sipNameNr_smoothChanged 2234
#define sipName_smoothChanged &sipStrings_Qt3DInput[2234]
#define sipNameNr_Acceleration 1653
#define sipName_Acceleration &sipStrings_Qt3DInput[1653]
#define sipNameNr_MetaModifier 2248
#define sipName_MetaModifier &sipStrings_Qt3DInput[2248]
#define sipNameNr_MiddleButton 2261
#define sipName_MiddleButton &sipStrings_Qt3DInput[2261]
#define sipNameNr_QActionInput 853
#define sipName_QActionInput &sipStrings_Qt3DInput[853]
#define sipNameNr_QAxisSetting 877
#define sipName_QAxisSetting &sipStrings_Qt3DInput[877]
#define sipNameNr_QInputAspect 901
#define sipName_QInputAspect &sipStrings_Qt3DInput[901]
#define sipNameNr_QMouseDevice 925
#define sipName_QMouseDevice &sipStrings_Qt3DInput[925]
#define sipNameNr_acceleration 2274
#define sipName_acceleration &sipStrings_Qt3DInput[2274]
#define sipNameNr_axisSettings 2287
#define sipName_axisSettings &sipStrings_Qt3DInput[2287]
#define sipNameNr_deceleration 2300
#define sipName_deceleration &sipStrings_Qt3DInput[2300]
#define sipNameNr_enterPressed 2313
#define sipName_enterPressed &sipStrings_Qt3DInput[2313]
#define sipNameNr_focusChanged 2326
#define sipName_focusChanged &sipStrings_Qt3DInput[2326]
#define sipNameNr_isAutoRepeat 2339
#define sipName_isAutoRepeat &sipStrings_Qt3DInput[2339]
#define sipNameNr_pressAndHold 2352
#define sipName_pressAndHold &sipStrings_Qt3DInput[2352]
#define sipNameNr_removeAction 2365
#define sipName_removeAction &sipStrings_Qt3DInput[2365]
#define sipNameNr_rightPressed 2378
#define sipName_rightPressed &sipStrings_Qt3DInput[2378]
#define sipNameNr_scaleChanged 2391
#define sipName_scaleChanged &sipStrings_Qt3DInput[2391]
#define sipNameNr_sourceDevice 2404
#define sipName_sourceDevice &sipStrings_Qt3DInput[2404]
#define sipNameNr_spacePressed 2417
#define sipName_spacePressed &sipStrings_Qt3DInput[2417]
#define sipNameNr_valueChanged 2430
#define sipName_valueChanged &sipStrings_Qt3DInput[2430]
#define sipNameNr_AltModifier 2443
#define sipName_AltModifier &sipStrings_Qt3DInput[2443]
#define sipNameNr_QInputChord 949
#define sipName_QInputChord &sipStrings_Qt3DInput[949]
#define sipNameNr_QMouseEvent 972
#define sipName_QMouseEvent &sipStrings_Qt3DInput[972]
#define sipNameNr_QWheelEvent 995
#define sipName_QWheelEvent &sipStrings_Qt3DInput[995]
#define sipNameNr_RightButton 2455
#define sipName_RightButton &sipStrings_Qt3DInput[2455]
#define sipNameNr_activeInput 2467
#define sipName_activeInput &sipStrings_Qt3DInput[2467]
#define sipNameNr_addSequence 2479
#define sipName_addSequence &sipStrings_Qt3DInput[2479]
#define sipNameNr_axesChanged 2491
#define sipName_axesChanged &sipStrings_Qt3DInput[2491]
#define sipNameNr_axisChanged 2503
#define sipName_axisChanged &sipStrings_Qt3DInput[2503]
#define sipNameNr_backPressed 2515
#define sipName_backPressed &sipStrings_Qt3DInput[2515]
#define sipNameNr_buttonCount 2527
#define sipName_buttonCount &sipStrings_Qt3DInput[2527]
#define sipNameNr_buttonNames 2539
#define sipName_buttonNames &sipStrings_Qt3DInput[2539]
#define sipNameNr_callPressed 2551
#define sipName_callPressed &sipStrings_Qt3DInput[2551]
#define sipNameNr_customEvent 2563
#define sipName_customEvent &sipStrings_Qt3DInput[2563]
#define sipNameNr_downPressed 2575
#define sipName_downPressed &sipStrings_Qt3DInput[2575]
#define sipNameNr_eventFilter 2587
#define sipName_eventFilter &sipStrings_Qt3DInput[2587]
#define sipNameNr_eventSource 2599
#define sipName_eventSource &sipStrings_Qt3DInput[2599]
#define sipNameNr_flipPressed 2611
#define sipName_flipPressed &sipStrings_Qt3DInput[2611]
#define sipNameNr_leftPressed 2623
#define sipName_leftPressed &sipStrings_Qt3DInput[2623]
#define sipNameNr_menuPressed 2635
#define sipName_menuPressed &sipStrings_Qt3DInput[2635]
#define sipNameNr_removeChord 2647
#define sipName_removeChord &sipStrings_Qt3DInput[2647]
#define sipNameNr_removeInput 2659
#define sipName_removeInput &sipStrings_Qt3DInput[2659]
#define sipNameNr_sensitivity 2671
#define sipName_sensitivity &sipStrings_Qt3DInput[2671]
#define sipNameNr_setAccepted 2683
#define sipName_setAccepted &sipStrings_Qt3DInput[2683]
#define sipNameNr_BackButton 2695
#define sipName_BackButton &sipStrings_Qt3DInput[2695]
#define sipNameNr_LeftButton 2706
#define sipName_LeftButton &sipStrings_Qt3DInput[2706]
#define sipNameNr_NoModifier 2717
#define sipName_NoModifier &sipStrings_Qt3DInput[2717]
#define sipNameNr_angleDelta 2728
#define sipName_angleDelta &sipStrings_Qt3DInput[2728]
#define sipNameNr_childEvent 2739
#define sipName_childEvent &sipStrings_Qt3DInput[2739]
#define sipNameNr_isAccepted 2750
#define sipName_isAccepted &sipStrings_Qt3DInput[2750]
#define sipNameNr_removeAxis 2761
#define sipName_removeAxis &sipStrings_Qt3DInput[2761]
#define sipNameNr_setButtons 2772
#define sipName_setButtons &sipStrings_Qt3DInput[2772]
#define sipNameNr_setTimeout 2783
#define sipName_setTimeout &sipStrings_Qt3DInput[2783]
#define sipNameNr_sourceAxis 2794
#define sipName_sourceAxis &sipStrings_Qt3DInput[2794]
#define sipNameNr_tabPressed 1794
#define sipName_tabPressed &sipStrings_Qt3DInput[1794]
#define sipNameNr_timerEvent 2805
#define sipName_timerEvent &sipStrings_Qt3DInput[2805]
#define sipNameNr_yesPressed 2816
#define sipName_yesPressed &sipStrings_Qt3DInput[2816]
#define sipNameNr_Modifiers 263
#define sipName_Modifiers &sipStrings_Qt3DInput[263]
#define sipNameNr_QKeyEvent 1107
#define sipName_QKeyEvent &sipStrings_Qt3DInput[1107]
#define sipNameNr_Qt3DInput 1528
#define sipName_Qt3DInput &sipStrings_Qt3DInput[1528]
#define sipNameNr_addAction 2827
#define sipName_addAction &sipStrings_Qt3DInput[2827]
#define sipNameNr_axisCount 2837
#define sipName_axisCount &sipStrings_Qt3DInput[2837]
#define sipNameNr_axisNames 2847
#define sipName_axisNames &sipStrings_Qt3DInput[2847]
#define sipNameNr_modifiers 2857
#define sipName_modifiers &sipStrings_Qt3DInput[2857]
#define sipNameNr_noPressed 2867
#define sipName_noPressed &sipStrings_Qt3DInput[2867]
#define sipNameNr_sequences 2877
#define sipName_sequences &sipStrings_Qt3DInput[2877]
#define sipNameNr_upPressed 2182
#define sipName_upPressed &sipStrings_Qt3DInput[2182]
#define sipNameNr_NoButton 2887
#define sipName_NoButton &sipStrings_Qt3DInput[2887]
#define sipNameNr_Velocity 2896
#define sipName_Velocity &sipStrings_Qt3DInput[2896]
#define sipNameNr_addChord 2905
#define sipName_addChord &sipStrings_Qt3DInput[2905]
#define sipNameNr_addInput 2914
#define sipName_addInput &sipStrings_Qt3DInput[2914]
#define sipNameNr_isActive 2923
#define sipName_isActive &sipStrings_Qt3DInput[2923]
#define sipNameNr_released 2932
#define sipName_released &sipStrings_Qt3DInput[2932]
#define sipNameNr_setFocus 2941
#define sipName_setFocus &sipStrings_Qt3DInput[2941]
#define sipNameNr_setScale 2950
#define sipName_setScale &sipStrings_Qt3DInput[2950]
#define sipNameNr_velocity 2959
#define sipName_velocity &sipStrings_Qt3DInput[2959]
#define sipNameNr_Buttons 363
#define sipName_Buttons &sipStrings_Qt3DInput[363]
#define sipNameNr_QAction 1230
#define sipName_QAction &sipStrings_Qt3DInput[1230]
#define sipNameNr_actions 2968
#define sipName_actions &sipStrings_Qt3DInput[2968]
#define sipNameNr_addAxis 2976
#define sipName_addAxis &sipStrings_Qt3DInput[2976]
#define sipNameNr_autorep 2984
#define sipName_autorep &sipStrings_Qt3DInput[2984]
#define sipNameNr_buttons 2992
#define sipName_buttons &sipStrings_Qt3DInput[2992]
#define sipNameNr_clicked 3000
#define sipName_clicked &sipStrings_Qt3DInput[3000]
#define sipNameNr_entered 3008
#define sipName_entered &sipStrings_Qt3DInput[3008]
#define sipNameNr_matches 3016
#define sipName_matches &sipStrings_Qt3DInput[3016]
#define sipNameNr_pressed 3024
#define sipName_pressed &sipStrings_Qt3DInput[3024]
#define sipNameNr_setAxes 3032
#define sipName_setAxes &sipStrings_Qt3DInput[3032]
#define sipNameNr_setAxis 3040
#define sipName_setAxis &sipStrings_Qt3DInput[3040]
#define sipNameNr_timeout 3048
#define sipName_timeout &sipStrings_Qt3DInput[3048]
#define sipNameNr_wasHeld 3056
#define sipName_wasHeld &sipStrings_Qt3DInput[3056]
#define sipNameNr_WheelX 3064
#define sipName_WheelX &sipStrings_Qt3DInput[3064]
#define sipNameNr_WheelY 3071
#define sipName_WheelY &sipStrings_Qt3DInput[3071]
#define sipNameNr_button 3078
#define sipName_button &sipStrings_Qt3DInput[3078]
#define sipNameNr_chords 3085
#define sipName_chords &sipStrings_Qt3DInput[3085]
#define sipNameNr_exited 3092
#define sipName_exited &sipStrings_Qt3DInput[3092]
#define sipNameNr_inputs 3099
#define sipName_inputs &sipStrings_Qt3DInput[3099]
#define sipNameNr_parent 3106
#define sipName_parent &sipStrings_Qt3DInput[3106]
#define sipNameNr_QAxis 1432
#define sipName_QAxis &sipStrings_Qt3DInput[1432]
#define sipNameNr_count 3113
#define sipName_count &sipStrings_Qt3DInput[3113]
#define sipNameNr_event 3119
#define sipName_event &sipStrings_Qt3DInput[3119]
#define sipNameNr_focus 3125
#define sipName_focus &sipStrings_Qt3DInput[3125]
#define sipNameNr_scale 3131
#define sipName_scale &sipStrings_Qt3DInput[3131]
#define sipNameNr_value 3137
#define sipName_value &sipStrings_Qt3DInput[3137]
#define sipNameNr_wheel 3143
#define sipName_wheel &sipStrings_Qt3DInput[3143]
#define sipNameNr_Axis 458
#define sipName_Axis &sipStrings_Qt3DInput[458]
#define sipNameNr_axes 3149
#define sipName_axes &sipStrings_Qt3DInput[3149]
#define sipNameNr_axis 3154
#define sipName_axis &sipStrings_Qt3DInput[3154]
#define sipNameNr_text 3159
#define sipName_text &sipStrings_Qt3DInput[3159]
#define sipNameNr_type 3164
#define sipName_type &sipStrings_Qt3DInput[3164]
#define sipNameNr_key 3169
#define sipName_key &sipStrings_Qt3DInput[3169]
#define sipNameNr_X 3069
#define sipName_X &sipStrings_Qt3DInput[3069]
#define sipNameNr_Y 3076
#define sipName_Y &sipStrings_Qt3DInput[3076]
#define sipNameNr_x 3173
#define sipName_x &sipStrings_Qt3DInput[3173]
#define sipNameNr_y 790
#define sipName_y &sipStrings_Qt3DInput[790]

#define sipMalloc                   sipAPI_Qt3DInput->api_malloc
#define sipFree                     sipAPI_Qt3DInput->api_free
#define sipBuildResult              sipAPI_Qt3DInput->api_build_result
#define sipCallMethod               sipAPI_Qt3DInput->api_call_method
#define sipCallProcedureMethod      sipAPI_Qt3DInput->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_Qt3DInput->api_call_error_handler
#define sipParseResultEx            sipAPI_Qt3DInput->api_parse_result_ex
#define sipParseResult              sipAPI_Qt3DInput->api_parse_result
#define sipParseArgs                sipAPI_Qt3DInput->api_parse_args
#define sipParseKwdArgs             sipAPI_Qt3DInput->api_parse_kwd_args
#define sipParsePair                sipAPI_Qt3DInput->api_parse_pair
#define sipInstanceDestroyed        sipAPI_Qt3DInput->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_Qt3DInput->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_Qt3DInput->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_Qt3DInput->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_Qt3DInput->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_Qt3DInput->api_convert_to_void_ptr
#define sipAddException             sipAPI_Qt3DInput->api_add_exception
#define sipNoFunction               sipAPI_Qt3DInput->api_no_function
#define sipNoMethod                 sipAPI_Qt3DInput->api_no_method
#define sipAbstractMethod           sipAPI_Qt3DInput->api_abstract_method
#define sipBadClass                 sipAPI_Qt3DInput->api_bad_class
#define sipBadCatcherResult         sipAPI_Qt3DInput->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_Qt3DInput->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_Qt3DInput->api_bad_operator_arg
#define sipTrace                    sipAPI_Qt3DInput->api_trace
#define sipTransferBack             sipAPI_Qt3DInput->api_transfer_back
#define sipTransferTo               sipAPI_Qt3DInput->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_Qt3DInput->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_Qt3DInput->api_wrapper_type
#define sipWrapperType_Type         sipAPI_Qt3DInput->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_Qt3DInput->api_voidptr_type
#define sipGetPyObject              sipAPI_Qt3DInput->api_get_pyobject
#define sipGetAddress               sipAPI_Qt3DInput->api_get_address
#define sipGetMixinAddress          sipAPI_Qt3DInput->api_get_mixin_address
#define sipGetCppPtr                sipAPI_Qt3DInput->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_Qt3DInput->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_Qt3DInput->api_call_hook
#define sipEndThread                sipAPI_Qt3DInput->api_end_thread
#define sipRaiseUnknownException    sipAPI_Qt3DInput->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_Qt3DInput->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_Qt3DInput->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_Qt3DInput->api_add_type_instance
#define sipPySlotExtend             sipAPI_Qt3DInput->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_Qt3DInput->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_Qt3DInput->api_can_convert_to_type
#define sipConvertToType            sipAPI_Qt3DInput->api_convert_to_type
#define sipForceConvertToType       sipAPI_Qt3DInput->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_Qt3DInput->api_convert_to_enum
#define sipConvertToBool            sipAPI_Qt3DInput->api_convert_to_bool
#define sipReleaseType              sipAPI_Qt3DInput->api_release_type
#define sipConvertFromType          sipAPI_Qt3DInput->api_convert_from_type
#define sipConvertFromNewType       sipAPI_Qt3DInput->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_Qt3DInput->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_Qt3DInput->api_convert_from_enum
#define sipGetState                 sipAPI_Qt3DInput->api_get_state
#define sipExportSymbol             sipAPI_Qt3DInput->api_export_symbol
#define sipImportSymbol             sipAPI_Qt3DInput->api_import_symbol
#define sipFindType                 sipAPI_Qt3DInput->api_find_type
#define sipBytes_AsChar             sipAPI_Qt3DInput->api_bytes_as_char
#define sipBytes_AsString           sipAPI_Qt3DInput->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_Qt3DInput->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_Qt3DInput->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_Qt3DInput->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_Qt3DInput->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_Qt3DInput->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_Qt3DInput->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_Qt3DInput->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_Qt3DInput->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_Qt3DInput->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_Qt3DInput->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_Qt3DInput->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_Qt3DInput->api_get_reference
#define sipKeepReference            sipAPI_Qt3DInput->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_Qt3DInput->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_Qt3DInput->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_Qt3DInput->api_type_from_py_type_object
#define sipTypeScope                sipAPI_Qt3DInput->api_type_scope
#define sipResolveTypedef           sipAPI_Qt3DInput->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_Qt3DInput->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_Qt3DInput->api_enable_autoconversion
#define sipInitMixin                sipAPI_Qt3DInput->api_init_mixin
#define sipExportModule             sipAPI_Qt3DInput->api_export_module
#define sipInitModule               sipAPI_Qt3DInput->api_init_module
#define sipGetInterpreter           sipAPI_Qt3DInput->api_get_interpreter
#define sipSetTypeUserData          sipAPI_Qt3DInput->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_Qt3DInput->api_get_type_user_data
#define sipPyTypeDict               sipAPI_Qt3DInput->api_py_type_dict
#define sipPyTypeName               sipAPI_Qt3DInput->api_py_type_name
#define sipGetCFunction             sipAPI_Qt3DInput->api_get_c_function
#define sipGetMethod                sipAPI_Qt3DInput->api_get_method
#define sipFromMethod               sipAPI_Qt3DInput->api_from_method
#define sipGetDate                  sipAPI_Qt3DInput->api_get_date
#define sipFromDate                 sipAPI_Qt3DInput->api_from_date
#define sipGetDateTime              sipAPI_Qt3DInput->api_get_datetime
#define sipFromDateTime             sipAPI_Qt3DInput->api_from_datetime
#define sipGetTime                  sipAPI_Qt3DInput->api_get_time
#define sipFromTime                 sipAPI_Qt3DInput->api_from_time
#define sipIsUserType               sipAPI_Qt3DInput->api_is_user_type
#define sipCheckPluginForType       sipAPI_Qt3DInput->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_Qt3DInput->api_unicode_new
#define sipUnicodeWrite             sipAPI_Qt3DInput->api_unicode_write
#define sipUnicodeData              sipAPI_Qt3DInput->api_unicode_data
#define sipGetBufferInfo            sipAPI_Qt3DInput->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_Qt3DInput->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_Qt3DInput->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_Qt3DInput->api_is_derived_class
#define sipGetUserObject            sipAPI_Qt3DInput->api_get_user_object
#define sipSetUserObject            sipAPI_Qt3DInput->api_set_user_object
#define sipRegisterEventHandler     sipAPI_Qt3DInput->api_register_event_handler
#define sipConvertToArray           sipAPI_Qt3DInput->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_Qt3DInput->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_Qt3DInput->api_enable_gc
#define sipPrintObject              sipAPI_Qt3DInput->api_print_object
#define sipLong_AsChar              sipAPI_Qt3DInput->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_Qt3DInput->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_Qt3DInput->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_Qt3DInput->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_Qt3DInput->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_Qt3DInput->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_Qt3DInput->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_Qt3DInput->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_Qt3DInput->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_Qt3DInput->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_Qt3DInput->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_Qt3DInput->api_long_as_size_t
#define sipVisitWrappers            sipAPI_Qt3DInput->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_Qt3DInput->api_register_exit_notifier
#define sipDeprecated               sipAPI_Qt3DInput->api_deprecated
#define sipPyTypeDictRef            sipAPI_Qt3DInput->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_Qt3DInput->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_Qt3DInput->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_Qt3DInput->api_get_frame
#define sipSetDestroyOnExit         sipAPI_Qt3DInput->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_Qt3DInput->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_Qt3DInput->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_Qt3DInput->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_Qt3DInput->api_connect_rx
#define sipConvertRx                sipAPI_Qt3DInput->api_convert_rx
#define sipDisconnectRx             sipAPI_Qt3DInput->api_disconnect_rx
#define sipFreeSipslot              sipAPI_Qt3DInput->api_free_sipslot
#define sipInvokeSlot               sipAPI_Qt3DInput->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_Qt3DInput->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_Qt3DInput->api_same_slot
#define sipSaveSlot                 sipAPI_Qt3DInput->api_save_slot
#define sipVisitSlot                sipAPI_Qt3DInput->api_visit_slot
#define sipIsPyMethod               sipAPI_Qt3DInput->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_Qt3DInput[];


#define sipType_Qt3DInput_QAbstractActionInput sipExportedTypes_Qt3DInput[5]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAbstractActionInput;

#define sipType_Qt3DInput_QAbstractAxisInput sipExportedTypes_Qt3DInput[6]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAbstractAxisInput;

#define sipType_Qt3DInput_QAbstractPhysicalDevice sipExportedTypes_Qt3DInput[7]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAbstractPhysicalDevice;

#define sipType_Qt3DInput_QAction sipExportedTypes_Qt3DInput[8]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAction;

#define sipType_Qt3DInput_QActionInput sipExportedTypes_Qt3DInput[9]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QActionInput;

#define sipType_Qt3DInput_QAnalogAxisInput sipExportedTypes_Qt3DInput[10]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAnalogAxisInput;

#define sipType_Qt3DInput_QAxis sipExportedTypes_Qt3DInput[11]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAxis;

#define sipType_Qt3DInput_QAxisAccumulator sipExportedTypes_Qt3DInput[12]

#define sipType_Qt3DInput_QAxisAccumulator_SourceAxisType sipExportedTypes_Qt3DInput[13]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAxisAccumulator;

#define sipType_Qt3DInput_QAxisSetting sipExportedTypes_Qt3DInput[14]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QAxisSetting;

#define sipType_Qt3DInput_QButtonAxisInput sipExportedTypes_Qt3DInput[15]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QButtonAxisInput;

#define sipType_Qt3DInput_QInputAspect sipExportedTypes_Qt3DInput[16]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QInputAspect;

#define sipType_Qt3DInput_QInputChord sipExportedTypes_Qt3DInput[17]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QInputChord;

#define sipType_Qt3DInput_QInputSequence sipExportedTypes_Qt3DInput[18]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QInputSequence;

#define sipType_Qt3DInput_QInputSettings sipExportedTypes_Qt3DInput[19]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QInputSettings;

#define sipType_Qt3DInput_QKeyboardDevice sipExportedTypes_Qt3DInput[21]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QKeyboardDevice;

#define sipType_Qt3DInput_QKeyboardHandler sipExportedTypes_Qt3DInput[22]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QKeyboardHandler;

#define sipType_Qt3DInput_QKeyEvent sipExportedTypes_Qt3DInput[20]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QKeyEvent;

#define sipType_Qt3DInput_QLogicalDevice sipExportedTypes_Qt3DInput[23]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QLogicalDevice;

#define sipType_Qt3DInput_QMouseDevice sipExportedTypes_Qt3DInput[24]

#define sipType_Qt3DInput_QMouseDevice_Axis sipExportedTypes_Qt3DInput[25]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QMouseDevice;

#define sipType_Qt3DInput_QMouseEvent sipExportedTypes_Qt3DInput[26]

#define sipType_Qt3DInput_QMouseEvent_Modifiers sipExportedTypes_Qt3DInput[28]

#define sipType_Qt3DInput_QMouseEvent_Buttons sipExportedTypes_Qt3DInput[27]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QMouseEvent;

#define sipType_Qt3DInput_QWheelEvent sipExportedTypes_Qt3DInput[31]

#define sipType_Qt3DInput_QWheelEvent_Modifiers sipExportedTypes_Qt3DInput[33]

#define sipType_Qt3DInput_QWheelEvent_Buttons sipExportedTypes_Qt3DInput[32]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QWheelEvent;

#define sipType_Qt3DInput_QMouseHandler sipExportedTypes_Qt3DInput[29]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QMouseHandler;

#define sipType_Qt3DInput_QPhysicalDeviceCreatedChangeBase sipExportedTypes_Qt3DInput[30]

extern sipClassTypeDef sipTypeDef_Qt3DInput_Qt3DInput_QPhysicalDeviceCreatedChangeBase;

#define sipType_QVector_0101Qt3DInput_QAxis sipExportedTypes_Qt3DInput[3]

extern sipMappedTypeDef sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAxis;

#define sipType_QVector_0101Qt3DInput_QAction sipExportedTypes_Qt3DInput[2]

extern sipMappedTypeDef sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAction;

#define sipType_QVector_0101Qt3DInput_QAbstractAxisInput sipExportedTypes_Qt3DInput[1]

extern sipMappedTypeDef sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAbstractAxisInput;

#define sipType_QVector_0101Qt3DInput_QAbstractActionInput sipExportedTypes_Qt3DInput[0]

extern sipMappedTypeDef sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAbstractActionInput;

#define sipType_QVector_0101Qt3DInput_QAxisSetting sipExportedTypes_Qt3DInput[4]

extern sipMappedTypeDef sipTypeDef_Qt3DInput_QVector_0101Qt3DInput_QAxisSetting;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_Qt3DInput;
extern sipExportedModuleDef sipModuleAPI_Qt3DInput;
extern sipTypeDef *sipExportedTypes_Qt3DInput[];

#define sipType_Qt_KeyboardModifiers sipImportedTypes_Qt3DInput_QtCore[10].it_td

#define sipType_QObject sipImportedTypes_Qt3DInput_QtCore[4].it_td

#define sipType_QEvent sipImportedTypes_Qt3DInput_QtCore[1].it_td

#define sipType_QEvent_Type sipImportedTypes_Qt3DInput_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_Qt3DInput_QtCore[8].it_td

#define sipType_QChildEvent sipImportedTypes_Qt3DInput_QtCore[0].it_td

#define sipType_QMetaMethod sipImportedTypes_Qt3DInput_QtCore[3].it_td

#define sipType_QPoint sipImportedTypes_Qt3DInput_QtCore[5].it_td

#define sipType_QVector_1800 sipImportedTypes_Qt3DInput_QtCore[9].it_td

#define sipType_QStringList sipImportedTypes_Qt3DInput_QtCore[7].it_td

#define sipType_QString sipImportedTypes_Qt3DInput_QtCore[6].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DInput_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DInput_QtCore[];

#define sipType_QMouseEvent sipImportedTypes_Qt3DInput_QtGui[2].it_td

#define sipType_QWheelEvent sipImportedTypes_Qt3DInput_QtGui[3].it_td

#define sipType_QKeyEvent sipImportedTypes_Qt3DInput_QtGui[0].it_td

#define sipType_QKeySequence_StandardKey sipImportedTypes_Qt3DInput_QtGui[1].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DInput_QtGui[];

#define sipType_Qt3DCore_QAbstractAspect sipImportedTypes_Qt3DInput_Qt3DCore[2].it_td

#define sipType_Qt3DCore_QNode sipImportedTypes_Qt3DInput_Qt3DCore[4].it_td

#define sipType_Qt3DCore_QComponent sipImportedTypes_Qt3DInput_Qt3DCore[3].it_td

#define sipType_Qt3DCore_QSceneChange sipImportedTypes_Qt3DInput_Qt3DCore[6].it_td

#define sipType_Qt3DCore_QNodeCreatedChangeBase sipImportedTypes_Qt3DInput_Qt3DCore[5].it_td

#define sipType_QSharedPointer_0100Qt3DCore_QSceneChange sipImportedTypes_Qt3DInput_Qt3DCore[0].it_td

#define sipType_QVector_0100Qt3DCore_QNodeId sipImportedTypes_Qt3DInput_Qt3DCore[1].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DInput_Qt3DCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_Qt3DInput_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_Qt3DInput_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_Qt3DInput_qt_metacast;
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"

#include <qsharedpointer.h>


// The dtor for the saved QSharedPointer.
#if defined(SIP_USE_PYCAPSULE)
template<class T>
void qt3d_QspDtor(PyObject *capsule)
{
    delete reinterpret_cast<QSharedPointer<T> *>(
            PyCapsule_GetPointer(capsule, 0));
}
#else
template<class T>
void qt3d_QspDtor(void *shared)
{
    delete reinterpret_cast<QSharedPointer<T> *>(array);
}
#endif


template<class T>
bool qt3d_SaveQsp(PyObject *py, QSharedPointer<T> *qsp)
{
    // Wrap the copy in a Python object.
#if defined(SIP_USE_PYCAPSULE)
    PyObject *qsp_obj = PyCapsule_New(qsp, 0, qt3d_QspDtor<T>);
#else
    PyObject *qsp_obj = PyCObject_FromVoidPtr(qsp, qt3d_QspDto<T>r);
#endif

    if (!qsp_obj)
        return false;

    sipSetUserObject((sipSimpleWrapper *)py, qsp_obj);

    return true;
}

#line 918 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DInput/sipAPIQt3DInput.h"

#endif
