/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DExtras.h"

#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 31 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 59 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboardhandler.sip"
#include <qkeyboardhandler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyevent.sip"
#include <qkeyevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qlogicaldevice.sip"
#include <qlogicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmousedevice.sip"
#include <qmousedevice.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qmousedevice.sip"
#include <qmousedevice.h>
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractactioninput.sip"
#include <qabstractactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractaxisinput.sip"
#include <qabstractaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qabstractphysicaldevice.sip"
#include <qabstractphysicaldevice.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaction.sip"
#include <qaction.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qactioninput.sip"
#include <qactioninput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qanalogaxisinput.sip"
#include <qanalogaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxis.sip"
#include <qaxis.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxisaccumulator.sip"
#include <qaxisaccumulator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qaxissetting.sip"
#include <qaxissetting.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qbuttonaxisinput.sip"
#include <qbuttonaxisinput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputaspect.sip"
#include <qinputaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputchord.sip"
#include <qinputchord.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsequence.sip"
#include <qinputsequence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qinputsettings.sip"
#include <qinputsettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DInput/qkeyboarddevice.sip"
#include <qkeyboarddevice.h>
#line 133 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 164 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 187 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 202 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 205 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 208 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 237 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 240 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 243 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 246 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 299 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 302 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 305 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 340 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 345 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 348 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 351 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 354 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 357 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 360 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 363 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 366 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 369 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 372 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 375 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 378 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 381 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 384 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrasQt3DExtrasQAbstractCameraController.cpp"


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_camera, "camera(self) -> QCamera|None");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_camera(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_camera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp))
        {
            ::Qt3DRender::QCamera*sipRes;

            sipRes = sipCpp->camera();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QCamera, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_camera, doc_Qt3DExtras_QAbstractCameraController_camera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_linearSpeed, "linearSpeed(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_linearSpeed(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_linearSpeed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->linearSpeed();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_linearSpeed, doc_Qt3DExtras_QAbstractCameraController_linearSpeed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_lookSpeed, "lookSpeed(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_lookSpeed(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_lookSpeed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->lookSpeed();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_lookSpeed, doc_Qt3DExtras_QAbstractCameraController_lookSpeed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_acceleration, "acceleration(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_acceleration(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_acceleration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->acceleration();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_acceleration, doc_Qt3DExtras_QAbstractCameraController_acceleration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_deceleration, "deceleration(self) -> float");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_deceleration(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_deceleration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->deceleration();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_deceleration, doc_Qt3DExtras_QAbstractCameraController_deceleration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_setCamera, "setCamera(self, camera: QCamera|None)");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_setCamera(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_setCamera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QCamera* a0;
        ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp, sipType_Qt3DRender_QCamera, &a0))
        {
            sipCpp->setCamera(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_setCamera, doc_Qt3DExtras_QAbstractCameraController_setCamera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_setLinearSpeed, "setLinearSpeed(self, linearSpeed: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_setLinearSpeed(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_setLinearSpeed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp, &a0))
        {
            sipCpp->setLinearSpeed(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_setLinearSpeed, doc_Qt3DExtras_QAbstractCameraController_setLinearSpeed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_setLookSpeed, "setLookSpeed(self, lookSpeed: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_setLookSpeed(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_setLookSpeed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp, &a0))
        {
            sipCpp->setLookSpeed(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_setLookSpeed, doc_Qt3DExtras_QAbstractCameraController_setLookSpeed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_setAcceleration, "setAcceleration(self, acceleration: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_setAcceleration(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_setAcceleration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp, &a0))
        {
            sipCpp->setAcceleration(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_setAcceleration, doc_Qt3DExtras_QAbstractCameraController_setAcceleration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_setDeceleration, "setDeceleration(self, deceleration: float)");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_setDeceleration(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_setDeceleration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp, &a0))
        {
            sipCpp->setDeceleration(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_setDeceleration, doc_Qt3DExtras_QAbstractCameraController_setDeceleration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_keyboardDevice, "keyboardDevice(self) -> QKeyboardDevice|None");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_keyboardDevice(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_keyboardDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp))
        {
            ::Qt3DInput::QKeyboardDevice*sipRes;

            sipRes = sipCpp->keyboardDevice();

            return sipConvertFromType(sipRes, sipType_Qt3DInput_QKeyboardDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_keyboardDevice, doc_Qt3DExtras_QAbstractCameraController_keyboardDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DExtras_QAbstractCameraController_mouseDevice, "mouseDevice(self) -> QMouseDevice|None");

extern "C" {static PyObject *meth_Qt3DExtras_QAbstractCameraController_mouseDevice(PyObject *, PyObject *);}
static PyObject *meth_Qt3DExtras_QAbstractCameraController_mouseDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DExtras::QAbstractCameraController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_Qt3DExtras_QAbstractCameraController, &sipCpp))
        {
            ::Qt3DInput::QMouseDevice*sipRes;

            sipRes = sipCpp->mouseDevice();

            return sipConvertFromType(sipRes, sipType_Qt3DInput_QMouseDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractCameraController, sipName_mouseDevice, doc_Qt3DExtras_QAbstractCameraController_mouseDevice);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DExtras_QAbstractCameraController(void *, const sipTypeDef *);}
static void *cast_Qt3DExtras_QAbstractCameraController(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DExtras::QAbstractCameraController *sipCpp = reinterpret_cast< ::Qt3DExtras::QAbstractCameraController *>(sipCppV);

    if (targetType == sipType_Qt3DExtras_QAbstractCameraController)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QEntity)->ctd_cast(static_cast< ::Qt3DCore::QEntity *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DExtras_QAbstractCameraController(void *, int);}
static void release_Qt3DExtras_QAbstractCameraController(void *sipCppV, int)
{
    ::Qt3DExtras::QAbstractCameraController *sipCpp = reinterpret_cast< ::Qt3DExtras::QAbstractCameraController *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_Qt3DExtras_QAbstractCameraController(sipSimpleWrapper *);}
static void dealloc_Qt3DExtras_QAbstractCameraController(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DExtras_QAbstractCameraController(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DExtras_QAbstractCameraController[] = {{3, 2, 1}};


static PyMethodDef methods_Qt3DExtras_QAbstractCameraController[] = {
    {sipName_acceleration, meth_Qt3DExtras_QAbstractCameraController_acceleration, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_acceleration},
    {sipName_camera, meth_Qt3DExtras_QAbstractCameraController_camera, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_camera},
    {sipName_deceleration, meth_Qt3DExtras_QAbstractCameraController_deceleration, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_deceleration},
    {sipName_keyboardDevice, meth_Qt3DExtras_QAbstractCameraController_keyboardDevice, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_keyboardDevice},
    {sipName_linearSpeed, meth_Qt3DExtras_QAbstractCameraController_linearSpeed, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_linearSpeed},
    {sipName_lookSpeed, meth_Qt3DExtras_QAbstractCameraController_lookSpeed, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_lookSpeed},
    {sipName_mouseDevice, meth_Qt3DExtras_QAbstractCameraController_mouseDevice, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_mouseDevice},
    {sipName_setAcceleration, meth_Qt3DExtras_QAbstractCameraController_setAcceleration, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_setAcceleration},
    {sipName_setCamera, meth_Qt3DExtras_QAbstractCameraController_setCamera, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_setCamera},
    {sipName_setDeceleration, meth_Qt3DExtras_QAbstractCameraController_setDeceleration, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_setDeceleration},
    {sipName_setLinearSpeed, meth_Qt3DExtras_QAbstractCameraController_setLinearSpeed, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_setLinearSpeed},
    {sipName_setLookSpeed, meth_Qt3DExtras_QAbstractCameraController_setLookSpeed, METH_VARARGS, doc_Qt3DExtras_QAbstractCameraController_setLookSpeed}
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DExtras_QAbstractCameraController[] = {
    {"decelerationChanged(float)", "\1decelerationChanged(self, deceleration: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"accelerationChanged(float)", "\1accelerationChanged(self, acceleration: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"lookSpeedChanged()", "\1lookSpeedChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"linearSpeedChanged()", "\1linearSpeedChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"cameraChanged()", "\1cameraChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DExtras_QAbstractCameraController = {
    &::Qt3DExtras::QAbstractCameraController::staticMetaObject,
    0,
    signals_Qt3DExtras_QAbstractCameraController,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DExtras_Qt3DExtras_QAbstractCameraController = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DExtras__QAbstractCameraController,
        SIP_NULLPTR,
        &plugin_Qt3DExtras_QAbstractCameraController,
    },
    {
        sipNameNr_QAbstractCameraController,
        {0, 0, 1},
        12, methods_Qt3DExtras_QAbstractCameraController,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_Qt3DExtras_QAbstractCameraController,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DExtras_QAbstractCameraController,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_Qt3DExtras_QAbstractCameraController,
    cast_Qt3DExtras_QAbstractCameraController,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
