/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 59 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 87 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 90 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 143 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 146 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 181 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 184 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 207 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 210 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 213 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 242 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 245 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 248 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 251 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 254 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 259 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 262 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 265 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 268 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 271 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 274 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 277 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 280 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 283 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 286 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 289 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 292 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 295 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 298 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCameraLens.cpp"


class sipQt3DRender_QCameraLens : public ::Qt3DRender::QCameraLens
{
public:
    sipQt3DRender_QCameraLens(::Qt3DCore::QNode*);
    virtual ~sipQt3DRender_QCameraLens();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QCameraLens(const sipQt3DRender_QCameraLens &);
    sipQt3DRender_QCameraLens &operator = (const sipQt3DRender_QCameraLens &);

    char sipPyMethods[7];
};

sipQt3DRender_QCameraLens::sipQt3DRender_QCameraLens(::Qt3DCore::QNode*a0): ::Qt3DRender::QCameraLens(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QCameraLens::~sipQt3DRender_QCameraLens()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QCameraLens::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QCameraLens);

    return ::Qt3DRender::QCameraLens::metaObject();
}

int sipQt3DRender_QCameraLens::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QCameraLens::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QCameraLens, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QCameraLens::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QCameraLens, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QCameraLens::qt_metacast(_clname));
}

bool sipQt3DRender_QCameraLens::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QCameraLens::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QCameraLens::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QCameraLens::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DRender_QCameraLens::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QCameraLens::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QCameraLens::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QCameraLens::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QCameraLens::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QCameraLens::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QCameraLens::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QCameraLens::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QCameraLens::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QCameraLens::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_projectionType, "projectionType(self) -> QCameraLens.ProjectionType");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_projectionType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_projectionType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            ::Qt3DRender::QCameraLens::ProjectionType sipRes;

            sipRes = sipCpp->projectionType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QCameraLens_ProjectionType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_projectionType, doc_Qt3DRender_QCameraLens_projectionType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_nearPlane, "nearPlane(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_nearPlane(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_nearPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->nearPlane();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_nearPlane, doc_Qt3DRender_QCameraLens_nearPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_farPlane, "farPlane(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_farPlane(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_farPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->farPlane();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_farPlane, doc_Qt3DRender_QCameraLens_farPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_fieldOfView, "fieldOfView(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_fieldOfView(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_fieldOfView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->fieldOfView();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_fieldOfView, doc_Qt3DRender_QCameraLens_fieldOfView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_aspectRatio, "aspectRatio(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_aspectRatio(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_aspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->aspectRatio();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_aspectRatio, doc_Qt3DRender_QCameraLens_aspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_left, "left(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_left(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_left(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->left();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_left, doc_Qt3DRender_QCameraLens_left);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_right, "right(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_right(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_right(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->right();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_right, doc_Qt3DRender_QCameraLens_right);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_bottom, "bottom(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_bottom(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_bottom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->bottom();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_bottom, doc_Qt3DRender_QCameraLens_bottom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_top, "top(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_top(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_top(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->top();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_top, doc_Qt3DRender_QCameraLens_top);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_projectionMatrix, "projectionMatrix(self) -> QMatrix4x4");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_projectionMatrix(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_projectionMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            ::QMatrix4x4*sipRes;

            sipRes = new ::QMatrix4x4(sipCpp->projectionMatrix());

            return sipConvertFromNewType(sipRes, sipType_QMatrix4x4, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_projectionMatrix, doc_Qt3DRender_QCameraLens_projectionMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setOrthographicProjection, "setOrthographicProjection(self, left: float, right: float, bottom: float, top: float, nearPlane: float, farPlane: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setOrthographicProjection(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setOrthographicProjection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        float a1;
        float a2;
        float a3;
        float a4;
        float a5;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffffff", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->setOrthographicProjection(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setOrthographicProjection, doc_Qt3DRender_QCameraLens_setOrthographicProjection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setFrustumProjection, "setFrustumProjection(self, left: float, right: float, bottom: float, top: float, nearPlane: float, farPlane: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setFrustumProjection(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setFrustumProjection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        float a1;
        float a2;
        float a3;
        float a4;
        float a5;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffffff", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->setFrustumProjection(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setFrustumProjection, doc_Qt3DRender_QCameraLens_setFrustumProjection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setPerspectiveProjection, "setPerspectiveProjection(self, fieldOfView: float, aspect: float, nearPlane: float, farPlane: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setPerspectiveProjection(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setPerspectiveProjection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        float a1;
        float a2;
        float a3;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->setPerspectiveProjection(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setPerspectiveProjection, doc_Qt3DRender_QCameraLens_setPerspectiveProjection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setProjectionType, "setProjectionType(self, projectionType: QCameraLens.ProjectionType)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setProjectionType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setProjectionType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QCameraLens::ProjectionType a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, sipType_Qt3DRender_QCameraLens_ProjectionType, &a0))
        {
            sipCpp->setProjectionType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setProjectionType, doc_Qt3DRender_QCameraLens_setProjectionType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setNearPlane, "setNearPlane(self, nearPlane: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setNearPlane(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setNearPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setNearPlane(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setNearPlane, doc_Qt3DRender_QCameraLens_setNearPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setFarPlane, "setFarPlane(self, farPlane: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setFarPlane(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setFarPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setFarPlane(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setFarPlane, doc_Qt3DRender_QCameraLens_setFarPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setFieldOfView, "setFieldOfView(self, fieldOfView: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setFieldOfView(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setFieldOfView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setFieldOfView(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setFieldOfView, doc_Qt3DRender_QCameraLens_setFieldOfView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setAspectRatio, "setAspectRatio(self, aspectRatio: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setAspectRatio(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setAspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setAspectRatio(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setAspectRatio, doc_Qt3DRender_QCameraLens_setAspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setLeft, "setLeft(self, left: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setLeft(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setLeft(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setLeft(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setLeft, doc_Qt3DRender_QCameraLens_setLeft);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setRight, "setRight(self, right: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setRight(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setRight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setRight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setRight, doc_Qt3DRender_QCameraLens_setRight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setBottom, "setBottom(self, bottom: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setBottom(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setBottom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setBottom(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setBottom, doc_Qt3DRender_QCameraLens_setBottom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setTop, "setTop(self, top: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setTop(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setTop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setTop(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setTop, doc_Qt3DRender_QCameraLens_setTop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setProjectionMatrix, "setProjectionMatrix(self, projectionMatrix: QMatrix4x4)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setProjectionMatrix(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setProjectionMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMatrix4x4* a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, sipType_QMatrix4x4, &a0))
        {
            sipCpp->setProjectionMatrix(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setProjectionMatrix, doc_Qt3DRender_QCameraLens_setProjectionMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_exposure, "exposure(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_exposure(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_exposure(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->exposure();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_exposure, doc_Qt3DRender_QCameraLens_exposure);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_setExposure, "setExposure(self, exposure: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_setExposure(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_setExposure(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, &a0))
        {
            sipCpp->setExposure(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_setExposure, doc_Qt3DRender_QCameraLens_setExposure);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_viewAll, "viewAll(self, cameraId: QNodeId)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_viewAll(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_viewAll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNodeId* a0;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, sipType_Qt3DCore_QNodeId, &a0))
        {
            sipCpp->viewAll(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_viewAll, doc_Qt3DRender_QCameraLens_viewAll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCameraLens_viewEntity, "viewEntity(self, entityId: QNodeId, cameraId: QNodeId)");

extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_viewEntity(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_viewEntity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNodeId* a0;
        ::Qt3DCore::QNodeId* a1;
        ::Qt3DRender::QCameraLens *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_Qt3DRender_QCameraLens, &sipCpp, sipType_Qt3DCore_QNodeId, &a0, sipType_Qt3DCore_QNodeId, &a1))
        {
            sipCpp->viewEntity(*a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraLens, sipName_viewEntity, doc_Qt3DRender_QCameraLens_viewEntity);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *meth_Qt3DRender_QCameraLens_sceneChangeEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCameraLens_sceneChangeEvent(PyObject *, PyObject *)
{

    sipNoMethod(SIP_NULLPTR, sipName_QCameraLens, sipName_sceneChangeEvent, SIP_NULLPTR);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QCameraLens(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QCameraLens(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QCameraLens *sipCpp = reinterpret_cast< ::Qt3DRender::QCameraLens *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QCameraLens)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QComponent)->ctd_cast(static_cast< ::Qt3DCore::QComponent *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QCameraLens(void *, int);}
static void release_Qt3DRender_QCameraLens(void *sipCppV, int)
{
    ::Qt3DRender::QCameraLens *sipCpp = reinterpret_cast< ::Qt3DRender::QCameraLens *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QCameraLens(Py_ssize_t);}
static void *array_Qt3DRender_QCameraLens(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QCameraLens[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QCameraLens(void *);}
static void array_delete_Qt3DRender_QCameraLens(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QCameraLens *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QCameraLens(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QCameraLens(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QCameraLens *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QCameraLens(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QCameraLens(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QCameraLens(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QCameraLens *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QCameraLens(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QCameraLens[] = {{2, 2, 1}};


static PyMethodDef methods_Qt3DRender_QCameraLens[] = {
    {sipName_aspectRatio, meth_Qt3DRender_QCameraLens_aspectRatio, METH_VARARGS, doc_Qt3DRender_QCameraLens_aspectRatio},
    {sipName_bottom, meth_Qt3DRender_QCameraLens_bottom, METH_VARARGS, doc_Qt3DRender_QCameraLens_bottom},
    {sipName_exposure, meth_Qt3DRender_QCameraLens_exposure, METH_VARARGS, doc_Qt3DRender_QCameraLens_exposure},
    {sipName_farPlane, meth_Qt3DRender_QCameraLens_farPlane, METH_VARARGS, doc_Qt3DRender_QCameraLens_farPlane},
    {sipName_fieldOfView, meth_Qt3DRender_QCameraLens_fieldOfView, METH_VARARGS, doc_Qt3DRender_QCameraLens_fieldOfView},
    {sipName_left, meth_Qt3DRender_QCameraLens_left, METH_VARARGS, doc_Qt3DRender_QCameraLens_left},
    {sipName_nearPlane, meth_Qt3DRender_QCameraLens_nearPlane, METH_VARARGS, doc_Qt3DRender_QCameraLens_nearPlane},
    {sipName_projectionMatrix, meth_Qt3DRender_QCameraLens_projectionMatrix, METH_VARARGS, doc_Qt3DRender_QCameraLens_projectionMatrix},
    {sipName_projectionType, meth_Qt3DRender_QCameraLens_projectionType, METH_VARARGS, doc_Qt3DRender_QCameraLens_projectionType},
    {sipName_right, meth_Qt3DRender_QCameraLens_right, METH_VARARGS, doc_Qt3DRender_QCameraLens_right},
    {sipName_sceneChangeEvent, meth_Qt3DRender_QCameraLens_sceneChangeEvent, METH_VARARGS, SIP_NULLPTR},
    {sipName_setAspectRatio, meth_Qt3DRender_QCameraLens_setAspectRatio, METH_VARARGS, doc_Qt3DRender_QCameraLens_setAspectRatio},
    {sipName_setBottom, meth_Qt3DRender_QCameraLens_setBottom, METH_VARARGS, doc_Qt3DRender_QCameraLens_setBottom},
    {sipName_setExposure, meth_Qt3DRender_QCameraLens_setExposure, METH_VARARGS, doc_Qt3DRender_QCameraLens_setExposure},
    {sipName_setFarPlane, meth_Qt3DRender_QCameraLens_setFarPlane, METH_VARARGS, doc_Qt3DRender_QCameraLens_setFarPlane},
    {sipName_setFieldOfView, meth_Qt3DRender_QCameraLens_setFieldOfView, METH_VARARGS, doc_Qt3DRender_QCameraLens_setFieldOfView},
    {sipName_setFrustumProjection, meth_Qt3DRender_QCameraLens_setFrustumProjection, METH_VARARGS, doc_Qt3DRender_QCameraLens_setFrustumProjection},
    {sipName_setLeft, meth_Qt3DRender_QCameraLens_setLeft, METH_VARARGS, doc_Qt3DRender_QCameraLens_setLeft},
    {sipName_setNearPlane, meth_Qt3DRender_QCameraLens_setNearPlane, METH_VARARGS, doc_Qt3DRender_QCameraLens_setNearPlane},
    {sipName_setOrthographicProjection, meth_Qt3DRender_QCameraLens_setOrthographicProjection, METH_VARARGS, doc_Qt3DRender_QCameraLens_setOrthographicProjection},
    {sipName_setPerspectiveProjection, meth_Qt3DRender_QCameraLens_setPerspectiveProjection, METH_VARARGS, doc_Qt3DRender_QCameraLens_setPerspectiveProjection},
    {sipName_setProjectionMatrix, meth_Qt3DRender_QCameraLens_setProjectionMatrix, METH_VARARGS, doc_Qt3DRender_QCameraLens_setProjectionMatrix},
    {sipName_setProjectionType, meth_Qt3DRender_QCameraLens_setProjectionType, METH_VARARGS, doc_Qt3DRender_QCameraLens_setProjectionType},
    {sipName_setRight, meth_Qt3DRender_QCameraLens_setRight, METH_VARARGS, doc_Qt3DRender_QCameraLens_setRight},
    {sipName_setTop, meth_Qt3DRender_QCameraLens_setTop, METH_VARARGS, doc_Qt3DRender_QCameraLens_setTop},
    {sipName_top, meth_Qt3DRender_QCameraLens_top, METH_VARARGS, doc_Qt3DRender_QCameraLens_top},
    {sipName_viewAll, meth_Qt3DRender_QCameraLens_viewAll, METH_VARARGS, doc_Qt3DRender_QCameraLens_viewAll},
    {sipName_viewEntity, meth_Qt3DRender_QCameraLens_viewEntity, METH_VARARGS, doc_Qt3DRender_QCameraLens_viewEntity}
};

static sipEnumMemberDef enummembers_Qt3DRender_QCameraLens[] = {
    {sipName_CustomProjection, static_cast<int>(::Qt3DRender::QCameraLens::CustomProjection), 57},
    {sipName_FrustumProjection, static_cast<int>(::Qt3DRender::QCameraLens::FrustumProjection), 57},
    {sipName_OrthographicProjection, static_cast<int>(::Qt3DRender::QCameraLens::OrthographicProjection), 57},
    {sipName_PerspectiveProjection, static_cast<int>(::Qt3DRender::QCameraLens::PerspectiveProjection), 57},
};

PyDoc_STRVAR(doc_Qt3DRender_QCameraLens, "\1QCameraLens(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QCameraLens[] = {
    {"viewSphere(QVector3D,float)", "\1viewSphere(self, center: QVector3D, radius: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"exposureChanged(float)", "\1exposureChanged(self, exposure: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"projectionMatrixChanged(QMatrix4x4)", "\1projectionMatrixChanged(self, projectionMatrix: QMatrix4x4)", SIP_NULLPTR, SIP_NULLPTR},
    {"topChanged(float)", "\1topChanged(self, top: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"bottomChanged(float)", "\1bottomChanged(self, bottom: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"rightChanged(float)", "\1rightChanged(self, right: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"leftChanged(float)", "\1leftChanged(self, left: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"aspectRatioChanged(float)", "\1aspectRatioChanged(self, aspectRatio: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"fieldOfViewChanged(float)", "\1fieldOfViewChanged(self, fieldOfView: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"farPlaneChanged(float)", "\1farPlaneChanged(self, farPlane: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"nearPlaneChanged(float)", "\1nearPlaneChanged(self, nearPlane: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"projectionTypeChanged(QCameraLens::ProjectionType)|(Qt3DRender::QCameraLens::ProjectionType)", "\1projectionTypeChanged(self, projectionType: QCameraLens.ProjectionType)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QCameraLens = {
    &::Qt3DRender::QCameraLens::staticMetaObject,
    0,
    signals_Qt3DRender_QCameraLens,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QCameraLens = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QCameraLens,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QCameraLens,
    },
    {
        sipNameNr_QCameraLens,
        {0, 0, 1},
        28, methods_Qt3DRender_QCameraLens,
        4, enummembers_Qt3DRender_QCameraLens,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QCameraLens,
    -1,
    -1,
    supers_Qt3DRender_QCameraLens,
    SIP_NULLPTR,
    init_type_Qt3DRender_QCameraLens,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QCameraLens,
    SIP_NULLPTR,
    array_Qt3DRender_QCameraLens,
    SIP_NULLPTR,
    release_Qt3DRender_QCameraLens,
    cast_Qt3DRender_QCameraLens,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QCameraLens,
    sizeof (::Qt3DRender::QCameraLens),
};
