/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _Qt3DCoreAPI_H
#define _Qt3DCoreAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_Qt3DCore[0]
#define sipNameNr_Qt3DCore__QStaticPropertyValueRemovedChangeBase 49
#define sipName_Qt3DCore__QStaticPropertyValueRemovedChangeBase &sipStrings_Qt3DCore[49]
#define sipNameNr_Qt3DCore__QStaticPropertyValueAddedChangeBase 97
#define sipName_Qt3DCore__QStaticPropertyValueAddedChangeBase &sipStrings_Qt3DCore[97]
#define sipNameNr_143 143
#define sipName_143 &sipStrings_Qt3DCore[143]
#define sipNameNr_Qt3DCore__QStaticPropertyUpdatedChangeBase 188
#define sipName_Qt3DCore__QStaticPropertyUpdatedChangeBase &sipStrings_Qt3DCore[188]
#define sipNameNr_Qt3DCore__QPropertyValueRemovedChangeBase 231
#define sipName_Qt3DCore__QPropertyValueRemovedChangeBase &sipStrings_Qt3DCore[231]
#define sipNameNr_Qt3DCore__QDynamicPropertyUpdatedChange 273
#define sipName_Qt3DCore__QDynamicPropertyUpdatedChange &sipStrings_Qt3DCore[273]
#define sipNameNr_Qt3DCore__QPropertyValueAddedChangeBase 313
#define sipName_Qt3DCore__QPropertyValueAddedChangeBase &sipStrings_Qt3DCore[313]
#define sipNameNr_353 353
#define sipName_353 &sipStrings_Qt3DCore[353]
#define sipNameNr_392 392
#define sipName_392 &sipStrings_Qt3DCore[392]
#define sipNameNr_QStaticPropertyValueRemovedChangeBase 59
#define sipName_QStaticPropertyValueRemovedChangeBase &sipStrings_Qt3DCore[59]
#define sipNameNr_Qt3DCore__QNode__PropertyTrackingMode 431
#define sipName_Qt3DCore__QNode__PropertyTrackingMode &sipStrings_Qt3DCore[431]
#define sipNameNr_Qt3DCore__QPropertyValueRemovedChange 469
#define sipName_Qt3DCore__QPropertyValueRemovedChange &sipStrings_Qt3DCore[469]
#define sipNameNr_Qt3DCore__QSceneChange__DeliveryFlags 507
#define sipName_Qt3DCore__QSceneChange__DeliveryFlags &sipStrings_Qt3DCore[507]
#define sipNameNr_Qt3DCore__QPropertyNodeRemovedChange 545
#define sipName_Qt3DCore__QPropertyNodeRemovedChange &sipStrings_Qt3DCore[545]
#define sipNameNr_Qt3DCore__QPropertyUpdatedChangeBase 582
#define sipName_Qt3DCore__QPropertyUpdatedChangeBase &sipStrings_Qt3DCore[582]
#define sipNameNr_Qt3DCore__QSceneChange__DeliveryFlag 619
#define sipName_Qt3DCore__QSceneChange__DeliveryFlag &sipStrings_Qt3DCore[619]
#define sipNameNr_QStaticPropertyValueAddedChangeBase 107
#define sipName_QStaticPropertyValueAddedChangeBase &sipStrings_Qt3DCore[107]
#define sipNameNr_656 656
#define sipName_656 &sipStrings_Qt3DCore[656]
#define sipNameNr_Qt3DCore__QPropertyValueAddedChange 692
#define sipName_Qt3DCore__QPropertyValueAddedChange &sipStrings_Qt3DCore[692]
#define sipNameNr_728 728
#define sipName_728 &sipStrings_Qt3DCore[728]
#define sipNameNr_Qt3DCore__QPropertyNodeAddedChange 763
#define sipName_Qt3DCore__QPropertyNodeAddedChange &sipStrings_Qt3DCore[763]
#define sipNameNr_defaultPropertyTrackingModeChanged 798
#define sipName_defaultPropertyTrackingModeChanged &sipStrings_Qt3DCore[798]
#define sipNameNr_833 833
#define sipName_833 &sipStrings_Qt3DCore[833]
#define sipNameNr_Qt3DCore__QComponentRemovedChange 867
#define sipName_Qt3DCore__QComponentRemovedChange &sipStrings_Qt3DCore[867]
#define sipNameNr_Qt3DCore__QSkeletonLoader__Status 901
#define sipName_Qt3DCore__QSkeletonLoader__Status &sipStrings_Qt3DCore[901]
#define sipNameNr_QStaticPropertyUpdatedChangeBase 198
#define sipName_QStaticPropertyUpdatedChangeBase &sipStrings_Qt3DCore[198]
#define sipNameNr_Qt3DCore__QAspectEngine__RunMode 935
#define sipName_Qt3DCore__QAspectEngine__RunMode &sipStrings_Qt3DCore[935]
#define sipNameNr_Qt3DCore__QNodeCreatedChangeBase 968
#define sipName_Qt3DCore__QNodeCreatedChangeBase &sipStrings_Qt3DCore[968]
#define sipNameNr_Qt3DCore__QPropertyUpdatedChange 1001
#define sipName_Qt3DCore__QPropertyUpdatedChange &sipStrings_Qt3DCore[1001]
#define sipNameNr_QPropertyValueRemovedChangeBase 241
#define sipName_QPropertyValueRemovedChangeBase &sipStrings_Qt3DCore[241]
#define sipNameNr_Qt3DCore__QComponentAddedChange 1034
#define sipName_Qt3DCore__QComponentAddedChange &sipStrings_Qt3DCore[1034]
#define sipNameNr_1066 1066
#define sipName_1066 &sipStrings_Qt3DCore[1066]
#define sipNameNr_Qt3DCore__QNodeDestroyedChange 1097
#define sipName_Qt3DCore__QNodeDestroyedChange &sipStrings_Qt3DCore[1097]
#define sipNameNr_setDefaultPropertyTrackingMode 1128
#define sipName_setDefaultPropertyTrackingMode &sipStrings_Qt3DCore[1128]
#define sipNameNr_QDynamicPropertyUpdatedChange 283
#define sipName_QDynamicPropertyUpdatedChange &sipStrings_Qt3DCore[283]
#define sipNameNr_QPropertyValueAddedChangeBase 323
#define sipName_QPropertyValueAddedChangeBase &sipStrings_Qt3DCore[323]
#define sipNameNr_Qt3DCore__QBackendNode__Mode 1159
#define sipName_Qt3DCore__QBackendNode__Mode &sipStrings_Qt3DCore[1159]
#define sipNameNr_Qt3DCore__QBackendNodeMapper 1188
#define sipName_Qt3DCore__QBackendNodeMapper &sipStrings_Qt3DCore[1188]
#define sipNameNr_QPropertyValueRemovedChange 479
#define sipName_QPropertyValueRemovedChange &sipStrings_Qt3DCore[479]
#define sipNameNr_1217 1217
#define sipName_1217 &sipStrings_Qt3DCore[1217]
#define sipNameNr_Qt3DCore__QAbstractSkeleton 1245
#define sipName_Qt3DCore__QAbstractSkeleton &sipStrings_Qt3DCore[1245]
#define sipNameNr_defaultPropertyTrackingMode 1273
#define sipName_defaultPropertyTrackingMode &sipStrings_Qt3DCore[1273]
#define sipNameNr_QPropertyNodeRemovedChange 555
#define sipName_QPropertyNodeRemovedChange &sipStrings_Qt3DCore[555]
#define sipNameNr_QPropertyUpdatedChangeBase 592
#define sipName_QPropertyUpdatedChangeBase &sipStrings_Qt3DCore[592]
#define sipNameNr_1301 1301
#define sipName_1301 &sipStrings_Qt3DCore[1301]
#define sipNameNr_1328 1328
#define sipName_1328 &sipStrings_Qt3DCore[1328]
#define sipNameNr_createJointsEnabledChanged 1355
#define sipName_createJointsEnabledChanged &sipStrings_Qt3DCore[1355]
#define sipNameNr_QPropertyValueAddedChange 702
#define sipName_QPropertyValueAddedChange &sipStrings_Qt3DCore[702]
#define sipNameNr_1382 1382
#define sipName_1382 &sipStrings_Qt3DCore[1382]
#define sipNameNr_Qt3DCore__QAbstractAspect 1408
#define sipName_Qt3DCore__QAbstractAspect &sipStrings_Qt3DCore[1408]
#define sipNameNr_Qt3DCore__QNodeIdTypePair 1434
#define sipName_Qt3DCore__QNodeIdTypePair &sipStrings_Qt3DCore[1434]
#define sipNameNr_Qt3DCore__QSkeletonLoader 1460
#define sipName_Qt3DCore__QSkeletonLoader &sipStrings_Qt3DCore[1460]
#define sipNameNr_QPropertyNodeAddedChange 773
#define sipName_QPropertyNodeAddedChange &sipStrings_Qt3DCore[773]
#define sipNameNr_inverseBindMatrixChanged 1486
#define sipName_inverseBindMatrixChanged &sipStrings_Qt3DCore[1486]
#define sipNameNr_QComponentRemovedChange 877
#define sipName_QComponentRemovedChange &sipStrings_Qt3DCore[877]
#define sipNameNr_Qt3DCore__QAspectEngine 1511
#define sipName_Qt3DCore__QAspectEngine &sipStrings_Qt3DCore[1511]
#define sipNameNr_QNodeCreatedChangeBase 978
#define sipName_QNodeCreatedChangeBase &sipStrings_Qt3DCore[978]
#define sipNameNr_QPropertyUpdatedChange 1011
#define sipName_QPropertyUpdatedChange &sipStrings_Qt3DCore[1011]
#define sipNameNr_Qt3DCore__QBackendNode 1535
#define sipName_Qt3DCore__QBackendNode &sipStrings_Qt3DCore[1535]
#define sipNameNr_Qt3DCore__QNodeCommand 1558
#define sipName_Qt3DCore__QNodeCommand &sipStrings_Qt3DCore[1558]
#define sipNameNr_Qt3DCore__QSceneChange 1581
#define sipName_Qt3DCore__QSceneChange &sipStrings_Qt3DCore[1581]
#define sipNameNr_clearPropertyTrackings 1604
#define sipName_clearPropertyTrackings &sipStrings_Qt3DCore[1604]
#define sipNameNr_setCreateJointsEnabled 1627
#define sipName_setCreateJointsEnabled &sipStrings_Qt3DCore[1627]
#define sipNameNr_QComponentAddedChange 1044
#define sipName_QComponentAddedChange &sipStrings_Qt3DCore[1044]
#define sipNameNr_Qt3DCore__ChangeFlags 1650
#define sipName_Qt3DCore__ChangeFlags &sipStrings_Qt3DCore[1650]
#define sipNameNr_clearPropertyTracking 1672
#define sipName_clearPropertyTracking &sipStrings_Qt3DCore[1672]
#define sipNameNr_isCreateJointsEnabled 1694
#define sipName_isCreateJointsEnabled &sipStrings_Qt3DCore[1694]
#define sipNameNr_unregisterBackendType 1716
#define sipName_unregisterBackendType &sipStrings_Qt3DCore[1716]
#define sipNameNr_PropertyTrackingMode 448
#define sipName_PropertyTrackingMode &sipStrings_Qt3DCore[448]
#define sipNameNr_PropertyValueRemoved 1738
#define sipName_PropertyValueRemoved &sipStrings_Qt3DCore[1738]
#define sipNameNr_QNodeDestroyedChange 1107
#define sipName_QNodeDestroyedChange &sipStrings_Qt3DCore[1107]
#define sipNameNr_Qt3DCore__ChangeFlag 1759
#define sipName_Qt3DCore__ChangeFlag &sipStrings_Qt3DCore[1759]
#define sipNameNr_Qt3DCore__QComponent 1780
#define sipName_Qt3DCore__QComponent &sipStrings_Qt3DCore[1780]
#define sipNameNr_Qt3DCore__QTransform 1801
#define sipName_Qt3DCore__QTransform &sipStrings_Qt3DCore[1801]
#define sipNameNr_notificationsBlocked 1822
#define sipName_notificationsBlocked &sipStrings_Qt3DCore[1822]
#define sipNameNr_setInverseBindMatrix 1843
#define sipName_setInverseBindMatrix &sipStrings_Qt3DCore[1843]
#define sipNameNr_Qt3DCore__QArmature 1864
#define sipName_Qt3DCore__QArmature &sipStrings_Qt3DCore[1864]
#define sipNameNr_Qt3DCore__QSkeleton 1884
#define sipName_Qt3DCore__QSkeleton &sipStrings_Qt3DCore[1884]
#define sipNameNr_componentMetaObject 1904
#define sipName_componentMetaObject &sipStrings_Qt3DCore[1904]
#define sipNameNr_registerBackendType 1718
#define sipName_registerBackendType &sipStrings_Qt3DCore[1718]
#define sipNameNr_setPropertyTracking 1924
#define sipName_setPropertyTracking &sipStrings_Qt3DCore[1924]
#define sipNameNr_setReplyToCommandId 1944
#define sipName_setReplyToCommandId &sipStrings_Qt3DCore[1944]
#define sipNameNr_PropertyValueAdded 1964
#define sipName_PropertyValueAdded &sipStrings_Qt3DCore[1964]
#define sipNameNr_QBackendNodeMapper 1198
#define sipName_QBackendNodeMapper &sipStrings_Qt3DCore[1198]
#define sipNameNr_blockNotifications 1983
#define sipName_blockNotifications &sipStrings_Qt3DCore[1983]
#define sipNameNr_subtreeIdsAndTypes 2002
#define sipName_subtreeIdsAndTypes &sipStrings_Qt3DCore[2002]
#define sipNameNr_translationChanged 2021
#define sipName_translationChanged &sipStrings_Qt3DCore[2021]
#define sipNameNr_worldMatrixChanged 2040
#define sipName_worldMatrixChanged &sipStrings_Qt3DCore[2040]
#define sipNameNr_CallbackTriggered 2059
#define sipName_CallbackTriggered &sipStrings_Qt3DCore[2059]
#define sipNameNr_QAbstractSkeleton 1255
#define sipName_QAbstractSkeleton &sipStrings_Qt3DCore[1255]
#define sipNameNr_Qt3DCore__QEntity 2077
#define sipName_Qt3DCore__QEntity &sipStrings_Qt3DCore[2077]
#define sipNameNr_Qt3DCore__QNodeId 2095
#define sipName_Qt3DCore__QNodeId &sipStrings_Qt3DCore[2095]
#define sipNameNr_fromAxesAndAngles 2113
#define sipName_fromAxesAndAngles &sipStrings_Qt3DCore[2113]
#define sipNameNr_inverseBindMatrix 2131
#define sipName_inverseBindMatrix &sipStrings_Qt3DCore[2131]
#define sipNameNr_jointCountChanged 2149
#define sipName_jointCountChanged &sipStrings_Qt3DCore[2149]
#define sipNameNr_removedFromEntity 2167
#define sipName_removedFromEntity &sipStrings_Qt3DCore[2167]
#define sipNameNr_sip_simplewrapper 2185
#define sipName_sip_simplewrapper &sipStrings_Qt3DCore[2185]
#define sipNameNr_CommandRequested 2203
#define sipName_CommandRequested &sipStrings_Qt3DCore[2203]
#define sipNameNr_ComponentRemoved 2220
#define sipName_ComponentRemoved &sipStrings_Qt3DCore[2220]
#define sipNameNr_Qt3DCore__QJoint 2237
#define sipName_Qt3DCore__QJoint &sipStrings_Qt3DCore[2237]
#define sipNameNr_TrackFinalValues 2254
#define sipName_TrackFinalValues &sipStrings_Qt3DCore[2254]
#define sipNameNr_disconnectNotify 2271
#define sipName_disconnectNotify &sipStrings_Qt3DCore[2271]
#define sipNameNr_fromAxisAndAngle 2288
#define sipName_fromAxisAndAngle &sipStrings_Qt3DCore[2288]
#define sipNameNr_propertyTracking 2305
#define sipName_propertyTracking &sipStrings_Qt3DCore[2305]
#define sipNameNr_removeChildJoint 2322
#define sipName_removeChildJoint &sipStrings_Qt3DCore[2322]
#define sipNameNr_rootJointChanged 2339
#define sipName_rootJointChanged &sipStrings_Qt3DCore[2339]
#define sipNameNr_rotationXChanged 2356
#define sipName_rotationXChanged &sipStrings_Qt3DCore[2356]
#define sipNameNr_rotationYChanged 2373
#define sipName_rotationYChanged &sipStrings_Qt3DCore[2373]
#define sipNameNr_rotationZChanged 2390
#define sipName_rotationZChanged &sipStrings_Qt3DCore[2390]
#define sipNameNr_sceneChangeEvent 2407
#define sipName_sceneChangeEvent &sipStrings_Qt3DCore[2407]
#define sipNameNr_setDeliveryFlags 2424
#define sipName_setDeliveryFlags &sipStrings_Qt3DCore[2424]
#define sipNameNr_shareableChanged 2441
#define sipName_shareableChanged &sipStrings_Qt3DCore[2441]
#define sipNameNr_unregisterAspect 2458
#define sipName_unregisterAspect &sipStrings_Qt3DCore[2458]
#define sipNameNr_DontTrackValues 2475
#define sipName_DontTrackValues &sipStrings_Qt3DCore[2475]
#define sipNameNr_PropertyUpdated 2491
#define sipName_PropertyUpdated &sipStrings_Qt3DCore[2491]
#define sipNameNr_QAbstractAspect 1418
#define sipName_QAbstractAspect &sipStrings_Qt3DCore[1418]
#define sipNameNr_QNodeIdTypePair 1444
#define sipName_QNodeIdTypePair &sipStrings_Qt3DCore[1444]
#define sipNameNr_QSkeletonLoader 1470
#define sipName_QSkeletonLoader &sipStrings_Qt3DCore[1470]
#define sipNameNr_Qt3DCore__QNode 2507
#define sipName_Qt3DCore__QNode &sipStrings_Qt3DCore[2507]
#define sipNameNr_fromEulerAngles 2523
#define sipName_fromEulerAngles &sipStrings_Qt3DCore[2523]
#define sipNameNr_notifyObservers 2539
#define sipName_notifyObservers &sipStrings_Qt3DCore[2539]
#define sipNameNr_removeComponent 2555
#define sipName_removeComponent &sipStrings_Qt3DCore[2555]
#define sipNameNr_rotationChanged 2571
#define sipName_rotationChanged &sipStrings_Qt3DCore[2571]
#define sipNameNr_setPropertyName 2587
#define sipName_setPropertyName &sipStrings_Qt3DCore[2587]
#define sipNameNr_setRemovedValue 2603
#define sipName_setRemovedValue &sipStrings_Qt3DCore[2603]
#define sipNameNr_skeletonChanged 2619
#define sipName_skeletonChanged &sipStrings_Qt3DCore[2619]
#define sipNameNr_ComponentAdded 2635
#define sipName_ComponentAdded &sipStrings_Qt3DCore[2635]
#define sipNameNr_PyQt5_Qt3DCore 2650
#define sipName_PyQt5_Qt3DCore &sipStrings_Qt3DCore[2650]
#define sipNameNr_TrackAllValues 2665
#define sipName_TrackAllValues &sipStrings_Qt3DCore[2665]
#define sipNameNr_enabledChanged 2680
#define sipName_enabledChanged &sipStrings_Qt3DCore[2680]
#define sipNameNr_executeCommand 2695
#define sipName_executeCommand &sipStrings_Qt3DCore[2695]
#define sipNameNr_registerAspect 2460
#define sipName_registerAspect &sipStrings_Qt3DCore[2460]
#define sipNameNr_rotateFromAxes 2710
#define sipName_rotateFromAxes &sipStrings_Qt3DCore[2710]
#define sipNameNr_scale3DChanged 2725
#define sipName_scale3DChanged &sipStrings_Qt3DCore[2725]
#define sipNameNr_setTranslation 2740
#define sipName_setTranslation &sipStrings_Qt3DCore[2740]
#define sipNameNr_DeliveryFlags 531
#define sipName_DeliveryFlags &sipStrings_Qt3DCore[531]
#define sipNameNr_QAspectEngine 1521
#define sipName_QAspectEngine &sipStrings_Qt3DCore[1521]
#define sipNameNr_addChildJoint 2755
#define sipName_addChildJoint &sipStrings_Qt3DCore[2755]
#define sipNameNr_addedToEntity 2769
#define sipName_addedToEntity &sipStrings_Qt3DCore[2769]
#define sipNameNr_connectNotify 2274
#define sipName_connectNotify &sipStrings_Qt3DCore[2274]
#define sipNameNr_deliveryFlags 2783
#define sipName_deliveryFlags &sipStrings_Qt3DCore[2783]
#define sipNameNr_isNodeEnabled 2797
#define sipName_isNodeEnabled &sipStrings_Qt3DCore[2797]
#define sipNameNr_matrixChanged 2811
#define sipName_matrixChanged &sipStrings_Qt3DCore[2811]
#define sipNameNr_nodeDestroyed 2825
#define sipName_nodeDestroyed &sipStrings_Qt3DCore[2825]
#define sipNameNr_parentChanged 2839
#define sipName_parentChanged &sipStrings_Qt3DCore[2839]
#define sipNameNr_removedNodeId 2853
#define sipName_removedNodeId &sipStrings_Qt3DCore[2853]
#define sipNameNr_setAddedValue 2867
#define sipName_setAddedValue &sipStrings_Qt3DCore[2867]
#define sipNameNr_setRootEntity 2881
#define sipName_setRootEntity &sipStrings_Qt3DCore[2881]
#define sipNameNr_setToIdentity 2895
#define sipName_setToIdentity &sipStrings_Qt3DCore[2895]
#define sipNameNr_sourceChanged 2909
#define sipName_sourceChanged &sipStrings_Qt3DCore[2909]
#define sipNameNr_statusChanged 2923
#define sipName_statusChanged &sipStrings_Qt3DCore[2923]
#define sipNameNr_BackendNodes 2937
#define sipName_BackendNodes &sipStrings_Qt3DCore[2937]
#define sipNameNr_DeliverToAll 2950
#define sipName_DeliverToAll &sipStrings_Qt3DCore[2950]
#define sipNameNr_DeliveryFlag 643
#define sipName_DeliveryFlag &sipStrings_Qt3DCore[643]
#define sipNameNr_QBackendNode 1545
#define sipName_QBackendNode &sipStrings_Qt3DCore[1545]
#define sipNameNr_QNodeCommand 1568
#define sipName_QNodeCommand &sipStrings_Qt3DCore[1568]
#define sipNameNr_QSceneChange 1591
#define sipName_QSceneChange &sipStrings_Qt3DCore[1591]
#define sipNameNr_addComponent 2963
#define sipName_addComponent &sipStrings_Qt3DCore[2963]
#define sipNameNr_parentEntity 2976
#define sipName_parentEntity &sipStrings_Qt3DCore[2976]
#define sipNameNr_processFrame 2989
#define sipName_processFrame &sipStrings_Qt3DCore[2989]
#define sipNameNr_propertyName 3002
#define sipName_propertyName &sipStrings_Qt3DCore[3002]
#define sipNameNr_removedValue 3015
#define sipName_removedValue &sipStrings_Qt3DCore[3015]
#define sipNameNr_rootEntityId 3028
#define sipName_rootEntityId &sipStrings_Qt3DCore[3028]
#define sipNameNr_rotateAround 3041
#define sipName_rotateAround &sipStrings_Qt3DCore[3041]
#define sipNameNr_scaleChanged 3054
#define sipName_scaleChanged &sipStrings_Qt3DCore[3054]
#define sipNameNr_setRootJoint 3067
#define sipName_setRootJoint &sipStrings_Qt3DCore[3067]
#define sipNameNr_setRotationX 3080
#define sipName_setRotationX &sipStrings_Qt3DCore[3080]
#define sipNameNr_setRotationY 3093
#define sipName_setRotationY &sipStrings_Qt3DCore[3093]
#define sipNameNr_setRotationZ 3106
#define sipName_setRotationZ &sipStrings_Qt3DCore[3106]
#define sipNameNr_setShareable 3119
#define sipName_setShareable &sipStrings_Qt3DCore[3119]
#define sipNameNr_ChangeFlags 1660
#define sipName_ChangeFlags &sipStrings_Qt3DCore[1660]
#define sipNameNr_NodeCreated 3132
#define sipName_NodeCreated &sipStrings_Qt3DCore[3132]
#define sipNameNr_NodeDeleted 3144
#define sipName_NodeDeleted &sipStrings_Qt3DCore[3144]
#define sipNameNr_addedNodeId 3156
#define sipName_addedNodeId &sipStrings_Qt3DCore[3156]
#define sipNameNr_childJoints 3168
#define sipName_childJoints &sipStrings_Qt3DCore[3168]
#define sipNameNr_componentId 3180
#define sipName_componentId &sipStrings_Qt3DCore[3180]
#define sipNameNr_customEvent 3192
#define sipName_customEvent &sipStrings_Qt3DCore[3192]
#define sipNameNr_eventFilter 3204
#define sipName_eventFilter &sipStrings_Qt3DCore[3204]
#define sipNameNr_isShareable 3216
#define sipName_isShareable &sipStrings_Qt3DCore[3216]
#define sipNameNr_nameChanged 3228
#define sipName_nameChanged &sipStrings_Qt3DCore[3228]
#define sipNameNr_sendCommand 3240
#define sipName_sendCommand &sipStrings_Qt3DCore[3240]
#define sipNameNr_setRotation 3252
#define sipName_setRotation &sipStrings_Qt3DCore[3252]
#define sipNameNr_setSkeleton 3264
#define sipName_setSkeleton &sipStrings_Qt3DCore[3264]
#define sipNameNr_translation 3276
#define sipName_translation &sipStrings_Qt3DCore[3276]
#define sipNameNr_worldMatrix 3288
#define sipName_worldMatrix &sipStrings_Qt3DCore[3288]
#define sipNameNr_AllChanges 3300
#define sipName_AllChanges &sipStrings_Qt3DCore[3300]
#define sipNameNr_ChangeFlag 1769
#define sipName_ChangeFlag &sipStrings_Qt3DCore[1769]
#define sipNameNr_QComponent 1790
#define sipName_QComponent &sipStrings_Qt3DCore[1790]
#define sipNameNr_QTransform 1811
#define sipName_QTransform &sipStrings_Qt3DCore[1811]
#define sipNameNr___invert__ 3311
#define sipName___invert__ &sipStrings_Qt3DCore[3311]
#define sipNameNr_addedValue 3322
#define sipName_addedValue &sipStrings_Qt3DCore[3322]
#define sipNameNr_childEvent 3333
#define sipName_childEvent &sipStrings_Qt3DCore[3333]
#define sipNameNr_childNodes 3344
#define sipName_childNodes &sipStrings_Qt3DCore[3344]
#define sipNameNr_components 3355
#define sipName_components &sipStrings_Qt3DCore[3355]
#define sipNameNr_jointCount 3366
#define sipName_jointCount &sipStrings_Qt3DCore[3366]
#define sipNameNr_metaObject 3377
#define sipName_metaObject &sipStrings_Qt3DCore[3377]
#define sipNameNr_parentNode 3388
#define sipName_parentNode &sipStrings_Qt3DCore[3388]
#define sipNameNr_qIdForNode 3399
#define sipName_qIdForNode &sipStrings_Qt3DCore[3399]
#define sipNameNr_rootEntity 3410
#define sipName_rootEntity &sipStrings_Qt3DCore[3410]
#define sipNameNr_setEnabled 3421
#define sipName_setEnabled &sipStrings_Qt3DCore[3421]
#define sipNameNr_setRunMode 3432
#define sipName_setRunMode &sipStrings_Qt3DCore[3432]
#define sipNameNr_setScale3D 3443
#define sipName_setScale3D &sipStrings_Qt3DCore[3443]
#define sipNameNr_timerEvent 3454
#define sipName_timerEvent &sipStrings_Qt3DCore[3454]
#define sipNameNr_Automatic 3465
#define sipName_Automatic &sipStrings_Qt3DCore[3465]
#define sipNameNr_QArmature 1874
#define sipName_QArmature &sipStrings_Qt3DCore[1874]
#define sipNameNr_QSkeleton 1894
#define sipName_QSkeleton &sipStrings_Qt3DCore[1894]
#define sipNameNr_ReadWrite 3475
#define sipName_ReadWrite &sipStrings_Qt3DCore[3475]
#define sipNameNr___index__ 3485
#define sipName___index__ &sipStrings_Qt3DCore[3485]
#define sipNameNr_commandId 3495
#define sipName_commandId &sipStrings_Qt3DCore[3495]
#define sipNameNr_inReplyTo 3505
#define sipName_inReplyTo &sipStrings_Qt3DCore[3505]
#define sipNameNr_isEnabled 3515
#define sipName_isEnabled &sipStrings_Qt3DCore[3515]
#define sipNameNr_rootJoint 3525
#define sipName_rootJoint &sipStrings_Qt3DCore[3525]
#define sipNameNr_rotationX 3535
#define sipName_rotationX &sipStrings_Qt3DCore[3535]
#define sipNameNr_rotationY 3545
#define sipName_rotationY &sipStrings_Qt3DCore[3545]
#define sipNameNr_rotationZ 3555
#define sipName_rotationZ &sipStrings_Qt3DCore[3555]
#define sipNameNr_sendReply 3565
#define sipName_sendReply &sipStrings_Qt3DCore[3565]
#define sipNameNr_setMatrix 3575
#define sipName_setMatrix &sipStrings_Qt3DCore[3575]
#define sipNameNr_setParent 3585
#define sipName_setParent &sipStrings_Qt3DCore[3585]
#define sipNameNr_setSource 3595
#define sipName_setSource &sipStrings_Qt3DCore[3595]
#define sipNameNr_subjectId 3605
#define sipName_subjectId &sipStrings_Qt3DCore[3605]
#define sipNameNr_NotReady 3615
#define sipName_NotReady &sipStrings_Qt3DCore[3615]
#define sipNameNr_Qt3DCore 2656
#define sipName_Qt3DCore &sipStrings_Qt3DCore[2656]
#define sipNameNr_ReadOnly 3624
#define sipName_ReadOnly &sipStrings_Qt3DCore[3624]
#define sipNameNr___bool__ 3633
#define sipName___bool__ &sipStrings_Qt3DCore[3633]
#define sipNameNr___hash__ 3642
#define sipName___hash__ &sipStrings_Qt3DCore[3642]
#define sipNameNr___iand__ 3651
#define sipName___iand__ &sipStrings_Qt3DCore[3651]
#define sipNameNr___ixor__ 3660
#define sipName___ixor__ &sipStrings_Qt3DCore[3660]
#define sipNameNr_createId 3669
#define sipName_createId &sipStrings_Qt3DCore[3669]
#define sipNameNr_entities 3678
#define sipName_entities &sipStrings_Qt3DCore[3678]
#define sipNameNr_entityId 3687
#define sipName_entityId &sipStrings_Qt3DCore[3687]
#define sipNameNr_fromAxes 3696
#define sipName_fromAxes &sipStrings_Qt3DCore[3696]
#define sipNameNr_parentId 3705
#define sipName_parentId &sipStrings_Qt3DCore[3705]
#define sipNameNr_rotation 3714
#define sipName_rotation &sipStrings_Qt3DCore[3714]
#define sipNameNr_setScale 3723
#define sipName_setScale &sipStrings_Qt3DCore[3723]
#define sipNameNr_setValue 3732
#define sipName_setValue &sipStrings_Qt3DCore[3732]
#define sipNameNr_skeleton 3741
#define sipName_skeleton &sipStrings_Qt3DCore[3741]
#define sipNameNr_QEntity 2087
#define sipName_QEntity &sipStrings_Qt3DCore[2087]
#define sipNameNr_QNodeId 2105
#define sipName_QNodeId &sipStrings_Qt3DCore[2105]
#define sipNameNr_RunMode 960
#define sipName_RunMode &sipStrings_Qt3DCore[960]
#define sipNameNr___and__ 3750
#define sipName___and__ &sipStrings_Qt3DCore[3750]
#define sipNameNr___int__ 3758
#define sipName___int__ &sipStrings_Qt3DCore[3758]
#define sipNameNr___ior__ 3766
#define sipName___ior__ &sipStrings_Qt3DCore[3766]
#define sipNameNr___xor__ 3774
#define sipName___xor__ &sipStrings_Qt3DCore[3774]
#define sipNameNr_aspects 3782
#define sipName_aspects &sipStrings_Qt3DCore[3782]
#define sipNameNr_destroy 3790
#define sipName_destroy &sipStrings_Qt3DCore[3790]
#define sipNameNr_replyTo 3798
#define sipName_replyTo &sipStrings_Qt3DCore[3798]
#define sipNameNr_runMode 3806
#define sipName_runMode &sipStrings_Qt3DCore[3806]
#define sipNameNr_scale3D 3814
#define sipName_scale3D &sipStrings_Qt3DCore[3814]
#define sipNameNr_setData 3822
#define sipName_setData &sipStrings_Qt3DCore[3822]
#define sipNameNr_setName 3830
#define sipName_setName &sipStrings_Qt3DCore[3830]
#define sipNameNr_Manual 3838
#define sipName_Manual &sipStrings_Qt3DCore[3838]
#define sipNameNr_QJoint 2247
#define sipName_QJoint &sipStrings_Qt3DCore[2247]
#define sipNameNr_Status 928
#define sipName_Status &sipStrings_Qt3DCore[928]
#define sipNameNr___eq__ 3845
#define sipName___eq__ &sipStrings_Qt3DCore[3845]
#define sipNameNr___ge__ 3852
#define sipName___ge__ &sipStrings_Qt3DCore[3852]
#define sipNameNr___gt__ 3859
#define sipName___gt__ &sipStrings_Qt3DCore[3859]
#define sipNameNr___le__ 3866
#define sipName___le__ &sipStrings_Qt3DCore[3866]
#define sipNameNr___lt__ 3873
#define sipName___lt__ &sipStrings_Qt3DCore[3873]
#define sipNameNr___ne__ 3880
#define sipName___ne__ &sipStrings_Qt3DCore[3880]
#define sipNameNr___or__ 3887
#define sipName___or__ &sipStrings_Qt3DCore[3887]
#define sipNameNr_create 3894
#define sipName_create &sipStrings_Qt3DCore[3894]
#define sipNameNr_isNull 3901
#define sipName_isNull &sipStrings_Qt3DCore[3901]
#define sipNameNr_matrix 3908
#define sipName_matrix &sipStrings_Qt3DCore[3908]
#define sipNameNr_parent 3915
#define sipName_parent &sipStrings_Qt3DCore[3915]
#define sipNameNr_peerId 3922
#define sipName_peerId &sipStrings_Qt3DCore[3922]
#define sipNameNr_source 3929
#define sipName_source &sipStrings_Qt3DCore[3929]
#define sipNameNr_status 3936
#define sipName_status &sipStrings_Qt3DCore[3936]
#define sipNameNr_Error 3943
#define sipName_Error &sipStrings_Qt3DCore[3943]
#define sipNameNr_Nodes 2944
#define sipName_Nodes &sipStrings_Qt3DCore[2944]
#define sipNameNr_QNode 2517
#define sipName_QNode &sipStrings_Qt3DCore[2517]
#define sipNameNr_Ready 3618
#define sipName_Ready &sipStrings_Qt3DCore[3618]
#define sipNameNr_event 3949
#define sipName_event &sipStrings_Qt3DCore[3949]
#define sipNameNr_scale 3955
#define sipName_scale &sipStrings_Qt3DCore[3955]
#define sipNameNr_value 3961
#define sipName_value &sipStrings_Qt3DCore[3961]
#define sipNameNr_Mode 464
#define sipName_Mode &sipStrings_Qt3DCore[464]
#define sipNameNr_data 3967
#define sipName_data &sipStrings_Qt3DCore[3967]
#define sipNameNr_mode 3972
#define sipName_mode &sipStrings_Qt3DCore[3972]
#define sipNameNr_name 3977
#define sipName_name &sipStrings_Qt3DCore[3977]
#define sipNameNr_type 3982
#define sipName_type &sipStrings_Qt3DCore[3982]
#define sipNameNr_get 3987
#define sipName_get &sipStrings_Qt3DCore[3987]
#define sipNameNr_id 3991
#define sipName_id &sipStrings_Qt3DCore[3991]

#define sipMalloc                   sipAPI_Qt3DCore->api_malloc
#define sipFree                     sipAPI_Qt3DCore->api_free
#define sipBuildResult              sipAPI_Qt3DCore->api_build_result
#define sipCallMethod               sipAPI_Qt3DCore->api_call_method
#define sipCallProcedureMethod      sipAPI_Qt3DCore->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_Qt3DCore->api_call_error_handler
#define sipParseResultEx            sipAPI_Qt3DCore->api_parse_result_ex
#define sipParseResult              sipAPI_Qt3DCore->api_parse_result
#define sipParseArgs                sipAPI_Qt3DCore->api_parse_args
#define sipParseKwdArgs             sipAPI_Qt3DCore->api_parse_kwd_args
#define sipParsePair                sipAPI_Qt3DCore->api_parse_pair
#define sipInstanceDestroyed        sipAPI_Qt3DCore->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_Qt3DCore->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_Qt3DCore->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_Qt3DCore->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_Qt3DCore->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_Qt3DCore->api_convert_to_void_ptr
#define sipAddException             sipAPI_Qt3DCore->api_add_exception
#define sipNoFunction               sipAPI_Qt3DCore->api_no_function
#define sipNoMethod                 sipAPI_Qt3DCore->api_no_method
#define sipAbstractMethod           sipAPI_Qt3DCore->api_abstract_method
#define sipBadClass                 sipAPI_Qt3DCore->api_bad_class
#define sipBadCatcherResult         sipAPI_Qt3DCore->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_Qt3DCore->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_Qt3DCore->api_bad_operator_arg
#define sipTrace                    sipAPI_Qt3DCore->api_trace
#define sipTransferBack             sipAPI_Qt3DCore->api_transfer_back
#define sipTransferTo               sipAPI_Qt3DCore->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_Qt3DCore->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_Qt3DCore->api_wrapper_type
#define sipWrapperType_Type         sipAPI_Qt3DCore->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_Qt3DCore->api_voidptr_type
#define sipGetPyObject              sipAPI_Qt3DCore->api_get_pyobject
#define sipGetAddress               sipAPI_Qt3DCore->api_get_address
#define sipGetMixinAddress          sipAPI_Qt3DCore->api_get_mixin_address
#define sipGetCppPtr                sipAPI_Qt3DCore->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_Qt3DCore->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_Qt3DCore->api_call_hook
#define sipEndThread                sipAPI_Qt3DCore->api_end_thread
#define sipRaiseUnknownException    sipAPI_Qt3DCore->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_Qt3DCore->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_Qt3DCore->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_Qt3DCore->api_add_type_instance
#define sipPySlotExtend             sipAPI_Qt3DCore->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_Qt3DCore->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_Qt3DCore->api_can_convert_to_type
#define sipConvertToType            sipAPI_Qt3DCore->api_convert_to_type
#define sipForceConvertToType       sipAPI_Qt3DCore->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_Qt3DCore->api_convert_to_enum
#define sipConvertToBool            sipAPI_Qt3DCore->api_convert_to_bool
#define sipReleaseType              sipAPI_Qt3DCore->api_release_type
#define sipConvertFromType          sipAPI_Qt3DCore->api_convert_from_type
#define sipConvertFromNewType       sipAPI_Qt3DCore->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_Qt3DCore->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_Qt3DCore->api_convert_from_enum
#define sipGetState                 sipAPI_Qt3DCore->api_get_state
#define sipExportSymbol             sipAPI_Qt3DCore->api_export_symbol
#define sipImportSymbol             sipAPI_Qt3DCore->api_import_symbol
#define sipFindType                 sipAPI_Qt3DCore->api_find_type
#define sipBytes_AsChar             sipAPI_Qt3DCore->api_bytes_as_char
#define sipBytes_AsString           sipAPI_Qt3DCore->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_Qt3DCore->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_Qt3DCore->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_Qt3DCore->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_Qt3DCore->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_Qt3DCore->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_Qt3DCore->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_Qt3DCore->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_Qt3DCore->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_Qt3DCore->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_Qt3DCore->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_Qt3DCore->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_Qt3DCore->api_get_reference
#define sipKeepReference            sipAPI_Qt3DCore->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_Qt3DCore->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_Qt3DCore->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_Qt3DCore->api_type_from_py_type_object
#define sipTypeScope                sipAPI_Qt3DCore->api_type_scope
#define sipResolveTypedef           sipAPI_Qt3DCore->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_Qt3DCore->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_Qt3DCore->api_enable_autoconversion
#define sipInitMixin                sipAPI_Qt3DCore->api_init_mixin
#define sipExportModule             sipAPI_Qt3DCore->api_export_module
#define sipInitModule               sipAPI_Qt3DCore->api_init_module
#define sipGetInterpreter           sipAPI_Qt3DCore->api_get_interpreter
#define sipSetTypeUserData          sipAPI_Qt3DCore->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_Qt3DCore->api_get_type_user_data
#define sipPyTypeDict               sipAPI_Qt3DCore->api_py_type_dict
#define sipPyTypeName               sipAPI_Qt3DCore->api_py_type_name
#define sipGetCFunction             sipAPI_Qt3DCore->api_get_c_function
#define sipGetMethod                sipAPI_Qt3DCore->api_get_method
#define sipFromMethod               sipAPI_Qt3DCore->api_from_method
#define sipGetDate                  sipAPI_Qt3DCore->api_get_date
#define sipFromDate                 sipAPI_Qt3DCore->api_from_date
#define sipGetDateTime              sipAPI_Qt3DCore->api_get_datetime
#define sipFromDateTime             sipAPI_Qt3DCore->api_from_datetime
#define sipGetTime                  sipAPI_Qt3DCore->api_get_time
#define sipFromTime                 sipAPI_Qt3DCore->api_from_time
#define sipIsUserType               sipAPI_Qt3DCore->api_is_user_type
#define sipCheckPluginForType       sipAPI_Qt3DCore->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_Qt3DCore->api_unicode_new
#define sipUnicodeWrite             sipAPI_Qt3DCore->api_unicode_write
#define sipUnicodeData              sipAPI_Qt3DCore->api_unicode_data
#define sipGetBufferInfo            sipAPI_Qt3DCore->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_Qt3DCore->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_Qt3DCore->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_Qt3DCore->api_is_derived_class
#define sipGetUserObject            sipAPI_Qt3DCore->api_get_user_object
#define sipSetUserObject            sipAPI_Qt3DCore->api_set_user_object
#define sipRegisterEventHandler     sipAPI_Qt3DCore->api_register_event_handler
#define sipConvertToArray           sipAPI_Qt3DCore->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_Qt3DCore->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_Qt3DCore->api_enable_gc
#define sipPrintObject              sipAPI_Qt3DCore->api_print_object
#define sipLong_AsChar              sipAPI_Qt3DCore->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_Qt3DCore->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_Qt3DCore->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_Qt3DCore->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_Qt3DCore->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_Qt3DCore->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_Qt3DCore->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_Qt3DCore->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_Qt3DCore->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_Qt3DCore->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_Qt3DCore->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_Qt3DCore->api_long_as_size_t
#define sipVisitWrappers            sipAPI_Qt3DCore->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_Qt3DCore->api_register_exit_notifier
#define sipDeprecated               sipAPI_Qt3DCore->api_deprecated
#define sipPyTypeDictRef            sipAPI_Qt3DCore->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_Qt3DCore->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_Qt3DCore->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_Qt3DCore->api_get_frame
#define sipSetDestroyOnExit         sipAPI_Qt3DCore->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_Qt3DCore->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_Qt3DCore->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_Qt3DCore->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_Qt3DCore->api_connect_rx
#define sipConvertRx                sipAPI_Qt3DCore->api_convert_rx
#define sipDisconnectRx             sipAPI_Qt3DCore->api_disconnect_rx
#define sipFreeSipslot              sipAPI_Qt3DCore->api_free_sipslot
#define sipInvokeSlot               sipAPI_Qt3DCore->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_Qt3DCore->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_Qt3DCore->api_same_slot
#define sipSaveSlot                 sipAPI_Qt3DCore->api_save_slot
#define sipVisitSlot                sipAPI_Qt3DCore->api_visit_slot
#define sipIsPyMethod               sipAPI_Qt3DCore->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_Qt3DCore[];


#define sipType_Qt3DCore_ChangeFlag sipExportedTypes_Qt3DCore[12]

#define sipType_Qt3DCore_QAbstractAspect sipExportedTypes_Qt3DCore[14]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QAbstractAspect;

#define sipType_Qt3DCore_QAspectEngine sipExportedTypes_Qt3DCore[17]

#define sipType_Qt3DCore_QAspectEngine_RunMode sipExportedTypes_Qt3DCore[18]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QAspectEngine;

#define sipType_Qt3DCore_QNode sipExportedTypes_Qt3DCore[28]

#define sipType_Qt3DCore_QNode_PropertyTrackingMode sipExportedTypes_Qt3DCore[29]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNode;

#define sipType_Qt3DCore_QAbstractSkeleton sipExportedTypes_Qt3DCore[15]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QAbstractSkeleton;

#define sipType_Qt3DCore_QComponent sipExportedTypes_Qt3DCore[22]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QComponent;

#define sipType_Qt3DCore_QArmature sipExportedTypes_Qt3DCore[16]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QArmature;

#define sipType_Qt3DCore_QBackendNodeMapper sipExportedTypes_Qt3DCore[21]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QBackendNodeMapper;

#define sipType_Qt3DCore_QBackendNode sipExportedTypes_Qt3DCore[19]

#define sipType_Qt3DCore_QBackendNode_Mode sipExportedTypes_Qt3DCore[20]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QBackendNode;

#define sipType_Qt3DCore_QSceneChange sipExportedTypes_Qt3DCore[43]

#define sipType_Qt3DCore_QSceneChange_DeliveryFlag sipExportedTypes_Qt3DCore[44]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QSceneChange;

#define sipType_Qt3DCore_QComponentAddedChange sipExportedTypes_Qt3DCore[23]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QComponentAddedChange;

#define sipType_Qt3DCore_QComponentRemovedChange sipExportedTypes_Qt3DCore[24]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QComponentRemovedChange;

#define sipType_Qt3DCore_QPropertyUpdatedChangeBase sipExportedTypes_Qt3DCore[38]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QPropertyUpdatedChangeBase;

#define sipType_Qt3DCore_QDynamicPropertyUpdatedChange sipExportedTypes_Qt3DCore[25]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QDynamicPropertyUpdatedChange;

#define sipType_Qt3DCore_QEntity sipExportedTypes_Qt3DCore[26]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QEntity;

#define sipType_Qt3DCore_QJoint sipExportedTypes_Qt3DCore[27]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QJoint;

#define sipType_Qt3DCore_QNodeIdTypePair sipExportedTypes_Qt3DCore[34]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNodeIdTypePair;

#define sipType_Qt3DCore_QNodeCommand sipExportedTypes_Qt3DCore[30]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNodeCommand;

#define sipType_Qt3DCore_QNodeCreatedChangeBase sipExportedTypes_Qt3DCore[31]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNodeCreatedChangeBase;

#define sipType_Qt3DCore_QNodeDestroyedChange sipExportedTypes_Qt3DCore[32]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNodeDestroyedChange;

#define sipType_Qt3DCore_QNodeId sipExportedTypes_Qt3DCore[33]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QNodeId;

#define sipType_Qt3DCore_QPropertyValueAddedChangeBase sipExportedTypes_Qt3DCore[40]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QPropertyValueAddedChangeBase;

#define sipType_Qt3DCore_QStaticPropertyValueAddedChangeBase sipExportedTypes_Qt3DCore[50]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QStaticPropertyValueAddedChangeBase;

#define sipType_Qt3DCore_QPropertyNodeAddedChange sipExportedTypes_Qt3DCore[35]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QPropertyNodeAddedChange;

#define sipType_Qt3DCore_QPropertyValueRemovedChangeBase sipExportedTypes_Qt3DCore[42]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QPropertyValueRemovedChangeBase;

#define sipType_Qt3DCore_QStaticPropertyValueRemovedChangeBase sipExportedTypes_Qt3DCore[51]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QStaticPropertyValueRemovedChangeBase;

#define sipType_Qt3DCore_QPropertyNodeRemovedChange sipExportedTypes_Qt3DCore[36]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QPropertyNodeRemovedChange;

#define sipType_Qt3DCore_QStaticPropertyUpdatedChangeBase sipExportedTypes_Qt3DCore[49]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QStaticPropertyUpdatedChangeBase;

#define sipType_Qt3DCore_QPropertyUpdatedChange sipExportedTypes_Qt3DCore[37]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QPropertyUpdatedChange;

#define sipType_Qt3DCore_QPropertyValueAddedChange sipExportedTypes_Qt3DCore[39]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QPropertyValueAddedChange;

#define sipType_Qt3DCore_QPropertyValueRemovedChange sipExportedTypes_Qt3DCore[41]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QPropertyValueRemovedChange;

#define sipType_Qt3DCore_ChangeFlags sipExportedTypes_Qt3DCore[13]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_ChangeFlags;

#define sipType_Qt3DCore_QSceneChange_DeliveryFlags sipExportedTypes_Qt3DCore[45]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QSceneChange_DeliveryFlags;

#define sipType_Qt3DCore_QSkeleton sipExportedTypes_Qt3DCore[46]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QSkeleton;

#define sipType_Qt3DCore_QSkeletonLoader sipExportedTypes_Qt3DCore[47]

#define sipType_Qt3DCore_QSkeletonLoader_Status sipExportedTypes_Qt3DCore[48]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QSkeletonLoader;

#define sipType_Qt3DCore_QTransform sipExportedTypes_Qt3DCore[52]

extern sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QTransform;

#define sipType_QVector_0100Qt3DCore_QNodeIdTypePair sipExportedTypes_Qt3DCore[11]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QVector_0100Qt3DCore_QNodeIdTypePair;

#define sipType_QVector_0101Qt3DCore_QJoint sipExportedTypes_Qt3DCore[8]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QJoint;

#define sipType_QVector_0101Qt3DCore_QEntity sipExportedTypes_Qt3DCore[7]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QEntity;

#define sipType_QVector_0101Qt3DCore_QAbstractAspect sipExportedTypes_Qt3DCore[5]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QAbstractAspect;

#define sipType_QSharedPointer_0100Qt3DCore_QSceneChange sipExportedTypes_Qt3DCore[4]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QSceneChange;

#define sipType_QVector_0101Qt3DCore_QNode sipExportedTypes_Qt3DCore[9]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QNode;

#define sipType_QVector_0100Qt3DCore_QNodeId sipExportedTypes_Qt3DCore[10]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QVector_0100Qt3DCore_QNodeId;

#define sipType_QSharedPointer_0100Qt3DCore_QNodeCreatedChangeBase sipExportedTypes_Qt3DCore[3]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QNodeCreatedChangeBase;

#define sipType_QSharedPointer_0100Qt3DCore_QNodeCommand sipExportedTypes_Qt3DCore[2]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QNodeCommand;

#define sipType_QSharedPointer_0100Qt3DCore_QEntity sipExportedTypes_Qt3DCore[1]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QEntity;

#define sipType_QVector_0101Qt3DCore_QComponent sipExportedTypes_Qt3DCore[6]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QComponent;

#define sipType_QSharedPointer_0100Qt3DCore_QBackendNodeMapper sipExportedTypes_Qt3DCore[0]

extern sipMappedTypeDef sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QBackendNodeMapper;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_Qt3DCore;
extern sipExportedModuleDef sipModuleAPI_Qt3DCore;
extern sipTypeDef *sipExportedTypes_Qt3DCore[];

#define sipType_QObject sipImportedTypes_Qt3DCore_QtCore[5].it_td

#define sipType_QByteArray sipImportedTypes_Qt3DCore_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_Qt3DCore_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_Qt3DCore_QtCore[7].it_td

#define sipType_QChildEvent sipImportedTypes_Qt3DCore_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_Qt3DCore_QtCore[3].it_td

#define sipType_QMetaObject sipImportedTypes_Qt3DCore_QtCore[4].it_td

#define sipType_QUrl sipImportedTypes_Qt3DCore_QtCore[8].it_td

#define sipType_QVariant sipImportedTypes_Qt3DCore_QtCore[9].it_td

#define sipType_QString sipImportedTypes_Qt3DCore_QtCore[6].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DCore_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DCore_QtCore[];

#define sipType_QMatrix4x4 sipImportedTypes_Qt3DCore_QtGui[0].it_td

#define sipType_QQuaternion sipImportedTypes_Qt3DCore_QtGui[1].it_td

#define sipType_QVector3D sipImportedTypes_Qt3DCore_QtGui[2].it_td
extern sipImportedTypeDef sipImportedTypes_Qt3DCore_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_Qt3DCore_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_Qt3DCore_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_Qt3DCore_qt_metacast;
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"

#include <qsharedpointer.h>


// The dtor for the saved QSharedPointer.
#if defined(SIP_USE_PYCAPSULE)
template<class T>
void qt3d_QspDtor(PyObject *capsule)
{
    delete reinterpret_cast<QSharedPointer<T> *>(
            PyCapsule_GetPointer(capsule, 0));
}
#else
template<class T>
void qt3d_QspDtor(void *shared)
{
    delete reinterpret_cast<QSharedPointer<T> *>(array);
}
#endif


template<class T>
bool qt3d_SaveQsp(PyObject *py, QSharedPointer<T> *qsp)
{
    // Wrap the copy in a Python object.
#if defined(SIP_USE_PYCAPSULE)
    PyObject *qsp_obj = PyCapsule_New(qsp, 0, qt3d_QspDtor<T>);
#else
    PyObject *qsp_obj = PyCObject_FromVoidPtr(qsp, qt3d_QspDto<T>r);
#endif

    if (!qsp_obj)
        return false;

    sipSetUserObject((sipSimpleWrapper *)py, qsp_obj);

    return true;
}

#line 1061 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipAPIQt3DCore.h"

#endif
