/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 166 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
#include <QtGlobal>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 35 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 47 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 103 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedatagenerator.sip"
#include <qtextureimagedatagenerator.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedatagenerator.sip"
#include <qtextureimagedatagenerator.h>
#line 310 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 313 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 342 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 411 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 482 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpainter.sip"
#include <qpainter.h>
#line 485 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 488 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 491 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 688 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 889 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 892 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 1097 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 1106 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 1117 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 1132 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 1149 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 1168 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 1189 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 1212 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 1275 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 1300 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 1327 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 1358 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 1391 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 1426 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 1463 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 1500 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 1539 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 1580 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 1623 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 1668 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 1715 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 1764 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 1815 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 1868 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 1923 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 1980 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 2039 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 2100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 2165 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 2232 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 2305 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 2380 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 2457 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 2536 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 2617 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 2700 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 2785 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 2872 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 2961 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 3052 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 3143 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 3236 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 3331 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 3428 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 3527 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 3628 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 3731 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 3838 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 3947 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 4058 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 4171 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 4286 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 4403 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 4522 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 4643 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 4766 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 4891 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 5018 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 5147 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 5278 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 39 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 5411 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 5546 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 63 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 5683 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 5822 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 5963 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 6106 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 6253 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 6402 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 6553 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 6706 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 6861 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 7018 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 7177 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 7338 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 7501 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 7666 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 45 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 7833 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 8002 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 8173 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 8346 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 8521 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 8698 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 8877 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 9058 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 9243 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 9432 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 9623 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 9816 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 10011 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 43 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 10206 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 54 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 10401 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 65 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 10596 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 76 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 10791 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 87 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 10986 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 98 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 11181 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 109 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 11376 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 120 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 11571 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 131 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 11766 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 142 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 11961 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 153 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 12156 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 188 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 12351 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 12550 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 12753 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedatagenerator.sip"
#include <qtextureimagedatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturewrapmode.sip"
#include <qtexturewrapmode.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturewrapmode.sip"
#include <qtexturewrapmode.h>
#line 12962 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedatagenerator.sip"
#include <qtextureimagedatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturewrapmode.sip"
#include <qtexturewrapmode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qviewport.sip"
#include <qviewport.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qviewport.sip"
#include <qviewport.h>
#line 13173 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgraphicsapifilter.sip"
#include <qgraphicsapifilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayer.sip"
#include <qlayer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlayerfilter.sip"
#include <qlayerfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetail.sip"
#include <qlevelofdetail.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailboundingsphere.sip"
#include <qlevelofdetailboundingsphere.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlevelofdetailswitch.sip"
#include <qlevelofdetailswitch.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qlinewidth.sip"
#include <qlinewidth.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmaterial.sip"
#include <qmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmemorybarrier.sip"
#include <qmemorybarrier.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmesh.sip"
#include <qmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qmultisampleantialiasing.sip"
#include <qmultisampleantialiasing.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodepthmask.sip"
#include <qnodepthmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnodraw.sip"
#include <qnodraw.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qnopicking.sip"
#include <qnopicking.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qobjectpicker.sip"
#include <qobjectpicker.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpaintedtextureimage.sip"
#include <qpaintedtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qparameter.sip"
#include <qparameter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickevent.sip"
#include <qpickevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickingsettings.sip"
#include <qpickingsettings.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicklineevent.sip"
#include <qpicklineevent.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpickpointevent.sip"
#include <qpickpointevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpicktriangleevent.sip"
#include <qpicktriangleevent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointlight.sip"
#include <qpointlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpointsize.sip"
#include <qpointsize.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qpolygonoffset.sip"
#include <qpolygonoffset.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qproximityfilter.sip"
#include <qproximityfilter.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrastermode.sip"
#include <qrastermode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycaster.sip"
#include <qraycaster.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qraycasterhit.sip"
#include <qraycasterhit.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderaspect.sip"
#include <qrenderaspect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapabilities.sip"
#include <qrendercapabilities.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendercapture.sip"
#include <qrendercapture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpass.sip"
#include <qrenderpass.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderpassfilter.sip"
#include <qrenderpassfilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersettings.sip"
#include <qrendersettings.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstate.sip"
#include <qrenderstate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrenderstateset.sip"
#include <qrenderstateset.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendersurfaceselector.sip"
#include <qrendersurfaceselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertarget.sip"
#include <qrendertarget.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetoutput.sip"
#include <qrendertargetoutput.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qrendertargetselector.sip"
#include <qrendertargetselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsceneloader.sip"
#include <qsceneloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscissortest.sip"
#include <qscissortest.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qscreenraycaster.sip"
#include <qscreenraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qseamlesscubemap.sip"
#include <qseamlesscubemap.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsetfence.sip"
#include <qsetfence.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderdata.sip"
#include <qshaderdata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderimage.sip"
#include <qshaderimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogram.sip"
#include <qshaderprogram.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qshaderprogrambuilder.sip"
#include <qshaderprogrambuilder.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsortpolicy.sip"
#include <qsortpolicy.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qspotlight.sip"
#include <qspotlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstencilmask.sip"
#include <qstencilmask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperation.sip"
#include <qstenciloperation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciloperationarguments.sip"
#include <qstenciloperationarguments.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltest.sip"
#include <qstenciltest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qstenciltestarguments.sip"
#include <qstenciltestarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qsubtreeenabler.sip"
#include <qsubtreeenabler.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechnique.sip"
#include <qtechnique.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtechniquefilter.sip"
#include <qtechniquefilter.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexture.sip"
#include <qtexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedata.sip"
#include <qtexturedata.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturedataupdate.sip"
#include <qtexturedataupdate.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturegenerator.sip"
#include <qtexturegenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimage.sip"
#include <qtextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedata.sip"
#include <qtextureimagedata.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtextureimagedatagenerator.sip"
#include <qtextureimagedatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qtexturewrapmode.sip"
#include <qtexturewrapmode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qviewport.sip"
#include <qviewport.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qwaitfence.sip"
#include <qwaitfence.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qwaitfence.sip"
#include <qwaitfence.h>
#line 13386 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_Qt3DRender[] = {
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', ':', ':', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'F', 'a', 'c', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 'D', 'a', 't', 'a', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', '>', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'R', 'e', 'a', 'd', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'T', 'e', 's', 't', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', ':', ':', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'F', 'a', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'T', 'e', 's', 't', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', ':', ':', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'l', 'i', 't', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', ':', ':', 'I', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', ':', ':', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'u', 'f', 'f', 'e', 'r', 'D', 'a', 't', 'a', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', ':', ':', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', ':', ':', 'F', 'a', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', '>', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 'D', 'a', 't', 'a', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'l', 'e', 'n', 'd', 'E', 'q', 'u', 'a', 't', 'i', 'o', 'n', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', ':', ':', 'B', 'l', 'e', 'n', 'd', 'i', 'n', 'g', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'A', 'p', 'i', 'F', 'i', 'l', 't', 'e', 'r', ':', ':', 'O', 'p', 'e', 'n', 'G', 'L', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'F', 'a', 'c', 't', 'o', 'r', 'y', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'C', 'a', 'm', 'e', 'r', 'a', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', ':', ':', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'P', 'i', 'c', 'k', 'R', 'e', 's', 'u', 'l', 't', 'M', 'o', 'd', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', '*', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'o', 'r', 't', 'P', 'o', 'l', 'i', 'c', 'y', ':', ':', 'S', 'o', 'r', 't', 'T', 'y', 'p', 'e', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'R', 'a', 'y', 'C', 'a', 's', 't', 'e', 'r', ':', ':', 'F', 'i', 'l', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'l', 'e', 'a', 'r', 'B', 'u', 'f', 'f', 'e', 'r', 's', ':', ':', 'B', 'u', 'f', 'f', 'e', 'r', 'T', 'y', 'p', 'e', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', '*', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 'D', 'a', 't', 'a', 'P', 't', 'r', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 'F', 'a', 'c', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'l', 'e', 'n', 'd', 'E', 'q', 'u', 'a', 't', 'i', 'o', 'n', ':', ':', 'B', 'l', 'e', 'n', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', ':', ':', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'H', 'a', 'n', 'd', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'F', 'r', 'o', 'n', 't', 'F', 'a', 'c', 'e', ':', ':', 'W', 'i', 'n', 'd', 'i', 'n', 'g', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'S', 'p', 'h', 'e', 'r', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'P', 'i', 'c', 'k', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', ':', ':', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'R', 'a', 'y', 'C', 'a', 's', 't', 'e', 'r', ':', ':', 'R', 'u', 'n', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'L', 'e', 'n', 's', ':', ':', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'c', 'e', 'n', 'e', 'L', 'o', 'a', 'd', 'e', 'r', ':', ':', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'u', 'b', 't', 'r', 'e', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'r', ':', ':', 'E', 'n', 'a', 'b', 'l', 'e', 'm', 'e', 'n', 't', 0,
    't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', ':', ':', 'V', 'e', 'r', 't', 'e', 'x', 'B', 'a', 's', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'M', 'e', 'm', 'o', 'r', 'y', 'B', 'a', 'r', 'r', 'i', 'e', 'r', ':', ':', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', ':', ':', 'S', 'h', 'a', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', '2', 'D', 'M', 'u', 'l', 't', 'i', 's', 'a', 'm', 'p', 'l', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 'D', 'a', 't', 'a', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', ':', ':', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'V', 'o', 'l', 'u', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', '1', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', '2', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'l', 'p', 'h', 'a', 'T', 'e', 's', 't', ':', ':', 'A', 'l', 'p', 'h', 'a', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'l', 'e', 'a', 'r', 'B', 'u', 'f', 'f', 'e', 'r', 's', ':', ':', 'B', 'u', 'f', 'f', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'D', 'e', 'p', 't', 'h', 'T', 'e', 's', 't', ':', ':', 'D', 'e', 'p', 't', 'h', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'M', 'e', 'm', 'o', 'r', 'y', 'B', 'a', 'r', 'r', 'i', 'e', 'r', ':', ':', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'A', 's', 'p', 'e', 'c', 't', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'I', 'm', 'a', 'g', 'e', ':', ':', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'o', 'm', 'p', 'u', 't', 'e', 'C', 'o', 'm', 'm', 'a', 'n', 'd', ':', ':', 'R', 'u', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'a', 'y', 'e', 'r', 'F', 'i', 'l', 't', 'e', 'r', ':', ':', 'F', 'i', 'l', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'M', 'u', 'l', 't', 'i', 'S', 'a', 'm', 'p', 'l', 'e', 'A', 'n', 't', 'i', 'A', 'l', 'i', 'a', 's', 'i', 'n', 'g', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', ':', ':', 'A', 'P', 'I', 0,
    's', 'e', 't', 'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'R', 'e', 'a', 'd', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'l', 'e', 'n', 'd', 'E', 'q', 'u', 'a', 't', 'i', 'o', 'n', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'A', 'p', 'i', 'F', 'i', 'l', 't', 'e', 'r', ':', ':', 'A', 'p', 'i', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'a', 's', 't', 'e', 'r', 'M', 'o', 'd', 'e', ':', ':', 'R', 'a', 's', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'a', 'y', 'C', 'a', 's', 't', 'e', 'r', 'H', 'i', 't', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', '*', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'u', 'l', 'l', 'F', 'a', 'c', 'e', ':', ':', 'C', 'u', 'l', 'l', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'a', 'y', 'C', 'a', 's', 't', 'e', 'r', 'H', 'i', 't', ':', ':', 'H', 'i', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'W', 'a', 'i', 't', 'F', 'e', 'n', 'c', 'e', ':', ':', 'H', 'a', 'n', 'd', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'V', 'o', 'l', 'u', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 't', 'e', 'n', 'c', 'i', 'l', 'T', 'e', 's', 't', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'P', 'r', 'o', 'j', 'e', 'c', 't', 'e', 'd', 'S', 'c', 'r', 'e', 'e', 'n', 'P', 'i', 'x', 'e', 'l', 'S', 'i', 'z', 'e', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', '*', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', ':', ':', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'a', 's', 't', 'e', 'r', 'M', 'o', 'd', 'e', ':', ':', 'F', 'a', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'e', 't', 'F', 'e', 'n', 'c', 'e', ':', ':', 'H', 'a', 'n', 'd', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 'B', 'u', 'i', 'l', 'd', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'o', 'r', 't', 'P', 'o', 'l', 'i', 'c', 'y', ':', ':', 'S', 'o', 'r', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'T', 'e', 's', 't', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', '2', 'D', 'M', 'u', 'l', 't', 'i', 's', 'a', 'm', 'p', 'l', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'a', 'c', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', '*', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'F', 'i', 'l', 't', 'e', 'r', 'K', 'e', 'y', '*', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', '*', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'c', 'h', 'n', 'i', 'q', 'u', 'e', '*', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'L', 'i', 'g', 'h', 't', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'u', 'f', 'f', 'e', 'r', 'D', 'a', 't', 'a', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 'S', 'w', 'i', 't', 'c', 'h', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'a', 'i', 'n', 't', 'e', 'd', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', ':', ':', 'S', 'i', 'z', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'c', 'e', 'n', 'e', 'L', 'o', 'a', 'd', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'I', 'm', 'a', 'g', 'e', ':', ':', 'A', 'c', 'c', 'e', 's', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 'A', 'r', 'r', 'a', 'y', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'J', 'o', 'i', 'n', 't', 'I', 'n', 'd', 'i', 'c', 'e', 's', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'J', 'o', 'i', 'n', 't', 'W', 'e', 'i', 'g', 'h', 't', 's', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    'd', 'e', 'p', 't', 'h', 'T', 'e', 's', 't', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'A', 'c', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'B', 'u', 'f', 'f', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', ':', ':', 'B', 'u', 't', 't', 'o', 'n', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'R', 'e', 'p', 'l', 'y', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'V', 'o', 'l', 'u', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'e', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'R', 'a', 'y', 'C', 'a', 's', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'U', 's', 'a', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'A', 'p', 'i', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', 'U', 'p', 'd', 'a', 't', 'e', 0,
    'S', 'R', 'G', 'B', '8', '_', 'P', 'u', 'n', 'c', 'h', 'T', 'h', 'r', 'o', 'u', 'g', 'h', '_', 'A', 'l', 'p', 'h', 'a', '1', '_', 'E', 'T', 'C', '2', 0,
    'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'R', 'e', 's', 't', 'a', 'r', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'M', 'i', 'p', 'M', 'a', 'p', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'T', 'e', 's', 't', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'L', 'i', 'g', 'h', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'E', 'n', 'v', 'i', 'r', 'o', 'n', 'm', 'e', 'n', 't', 'L', 'i', 'g', 'h', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 'D', 'a', 't', 'a', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'i', 's', 'A', 'u', 't', 'o', 'M', 'i', 'p', 'M', 'a', 'p', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'F', 'a', 'c', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'a', 'y', 'e', 'r', '*', '>', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'F', 'u', 'n', 'c', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'l', 'i', 't', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'D', 'i', 's', 'p', 'a', 't', 'c', 'h', 'C', 'o', 'm', 'p', 'u', 't', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'r', 'o', 'x', 'i', 'm', 'i', 't', 'y', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'c', 'r', 'e', 'e', 'n', 'R', 'a', 'y', 'C', 'a', 's', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'e', 'a', 'm', 'l', 'e', 's', 's', 'C', 'u', 'b', 'e', 'm', 'a', 'p', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'c', 'h', 'n', 'i', 'q', 'u', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'a', 'l', 'l', 'T', 'e', 's', 't', 's', 'P', 'a', 's', 's', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 'B', 'y', 't', 'e', 'O', 'f', 'f', 's', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'e', 'p', 't', 'h', 'T', 'e', 's', 't', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'o', 'm', 'p', 'u', 't', 'e', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'F', 'r', 'a', 'm', 'e', 'G', 'r', 'a', 'p', 'h', 'N', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'F', 'r', 'u', 's', 't', 'u', 'm', 'C', 'u', 'l', 'l', 'i', 'n', 'g', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'P', 'o', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', 'S', 'e', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'u', 'b', 't', 'r', 'e', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', '1', 'D', 'A', 'r', 'r', 'a', 'y', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', '2', 'D', 'A', 'r', 'r', 'a', 'y', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'a', 'n', 'g', 'e', 'n', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    'q', 'u', 'a', 'd', 'r', 'a', 't', 'i', 'c', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 'i', 'z', 'e', 0,
    's', 't', 'e', 'n', 'c', 'i', 'l', 'T', 'e', 's', 't', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'L', 'i', 'g', 'h', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'l', 'p', 'h', 'a', 'C', 'o', 'v', 'e', 'r', 'a', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'l', 'e', 'n', 'd', 'E', 'q', 'u', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'M', 'e', 'm', 'o', 'r', 'y', 'B', 'a', 'r', 'r', 'i', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'L', 'i', 'n', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 'O', 'f', 'f', 's', 'e', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'C', 'a', 'p', 't', 'u', 'r', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'L', 'o', 'a', 'd', 'e', 'r', 0,
    'c', 'o', 'n', 's', 't', 'a', 'n', 't', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'N', 'o', 'r', 'm', 'a', 'l', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 0,
    'f', 'a', 'c', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'M', 'e', 't', 'h', 'o', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'C', 'o', 'm', 'p', 'u', 't', 'e', 'S', 'h', 'a', 'r', 'e', 'd', 'M', 'e', 'm', 'o', 'r', 'y', 'S', 'i', 'z', 'e', 0,
    'n', 'o', 't', 'i', 'f', 'y', 'D', 'a', 't', 'a', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'R', 'e', 's', 't', 'a', 'r', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'w', 'o', 'r', 'l', 'd', 'S', 'p', 'a', 'c', 'e', 'T', 'o', 'l', 'e', 'r', 'a', 'n', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'C', 'a', 'm', 'e', 'r', 'a', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'l', 'e', 'a', 'r', 'B', 'u', 'f', 'f', 'e', 'r', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'M', 'e', 's', 'h', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'O', 'b', 'j', 'e', 'c', 't', 'P', 'i', 'c', 'k', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'a', 'y', 'C', 'a', 's', 't', 'e', 'r', 'H', 'i', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'A', 's', 'p', 'e', 'c', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'm', 'p', 'u', 't', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'o', 'l', 'o', 'r', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 0,
    'd', 'e', 'p', 't', 'h', 'T', 'e', 's', 't', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'O', 'r', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'D', 'i', 's', 'c', 'a', 'r', 'd', 'A', 'l', 'l', 'M', 'a', 't', 'c', 'h', 'i', 'n', 'g', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'D', 'i', 's', 'c', 'a', 'r', 'd', 'A', 'n', 'y', 'M', 'a', 't', 'c', 'h', 'i', 'n', 'g', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'p', 'h', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'l', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'a', 'y', 'e', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'N', 'o', 'D', 'e', 'p', 't', 'h', 'M', 'a', 's', 'k', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'c', 'e', 'n', 'e', 'L', 'o', 'a', 'd', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'c', 'i', 's', 's', 'o', 'r', 'T', 'e', 's', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'M', 'a', 's', 'k', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'T', 'e', 's', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', 0,
    'T', 'a', 'r', 'g', 'e', 't', '2', 'D', 'M', 'u', 'l', 't', 'i', 's', 'a', 'm', 'p', 'l', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    'c', 'l', 'e', 'a', 'r', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'm', 'p', 'u', 't', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 'i', 'z', 'e', 0,
    'g', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'A', 'p', 'i', 'F', 'i', 'l', 't', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'i', 'n', 'e', 'a', 'r', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 's', 't', 'a', 'r', 't', 'I', 'n', 'd', 'e', 'x', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'l', 'l', 'T', 'e', 's', 't', 's', 'P', 'a', 's', 's', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'I', 'n', 'd', 'e', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 'B', 'y', 't', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'P', 'e', 'r', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'c', 'c', 'e', 'p', 't', 'A', 'l', 'l', 'M', 'a', 't', 'c', 'h', 'i', 'n', 'g', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'A', 'c', 'c', 'e', 'p', 't', 'A', 'n', 'y', 'M', 'a', 't', 'c', 'h', 'i', 'n', 'g', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'C', 'o', 'l', 'o', 'r', 'D', 'e', 'p', 't', 'h', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'D', 'o', 'n', 't', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'V', 'i', 'e', 'w', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'L', 'e', 'n', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'D', 'e', 'p', 't', 'h', 'R', 'a', 'n', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'o', 'i', 'n', 't', 'L', 'i', 'g', 'h', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'a', 's', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'h', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'o', 'r', 't', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'r', 'a', 'm', 'e', 'G', 'r', 'a', 'p', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'p', 'h', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'R', 'e', 's', 't', 'a', 'r', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'Q', 'u', 'a', 'd', 'r', 'a', 't', 'i', 'c', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'e', 's', 'P', 'e', 'r', 'P', 'a', 't', 'c', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 'l', 'p', 'h', 'a', 'T', 'e', 's', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'l', 'i', 'p', 'P', 'l', 'a', 'n', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'o', 'l', 'o', 'r', 'M', 'a', 's', 'k', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'D', 'e', 'p', 't', 'h', 'T', 'e', 's', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'D', 'i', 't', 'h', 'e', 'r', 'i', 'n', 'g', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'F', 'i', 'l', 't', 'e', 'r', 'K', 'e', 'y', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'F', 'r', 'o', 'n', 't', 'F', 'a', 'c', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'i', 'n', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'N', 'o', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'R', 'a', 'y', 'C', 'a', 's', 't', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'p', 'o', 't', 'L', 'i', 'g', 'h', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'c', 'h', 'n', 'i', 'q', 'u', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', '1', 'D', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', '2', 'D', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', '3', 'D', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'W', 'a', 'i', 't', 'F', 'e', 'n', 'c', 'e', 0,
    'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 0,
    'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'S', 't', 'r', 'i', 'p', 'A', 'd', 'j', 'a', 'c', 'e', 'n', 'c', 'y', 0,
    'a', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'D', 'e', 'p', 't', 'h', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'c', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'g', 'b', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'o', 'n', 't', 'O', 'u', 't', 'p', 'u', 't', 'M', 'a', 's', 'k', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'M', 'i', 'p', 'M', 'a', 'p', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'M', 'e', 't', 'h', 'o', 'd', 0,
    's', 'e', 't', 'M', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'e', 't', 'W', 'o', 'r', 'l', 'd', 'S', 'p', 'a', 'c', 'e', 'T', 'o', 'l', 'e', 'r', 'a', 'n', 'c', 'e', 0,
    's', 't', 'e', 'n', 'c', 'i', 'l', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'V', 'o', 'l', 'u', 'm', 'e', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 0,
    'D', 'r', 'a', 'w', 'I', 'n', 'd', 'i', 'r', 'e', 'c', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'A', 'l', 'p', 'h', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'C', 'o', 'l', 'o', 'r', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'o', 'u', 'r', 'c', 'e', '1', 'C', 'o', 'l', 'o', 'r', '0', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'u', 'l', 'l', 'F', 'a', 'c', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'S', 'e', 't', 'F', 'e', 'n', 'c', 'e', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'R', 'G', 'B', '_', 'B', 'P', '_', 'U', 'N', 'S', 'I', 'G', 'N', 'E', 'D', '_', 'F', 'L', 'O', 'A', 'T', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'E', 'T', 'C', '2', '_', 'E', 'A', 'C', 0,
    'a', 'l', 'l', 'T', 'e', 's', 't', 's', 'P', 'a', 's', 's', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'b', 'a', 'c', 'k', 'O', 'u', 't', 'p', 'u', 't', 'M', 'a', 's', 'k', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'a', 's', 'k', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'g', 'b', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'd', 'e', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 'B', 'y', 't', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    'l', 'o', 'c', 'a', 'l', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'C', 'o', 'm', 'p', 'u', 't', 'e', 'I', 'n', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'R', 'e', 'c', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'i', 'c', 'k', 'R', 'e', 's', 'u', 'l', 't', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'e', 'A', 'b', 'o', 'u', 't', 'V', 'i', 'e', 'w', 'C', 'e', 'n', 't', 'e', 'r', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'u', 't', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    's', 'e', 't', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'B', 'a', 's', 'e', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'o', 'l', 'u', 'm', 'e', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'a', 'i', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'o', 'r', 'l', 'd', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'L', 'u', 'm', 'i', 'n', 'a', 'n', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'N', 'e', 'a', 'r', 'e', 's', 't', 'M', 'i', 'p', 'M', 'a', 'p', 'N', 'e', 'a', 'r', 'e', 's', 't', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'o', 'u', 'r', 'c', 'e', '1', 'A', 'l', 'p', 'h', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'o', 'u', 'r', 'c', 'e', '1', 'C', 'o', 'l', 'o', 'r', 0,
    'V', 'e', 'r', 't', 'e', 'x', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    'a', 'l', 'p', 'h', 'a', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'l', 'e', 'n', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 'M', 'o', 'u', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'S', 'p', 'h', 'e', 'r', 'e', 0,
    'd', 'e', 'p', 't', 'h', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 'L', 'a', 'y', 'e', 'r', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 's', 't', 'a', 'n', 'c', 'e', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 'G', 'r', 'a', 'p', 'h', 'N', 'o', 'd', 'e', 0,
    'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 'u', 'a', 'd', 'r', 'a', 't', 'i', 'c', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'l', 'e', 'a', 'r', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'u', 't', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    's', 'e', 't', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    's', 'e', 't', 'F', 'r', 'u', 's', 't', 'u', 'm', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'a', 'r', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 0,
    's', 'e', 't', 'R', 'e', 's', 't', 'a', 'r', 't', 'I', 'n', 'd', 'e', 'x', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'e', 'x', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    's', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'L', 'e', 'n', 's', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'G', 'r', 'e', 'a', 't', 'e', 'r', 'E', 'q', 'u', 'a', 'l', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'R', 'e', 'f', 'T', 'o', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 'M', 'i', 'p', 'M', 'a', 'p', 'N', 'e', 'a', 'r', 'e', 's', 't', 0,
    'N', 'e', 'a', 'r', 'e', 's', 't', 'M', 'i', 'p', 'M', 'a', 'p', 'L', 'i', 'n', 'e', 'a', 'r', 0,
    'N', 'e', 'a', 'r', 'e', 's', 't', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 'P', 'i', 'c', 'k', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'o', 'u', 'r', 'c', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'E', 'f', 'f', 'e', 'c', 't', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'N', 'o', 'D', 'r', 'a', 'w', 0,
    'R', 'G', 'B', '_', 'B', 'P', '_', 'S', 'I', 'G', 'N', 'E', 'D', '_', 'F', 'L', 'O', 'A', 'T', 0,
    'S', 'h', 'a', 'd', 'e', 'r', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'S', 'o', 'u', 'r', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 'S', 'a', 't', 'u', 'r', 'a', 't', 'e', 0,
    'T', 'a', 'r', 'g', 'e', 't', '2', 'D', 'M', 'u', 'l', 't', 'i', 's', 'a', 'm', 'p', 'l', 'e', 0,
    'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'c', 'o', 'n', 's', 't', 'a', 'n', 't', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    'h', 'o', 'v', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'm', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'm', 'a', 'j', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 'l', 'l', 'A', 'b', 'o', 'u', 't', 'V', 'i', 'e', 'w', 'C', 'e', 'n', 't', 'e', 'r', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'F', 'r', 'a', 'm', 'e', 'G', 'r', 'a', 'p', 'h', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'p', 'h', 'a', 0,
    's', 'e', 't', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'e', 'x', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'e', 's', 'P', 'e', 'r', 'P', 'a', 't', 'c', 'h', 0,
    't', 'i', 'l', 't', 'A', 'b', 'o', 'u', 't', 'V', 'i', 'e', 'w', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'w', 'o', 'r', 'l', 'd', 'S', 'p', 'a', 'c', 'e', 'T', 'o', 'l', 'e', 'r', 'a', 'n', 'c', 'e', 0,
    'D', 'r', 'a', 'w', 'I', 'n', 'd', 'i', 'r', 'e', 'c', 't', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'L', 'i', 'n', 'e', 'S', 't', 'r', 'i', 'p', 'A', 'd', 'j', 'a', 'c', 'e', 'n', 'c', 'y', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 'M', 'i', 'p', 'M', 'a', 'p', 'L', 'i', 'n', 'e', 'a', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'L', 'a', 'y', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 0,
    'T', 'a', 'r', 'g', 'e', 't', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 'A', 'r', 'r', 'a', 'y', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 's', 'A', 'd', 'j', 'a', 'c', 'e', 'n', 'c', 'y', 0,
    'a', 'l', 'p', 'h', 'a', 'M', 'a', 's', 'k', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'I', 'n', 'd', 'e', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'o', 'r', 'B', 'u', 'f', 'f', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'm', 'p', 'u', 't', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    'c', 'u', 't', 'O', 'f', 'f', 'A', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'r', 'a', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'e', 'l', 'd', 'O', 'f', 'V', 'i', 'e', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'V', 'e', 'r', 't', 'e', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    'g', 'r', 'e', 'e', 'n', 'M', 'a', 's', 'k', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'd', 'e', 'x', 'O', 'f', 'f', 's', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'C', 'o', 'u', 'n', 't', 'X', 0,
    'm', 'a', 'x', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'C', 'o', 'u', 'n', 't', 'Y', 0,
    'm', 'a', 'x', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'C', 'o', 'u', 'n', 't', 'Z', 0,
    'm', 'i', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'p', 'a', 'n', 'A', 'b', 'o', 'u', 't', 'V', 'i', 'e', 'w', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    's', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'C', 'l', 'e', 'a', 'r', 'D', 'e', 'p', 't', 'h', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'g', 'b', 'a', 0,
    's', 'e', 't', 'F', 'r', 'o', 'n', 't', 'O', 'u', 't', 'p', 'u', 't', 'M', 'a', 's', 'k', 0,
    's', 'e', 't', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'M', 'i', 'p', 'M', 'a', 'p', 's', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    's', 'e', 't', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'I', 'm', 'a', 'g', 'e', 'S', 't', 'o', 'r', 'e', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'P', 'i', 'x', 'e', 'l', 'U', 'n', 'p', 'a', 'c', 'k', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', ':', ':', 'Q', 'M', 'e', 's', 'h', 0,
    'S', 'h', 'a', 'd', 'e', 'r', 'I', 'm', 'a', 'g', 'e', 'A', 'c', 'c', 'e', 's', 's', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'F', 'e', 'e', 'd', 'b', 'a', 'c', 'k', 0,
    'a', 'c', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'l', 'u', 'e', 'M', 'a', 's', 'k', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'y', 't', 'e', 'O', 'f', 'f', 's', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'y', 't', 'e', 'S', 't', 'r', 'i', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'V', 'a', 'l', 'u', 'e', 0,
    'c', 'o', 'm', 'p', 'u', 't', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    'd', 'e', 'p', 't', 'h', 'S', 't', 'e', 'p', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'm', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'l', 't', 'e', 'r', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'A', 'p', 'i', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'r', 'r', 'a', 'd', 'i', 'a', 'n', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'i', 'n', 'e', 'a', 'r', 'A', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', 0,
    'l', 'o', 'c', 'a', 'l', 'I', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'm', 'a', 'x', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'S', 'i', 'z', 'e', 'X', 0,
    'm', 'a', 'x', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'S', 'i', 'z', 'e', 'Y', 0,
    'm', 'a', 'x', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'S', 'i', 'z', 'e', 'Z', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 0,
    'p', 'i', 'c', 'k', 'M', 'e', 't', 'h', 'o', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'l', 'a', 'n', 'e', 'I', 'n', 'd', 'e', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'a', 's', 't', 'e', 'r', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'r', 'e', 's', 't', 'a', 'r', 't', 'I', 'n', 'd', 'e', 'x', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'O', 'u', 't', 'p', 'u', 't', 'M', 'a', 's', 'k', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'a', 's', 'k', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'g', 'b', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'N', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'P', 'i', 'c', 'k', 'R', 'e', 's', 'u', 'l', 't', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'R', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'e', 'x', 'B', 'a', 's', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'V', 'o', 'l', 'u', 'm', 'e', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 0,
    's', 'e', 't', 'W', 'a', 'i', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'W', 'o', 'r', 'l', 'd', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'R', 'e', 'c', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'R', 'g', 'b', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    't', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'S', 'h', 'a', 'd', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'e', 'w', 'C', 'e', 'n', 't', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'e', 'w', 'M', 'a', 't', 'r', 'i', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'e', 'w', 'V', 'e', 'c', 't', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'X', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'Y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'Z', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'o', 'r', 'l', 'd', 'I', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'C', 'o', 'l', 'o', 'r', 'D', 'e', 'p', 't', 'h', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'C', 'o', 'm', 'm', 'p', 'a', 'r', 'e', 'N', 'o', 't', 'E', 'q', 'u', 'a', 'l', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'L', 'e', 's', 's', 'E', 'q', 'u', 'a', 'l', 0,
    'C', 'o', 'u', 'n', 't', 'e', 'r', 'C', 'l', 'o', 'c', 'k', 'W', 'i', 's', 'e', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 'X', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 'Y', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 'Z', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'P', 'o', 's', 'i', 't', 'i', 'v', 'e', 'X', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'P', 'o', 's', 'i', 't', 'i', 'v', 'e', 'Y', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'P', 'o', 's', 'i', 't', 'i', 'v', 'e', 'Z', 0,
    'C', 'u', 's', 't', 'o', 'm', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'F', 'r', 'o', 'n', 't', 'A', 'n', 'd', 'B', 'a', 'c', 'k', 'F', 'a', 'c', 'e', 0,
    'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', '3', 'D', 'R', 'e', 'n', 'd', 'e', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'r', 'a', 'm', 'e', 'G', 'r', 'a', 'p', 'h', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'p', 'h', 'a', 0,
    'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'i', 'n', 't', 'e', 'n', 's', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'E', 'x', 't', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'm', 'i', 'n', 'E', 'x', 't', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'e', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'e', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'r', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'd', 'M', 'a', 's', 'k', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', 0,
    's', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'B', 'l', 'e', 'n', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', 0,
    's', 'e', 't', 'D', 'e', 'p', 't', 'h', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'L', 'a', 'y', 'e', 'r', 's', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    's', 'e', 't', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 'T', 'y', 'p', 'e', 0,
    's', 'o', 'r', 't', 'T', 'y', 'p', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'R', 'g', 'b', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'e', 's', 'P', 'e', 'r', 'P', 'a', 't', 'c', 'h', 0,
    'w', 'a', 'i', 't', 'O', 'n', 'C', 'P', 'U', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'n', 't', 'r', 'o', 'l', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'L', 'u', 'm', 'i', 'n', 'a', 'n', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'd', 0,
    'P', 'i', 'x', 'e', 'l', 'P', 'a', 'c', 'k', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'R', 'e', 'v', 'e', 'r', 's', 'e', 'S', 'u', 'b', 't', 'r', 'a', 'c', 't', 0,
    'S', 'R', 'G', 'B', '_', 'A', 'l', 'p', 'h', 'a', '_', 'D', 'X', 'T', '1', 0,
    'S', 'R', 'G', 'B', '_', 'A', 'l', 'p', 'h', 'a', '_', 'D', 'X', 'T', '3', 0,
    'S', 'R', 'G', 'B', '_', 'A', 'l', 'p', 'h', 'a', '_', 'D', 'X', 'T', '5', 0,
    'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'C', 'o', 's', 't', 0,
    'T', 'a', 'r', 'g', 'e', 't', 'A', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', 0,
    'T', 'a', 'r', 'g', 'e', 't', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 0,
    'V', 'e', 'r', 't', 'e', 'x', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'd', 'd', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    'a', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 0,
    'c', 'l', 'e', 'a', 'r', 'D', 'e', 'p', 't', 'h', 'V', 'a', 'l', 'u', 'e', 0,
    'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'a', 't', 'a', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'a', 't', 'a', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'c', 't', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'a', 'c', 'e', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'o', 'n', 't', 'O', 'u', 't', 'p', 'u', 't', 'M', 'a', 's', 'k', 0,
    'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'M', 'i', 'p', 'M', 'a', 'p', 's', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'm', 'a', 'x', 'S', 'S', 'B', 'O', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 's', 0,
    'm', 'a', 'x', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'U', 'n', 'i', 't', 's', 0,
    'm', 'e', 's', 'h', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'i', 'c', 'k', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'o', 'r', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'F', 'i', 'l', 't', 'e', 'r', 'K', 'e', 'y', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'T', 'e', 'c', 'h', 'n', 'i', 'q', 'u', 'e', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'H', 'o', 'v', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'M', 'a', 'j', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'i', 'n', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'i', 'z', 'e', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'e', 'n', 'c', 'i', 'l', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'C', 'o', 'm', 'p', 'u', 't', 'e', 0,
    's', 'y', 'n', 'c', 'D', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 'p', 'V', 'e', 'c', 't', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'G', 'r', 'e', 'a', 't', 'e', 'r', 0,
    'G', 'r', 'e', 'a', 't', 'e', 'r', 'O', 'r', 'E', 'q', 'u', 'a', 'l', 0,
    'I', 'n', 'd', 'e', 'x', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'K', 'e', 'y', 'p', 'a', 'd', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'L', 'i', 'g', 'h', 't', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'L', 'i', 'n', 'e', 's', 'A', 'd', 'j', 'a', 'c', 'e', 'n', 'c', 'y', 0,
    'M', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 'R', 'e', 'p', 'e', 'a', 't', 0,
    'R', 'G', '1', '1', '_', 'E', 'A', 'C', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '1', '1', '_', 'E', 'A', 'C', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', 'A', '8', '_', 'E', 'T', 'C', '2', '_', 'E', 'A', 'C', 0,
    'R', 'G', '_', 'A', 'T', 'I', '2', 'N', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '_', 'A', 'T', 'I', '2', 'N', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'a', 'd', 'd', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'b', 'a', 'c', 'k', 'O', 'u', 't', 'p', 'u', 't', 'M', 'a', 's', 'k', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'a', 's', 'k', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'g', 'b', 0,
    'd', 'i', 'v', 'i', 's', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'H', 'o', 'v', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'l', 'a', 'y', 'e', 'r', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'o', 'c', 'a', 'l', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'm', 'a', 'x', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'S', 'i', 'z', 'e', 0,
    'm', 'a', 'x', 'U', 'B', 'O', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 's', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'R', 'e', 'c', 't', 0,
    'p', 'i', 'c', 'k', 'R', 'e', 's', 'u', 'l', 't', 'M', 'o', 'd', 'e', 0,
    'p', 'r', 'e', 's', 's', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'I', 'n', 'd', 'e', 'x', 0,
    'p', 'r', 'o', 'f', 'i', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'R', 'e', 'a', 'd', 'e', 'r', 0,
    'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'C', 'a', 'p', 't', 'u', 'r', 'e', 0,
    'r', 'u', 'n', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'u', 'n', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'a', 'm', 'p', 'l', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'M', 'a', 's', 'k', 'e', 'd', 0,
    's', 'e', 't', 'A', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 0,
    's', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    's', 'e', 't', 'C', 'u', 't', 'O', 'f', 'f', 'A', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'r', 'a', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'F', 'i', 'e', 'l', 'd', 'O', 'f', 'V', 'i', 'e', 'w', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'V', 'e', 'r', 't', 'e', 'x', 0,
    's', 'e', 't', 'G', 'r', 'e', 'e', 'n', 'M', 'a', 's', 'k', 'e', 'd', 0,
    's', 'e', 't', 'I', 'n', 'd', 'e', 'x', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'u', 'n', 't', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 'm', 'e', 'o', 'u', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'W', 'o', 'r', 'l', 'd', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'B', 'a', 's', 'e', 'T', 'y', 'p', 'e', 0,
    'v', 'o', 'l', 'u', 'm', 'e', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 0,
    'w', 'a', 'i', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    'w', 'o', 'r', 'l', 'd', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'A', 't', 'o', 'm', 'i', 'c', 'C', 'o', 'u', 'n', 't', 'e', 'r', 0,
    'C', 'l', 'a', 'm', 'p', 'T', 'o', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'A', 'l', 'w', 'a', 'y', 's', 0,
    'D', 'e', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'W', 'r', 'a', 'p', 0,
    'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'W', 'r', 'a', 'p', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 'F', 'e', 'n', 'c', 'e', 'I', 'd', 0,
    'R', '1', '1', '_', 'E', 'A', 'C', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', '1', '1', '_', 'E', 'A', 'C', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', '_', 'A', 'T', 'I', '1', 'N', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', '_', 'A', 'T', 'I', '1', 'N', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'S', 'R', 'G', 'B', '_', 'B', 'P', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'S', 'h', 'a', 'd', 'e', 'r', 'S', 't', 'o', 'r', 'a', 'g', 'e', 0,
    'S', 'h', 'i', 'f', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'T', 'a', 'r', 'g', 'e', 't', '1', 'D', 'A', 'r', 'r', 'a', 'y', 0,
    'T', 'a', 'r', 'g', 'e', 't', '2', 'D', 'A', 'r', 'r', 'a', 'y', 0,
    'T', 'a', 'r', 'g', 'e', 't', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'U', 'p', 'd', 'a', 't', 'e', 0,
    'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'S', 't', 'r', 'i', 'p', 0,
    'U', 'n', 'i', 'f', 'o', 'r', 'm', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'S', 'h', 'o', 'r', 't', 0,
    'a', 'c', 'c', 'e', 's', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'd', 'd', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', 0,
    'a', 'l', 'p', 'h', 'a', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 0,
    'b', 'l', 'e', 'n', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'b', 'o', 't', 't', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'm', 'e', 'r', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 'M', 'o', 'u', 's', 'e', 0,
    'd', 'a', 't', 'a', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'd', 'a', 't', 'a', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', 0,
    'd', 'e', 'p', 't', 'h', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'd', 'r', 'i', 'v', 'e', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'e', 'f', 'f', 'e', 'c', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'e', 'n', 't', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 's', 't', 'a', 'n', 'c', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'i', 's', 'A', 'l', 'p', 'h', 'a', 'M', 'a', 's', 'k', 'e', 'd', 0,
    'i', 's', 'D', 'r', 'a', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'G', 'r', 'e', 'e', 'n', 'M', 'a', 's', 'k', 'e', 'd', 0,
    'l', 'a', 'y', 'e', 'r', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'I', 'm', 'a', 'g', 'e', 'U', 'n', 'i', 't', 's', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'r', 'i', 'g', 'i', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'U', 'p', 'd', 'a', 't', 'e', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'B', 'l', 'u', 'e', 'M', 'a', 's', 'k', 'e', 'd', 0,
    's', 'e', 't', 'B', 'y', 't', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'B', 'y', 't', 'e', 'S', 't', 'r', 'i', 'd', 'e', 0,
    's', 'e', 't', 'C', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'D', 'e', 'p', 't', 'h', 'S', 't', 'e', 'p', 's', 0,
    's', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'F', 'i', 'l', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'I', 'r', 'r', 'a', 'd', 'i', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'P', 'i', 'c', 'k', 'M', 'e', 't', 'h', 'o', 'd', 0,
    's', 'e', 't', 'P', 'l', 'a', 'n', 'e', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'R', 'a', 's', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'R', 'g', 'b', 'a', 0,
    's', 'e', 't', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 's', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'e', 'x', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'C', 'e', 'n', 't', 'e', 'r', 0,
    's', 'e', 't', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'X', 0,
    's', 'e', 't', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'Y', 0,
    's', 'e', 't', 'W', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'Z', 0,
    's', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    's', 'm', 'o', 'o', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'a', 'r', 'g', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 's', 0,
    't', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 'T', 'y', 'p', 'e', 0,
    't', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'I', 'n', 'd', 'e', 'x', 0,
    'v', 'e', 'n', 'd', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'B', 'u', 'f', 'f', 'e', 'r', 'U', 'p', 'd', 'a', 't', 'e', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'E', 'q', 'u', 'a', 'l', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'N', 'e', 'v', 'e', 'r', 0,
    'D', 'e', 'p', 't', 'h', 'S', 't', 'e', 'n', 'c', 'i', 'l', 0,
    'E', 'l', 'e', 'm', 'e', 'n', 't', 'A', 'r', 'r', 'a', 'y', 0,
    'F', 'r', 'o', 'n', 't', 'A', 'n', 'd', 'B', 'a', 'c', 'k', 0,
    'M', 'e', 't', 'a', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'M', 'i', 'd', 'd', 'l', 'e', 'B', 'u', 't', 't', 'o', 'n', 0,
    'P', 'o', 'i', 'n', 't', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 0,
    'P', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'a', 'b', 'l', 'e', 0,
    'R', 'G', 'B', 'A', '1', '6', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', 'A', '1', '6', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', 0,
    'T', 'a', 'r', 'g', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'e', 't', 'c', 'h', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'B', 'y', 't', 'e', 0,
    'V', 'e', 'r', 't', 'e', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'a', 'd', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'a', 'd', 'd', 'F', 'i', 'l', 't', 'e', 'r', 'K', 'e', 'y', 0,
    'a', 'd', 'd', 'I', 'm', 'a', 'g', 'e', 'D', 'a', 't', 'a', 0,
    'a', 'd', 'd', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'a', 'd', 'd', 'T', 'e', 'c', 'h', 'n', 'i', 'q', 'u', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'd', 'e', 'p', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'a', 'm', 'm', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'B', 'l', 'u', 'e', 'M', 'a', 's', 'k', 'e', 'd', 0,
    'i', 's', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', 0,
    'l', 'a', 'y', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'j', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'm', 'i', 'n', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'r', 'e', 'a', 'd', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'O', 'u', 't', 'p', 'u', 't', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', 'e', 's', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', 's', 0,
    'r', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 'l', 'l', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'I', 'n', 't', 'e', 'n', 's', 'i', 't', 'y', 0,
    's', 'e', 't', 'M', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 's', 0,
    's', 'e', 't', 'N', 'e', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 0,
    's', 'e', 't', 'N', 'e', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'R', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 0,
    's', 'e', 't', 'R', 'e', 'd', 'M', 'a', 's', 'k', 'e', 'd', 0,
    's', 'e', 't', 'S', 'o', 'r', 't', 'T', 'y', 'p', 'e', 's', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'R', 'g', 'b', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'd', 0,
    's', 'e', 't', 'W', 'a', 'i', 't', 'O', 'n', 'C', 'P', 'U', 0,
    's', 'e', 't', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 'X', 0,
    's', 'e', 't', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 'Y', 0,
    's', 'e', 't', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 'Z', 0,
    's', 'o', 'r', 't', 'T', 'y', 'p', 'e', 's', 'I', 'n', 't', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'S', 'S', 'B', 'O', 0,
    't', 'i', 'l', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'u', 's', 'a', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'e', 'x', '1', 'I', 'n', 'd', 'e', 'x', 0,
    'v', 'e', 'r', 't', 'e', 'x', '2', 'I', 'n', 'd', 'e', 'x', 0,
    'v', 'e', 'r', 't', 'e', 'x', '3', 'I', 'n', 'd', 'e', 'x', 0,
    'w', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'l', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'B', 'a', 'c', 'k', 'T', 'o', 'F', 'r', 'o', 'n', 't', 0,
    'C', 'l', 'a', 'm', 'p', 'T', 'o', 'E', 'd', 'g', 'e', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'L', 'e', 's', 's', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'N', 'o', 'n', 'e', 0,
    'C', 'o', 'r', 'e', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'D', 'e', 'p', 't', 'h', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'D', 'y', 'n', 'a', 'm', 'i', 'c', 'C', 'o', 'p', 'y', 0,
    'D', 'y', 'n', 'a', 'm', 'i', 'c', 'D', 'r', 'a', 'w', 0,
    'D', 'y', 'n', 'a', 'm', 'i', 'c', 'R', 'e', 'a', 'd', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'F', 'r', 'o', 'n', 't', 'T', 'o', 'B', 'a', 'c', 'k', 0,
    'I', 'n', 'd', 'e', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'L', 'e', 's', 's', 'O', 'r', 'E', 'q', 'u', 'a', 'l', 0,
    'L', 'i', 'n', 'e', 'P', 'i', 'c', 'k', 'i', 'n', 'g', 0,
    'N', 'e', 'a', 'r', 'e', 's', 't', 'P', 'i', 'c', 'k', 0,
    'P', 'i', 'x', 'e', 'l', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 'u', 'e', 'r', 'y', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'R', 'G', 'B', '1', '6', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', '1', '6', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', 'A', '8', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', 'A', '8', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'i', 'g', 'h', 't', 'B', 'u', 't', 't', 'o', 'n', 0,
    'S', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 0,
    'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'F', 'a', 'n', 0,
    'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'H', 'i', 't', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'I', 'n', 't', 0,
    'a', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'I', 'n', 'd', 'e', 'x', 0,
    'c', 'o', 'l', 'o', 'r', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'u', 't', 'O', 'f', 'f', 'A', 'n', 'g', 'l', 'e', 0,
    'd', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'e', 'n', 't', 'i', 't', 'y', 'N', 'a', 'm', 'e', 's', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'i', 'e', 'l', 'd', 'O', 'f', 'V', 'i', 'e', 'w', 0,
    'f', 'i', 'r', 's', 't', 'V', 'e', 'r', 't', 'e', 'x', 0,
    'g', 'l', 's', 'l', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'h', 'i', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'd', 'e', 'x', 'O', 'f', 'f', 's', 'e', 't', 0,
    'i', 's', 'R', 'e', 'd', 'M', 'a', 's', 'k', 'e', 'd', 0,
    'l', 'e', 'f', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'S', 'S', 'B', 'O', 'S', 'i', 'z', 'e', 0,
    'm', 'i', 'p', 'm', 'a', 'p', 'L', 'e', 'v', 'e', 'l', 0,
    'm', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'a', 'n', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'L', 'a', 'y', 'e', 'r', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'M', 'a', 't', 'c', 'h', 0,
    's', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 0,
    's', 'e', 't', 'F', 'a', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'F', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 0,
    's', 'e', 't', 'F', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    's', 'e', 't', 'M', 'e', 's', 'h', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'M', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'M', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    's', 'e', 't', 'S', 'i', 'z', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'S', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 0,
    's', 'e', 't', 'S', 'y', 'n', 'c', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'U', 'p', 'V', 'e', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    's', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'U', 'B', 'O', 0,
    't', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'u', 'n', 't', 0,
    'A', 'l', 'l', 'B', 'u', 'f', 'f', 'e', 'r', 's', 0,
    'B', 'a', 'c', 'k', 'B', 'u', 't', 't', 'o', 'n', 0,
    'C', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 0,
    'L', 'e', 'f', 't', 'B', 'u', 't', 't', 'o', 'n', 0,
    'N', 'o', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 0,
    'P', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', 0,
    'R', 'G', '1', '6', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '1', '6', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', '8', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', '8', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', 'A', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'S', 'R', 'G', 'B', '8', '_', 'E', 'T', 'C', '2', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'S', 'h', 'o', 't', 0,
    'S', 't', 'a', 't', 'i', 'c', 'C', 'o', 'p', 'y', 0,
    'S', 't', 'a', 't', 'i', 'c', 'D', 'r', 'a', 'w', 0,
    'S', 't', 'a', 't', 'i', 'c', 'R', 'e', 'a', 'd', 0,
    'S', 't', 'r', 'e', 'a', 'm', 'C', 'o', 'p', 'y', 0,
    'S', 't', 'r', 'e', 'a', 'm', 'D', 'r', 'a', 'w', 0,
    'S', 't', 'r', 'e', 'a', 'm', 'R', 'e', 'a', 'd', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'a', 'c', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 0,
    'a', 'p', 'i', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'b', 'y', 't', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    'b', 'y', 't', 'e', 'S', 't', 'r', 'i', 'd', 'e', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    'd', 'e', 'p', 't', 'h', 'S', 't', 'e', 'p', 's', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'f', 'i', 'l', 't', 'e', 'r', 'K', 'e', 'y', 's', 0,
    'f', 'i', 'l', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    'f', 'r', 'a', 'm', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'i', 'r', 'r', 'a', 'd', 'i', 'a', 'n', 'c', 'e', 0,
    'i', 's', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    'i', 's', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 0,
    'i', 's', 'M', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 0,
    'i', 's', 'S', 'y', 'n', 'c', 'D', 'a', 't', 'a', 0,
    'l', 'o', 'a', 'd', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'l', 'o', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'S', 'a', 'm', 'p', 'l', 'e', 's', 0,
    'm', 'a', 'x', 'U', 'B', 'O', 'S', 'i', 'z', 'e', 0,
    'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'p', 'i', 'c', 'k', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'p', 'l', 'a', 'n', 'e', 'I', 'n', 'd', 'e', 'x', 0,
    'p', 'o', 'i', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'r', 'a', 's', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'a', 'v', 'e', 'T', 'o', 'F', 'i', 'l', 'e', 0,
    's', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 's', 0,
    's', 'e', 't', 'D', 'i', 'v', 'i', 's', 'o', 'r', 0,
    's', 'e', 't', 'L', 'a', 'y', 'e', 'r', 'e', 'd', 0,
    's', 'e', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    's', 'e', 't', 'R', 'u', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'R', 'u', 'n', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'S', 'a', 'm', 'p', 'l', 'e', 's', 0,
    's', 'e', 't', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 'o', 'u', 't', 0,
    's', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'd', 'e', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'R', 'e', 'c', 't', 0,
    't', 'e', 'c', 'h', 'n', 'i', 'q', 'u', 'e', 's', 0,
    't', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 's', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'D', 'a', 't', 'a', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'S', 'i', 'z', 'e', 0,
    'v', 'i', 'e', 'w', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'v', 'i', 'e', 'w', 'E', 'n', 't', 'i', 't', 'y', 0,
    'v', 'i', 'e', 'w', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'v', 'i', 'e', 'w', 'S', 'p', 'h', 'e', 'r', 'e', 0,
    'v', 'i', 'e', 'w', 'V', 'e', 'c', 't', 'o', 'r', 0,
    'w', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'X', 0,
    'w', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'Y', 0,
    'w', 'o', 'r', 'k', 'G', 'r', 'o', 'u', 'p', 'Z', 0,
    'D', '3', '2', 'F', 'S', '8', 'X', '2', '4', 0,
    'D', 'e', 'c', 'r', 'e', 'm', 'e', 'n', 't', 0,
    'E', 'n', 't', 'i', 't', 'y', 'H', 'i', 't', 0,
    'H', 'a', 'l', 'f', 'F', 'l', 'o', 'a', 't', 0,
    'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 0,
    'L', 'i', 'n', 'e', 'S', 't', 'r', 'i', 'p', 0,
    'N', 'o', 'C', 'u', 'l', 'l', 'i', 'n', 'g', 0,
    'N', 'o', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'R', '1', '6', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', '1', '6', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '8', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '8', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', '8', '_', 'E', 'T', 'C', '1', 0,
    'R', 'G', 'B', 'A', '_', 'D', 'X', 'T', '1', 0,
    'R', 'G', 'B', 'A', '_', 'D', 'X', 'T', '3', 0,
    'R', 'G', 'B', 'A', '_', 'D', 'X', 'T', '5', 0,
    'R', 'G', 'B', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'R', 'e', 'a', 'd', 'W', 'r', 'i', 't', 'e', 0,
    'S', 'R', 'G', 'B', '_', 'D', 'X', 'T', '1', 0,
    'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 's', 0,
    'W', 'r', 'i', 't', 'e', 'O', 'n', 'l', 'y', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'a', 'd', 'd', 'O', 'u', 't', 'p', 'u', 't', 0,
    'c', 'a', 'p', 't', 'u', 'r', 'e', 'I', 'd', 0,
    'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'd', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'e', 'd', 'g', 'e', 'I', 'n', 'd', 'e', 'x', 0,
    'i', 'm', 'a', 'g', 'e', 'D', 'a', 't', 'a', 0,
    'i', 'n', 't', 'e', 'n', 's', 'i', 't', 'y', 0,
    'i', 's', 'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'm', 'a', 'x', 'E', 'x', 't', 'e', 'n', 't', 0,
    'm', 'i', 'n', 'E', 'x', 't', 'e', 'n', 't', 0,
    'm', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 's', 0,
    'm', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'n', 'e', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 0,
    'n', 'e', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 0,
    'p', 'i', 'x', 'e', 'l', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 0,
    's', 'a', 'v', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 0,
    's', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    's', 'e', 't', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    's', 'e', 't', 'E', 'f', 'f', 'e', 'c', 't', 0,
    's', 'e', 't', 'E', 'n', 't', 'i', 't', 'y', 0,
    's', 'e', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    's', 'e', 't', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'L', 'a', 'y', 'e', 'r', 's', 0,
    's', 'e', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    's', 'e', 't', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    's', 'e', 't', 'S', 'm', 'o', 'o', 't', 'h', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'u', 's', 0,
    's', 'e', 't', 'T', 'a', 'r', 'g', 'e', 't', 0,
    's', 'e', 't', 'V', 'e', 'n', 'd', 'o', 'r', 0,
    's', 'o', 'r', 't', 'T', 'y', 'p', 'e', 's', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'R', 'g', 'b', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'd', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    'w', 'a', 'i', 't', 'O', 'n', 'C', 'P', 'U', 0,
    'w', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 'X', 0,
    'w', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 'Y', 0,
    'w', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 'Z', 0,
    'A', 'l', 'l', 'F', 'a', 'c', 'e', 's', 0,
    'A', 'l', 'l', 'P', 'i', 'c', 'k', 's', 0,
    'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'L', 'i', 'n', 'e', 'L', 'o', 'o', 'p', 0,
    'N', 'o', 'B', 'u', 't', 't', 'o', 'n', 0,
    'N', 'o', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'N', 'o', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'N', 'o', 't', 'R', 'e', 'a', 'd', 'y', 0,
    'O', 'n', 'D', 'e', 'm', 'a', 'n', 'd', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 'E', 'S', 0,
    'P', 'o', 'i', 'n', 't', 'H', 'i', 't', 0,
    'R', '8', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', '8', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '1', '1', 'B', '1', '0', 'F', 0,
    'R', 'G', 'B', '1', '0', 'A', '2', 'U', 0,
    'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    'T', 'a', 'r', 'g', 'e', 't', '1', 'D', 0,
    'T', 'a', 'r', 'g', 'e', 't', '2', 'D', 0,
    'T', 'a', 'r', 'g', 'e', 't', '3', 'D', 0,
    'T', 'h', 'r', 'e', 'a', 'd', 'e', 'd', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'c', 'a', 'l', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'a', 'd', 'd', 'L', 'a', 'y', 'e', 'r', 0,
    'a', 'd', 'd', 'M', 'a', 't', 'c', 'h', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'e', 'n', 't', 'i', 't', 'y', 'I', 'd', 0,
    'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', 0,
    'f', 'a', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    'f', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 0,
    'f', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'm', 'a', 't', 'c', 'h', 'A', 'l', 'l', 0,
    'm', 'a', 't', 'c', 'h', 'A', 'n', 'y', 0,
    'm', 'e', 's', 'h', 'N', 'a', 'm', 'e', 0,
    'm', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'd', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'D', 'e', 'p', 't', 'h', 0,
    's', 'e', 't', 'F', 'a', 'c', 'e', 's', 0,
    's', 'e', 't', 'G', 'a', 'm', 'm', 'a', 0,
    's', 'e', 't', 'I', 'm', 'a', 'g', 'e', 0,
    's', 'e', 't', 'L', 'a', 'y', 'e', 'r', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'U', 's', 'a', 'g', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'W', 'i', 'd', 't', 'h', 0,
    's', 'i', 'z', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 0,
    'u', 'p', 'V', 'e', 'c', 't', 'o', 'r', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'w', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'z', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'l', 'o', 'r', '1', '0', 0,
    'C', 'o', 'l', 'o', 'r', '1', '1', 0,
    'C', 'o', 'l', 'o', 'r', '1', '2', 0,
    'C', 'o', 'l', 'o', 'r', '1', '3', 0,
    'C', 'o', 'l', 'o', 'r', '1', '4', 0,
    'C', 'o', 'l', 'o', 'r', '1', '5', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'X', 0,
    'L', 'i', 'n', 'e', 'H', 'i', 't', 0,
    'L', 'o', 'a', 'd', 'i', 'n', 'g', 0,
    'P', 'a', 't', 'c', 'h', 'e', 's', 0,
    'R', 'G', 'B', '1', '0', 'A', '2', 0,
    'R', 'G', 'B', 'A', '1', '6', 'F', 0,
    'R', 'G', 'B', 'A', '1', '6', 'I', 0,
    'R', 'G', 'B', 'A', '1', '6', 'U', 0,
    'R', 'G', 'B', 'A', '3', '2', 'F', 0,
    'R', 'G', 'B', 'A', '3', '2', 'I', 0,
    'R', 'G', 'B', 'A', '3', '2', 'U', 0,
    'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'U', 'n', 'i', 'f', 'o', 'r', 'm', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 's', 0,
    'b', 'u', 't', 't', 'o', 'n', 's', 0,
    'c', 'l', 'e', 'a', 'n', 'u', 'p', 0,
    'c', 'l', 'i', 'c', 'k', 'e', 'd', 0,
    'd', 'i', 'v', 'i', 's', 'o', 'r', 0,
    'e', 'n', 't', 'e', 'r', 'e', 'd', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'l', 'a', 'y', 'e', 'r', 'e', 'd', 0,
    'o', 'u', 't', 'p', 'u', 't', 's', 0,
    'p', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'r', 'u', 'n', 'M', 'o', 'd', 'e', 0,
    'r', 'u', 'n', 'T', 'y', 'p', 'e', 0,
    's', 'a', 'm', 'p', 'l', 'e', 's', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'F', 'a', 'c', 'e', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 0,
    's', 'e', 't', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'T', 'y', 'p', 'e', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 0,
    't', 'i', 'm', 'e', 'o', 'u', 't', 0,
    't', 'r', 'i', 'g', 'g', 'e', 'r', 0,
    'v', 'i', 'e', 'w', 'A', 'l', 'l', 0,
    'C', 'o', 'l', 'o', 'r', '1', 0,
    'C', 'o', 'l', 'o', 'r', '2', 0,
    'C', 'o', 'l', 'o', 'r', '3', 0,
    'C', 'o', 'l', 'o', 'r', '4', 0,
    'C', 'o', 'l', 'o', 'r', '5', 0,
    'C', 'o', 'l', 'o', 'r', '6', 0,
    'C', 'o', 'l', 'o', 'r', '7', 0,
    'C', 'o', 'l', 'o', 'r', '8', 0,
    'C', 'o', 'l', 'o', 'r', '9', 0,
    'D', 'o', 'u', 'b', 'l', 'e', 0,
    'I', 'n', 'v', 'e', 'r', 't', 0,
    'M', 'a', 'n', 'u', 'a', 'l', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 0,
    'P', 'o', 'i', 'n', 't', 's', 0,
    'R', '5', 'G', '6', 'B', '5', 0,
    'R', 'G', 'B', '1', '6', 'F', 0,
    'R', 'G', 'B', '1', '6', 'I', 0,
    'R', 'G', 'B', '1', '6', 'U', 0,
    'R', 'G', 'B', '3', '2', 'F', 0,
    'R', 'G', 'B', '3', '2', 'I', 0,
    'R', 'G', 'B', '3', '2', 'U', 0,
    'R', 'G', 'B', '5', 'A', '1', 0,
    'R', 'G', 'B', '9', 'E', '5', 0,
    'R', 'G', 'B', 'A', '8', 'I', 0,
    'R', 'G', 'B', 'A', '8', 'U', 0,
    'V', 'u', 'l', 'k', 'a', 'n', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'c', 'c', 'e', 's', 's', 0,
    'b', 'o', 't', 't', 'o', 'm', 0,
    'b', 'u', 't', 't', 'o', 'n', 0,
    'c', 'a', 'm', 'e', 'r', 'a', 0,
    'c', 'e', 'n', 't', 'e', 'r', 0,
    'e', 'f', 'f', 'e', 'c', 't', 0,
    'e', 'n', 't', 'i', 't', 'y', 0,
    'e', 'x', 'i', 't', 'e', 'd', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 0,
    'h', 'e', 'i', 'g', 'h', 't', 0,
    'l', 'a', 'y', 'e', 'r', 's', 0,
    'l', 'e', 'n', 'g', 't', 'h', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 0,
    'o', 'f', 'f', 's', 'e', 't', 0,
    'o', 'p', 't', 'i', 'o', 'n', 0,
    'o', 'r', 'i', 'g', 'i', 'n', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'r', 'a', 'd', 'i', 'u', 's', 0,
    'r', 'o', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'A', 'p', 'i', 0,
    's', 'e', 't', 'T', 'o', 'p', 0,
    's', 'm', 'o', 'o', 't', 'h', 0,
    's', 'o', 'u', 'r', 'c', 'e', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    's', 't', 'r', 'i', 'd', 'e', 0,
    't', 'a', 'r', 'g', 'e', 't', 0,
    'u', 'p', 'd', 'a', 't', 'e', 0,
    'v', 'e', 'n', 'd', 'o', 'r', 0,
    'D', '2', '4', 'S', '8', 0,
    'E', 'r', 'r', 'o', 'r', 0,
    'F', 'i', 'x', 'e', 'd', 0,
    'L', 'i', 'n', 'e', 's', 0,
    'N', 'o', 'n', 'e', '_', 0,
    'R', 'G', '1', '6', 'F', 0,
    'R', 'G', '1', '6', 'I', 0,
    'R', 'G', '1', '6', 'U', 0,
    'R', 'G', '3', '2', 'F', 0,
    'R', 'G', '3', '2', 'I', 0,
    'R', 'G', '3', '2', 'U', 0,
    'R', 'G', '3', 'B', '2', 0,
    'R', 'G', 'B', '8', 'I', 0,
    'R', 'G', 'B', '8', 'U', 0,
    'R', 'G', 'B', 'A', '4', 0,
    'S', 'P', 'I', 'R', 'V', 0,
    'S', 'R', 'G', 'B', '8', 0,
    'c', 'o', 'l', 'o', 'r', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'd', 'e', 'p', 't', 'h', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'a', 'c', 'e', 's', 0,
    'f', 'r', 'o', 'n', 't', 0,
    'g', 'a', 'm', 'm', 'a', 0,
    'i', 'm', 'a', 'g', 'e', 0,
    'l', 'a', 'y', 'e', 'r', 0,
    'm', 'o', 'v', 'e', 'd', 0,
    'p', 'a', 'i', 'n', 't', 0,
    'r', 'i', 'g', 'h', 't', 0,
    'u', 's', 'a', 'g', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'w', 'i', 'd', 't', 'h', 0,
    'D', '3', '2', 'F', 0,
    'F', 'i', 'l', 'l', 0,
    'G', 'L', 'S', 'L', 0,
    'K', 'e', 'e', 'p', 0,
    'R', '1', '6', 'F', 0,
    'R', '1', '6', 'I', 0,
    'R', '1', '6', 'U', 0,
    'R', '3', '2', 'F', 0,
    'R', '3', '2', 'I', 0,
    'R', '3', '2', 'U', 0,
    'R', 'G', '8', 'I', 0,
    'R', 'G', '8', 'U', 0,
    'Z', 'e', 'r', 'o', 0,
    'd', 'a', 't', 'a', 0,
    'h', 'i', 't', 's', 0,
    'l', 'e', 'f', 't', 0,
    'l', 'e', 'n', 's', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    'r', 'e', 'c', 't', 0,
    'r', 'o', 'l', 'l', 0,
    's', 'e', 't', 'X', 0,
    's', 'e', 't', 'Y', 0,
    's', 'e', 't', 'Z', 0,
    's', 'i', 'z', 'e', 0,
    's', 'w', 'a', 'p', 0,
    't', 'i', 'l', 't', 0,
    't', 'y', 'p', 'e', 0,
    'A', 'd', 'd', 0,
    'D', '1', '6', 0,
    'D', '2', '4', 0,
    'D', '3', '2', 0,
    'M', 'a', 'x', 0,
    'M', 'i', 'n', 0,
    'O', 'n', 'e', 0,
    'R', '8', 'I', 0,
    'R', '8', 'U', 0,
    'R', 'H', 'I', 0,
    'a', 'p', 'i', 0,
    'l', 'o', 'g', 0,
    'p', 'a', 'n', 0,
    't', 'o', 'p', 0,
    'u', 'v', 'w', 0,
    'z', 0,
};

bool sipVH_Qt3DRender_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DRender::QTextureImageDataGenerator& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::Qt3DRender::QTextureImageDataGenerator *>(&a0), sipType_Qt3DRender_QTextureImageDataGenerator, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::Qt3DRender::QTextureImageDataPtr sipVH_Qt3DRender_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt3DRender::QTextureImageDataPtr sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSharedPointer_0100Qt3DRender_QTextureImageData, &sipRes);

    return sipRes;
}

bool sipVH_Qt3DRender_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DRender::QTextureGenerator& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::Qt3DRender::QTextureGenerator *>(&a0), sipType_Qt3DRender_QTextureGenerator, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::Qt3DRender::QTextureDataPtr sipVH_Qt3DRender_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt3DRender::QTextureDataPtr sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSharedPointer_0100Qt3DRender_QTextureData, &sipRes);

    return sipRes;
}

::QVariant sipVH_Qt3DRender_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QVariant& a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QVariant(a0), sipType_QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_Qt3DRender_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPainter, SIP_NULLPTR);
}

bool sipVH_Qt3DRender_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DRender::QGeometryFactory& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::Qt3DRender::QGeometryFactory *>(&a0), sipType_Qt3DRender_QGeometryFactory, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::Qt3DRender::QGeometry* sipVH_Qt3DRender_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt3DRender::QGeometry* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_Qt3DRender_QGeometry, &sipRes);

    return sipRes;
}

bool sipVH_Qt3DRender_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DRender::QBufferDataGenerator& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::Qt3DRender::QBufferDataGenerator *>(&a0), sipType_Qt3DRender_QBufferDataGenerator, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QByteArray sipVH_Qt3DRender_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QByteArray sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QByteArray, &sipRes);

    return sipRes;
}

::Qt3DRender::QTextureImageDataGeneratorPtr sipVH_Qt3DRender_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt3DRender::QTextureImageDataGeneratorPtr sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSharedPointer_0100Qt3DRender_QTextureImageDataGenerator, &sipRes);

    return sipRes;
}

void sipVH_Qt3DRender_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DCore::QSceneChangePtr& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::Qt3DCore::QSceneChangePtr(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, SIP_NULLPTR);
}

bool sipVH_Qt3DRender_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_Qt3DRender_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_Qt3DRender_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_Qt3DRender_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_Qt3DRender_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_Qt3DRender_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

::qintptr sipVH_Qt3DRender_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::qintptr sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_qintptr, &sipRes);

    return sipRes;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_Qt3DRender_QCamera(void **);}
static const sipTypeDef *sipSubClass_Qt3DRender_QCamera(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 36 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
        static struct class_graph {
            const char *name;
            sipTypeDef **type;
            int yes, no;
        } graph[] = {
            {sipName_Qt3DRender__QAbstractLight, &sipType_Qt3DRender_QAbstractLight, 40, 1},
        #if QT3DRENDER_VERSION >= 0x050b00
            {sipName_Qt3DRender__QAbstractRayCaster, &sipType_Qt3DRender_QAbstractRayCaster, 43, 2},
        #else
            {0, 0, 43, 2},
        #endif
            {sipName_Qt3DRender__QAbstractTexture, &sipType_Qt3DRender_QAbstractTexture, 45, 3},
            {sipName_Qt3DRender__QAbstractTextureImage, &sipType_Qt3DRender_QAbstractTextureImage, 58, 4},
            {sipName_Qt3DRender__QRenderState, &sipType_Qt3DRender_QRenderState, 60, 5},
            {sipName_Qt3DRender__QAttribute, &sipType_Qt3DRender_QAttribute, -1, 6},
            {sipName_Qt3DRender__QFrameGraphNode, &sipType_Qt3DRender_QFrameGraphNode, 82, 7},
            {sipName_Qt3DRender__QBuffer, &sipType_Qt3DRender_QBuffer, -1, 8},
            {sipName_Qt3DRender__QCamera, &sipType_Qt3DRender_QCamera, -1, 9},
            {sipName_Qt3DRender__QCameraLens, &sipType_Qt3DRender_QCameraLens, -1, 10},
            {sipName_Qt3DRender__QComputeCommand, &sipType_Qt3DRender_QComputeCommand, -1, 11},
            {sipName_Qt3DRender__QEffect, &sipType_Qt3DRender_QEffect, -1, 12},
        #if QT3DRENDER_VERSION >= 0x050900
            {sipName_Qt3DRender__QEnvironmentLight, &sipType_Qt3DRender_QEnvironmentLight, -1, 13},
        #else
            {0, 0, -1, 13},
        #endif
            {sipName_Qt3DRender__QFilterKey, &sipType_Qt3DRender_QFilterKey, -1, 14},
            {sipName_Qt3DRender__QGeometry, &sipType_Qt3DRender_QGeometry, -1, 15},
            {sipName_Qt3DRender__QGeometryRenderer, &sipType_Qt3DRender_QGeometryRenderer, 103, 16},
            {sipName_Qt3DRender__QGraphicsApiFilter, &sipType_Qt3DRender_QGraphicsApiFilter, -1, 17},
            {sipName_Qt3DRender__QLayer, &sipType_Qt3DRender_QLayer, -1, 18},
        #if QT3DRENDER_VERSION >= 0x050900
            {sipName_Qt3DRender__QLevelOfDetail, &sipType_Qt3DRender_QLevelOfDetail, 104, 19},
        #else
            {0, 0, 104, 19},
        #endif
            {sipName_Qt3DRender__QMaterial, &sipType_Qt3DRender_QMaterial, -1, 20},
            {sipName_Qt3DRender__QObjectPicker, &sipType_Qt3DRender_QObjectPicker, -1, 21},
            {sipName_Qt3DRender__QParameter, &sipType_Qt3DRender_QParameter, -1, 22},
            {sipName_Qt3DRender__QPickEvent, &sipType_Qt3DRender_QPickEvent, 105, 23},
            {sipName_Qt3DRender__QPickingSettings, &sipType_Qt3DRender_QPickingSettings, -1, 24},
            {sipName_Qt3DRender__QRenderAspect, &sipType_Qt3DRender_QRenderAspect, -1, 25},
        #if QT3DRENDER_VERSION >= 0x050f00
            {sipName_Qt3DRender__QRenderCapabilities, &sipType_Qt3DRender_QRenderCapabilities, -1, 26},
        #else
            {0, 0, -1, 26},
        #endif
        #if QT3DRENDER_VERSION >= 0x050800
            {sipName_Qt3DRender__QRenderCaptureReply, &sipType_Qt3DRender_QRenderCaptureReply, -1, 27},
        #else
            {0, 0, -1, 27},
        #endif
            {sipName_Qt3DRender__QRenderPass, &sipType_Qt3DRender_QRenderPass, -1, 28},
            {sipName_Qt3DRender__QRenderSettings, &sipType_Qt3DRender_QRenderSettings, -1, 29},
            {sipName_Qt3DRender__QRenderTarget, &sipType_Qt3DRender_QRenderTarget, -1, 30},
            {sipName_Qt3DRender__QRenderTargetOutput, &sipType_Qt3DRender_QRenderTargetOutput, -1, 31},
            {sipName_Qt3DRender__QSceneLoader, &sipType_Qt3DRender_QSceneLoader, -1, 32},
            {sipName_Qt3DRender__QShaderData, &sipType_Qt3DRender_QShaderData, -1, 33},
        #if QT3DRENDER_VERSION >= 0x050e00
            {sipName_Qt3DRender__QShaderImage, &sipType_Qt3DRender_QShaderImage, -1, 34},
        #else
            {0, 0, -1, 34},
        #endif
            {sipName_Qt3DRender__QShaderProgram, &sipType_Qt3DRender_QShaderProgram, -1, 35},
        #if QT3DRENDER_VERSION >= 0x050a00
            {sipName_Qt3DRender__QShaderProgramBuilder, &sipType_Qt3DRender_QShaderProgramBuilder, -1, 36},
        #else
            {0, 0, -1, 36},
        #endif
            {sipName_Qt3DRender__QStencilOperationArguments, &sipType_Qt3DRender_QStencilOperationArguments, -1, 37},
            {sipName_Qt3DRender__QStencilTestArguments, &sipType_Qt3DRender_QStencilTestArguments, -1, 38},
            {sipName_Qt3DRender__QTechnique, &sipType_Qt3DRender_QTechnique, -1, 39},
            {sipName_Qt3DRender__QTextureWrapMode, &sipType_Qt3DRender_QTextureWrapMode, -1, -1},
            {sipName_Qt3DRender__QDirectionalLight, &sipType_Qt3DRender_QDirectionalLight, -1, 41},
            {sipName_Qt3DRender__QPointLight, &sipType_Qt3DRender_QPointLight, -1, 42},
            {sipName_Qt3DRender__QSpotLight, &sipType_Qt3DRender_QSpotLight, -1, -1},
        #if QT3DRENDER_VERSION >= 0x050b00
            {sipName_Qt3DRender__QRayCaster, &sipType_Qt3DRender_QRayCaster, -1, 44},
        #else
            {0, 0, -1, 44},
        #endif
        #if QT3DRENDER_VERSION >= 0x050b00
            {sipName_Qt3DRender__QScreenRayCaster, &sipType_Qt3DRender_QScreenRayCaster, -1, -1},
        #else
            {0, 0, -1, -1},
        #endif
        #if QT3DRENDER_VERSION >= 0x050d00
            {sipName_Qt3DRender__QSharedGLTexture, &sipType_Qt3DRender_QSharedGLTexture, -1, 46},
        #else
            {0, 0, -1, 46},
        #endif
            {sipName_Qt3DRender__QTexture1D, &sipType_Qt3DRender_QTexture1D, -1, 47},
            {sipName_Qt3DRender__QTexture1DArray, &sipType_Qt3DRender_QTexture1DArray, -1, 48},
            {sipName_Qt3DRender__QTexture2D, &sipType_Qt3DRender_QTexture2D, -1, 49},
            {sipName_Qt3DRender__QTexture2DArray, &sipType_Qt3DRender_QTexture2DArray, -1, 50},
            {sipName_Qt3DRender__QTexture2DMultisample, &sipType_Qt3DRender_QTexture2DMultisample, -1, 51},
            {sipName_Qt3DRender__QTexture2DMultisampleArray, &sipType_Qt3DRender_QTexture2DMultisampleArray, -1, 52},
            {sipName_Qt3DRender__QTexture3D, &sipType_Qt3DRender_QTexture3D, -1, 53},
            {sipName_Qt3DRender__QTextureBuffer, &sipType_Qt3DRender_QTextureBuffer, -1, 54},
            {sipName_Qt3DRender__QTextureCubeMap, &sipType_Qt3DRender_QTextureCubeMap, -1, 55},
            {sipName_Qt3DRender__QTextureCubeMapArray, &sipType_Qt3DRender_QTextureCubeMapArray, -1, 56},
            {sipName_Qt3DRender__QTextureLoader, &sipType_Qt3DRender_QTextureLoader, -1, 57},
            {sipName_Qt3DRender__QTextureRectangle, &sipType_Qt3DRender_QTextureRectangle, -1, -1},
        #if QT3DRENDER_VERSION >= 0x050800
            {sipName_Qt3DRender__QPaintedTextureImage, &sipType_Qt3DRender_QPaintedTextureImage, -1, 59},
        #else
            {0, 0, -1, 59},
        #endif
            {sipName_Qt3DRender__QTextureImage, &sipType_Qt3DRender_QTextureImage, -1, -1},
            {sipName_Qt3DRender__QAlphaCoverage, &sipType_Qt3DRender_QAlphaCoverage, -1, 61},
            {sipName_Qt3DRender__QAlphaTest, &sipType_Qt3DRender_QAlphaTest, -1, 62},
            {sipName_Qt3DRender__QBlendEquation, &sipType_Qt3DRender_QBlendEquation, -1, 63},
            {sipName_Qt3DRender__QBlendEquationArguments, &sipType_Qt3DRender_QBlendEquationArguments, -1, 64},
            {sipName_Qt3DRender__QClipPlane, &sipType_Qt3DRender_QClipPlane, -1, 65},
            {sipName_Qt3DRender__QColorMask, &sipType_Qt3DRender_QColorMask, -1, 66},
            {sipName_Qt3DRender__QCullFace, &sipType_Qt3DRender_QCullFace, -1, 67},
        #if QT3DRENDER_VERSION >= 0x050e00
            {sipName_Qt3DRender__QDepthRange, &sipType_Qt3DRender_QDepthRange, -1, 68},
        #else
            {0, 0, -1, 68},
        #endif
            {sipName_Qt3DRender__QDepthTest, &sipType_Qt3DRender_QDepthTest, -1, 69},
            {sipName_Qt3DRender__QDithering, &sipType_Qt3DRender_QDithering, -1, 70},
            {sipName_Qt3DRender__QFrontFace, &sipType_Qt3DRender_QFrontFace, -1, 71},
        #if QT3DRENDER_VERSION >= 0x050a00
            {sipName_Qt3DRender__QLineWidth, &sipType_Qt3DRender_QLineWidth, -1, 72},
        #else
            {0, 0, -1, 72},
        #endif
            {sipName_Qt3DRender__QMultiSampleAntiAliasing, &sipType_Qt3DRender_QMultiSampleAntiAliasing, -1, 73},
            {sipName_Qt3DRender__QNoDepthMask, &sipType_Qt3DRender_QNoDepthMask, -1, 74},
            {sipName_Qt3DRender__QPointSize, &sipType_Qt3DRender_QPointSize, -1, 75},
            {sipName_Qt3DRender__QPolygonOffset, &sipType_Qt3DRender_QPolygonOffset, -1, 76},
        #if QT3DRENDER_VERSION >= 0x050e00
            {sipName_Qt3DRender__QRasterMode, &sipType_Qt3DRender_QRasterMode, -1, 77},
        #else
            {0, 0, -1, 77},
        #endif
            {sipName_Qt3DRender__QScissorTest, &sipType_Qt3DRender_QScissorTest, -1, 78},
            {sipName_Qt3DRender__QSeamlessCubemap, &sipType_Qt3DRender_QSeamlessCubemap, -1, 79},
            {sipName_Qt3DRender__QStencilMask, &sipType_Qt3DRender_QStencilMask, -1, 80},
            {sipName_Qt3DRender__QStencilOperation, &sipType_Qt3DRender_QStencilOperation, -1, 81},
            {sipName_Qt3DRender__QStencilTest, &sipType_Qt3DRender_QStencilTest, -1, -1},
        #if QT3DRENDER_VERSION >= 0x050a00
            {sipName_Qt3DRender__QBlitFramebuffer, &sipType_Qt3DRender_QBlitFramebuffer, -1, 83},
        #else
            {0, 0, -1, 83},
        #endif
            {sipName_Qt3DRender__QCameraSelector, &sipType_Qt3DRender_QCameraSelector, -1, 84},
            {sipName_Qt3DRender__QClearBuffers, &sipType_Qt3DRender_QClearBuffers, -1, 85},
            {sipName_Qt3DRender__QDispatchCompute, &sipType_Qt3DRender_QDispatchCompute, -1, 86},
            {sipName_Qt3DRender__QFrustumCulling, &sipType_Qt3DRender_QFrustumCulling, -1, 87},
            {sipName_Qt3DRender__QLayerFilter, &sipType_Qt3DRender_QLayerFilter, -1, 88},
        #if QT3DRENDER_VERSION >= 0x050900
            {sipName_Qt3DRender__QMemoryBarrier, &sipType_Qt3DRender_QMemoryBarrier, -1, 89},
        #else
            {0, 0, -1, 89},
        #endif
            {sipName_Qt3DRender__QNoDraw, &sipType_Qt3DRender_QNoDraw, -1, 90},
        #if QT3DRENDER_VERSION >= 0x050e00
            {sipName_Qt3DRender__QNoPicking, &sipType_Qt3DRender_QNoPicking, -1, 91},
        #else
            {0, 0, -1, 91},
        #endif
        #if QT3DRENDER_VERSION >= 0x050a00
            {sipName_Qt3DRender__QProximityFilter, &sipType_Qt3DRender_QProximityFilter, -1, 92},
        #else
            {0, 0, -1, 92},
        #endif
        #if QT3DRENDER_VERSION >= 0x050800
            {sipName_Qt3DRender__QRenderCapture, &sipType_Qt3DRender_QRenderCapture, -1, 93},
        #else
            {0, 0, -1, 93},
        #endif
            {sipName_Qt3DRender__QRenderPassFilter, &sipType_Qt3DRender_QRenderPassFilter, -1, 94},
            {sipName_Qt3DRender__QRenderStateSet, &sipType_Qt3DRender_QRenderStateSet, -1, 95},
            {sipName_Qt3DRender__QRenderSurfaceSelector, &sipType_Qt3DRender_QRenderSurfaceSelector, -1, 96},
            {sipName_Qt3DRender__QRenderTargetSelector, &sipType_Qt3DRender_QRenderTargetSelector, -1, 97},
        #if QT3DRENDER_VERSION >= 0x050d00
            {sipName_Qt3DRender__QSetFence, &sipType_Qt3DRender_QSetFence, -1, 98},
        #else
            {0, 0, -1, 98},
        #endif
            {sipName_Qt3DRender__QSortPolicy, &sipType_Qt3DRender_QSortPolicy, -1, 99},
        #if QT3DRENDER_VERSION >= 0x050e00
            {sipName_Qt3DRender__QSubtreeEnabler, &sipType_Qt3DRender_QSubtreeEnabler, -1, 100},
        #else
            {0, 0, -1, 100},
        #endif
            {sipName_Qt3DRender__QTechniqueFilter, &sipType_Qt3DRender_QTechniqueFilter, -1, 101},
            {sipName_Qt3DRender__QViewport, &sipType_Qt3DRender_QViewport, -1, 102},
        #if QT3DRENDER_VERSION >= 0x050d00
            {sipName_Qt3DRender__QWaitFence, &sipType_Qt3DRender_QWaitFence, -1, -1},
        #else
            {0, 0, -1, -1},
        #endif
            {sipName_Qt3DRender__QMesh, &sipType_Qt3DRender_QMesh, -1, -1},
        #if QT3DRENDER_VERSION >= 0x050900
            {sipName_Qt3DRender__QLevelOfDetailSwitch, &sipType_Qt3DRender_QLevelOfDetailSwitch, -1, -1},
        #else
            {0, 0, -1, -1},
        #endif
        #if QT3DRENDER_VERSION >= 0x050a00
            {sipName_Qt3DRender__QPickLineEvent, &sipType_Qt3DRender_QPickLineEvent, -1, 106},
        #else
            {0, 0, -1, 106},
        #endif
        #if QT3DRENDER_VERSION >= 0x050a00
            {sipName_Qt3DRender__QPickPointEvent, &sipType_Qt3DRender_QPickPointEvent, -1, 107},
        #else
            {0, 0, -1, 107},
        #endif
            {sipName_Qt3DRender__QPickTriangleEvent, &sipType_Qt3DRender_QPickTriangleEvent, -1, -1},
        };
        
        int i = 0;
        
        sipType = NULL;
        
        do
        {
            struct class_graph *cg = &graph[i];
        
            if (cg->name != NULL && sipCpp->inherits(cg->name))
            {
                sipType = *cg->type;
                i = cg->yes;
            }
            else
                i = cg->no;
        }
        while (i >= 0);
#line 15062 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRendercmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractLight__Type, SIP_NULLPTR, 0}, sipNameNr_Type, 22, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractRayCaster__FilterMode, SIP_NULLPTR, 0}, sipNameNr_FilterMode, 24, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractRayCaster__RunMode, SIP_NULLPTR, 0}, sipNameNr_RunMode, 24, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractTexture__ComparisonFunction, SIP_NULLPTR, 0}, sipNameNr_ComparisonFunction, 27, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractTexture__ComparisonMode, SIP_NULLPTR, 0}, sipNameNr_ComparisonMode, 27, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractTexture__CubeMapFace, SIP_NULLPTR, 0}, sipNameNr_CubeMapFace, 27, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractTexture__Filter, SIP_NULLPTR, 0}, sipNameNr_Filter, 27, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractTexture__HandleType, SIP_NULLPTR, 0}, sipNameNr_HandleType, 27, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractTexture__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 27, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractTexture__Target, SIP_NULLPTR, 0}, sipNameNr_Target, 27, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAbstractTexture__TextureFormat, SIP_NULLPTR, 0}, sipNameNr_TextureFormat, 27, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAlphaTest__AlphaFunction, SIP_NULLPTR, 0}, sipNameNr_AlphaFunction, 38, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAttribute__AttributeType, SIP_NULLPTR, 0}, sipNameNr_AttributeType, 40, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QAttribute__VertexBaseType, SIP_NULLPTR, 0}, sipNameNr_VertexBaseType, 40, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QBlendEquation__BlendFunction, SIP_NULLPTR, 0}, sipNameNr_BlendFunction, 43, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QBlendEquationArguments__Blending, SIP_NULLPTR, 0}, sipNameNr_Blending, 45, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QBlitFramebuffer__InterpolationMethod, SIP_NULLPTR, 0}, sipNameNr_InterpolationMethod, 47, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QBuffer__AccessType, SIP_NULLPTR, 0}, sipNameNr_AccessType, 49, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QBuffer__BufferType, SIP_NULLPTR, 0}, sipNameNr_BufferType, 49, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QBuffer__UsageType, SIP_NULLPTR, 0}, sipNameNr_UsageType, 49, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QCamera__CameraTranslationOption, SIP_NULLPTR, 0}, sipNameNr_CameraTranslationOption, 54, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QCameraLens__ProjectionType, SIP_NULLPTR, 0}, sipNameNr_ProjectionType, 56, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QClearBuffers__BufferType, SIP_NULLPTR, 0}, sipNameNr_BufferType, 59, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QComputeCommand__RunType, SIP_NULLPTR, 0}, sipNameNr_RunType, 64, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QCullFace__CullingMode, SIP_NULLPTR, 0}, sipNameNr_CullingMode, 66, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QDepthTest__DepthFunction, SIP_NULLPTR, 0}, sipNameNr_DepthFunction, 69, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QFrontFace__WindingDirection, SIP_NULLPTR, 0}, sipNameNr_WindingDirection, 78, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QGeometryRenderer__PrimitiveType, SIP_NULLPTR, 0}, sipNameNr_PrimitiveType, 83, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QGraphicsApiFilter__Api, SIP_NULLPTR, 0}, sipNameNr_Api, 85, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QGraphicsApiFilter__OpenGLProfile, SIP_NULLPTR, 0}, sipNameNr_OpenGLProfile, 85, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QLayerFilter__FilterMode, SIP_NULLPTR, 0}, sipNameNr_FilterMode, 89, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QLevelOfDetail__ThresholdType, SIP_NULLPTR, 0}, sipNameNr_ThresholdType, 91, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QMemoryBarrier__Operation, SIP_NULLPTR, 0}, sipNameNr_Operation, 97, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QMesh__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 100, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QPickEvent__Buttons, SIP_NULLPTR, 0}, sipNameNr_Buttons, 109, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QPickEvent__Modifiers, SIP_NULLPTR, 0}, sipNameNr_Modifiers, 109, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QPickingSettings__FaceOrientationPickingMode, SIP_NULLPTR, 0}, sipNameNr_FaceOrientationPickingMode, 115, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QPickingSettings__PickMethod, SIP_NULLPTR, 0}, sipNameNr_PickMethod, 115, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QPickingSettings__PickResultMode, SIP_NULLPTR, 0}, sipNameNr_PickResultMode, 115, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QPointSize__SizeMode, SIP_NULLPTR, 0}, sipNameNr_SizeMode, 120, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QRasterMode__FaceMode, SIP_NULLPTR, 0}, sipNameNr_FaceMode, 124, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QRasterMode__RasterMode, SIP_NULLPTR, 0}, sipNameNr_RasterMode, 124, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QRayCasterHit__HitType, SIP_NULLPTR, 0}, sipNameNr_HitType, 128, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QRenderAspect__RenderType, SIP_NULLPTR, 0}, sipNameNr_RenderType, 130, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QRenderCapabilities__API, SIP_NULLPTR, 0}, sipNameNr_API, 132, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QRenderCapabilities__Profile, SIP_NULLPTR, 0}, sipNameNr_Profile, 132, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QRenderSettings__RenderPolicy, SIP_NULLPTR, 0}, sipNameNr_RenderPolicy, 139, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QRenderTargetOutput__AttachmentPoint, SIP_NULLPTR, 0}, sipNameNr_AttachmentPoint, 145, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QSceneLoader__ComponentType, SIP_NULLPTR, 0}, sipNameNr_ComponentType, 148, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QSceneLoader__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 148, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QSetFence__HandleType, SIP_NULLPTR, 0}, sipNameNr_HandleType, 154, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QShaderImage__Access, SIP_NULLPTR, 0}, sipNameNr_Access, 157, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QShaderImage__ImageFormat, SIP_NULLPTR, 0}, sipNameNr_ImageFormat, 157, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QShaderProgram__Format, SIP_NULLPTR, 0}, sipNameNr_Format, 160, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QShaderProgram__ShaderType, SIP_NULLPTR, 0}, sipNameNr_ShaderType, 160, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QShaderProgram__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 160, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QSortPolicy__SortType, SIP_NULLPTR, 0}, sipNameNr_SortType, 166, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QStencilOperationArguments__FaceMode, SIP_NULLPTR, 0}, sipNameNr_FaceMode, 171, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QStencilOperationArguments__Operation, SIP_NULLPTR, 0}, sipNameNr_Operation, 171, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QStencilTestArguments__StencilFaceMode, SIP_NULLPTR, 0}, sipNameNr_StencilFaceMode, 175, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QStencilTestArguments__StencilFunction, SIP_NULLPTR, 0}, sipNameNr_StencilFunction, 175, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QSubtreeEnabler__Enablement, SIP_NULLPTR, 0}, sipNameNr_Enablement, 178, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QTextureImage__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 195, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QTextureWrapMode__WrapMode, SIP_NULLPTR, 0}, sipNameNr_WrapMode, 201, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DRender__QWaitFence__HandleType, SIP_NULLPTR, 0}, sipNameNr_HandleType, 204, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_Qt3DRender[] = {
    &sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_PropertyReaderInterface.mtd_base,
    &sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QBufferDataGenerator.mtd_base,
    &sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QGeometryFactory.mtd_base,
    &sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QTextureData.mtd_base,
    &sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QTextureGenerator.mtd_base,
    &sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QTextureImageData.mtd_base,
    &sipTypeDef_Qt3DRender_QSharedPointer_0100Qt3DRender_QTextureImageDataGenerator.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QAbstractTextureImage.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QAttribute.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QFilterKey.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QLayer.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QParameter.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0100Qt3DRender_QRayCasterHit.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QRenderPass.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QRenderState.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QRenderTargetOutput.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0100Qt3DRender_QRenderTargetOutput_AttachmentPoint.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0100Qt3DRender_QSortPolicy_SortType.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0101Qt3DRender_QTechnique.mtd_base,
    &sipTypeDef_Qt3DRender_QVector_0100Qt3DRender_QTextureImageDataPtr.mtd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_PropertyReaderInterface.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QAbstractFunctor.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QAbstractLight.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QAbstractRayCaster.ctd_base,
    &enumTypes[1].etd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QAbstractTexture.ctd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &enumTypes[7].etd_base,
    &enumTypes[8].etd_base,
    &enumTypes[9].etd_base,
    &enumTypes[10].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QAbstractTextureImage.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QAlphaCoverage.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QAlphaTest.ctd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QAttribute.ctd_base,
    &enumTypes[12].etd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QBlendEquation.ctd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QBlendEquationArguments.ctd_base,
    &enumTypes[15].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QBlitFramebuffer.ctd_base,
    &enumTypes[16].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QBuffer.ctd_base,
    &enumTypes[17].etd_base,
    &enumTypes[18].etd_base,
    &enumTypes[19].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QBufferDataGenerator.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QCamera.ctd_base,
    &enumTypes[20].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QCameraLens.ctd_base,
    &enumTypes[21].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QCameraSelector.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QClearBuffers.ctd_base,
    &enumTypes[22].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QClearBuffers_BufferTypeFlags.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QClipPlane.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QColorMask.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QComputeCommand.ctd_base,
    &enumTypes[23].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QCullFace.ctd_base,
    &enumTypes[24].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QDepthRange.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QDepthTest.ctd_base,
    &enumTypes[25].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QDirectionalLight.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QDispatchCompute.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QDithering.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QEffect.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QEnvironmentLight.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QFilterKey.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QFrameGraphNode.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QFrontFace.ctd_base,
    &enumTypes[26].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QFrustumCulling.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QGeometry.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QGeometryFactory.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QGeometryRenderer.ctd_base,
    &enumTypes[27].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QGraphicsApiFilter.ctd_base,
    &enumTypes[28].etd_base,
    &enumTypes[29].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QLayer.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QLayerFilter.ctd_base,
    &enumTypes[30].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QLevelOfDetail.ctd_base,
    &enumTypes[31].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QLevelOfDetailBoundingSphere.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QLevelOfDetailSwitch.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QLineWidth.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QMaterial.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QMemoryBarrier.ctd_base,
    &enumTypes[32].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QMemoryBarrier_Operations.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QMesh.ctd_base,
    &enumTypes[33].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QMultiSampleAntiAliasing.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QNoDepthMask.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QNoDraw.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QNoPicking.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QObjectPicker.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPaintedTextureImage.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QParameter.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPickEvent.ctd_base,
    &enumTypes[34].etd_base,
    &enumTypes[35].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPickLineEvent.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPickPointEvent.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPickTriangleEvent.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPickingSettings.ctd_base,
    &enumTypes[36].etd_base,
    &enumTypes[37].etd_base,
    &enumTypes[38].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPointLight.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPointSize.ctd_base,
    &enumTypes[39].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QPolygonOffset.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QProximityFilter.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRasterMode.ctd_base,
    &enumTypes[40].etd_base,
    &enumTypes[41].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRayCaster.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRayCasterHit.ctd_base,
    &enumTypes[42].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderAspect.ctd_base,
    &enumTypes[43].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderCapabilities.ctd_base,
    &enumTypes[44].etd_base,
    &enumTypes[45].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderCapture.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderCaptureReply.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderPass.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderPassFilter.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderSettings.ctd_base,
    &enumTypes[46].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderState.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderStateSet.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderSurfaceSelector.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderTarget.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderTargetOutput.ctd_base,
    &enumTypes[47].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QRenderTargetSelector.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QSceneLoader.ctd_base,
    &enumTypes[48].etd_base,
    &enumTypes[49].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QScissorTest.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QScreenRayCaster.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QSeamlessCubemap.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QSetFence.ctd_base,
    &enumTypes[50].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QShaderData.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QShaderImage.ctd_base,
    &enumTypes[51].etd_base,
    &enumTypes[52].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QShaderProgram.ctd_base,
    &enumTypes[53].etd_base,
    &enumTypes[54].etd_base,
    &enumTypes[55].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QShaderProgramBuilder.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QSharedGLTexture.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QSortPolicy.ctd_base,
    &enumTypes[56].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QSpotLight.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QStencilMask.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QStencilOperation.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QStencilOperationArguments.ctd_base,
    &enumTypes[57].etd_base,
    &enumTypes[58].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QStencilTest.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QStencilTestArguments.ctd_base,
    &enumTypes[59].etd_base,
    &enumTypes[60].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QSubtreeEnabler.ctd_base,
    &enumTypes[61].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTechnique.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTechniqueFilter.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTexture1D.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTexture1DArray.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTexture2D.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTexture2DArray.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTexture2DMultisample.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTexture2DMultisampleArray.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTexture3D.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureBuffer.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureCubeMap.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureCubeMapArray.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureData.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureDataUpdate.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureGenerator.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureImage.ctd_base,
    &enumTypes[62].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureImageData.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureImageDataGenerator.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureLoader.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureRectangle.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QTextureWrapMode.ctd_base,
    &enumTypes[63].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QViewport.ctd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_QWaitFence.ctd_base,
    &enumTypes[64].etd_base,
    &sipTypeDef_Qt3DRender_Qt3DRender_Render.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"Qt3DRender::PropertyReaderInterfacePtr", "QSharedPointer<Qt3DRender::PropertyReaderInterface>"},
    {"Qt3DRender::QAbstractRayCaster::Hits", "QVector<Qt3DRender::QRayCasterHit>"},
    {"Qt3DRender::QBufferDataGeneratorPtr", "QSharedPointer<Qt3DRender::QBufferDataGenerator>"},
    {"Qt3DRender::QGeometryFactoryPtr", "QSharedPointer<Qt3DRender::QGeometryFactory>"},
    {"Qt3DRender::QTextureDataPtr", "QSharedPointer<Qt3DRender::QTextureData>"},
    {"Qt3DRender::QTextureGeneratorPtr", "QSharedPointer<Qt3DRender::QTextureGenerator>"},
    {"Qt3DRender::QTextureImageDataGeneratorPtr", "QSharedPointer<Qt3DRender::QTextureImageDataGenerator>"},
    {"Qt3DRender::QTextureImageDataPtr", "QSharedPointer<Qt3DRender::QTextureImageData>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_Qt3DRender_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPoint"},
    {"QPointF"},
    {"QRect"},
    {"QRectF"},
    {"QSize"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"QVector<int>"},
    {"qintptr"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DRender_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_Qt3DRender_QtGui[] = {
    {"QColor"},
    {"QImage"},
    {"QMatrix4x4"},
    {"QOpenGLTexture::PixelFormat"},
    {"QOpenGLTexture::PixelType"},
    {"QOpenGLTexture::Target"},
    {"QOpenGLTexture::TextureFormat"},
    {"QPainter"},
    {"QQuaternion"},
    {"QVector3D"},
    {"QVector<qreal>"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from Qt3DCore. */
sipImportedTypeDef sipImportedTypes_Qt3DRender_Qt3DCore[] = {
    {"QSharedPointer<Qt3DCore::QSceneChange>"},
    {"Qt3DCore::QAbstractAspect"},
    {"Qt3DCore::QComponent"},
    {"Qt3DCore::QEntity"},
    {"Qt3DCore::QNode"},
    {"Qt3DCore::QNodeId"},
    {"Qt3DCore::QTransform"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_Qt3DRender_QtCore, sipImportedVirtErrorHandlers_Qt3DRender_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_Qt3DRender_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.Qt3DCore", sipImportedTypes_Qt3DRender_Qt3DCore, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_Qt3DRender_QCamera, {4, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_Qt3DRender = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_Qt3DRender,
    0,
    sipStrings_Qt3DRender,
    importsTable,
    SIP_NULLPTR,
    207,
    sipExportedTypes_Qt3DRender,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    8,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_Qt3DRender;

sip_qt_metaobject_func sip_Qt3DRender_qt_metaobject;
sip_qt_metacall_func sip_Qt3DRender_qt_metacall;
sip_qt_metacast_func sip_Qt3DRender_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_Qt3DRender()
#else
PyMODINIT_FUNC PyInit_Qt3DRender()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.Qt3DRender",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_Qt3DRender = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_Qt3DRender == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_Qt3DRender, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_Qt3DRender_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_Qt3DRender_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_Qt3DRender_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_Qt3DRender_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_Qt3DRender, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
